## Author : Piyal Roy
## Email  : piyalroy00@gmail.com

from difflib import get_close_matches
import re

dictPos = {
'-':'SYM','.':'SYM','ঁ':'SYM','ং':'SYM','অ-কার্বনিক':'JJ','অ-বংশানুক্রমিক':'JJ','অ-ভূমিজ':'JJ',
'অ-ভৌম':'JJ','অ-সীমিত':'JJ','অ':'NN','অঁরি':'NNP','অংক':'NN','অংকার':'NN','অংকে':'NNS',
'অংকের':'NN','অংগ':'NN','অংগীকার':'NN','অংটী':'NN','অংশ':'NN','অংশকালিক':'JJ','অংশগ্রহণ':'VB',
'অংশগ্রহণকারী':'NN','অংশগ্রহন':'VB','অংশটুকু':'NN','অংশদান':'NN','অংশদেশের':'NN','অংশধারী':'NN','অংশসমূহ':'NN',
'অংশিদারী':'NN','অংশীদারি':'NN','অংশীদারের':'NN','অংশু':'NN','অংশুমন্ত':'NN','অংশে':'NN','অই':'DT',
'অইসব':'NN','অঋণী':'JJ','অওকাদ':'NN','অকংগ্রেসি':'JJ','অকটোবরে':'NNP','অকথ্য':'JJ','অকপট':'NN',
'অকম্পন':'NN','অকম্পিত':'JJ','অকরকরা':'NN','অকরণীয়':'JJ','অকর্তিত':'JJ','অকর্মক':'NN','অকর্মঠ':'JJ',
'অকর্মণ্য':'NN','অকর্মা':'NN','অকলঙ্ক':'JJ','অকল্পনীয়':'JJ','অকল্পিত':'JJ','অকল্যাণকামী':'JJ','অকল্যানই':'NN',
'অকস্মাত্':'RB','অকাট':'JJ','অকাতরে':'RB','অকাদেমীর':'NNP','অকারণ':'RB','অকারণে':'NN','অকারন':'NN',
'অকারান্ত':'JJ','অকার্য':'NN','অকার্যকর':'JJ','অকাল':'NN','অকালি':'NN','অকাল্পনিক':'JJ','অকিঞ্চন':'JJ',
'অকিঞ্চিত্কর':'JJ','অকীর্তি':'NN','অকুটিল':'JJ','অকুটিলতা':'NN','অকুপেশনাল':'JJ','অকুলিন':'NN','অকুশলতা':'NN',
'অকুস্থল':'NN','অকূল':'JJ','অকৃত':'JJ','অকৃতকার্য':'JJ','অকৃতজ্ঞ':'JJ','অকৃতজ্ঞতা':'NN','অকৃতদার':'NN',
'অকৃত্তিম':'VB','অকৃত্য':'NN','অকৃত্যকারী':'JJ','অকৃত্রিম':'JJ','অকৃত্রিমতা':'NN','অকৃপা':'NN','অকৃষ্ট':'JJ',
'অকেজো':'NN','অকোলা':'NN','অক্কলকোট':'NN','অক্টোপাস':'NN','অক্টোবর':'NN','অক্টোবরে':'NNP','অক্মোলা':'NN',
'অক্রূর':'NNP','অক্রোধ':'NN','অক্রোধী':'JJ','অক্লান্ত':'JJ','অক্লান্তভাবে':'RB','অক্লান্তিক':'JJ','অক্লেশ':'RB',
'অক্ষ':'NN','অক্ষদণ্ড':'NN','অক্ষধুর':'NN','অক্ষম':'NN','অক্ষমতার':'NN','অক্ষমালিক':'NN','অক্ষম্য':'JJ',
'অক্ষর-বিন্যাস':'NN','অক্ষর':'NN','অক্ষরন্যাস':'NN','অক্ষরপঙ্কতি':'NN','অক্ষরমালা':'NN','অক্ষরে':'NN','অক্ষরেখা':'JJ',
'অক্ষরের':'NN','অক্ষাংশ':'NN','অক্ষাগ্র':'NN','অক্ষি':'NN','অক্ষিতারা':'NN','অক্ষিপক্ষ':'NN','অক্ষীয়':'JJ',
'অক্ষুণ্ণ':'JJ','অক্ষুমুখ':'NN','অক্ষের':'NN','অক্ষোভ':'NN','অক্ষৌহিণী':'NN','অক্ষয়-তৃতীয়া':'NN','অক্ষয়':'JJ',
'অক্ষয়কুমার':'NN','অক্ষয়তৃতীয়া':'NN','অক্ষয়নবমী':'NN','অক্সফর্ড':'NN','অক্সাইড':'NN','অক্সিজেন':'NN',
'অক্সিলারি':'JJ','অখচ':'NN','অখণ্ডনীয়':'JJ','অখণ্ডিত':'JJ','অখন্ডতা':'NN','অখন্ডিত':'JJ','অখাত':'NN',
'অখাদ্য':'NN','অখানি':'NN','অখিল':'NN','অখিলবন্ধু':'NNP','অখুশী':'RB','অখেলোয়াড়':'NNS','অখৈনি':'NN',
'অখ্তাবর':'NN','অখ্যাত':'JJ','অখ্যাতি':'NN','অগঠিত':'JJ','অগড়':'NN','অগণিত':'JJ','অগণ্য':'JJ',
'অগতি':'NN','অগত্যা':'NN','অগদতন্ত্র':'NN','অগন':'NN','অগনতান্ত্রিক':'JJ','অগনিত':'NN','অগভীর':'JJ',
'অগম্য':'JJ','অগম্যতা':'NN','অগরু':'NN','অগর্বিত':'JJ','অগষ্ট':'NNP','অগস্ত্য':'NN','অগস্ত্যগীতা':'NN',
'অগাধ':'NN','অগাবে':'NN','অগাস্ট':'NNP','অগিন':'NN','অগিয়া':'NN','অগুঢ়':'JJ','অগুনতি':'JJ',
'অগুপ্ত':'JJ','অগুরুত্বপূর্ণ':'NN','অগৃহীত':'JJ','অগের':'JJ','অগোচর':'JJ','অগোছালো':'NN','অগোপন':'JJ',
'অগৌরবজনক':'NN','অগ্নায়ী':'NN','অগ্নি-কুণ্ড':'NN','অগ্নি-পরীক্ষা':'NN','অগ্নি':'NN','অগ্নিকাণ্ড':'NN','অগ্নিকার্য':'NN',
'অগ্নিকুণ্ড':'NN','অগ্নিক্রিয়া':'NN','অগ্নিগর্ভ':'JJ','অগ্নিদেব':'NN','অগ্নিনাশক-যন্ত্র':'NN','অগ্নিনির্বপক':'NN','অগ্নিনির্বাপক':'JJ',
'অগ্নিপরীক্ষা':'NN','অগ্নিপাবক':'NN','অগ্নিপূজক':'NN','অগ্নিপ্রভায়':'NN','অগ্নিবর্ণ':'NN','অগ্নিবর্ধক':'JJ','অগ্নিবাণ':'NN',
'অগ্নিমান্দ্য':'NN','অগ্নিমুখ':'NN','অগ্নিশর্মা':'VB','অগ্নিশিখা':'NN','অগ্নিষ্টোম':'NN','অগ্নিসংস্কার':'NN','অগ্নিস্থ':'JJ',
'অগ্নুত্পাত':'NN','অগ্ন্যাশয়':'NN','অগ্যস্ত':'NN','অগ্র':'NN','অগ্রগণ্য':'JJ','অগ্রগতি':'NN','অগ্রগতির':'NN',
'অগ্রগন্ধা':'NN','অগ্রগামী':'NN','অগ্রজ':'NN','অগ্রণী':'NN','অগ্রদূত':'NN','অগ্রপদকে':'NN','অগ্রবর্তী':'JJ',
'অগ্রভাগ':'NN','অগ্রযাত্রা':'NN','অগ্রসর':'JJ','অগ্রসারিত':'NN','অগ্রসেন':'NNP','অগ্রহণীয়':'JJ','অগ্রহস্ত':'NN',
'অগ্রহায়ণের':'JJ','অগ্রা':'NN','অগ্রাধিকার':'NN','অগ্রাশন':'NN','অগ্রাহ্য':'NN','অগ্রায়ুধ':'NN','অগ্রিম':'NN',
'অগ্রে':'NN','অগ্ৰ্যাধিকার':'NN','অঘটন':'NN','অঘটনীয়':'JJ','অঘটিত':'JJ','অঘমর্ষণ':'NN','অঘারি':'JJ',
'অঘাসুর':'NN','অঘোর':'NN','অঘোরপন্থা':'NN','অঘোরা':'NN','অঘোষ':'JJ','অঘ্রাণী':'NN','অঙ্ক':'NN',
'অঙ্কটা':'NN','অঙ্কদেশ':'NN','অঙ্কন':'NN','অঙ্কনীয়':'JJ','অঙ্কবিশিষ্ট':'JJ','অঙ্কশাস্ত্রে':'NN','অঙ্কশায়ী':'JJ',
'অঙ্কিত':'NN','অঙ্কুর':'NN','অঙ্কুরোদ্গম':'VB','অঙ্কুশ':'NN','অঙ্কেই':'NN','অঙ্গ-প্রত্যঙ্গ':'NN','অঙ্গ-ভঙ্গী':'NN',
'অঙ্গ':'NN','অঙ্গচ্ছেদ':'NN','অঙ্গচ্ছেদন':'NN','অঙ্গজ-জনন':'NN','অঙ্গদ':'NN','অঙ্গনে':'NN','অঙ্গন্যাস':'NN',
'অঙ্গবাচক':'NN','অঙ্গবিকার':'NN','অঙ্গভঙ্গ':'NN','অঙ্গভঙ্গি':'NNS','অঙ্গভঙ্গী':'NN','অঙ্গভার':'NN','অঙ্গরক্ষক':'NN',
'অঙ্গরাজ্য':'NN','অঙ্গরোম':'NN','অঙ্গহীন':'JJ','অঙ্গহীনতা':'NN','অঙ্গাতক':'NN','অঙ্গারক':'NN','অঙ্গিকার':'NN',
'অঙ্গিরা':'NN','অঙ্গী':'NN','অঙ্গীকার':'VB','অঙ্গীকারও':'NN','অঙ্গীকৃত':'JJ','অঙ্গীবাচক':'NN','অঙ্গীভূত':'NN',
'অঙ্গুলী':'NN','অঙ্গে':'NNS','অঙ্গোলা':'NN','অচঞ্চল':'JJ','অচপল':'JJ','অচপলতা':'NN','অচর':'JJ',
'অচল':'NN','অচলকন্যা':'NN','অচলা':'NN','অচলাবস্থা':'NN','অচিত্রিত':'JJ','অচিন্তন':'NN','অচিন্তনীয়':'JJ',
'অচিরপ্রভা':'NN','অচিরাংশু':'NN','অচিরেই':'RB','অচিহ্নিত':'JJ','অচেতন':'NN','অচৈতন্য':'NN','অচৌর্য':'NN',
'অচ্ছদ্ম':'NN','অচ্ছল':'NN','অচ্ছুত্':'NN','অচ্যুতাগ্রজ':'NN','অচয়নিত':'JJ','অছবানি':'NN','অছাত্র':'VBN',
'অছাত্ররা':'NNS','অছি':'NN','অছেদ্য':'JJ','অজ':'NN','অজকর্ণ':'NN','অজগন্ধা':'NN','অজগর':'NN',
'অজগরের':'NN','অজদন্তী':'NN','অজনন':'NN','অজনপ্রিয়':'JJ','অজন্তা':'NN','অজন্মগত':'JJ','অজন্মা':'NN',
'অজপতি':'NN','অজপা':'NN','অজবহ':'JJ','অজয়':'NN','অজর':'JJ','অজস্র':'NN','অজাত':'NN',
'অজাতরজস্কা':'JJ','অজাতশত্রু':'NN','অজাতি':'JJ','অজানা-অচেনা':'JJ','অজানা':'NN','অজান্তে':'RB','অজামিল':'NN',
'অজামুখ':'NN','অজাসুর':'NN','অজিজ্ঞাসু':'JJ','অজিত':'NN','অজিদের':'NN','অজির':'NN','অজিল':'NN',
'অজীর্ণ':'NN','অজীর্ণরোগগ্রস্ত':'JJ','অজীর্ণী':'JJ','অজুজা':'NN','অজুত':'NN','অজুহাতই':'NN','অজুহাতগুলোই':'NNS',
'অজুহাতবাজ':'NN','অজুহাত‌ের':'NNS','অজেয়':'JJ','অজৈব':'JJ','অজৈব্য':'NN','অজ্ঞ':'JJ','অজ্ঞতা':'NN',
'অজ্ঞতার':'NN','অজ্ঞলের':'NN','অজ্ঞাত':'NN','অজ্ঞান':'NN','অজ্ঞানতাপূর্ণ':'JJ','অজ্ঞানেই':'NN','অজ্ঞাবাদী':'NN',
'অজ্ঞেয়':'JJ','অজ্ঞেয়বাদ':'NN','অজ্ঞেয়বাদী':'JJ','অঝর':'JJ','অঝোরে':'JJ','অঞ্চল':'NN','অঞ্চলে':'NN',
'অঞ্জন':'NN','অঞ্জনযুক্ত':'JJ','অঞ্জনরহিত':'JJ','অঞ্জনহারি':'NN','অঞ্জনা':'NNP','অঞ্জনিত':'JJ','অঞ্জনী':'NN',
'অঞ্জলি':'NN','অঞ্জলিবদ্ধ':'JJ','অঞ্জলির':'NNP','অঞ্জা':'NN','অঞ্জু':'NN','অটবী':'NN','অটল':'NN',
'অটিজম':'NNP','অটিজমের':'NNP','অটিস্টক':'NNP','অটুট':'JJ','অটো':'NN','অটোমেটিক':'JJ','অটোমেটিক্যালি':'RB',
'অটোমেটেড':'NN','অটোমোবাইল':'NN','অটোমোবাইলসের':'NNS','অটোমোবিল':'NN','অটোরিকশা':'NNP','অট্টম':'NNS','অট্টহাসি':'NN',
'অট্টালিকাময়':'JJ','অড়হর':'NN','অডানা':'NN','অডার':'NN','অডিও':'NN','অডিটর':'NN','অঢেল':'JJ',
'অণিমা':'NN','অণু':'NN','অণুপ্রভা':'NN','অণ্ডকোষ':'NN','অণ্ডকোষযুক্ত':'JJ','অণ্ডগ্রন্থি':'NN','অণ্ডজ':'JJ',
'অণ্ডবৃদ্ধি':'NN','অণ্ডী':'NN','অত':'RB','অতঃপর':'RB','অতই':'NN','অতএব':'RB','অতচ':'CC',
'অতটা':'NN','অতর্কিত':'JJ','অতল':'NN','অতলস্পর্শীতা':'NN','অতশত':'NNS','অতসব':'NN','অতাপস':'JJ',
'অতি':'RB','অতিকথন':'NN','অতিকায়':'NN','অতিকৃচ্ছ':'NN','অতিক্রম':'VB','অতিক্রমকারী':'JJ','অতিক্রমণ':'NN',
'অতিক্রমযোগ্য':'JJ','অতিক্রমী':'JJ','অতিক্রান্ত':'JJ','অতিচার':'NN','অতিতেও':'NN','অতিথি-গৃহ':'NN','অতিথি-ভবন':'NN',
'অতিথি-শালা':'NN','অতিথি-সত্কার':'NN','অতিথি':'NN','অতিথিদের':'NN','অতিথিপরায়ণ':'JJ','অতিথীরা':'NNS','অতিথ্যকর্তা':'NN',
'অতিদরিদ্র্যদের':'NN','অতিদূরাত্':'RP','অতিদ্রুত':'NN','অতিধনীদের':'NN','অতিনম্র':'JJ','অতিনাভ':'NN','অতিপক্ক':'JJ',
'অতিপাণ্ডুকম্বলা':'NN','অতিপাতক':'NN','অতিপ্রবাহ':'NN','অতিবর্ষণ':'NN','অতিবাহিত':'VBN','অতিবিলাস':'NN','অতিবীর':'NN',
'অতিবুদ্ধিমানদের':'NN','অতিবেগুণী':'NN','অতিব্যবহার':'NN','অতিব্যয়ী':'JJ','অতিভোজী':'NN','অতিমাত্রায়':'CD','অতিমাত্রায়':'RB',
'অতিমানব':'JJ','অতিরঞ্জন':'NN','অতিরিক্ত':'JJ','অতিশীগ্রই':'NN','অতিশয়':'NN','অতিশয়োক্তি':'NN','অতিষ্ঠ':'JJ',
'অতীত':'NN','অতীতকাল':'NN','অতীতে':'NN','অতীতের':'NN','অতীন্দ্রিয়':'NN','অতীব':'RB','অতুঙ্গ':'JJ',
'অতুল':'JJ','অতুলনীয়':'NN','অতুষ্টি':'NN','অতৃপ্ত':'JJ','অতৃপ্তি':'NN','অতেশয়োক্তি':'NN','অতো':'JJ',
'অত্তিঙ্গল':'NN','অত্যধিক':'JJ','অত্যন্ত':'RB','অত্যন্নোতি':'NN','অত্যম্লপর্ণী':'NN','অত্যল্প':'JJ','অত্যাচার':'VB',
'অত্যাচারই':'NN','অত্যাচারনির্যাতন':'NN','অত্যাচারনো':'VB','অত্যাচারমূলক':'JJ','অত্যাচারী':'NN','অত্যাচারের':'NN','অত্যাধিক':'NN',
'অত্যানন্দ':'NN','অত্যান্ত':'RB','অত্যাবশ্যক':'JJ','অত্যুক্তি':'NN','অত্যুজ্জ্বল':'JJ','অত্যুহ':'NN','অত্যোক্তি':'NN',
'অত্যোত্সাহী':'JJ','অত্রি':'NN','অত্রিপ্রিয়া':'NN','অত্রেয়':'NN','অত‌ি':'RB','অথচ':'CC','অথছ':'RP',
'অথবা':'CC','অথর্ই':'VBG','অথর্নীতির':'NN','অথর্ব-শির':'NN','অথর্ব':'NN','অথর্বন':'NN','অথার্থ':'JJ',
'অথৈ':'NN','অথ্যলেটিক্স':'NN','অদক্ষ':'JJ','অদক্ষতা':'NN','অদণ্ডনীয়':'JJ','অদণ্ডিত':'JJ','অদত্ত':'JJ',
'অদত্তা':'NN','অদপতন':'NN','অদবান':'NN','অদমিত':'JJ','অদম্য':'JJ','অদরকারি':'NN','অদর্শন':'NN',
'অদর্শনীয়':'JJ','অদল-বদল':'NN','অদল':'NN','অদলবদল':'VB','অদলিত':'JJ','অদানী':'JJ','অদাহ্য':'JJ',
'অদিকার':'NNS','অদিতি':'NN','অদীক্ষিত':'JJ','অদূর':'NN','অদূরদর্শী':'JJ','অদূরে':'RB','অদৃঢ়':'JJ',
'অদৃশতা':'NN','অদৃশ্য':'DM','অদৃশ্যতা':'NN','অদৃষ্ট':'JJ','অদৃষ্টবাদ':'NN','অদৃষ্টিগোচর':'JJ','অদেখা':'NN',
'অদের':'NNS','অদেয়':'NN','অদ্বিত':'NN','অদ্বিতকে':'VB','অদ্বিতের':'NN','অদ্বুত':'JJ','অদ্বৈতবাদ':'NN',
'অদ্বৈতবাদী':'JJ','অদ্বয়তারক':'NN','অদ্ভুত-রস':'NN','অদ্ভুত':'JJ','অদ্ভুতরকম':'NN','অদ্ভুদ':'JJ','অদ্ভূত':'JJ',
'অদ্য':'NN','অদ্যাপি':'RB','অদ্রবণীয়':'JJ','অদ্রষ্টব্য':'JJ','অদ্রি-তনয়া':'NN','অদ্রি':'NN','অদ্রোহ':'NN',
'অদ্রোহী':'JJ','অধঃ':'RB','অধঃক্ষিপ্ত':'JJ','অধঃক্ষেপ':'NN','অধঃপতন':'NN','অধঃপতনকারী':'JJ','অধঃপতনেরই':'NN',
'অধঃপতিত':'NN','অধক্ষ্য':'NN','অধপতন':'NN','অধম':'NN','অধমতম':'JJ','অধমতা':'NN','অধমর্ণ':'NN',
'অধর-বিম্ব':'NN','অধর':'NN','অধরপান':'NN','অধরবিম্ব':'NN','অধরামধু':'NN','অধরোষ্ঠ':'NN','অধর্ম':'NN',
'অধশিক্কিত':'VBN','অধস্তন':'NN','অধাতু':'NN','অধাধারন':'NN','অধারাবাহিক':'JJ','অধার্মিক':'JJ','অধার্মিকতা':'NN',
'অধি-দিন':'NN','অধি':'NN','অধিআকংশ':'CD','অধিক-অঙ্গ':'NN','অধিক':'RBR','অধিককোণ':'NN','অধিকতঃ':'RB',
'অধিকতম':'NN','অধিকতর':'RB','অধিকন্তু':'RP','অধিকভাবে':'RB','অধিকরণ-শুল্ক':'NN','অধিকরণ':'NN','অধিকরণশুল্ক':'NN',
'অধিকরণের':'NN','অধিকর্তা':'NN','অধিকর্তারা':'NN','অধিকর্মা':'NN','অধিকাংশ':'JJS','অধিকাংশত':'RB','অধিকাঙ্গ':'NN',
'অধিকাধিক':'JJ','অধিকার-পত্র':'NN','অধিকার':'NNS','অধিকারই':'RB','অধিকারও':'NNS','অধিকারচ্যূত':'JJ','অধিকারপত্র':'NN',
'অধিকারপরিপন্থী':'NN','অধিকারপূর্ণ':'JJ','অধিকারপূর্বক':'RB','অধিকারভুক্ত':'JJ','অধিকাররহিত':'NN','অধিকারশূণ্য':'JJ','অধিকারহীন':'JJ',
'অধিকারহীনতা':'NN','অধিকারি':'NN','অধিকারী':'NN','অধিকারীও':'VBN','অধিকারে':'DM','অধিকারের':'NN','অধিকৃত':'NN',
'অধিক্রম':'NN','অধিক্ষিপ্ত':'JJ','অধিগত':'JJ','অধিগম':'NN','অধিগুপ্ত':'JJ','অধিগৃহীত':'JJ','অধিগ্রহণ':'NN',
'অধিগ্রহন':'NN','অধিত্যকা':'NN','অধিত্যকার':'JJ','অধিদপ্তর':'NNP','অধিদপ্তরের':'NN','অধিদফতরগুলো':'NNS','অধিদিন':'NN',
'অধিদেবী':'NN','অধিনব':'NN','অধিনস্থ':'NN','অধিনায়ক':'NN','অধিনায়কের':'NN','অধিনিয়ম':'NN','অধিনে':'IN',
'অধিপতি':'NN','অধিপত্র':'NN','অধিপ্রাণবাদমূলক':'JJ','অধিবক্তা':'NN','অধিবর্ষ':'NN','অধিবাচক':'NN','অধিবাস':'NN',
'অধিবাসীকৃষক':'NN','অধিবাসীদের':'NN','অধিবিন্না':'NN','অধিবেত্তা':'NN','অধিবেদন':'NN','অধিবেশনে':'NN','অধিভার':'NN',
'অধিভৌতিক':'JJ','অধিমত':'NN','অধিমন্থ':'NN','অধিমাংস':'NN','অধিযজ্ঞ':'NN','অধিরথ':'NN','অধিরাজ্য':'NN',
'অধিরেশন':'NN','অধিরোহিণী':'NN','অধিশুল্ক':'NN','অধিশোষণ':'NN','অধিশ্রয়ণ':'NN','অধিষ্ঠাতা':'NN','অধিষ্ঠিত':'NN',
'অধিসূচনা':'NN','অধিস্থাপন':'NN','অধীক্ষক':'NN','অধীণস্থ':'NN','অধীত':'JJ','অধীন':'IN','অধীনতা':'NN',
'অধীনস্থ':'NN','অধীনস্হ':'VB','অধীনে':'IN','অধীবাসীরা':'NNS','অধীর':'NN','অধীশ':'NN','অধৃত':'JJ',
'অধৈর্য':'JJ','অধোগত':'JJ','অধোগতি':'NN','অধোগমন':'VB','অধোগামী':'JJ','অধোজানু':'NN','অধোদৃষ্টি':'NN',
'অধোদেশ':'NN','অধোবস্ত্র':'NN','অধোবাচক':'NN','অধোবিন্দু':'NN','অধোভাগ':'NN','অধোমুখ':'JJ','অধোমেণ্টাম':'NNP',
'অধোযন্ত্র':'NN','অধ্বর':'NN','অধ্যক্ষ':'NN','অধ্যক্ষের':'JJ','অধ্যদেশ':'NN','অধ্যবসায়':'NN','অধ্যবসায়ী':'JJ',
'অধ্যবসায়ের':'NN','অধ্যর্থন':'NN','অধ্যাত্মা':'NN','অধ্যাদেশ':'NN','অধ্যাপক':'NN','অধ্যাপকীয়':'JJ','অধ্যাপন':'NN',
'অধ্যাপনাকার্য':'NN','অধ্যাপিকা':'NN','অধ্যাপিত':'JJ','অধ্যাবসায়':'NN','অধ্যারোপিত':'JJ','অধ্যাসন':'NN','অধ্যায়ী':'JJ',
'অধ্যুষিত':'JJ','অধ্যয়ণ':'NN','অধ্যয়ন-কক্ষ':'NN','অধ্যয়ন':'VB','অধ্যয়নকক্ষ':'NN','অধ্যয়নপ্রিয়':'JJ','অধ্যয়নশীল':'NN',
'অধ্যয়নাবকাশ':'NN','অধ্রুব':'JJ','অন':'IN','অনওয়াঁসী':'NN','অনওয়াকাশিত':'NN','অনকের':'NN','অনগ্নতা':'NN',
'অনগ্রসর':'NNP','অনগ্রসরতা':'NN','অনঙ্গ-ক্রীড়া':'NN','অনঙ্গ':'NN','অনচ্ছ':'JJ','অনজু':'NN','অনটনের':'NN',
'অনত':'JJ','অনতঃসত্ত্বা':'NN','অনতিক্রম':'NN','অনতিক্রমণীয়':'JJ','অনতিক্রমিত':'JJ','অনতিক্রান্ত':'JJ','অনতিবাহিত':'JJ',
'অনদ্যতন-ভবিষ্যত':'NN','অনদ্যতন':'NN','অনধিক':'JJ','অনধিকার':'NN','অনধিগত':'JJ','অনধ্যক্ষ':'JJ','অনধ্যবসায়':'NN',
'অনধ্যয়ন':'NN','অননুকৃত':'JJ','অননুজ্ঞা':'NN','অননুভাষণ':'NN','অননুমতি':'NN','অননুরক্ত':'NN','অননুসরণযোগ্য':'JJ',
'অননেট':'NN','অননেটের':'NN','অনন্ত':'NN','অনন্তকে':'NN','অনন্তজ্ঞান':'NN','অনন্তটঙ্ক':'NN','অনন্ততা':'NN',
'অনন্তদর্শন':'NN','অনন্তদৃষ্টি':'NN','অনন্তদেব':'NN','অনন্তনাগ':'NN','অনন্তপার':'JJ','অনন্তপুর':'NN','অনন্তবিজয়':'NN',
'অনন্তবীর্য':'NN','অনন্তমূল':'NN','অনন্তরূপ':'JJ','অনন্তলোকীয়':'JJ','অনন্তশক্তি':'NN','অনন্তশীর্ষা':'NN','অনন্তানুবন্ধী':'NN',
'অনন্তাভিধেয়':'JJ','অনন্পূর্ণ':'NN','অনন্বয়':'NN','অনন্য':'JJ','অনন্যগতিক':'JJ','অনন্যতা':'NN','অনন্যদৃষ্টি':'JJ',
'অনন্যপূর্বা':'NN','অনন্যবৃত্তি':'JJ','অনন্যবড়':'NN','অনন্যভাব':'JJ','অনন্যা':'NN','অনন্যোপায়':'RB','অননয়ের':'NN',
'অনপকার':'NN','অনপকারী':'JJ','অনপনেয়':'JJ','অনপহৃত':'JJ','অনপায়া':'NN','অনবকাশ':'NN','অনবগাহী':'JJ',
'অনবদ্য':'JJ','অনবদ্যা':'NN','অনবদ‌্য':'JJ','অনবনত':'JJ','অনবরত':'RB','অনবরততা':'NN','অনবরুদ্ধ':'JJ',
'অনবলম্বন':'NN','অনবলম্বিত':'JJ','অনবসর':'NN','অনবসান':'JJ','অনবস্থা':'NN','অনবহেলিত':'JJ','অনবাকাঙ্ক্ষমান':'NN',
'অনভিজ্ঞ':'JJ','অনভিজ্ঞতা':'NN','অনভিলাষ':'NN','অনভিলাষী':'JJ','অনভিষ্ট':'JJ','অনভ্যস্ত':'JJ','অনভ্যাস':'NN',
'অনমনীয়':'JJ','অনমোদনের':'NN','অনরণ্য':'NN','অনরথক':'CC','অনরসা':'NN','অনর্কচতুর্দশী':'NN','অনর্গল':'RB',
'অনর্ঘ্য':'JJ','অনর্থ':'NN','অনর্থক':'JJ','অনর্থনাশী':'JJ','অনল':'NN','অনলঙ্কৃত':'JJ','অনলপ্রভা':'NN',
'অনলমুখী':'JJ','অনলা':'NN','অনলাইনে':'NN','অনলাইনের':'NN','অনশন':'NN','অনশনের':'IN','অনশ্ব':'JJ',
'অনসনও':'VBG','অনসূয়':'NN','অনস্তমিত':'JJ','অনস্বীকার্য':'JJ','অনাকর্ষক':'JJ','অনাকাঙ্ক্ষিত':'JJ','অনাকাঙ্থা':'NN',
'অনাক্রমণ':'NN','অনাক্রান্ত':'JJ','অনাক্রান্তা':'NN','অনাগত':'NN','অনাগতার্তবা':'JJ','অনাগমন':'NN','অনাগম্য':'JJ',
'অনাঘাত':'NN','অনাঙ্ক্ষা':'NN','অনাচার':'NN','অনাচারঅবিচারকে':'NN','অনাচারকেই':'NN','অনাচারিতা':'NN','অনাচারী':'JJ',
'অনাচারের':'NN','অনাচ্ছাদন':'NN','অনাজ্ঞাকারী':'JJ','অনাড়ম্বরতা':'NN','অনাড়ি':'NN','অনাতিজ্ঞ':'JJ','অনাত্মকদুঃখ':'NN',
'অনাত্মজ্ঞ':'JJ','অনাত্মীয়':'NN','অনাথ':'NN','অনাথাশ্রম':'NN','অনাদর':'VB','অনাদরেরও':'NN','অনাদায়ে':'NN',
'অনাদি':'JJ','অনাদৃত':'JJ','অনাধৃষ্টি':'NN','অনানুষ্ঠানিক':'JJ','অনাপত্তি':'NN','অনাপ্যায়িত':'JJ','অনাপ্লুত':'JJ',
'অনাবরণ':'NN','অনাবর্তী':'JJ','অনাবশ্যক':'RB','অনাবশ্যকতা':'NN','অনাবশ্যকভাবে':'RB','অনাবাদী':'JJ','অনাবিল':'NN',
'অনাবৃত':'NN','অনাবৃত্ত':'JJ','অনাবৃষ্টি':'NN','অনাবেদক':'NN','অনাবেদনকারী':'JJ','অনাভিলাষিতা':'NN','অনামিকা':'NN',
'অনামী':'JJ','অনামুখো':'JJ','অনাময়':'NNP','অনার':'NN','অনারক্ষিত':'JJ','অনারূঢ়':'JJ','অনারেরিয়াম':'NN',
'অনার্জিত':'JJ','অনার্দ্র':'JJ','অনার্দ্রতা':'NN','অনার্য':'NN','অনার্ষ':'JJ','অনার্স':'NN','অনার্সমাস্টার্স':'NNS',
'অনালম্বী':'NN','অনালাপ':'JJ','অনালোচিত':'JJ','অনাশ্রমী':'JJ','অনাসক্ত':'JJ','অনাসক্তি':'NN','অনাস্থা':'NN',
'অনাস্বাদিত':'JJ','অনাহত':'NN','অনাহার':'NN','অনাহারমার্গনা':'NN','অনাহারী':'NN','অনাহার্য':'JJ','অনাহিতাগ্নি':'JJ',
'অনাড়ম্বর':'JJ','অনায়াস':'RB','অনায়ুষা':'NN','অনিঃস্পৃহতা':'NN','অনিকেত':'JJ','অনিচ্ছা':'NN','অনিচ্ছুক':'JJ',
'অনিচ্ছুকএকদম':'RB','অনিচ্ছুকএতো':'NN','অনিচ্ছুককিছু':'NN','অনিচ্ছুকপাকিস্তান':'NN','অনিত্য':'JJ','অনিত্যতা':'NN','অনিদ্র':'JJ',
'অনিদ্রা':'NN','অনিদ্রিত':'JJ','অনিনি':'NN','অনিন্দ':'NNP','অনিন্দনীয়':'JJ','অনিন্দ্য':'JJ','অনিপুণ':'JJ',
'অনিপূণতা':'NN','অনিবর্তী':'JJ','অনিবার':'RB','অনিবার্যতা':'NN','অনিবার্য্য':'JJ','অনিবৃত্তি-বাদর':'NN','অনিভৃত':'JJ',
'অনিমগ্ন':'JJ','অনিমণ্ত্রিত':'JJ','অনিমিষাচার্য':'NN','অনিমেষ':'NN','অনিমেষকে':'NNP','অনিময়':'JJ','অনিযুক্ত':'JJ',
'অনিরপেক্ষ':'JJ','অনিরুদ্ধ':'NN','অনিরুপিত':'JJ','অনির্জিত':'JJ','অনির্ণয়':'NN','অনির্দিষ্ট':'JJ','অনির্দিষ্টের':'NN',
'অনির্ধারিত':'JJ','অনির্বচনীয়':'JJ','অনির্বাচিত':'JJ','অনির্বাণ':'NNP','অনির্বাহ্য':'JJ','অনির্বীজকৃত':'NN','অনির্মিত':'JJ',
'অনিল':'NN','অনিলাত্মজ':'NN','অনিশ্চিত':'NN','অনিশ্চিতকালীন':'JJ','অনিশ্চয়তা':'NN','অনিশ্চয়াত্মক':'JJ','অনিষিদ্ধ':'NN',
'অনিষ্টকর':'JJ','অনিষ্টকারী':'NN','অনিষ্টসূচক':'JJ','অনিহা':'NN','অনিয়ত':'JJ','অনিয়ন্ত্রণ':'NN','অনিয়ন্ত্রত':'JJ',
'অনিয়ন্ত্রিত':'NN','অনিয়ম':'DM','অনিয়মই':'NNS','অনিয়মবদ্ধ':'JJ','অনিয়মিত':'RB','অনিয়মিতি':'NN','অনিয়মে':'RB',
'অনিয়মের':'NNS','অনীক':'NN','অনীতি':'NN','অনীহা':'NN','অনু':'NN','অনুকম্পা':'NN','অনুকম্পিত':'JJ',
'অনুকরণ':'VB','অনুকরণকারী':'NN','অনুকরণবৃত্তি':'NN','অনুকরণীয়':'JJ','অনুকর্তা':'NN','অনুকর্ষণ':'NN','অনুকল্পিত':'JJ',
'অনুকারক':'NN','অনুকুল':'JJ','অনুকূল':'JJ','অনুকূলতা':'NN','অনুকূলে':'RB','অনুকৃত':'JJ','অনুকৃতি':'NN',
'অনুক্তি':'NN','অনুক্রমণিকা':'NN','অনুক্রমহীনতা':'NN','অনুক্রমিকভাবে':'NN','অনুগমন':'NN','অনুগল্পের':'JJ','অনুগামী':'NN',
'অনুগীত':'NN','অনুগুণ':'NN','অনুগৃহীত':'JJ','অনুগ্রহ':'VB','অনুগ্রহপাত্র':'JJ','অনুগ্রাহক':'JJ','অনুগ্রীহিত':'JJ',
'অনুঘটন':'NN','অনুচর':'NN','অনুচরী':'NN','অনুচান':'NN','অনুচিত':'NNP','অনুচিন্তা':'NN','অনুচ্চ':'JJ',
'অনুচ্চাকাঙ্খী':'JJ','অনুচ্ছিষ্ট':'JJ','অনুচ্ছেদ':'NN','অনুচ্ছেদের':'NN','অনুজ':'NN','অনুজদের':'NNS','অনুজা':'NN',
'অনুজ্ঞা-পত্র':'NN','অনুজ্ঞাপত্র':'NN','অনুজ্ঞাপ্রাপ্ত':'JJ','অনুঢ়া':'NN','অনুতপ্ত':'NN','অনুতাপ':'VB','অনুতোষ':'NN',
'অনুত্তরিত':'NN','অনুত্তীর্ণ':'VBD','অনুত্পত্তি':'NN','অনুত্পন্ন':'JJ','অনুত্পাদক':'JJ','অনুত্পাদন':'NN','অনুত্পাদিত':'JJ',
'অনুত্সাহী':'JJ','অনুদনীয়':'JJ','অনুদান':'NN','অনুদানপ্রদত্ত':'JJ','অনুদানের':'NN','অনুদার':'JJ','অনুদিত':'VBN',
'অনুদেশ':'NN','অনুদ্ধত':'JJ','অনুদ্ধার':'NN','অনুদ্বিগ্ন':'JJ','অনুদ্বেগ':'NN','অনুদ্ভূত':'JJ','অনুদ্যমী':'JJ',
'অনুদ্যোগ':'NN','অনুদয়':'NN','অনুধাবন':'NN','অনুনাদ':'NN','অনুনাদিত':'JJ','অনুনাসিক':'JJ','অনুনাসিকতা':'NN',
'অনুনীতি':'NN','অনুন্নত':'VBN','অনুনয়':'VB','অনুপ':'NN','অনুপচারিত':'JJ','অনুপপুর':'NN','অনুপবিত':'NN',
'অনুপম':'NN','অনুপযুক্ত':'NN','অনুপযোগিতা':'NN','অনুপলক্ষিত':'JJ','অনুপস্থিত':'VBG','অনুপস্থিতি':'NN','অনুপস্হিত':'JJ',
'অনুপাত.দর':'NN','অনুপাতে':'NN','অনুপালন':'NN','অনুপূরক':'NN','অনুপূর্ববত্সা':'NN','অনুপেক্ষিত':'JJ','অনুপ্রবেশ':'NN',
'অনুপ্রবেশকারীদের':'NNS','অনুপ্রাণিত':'VB','অনুপ্রানিত':'VBN','অনুপ্রাপ্তি':'NN','অনুপ্রাশন':'NN','অনুপ্রেক্ষা':'NN','অনুপ্রেরণ':'NN',
'অনুপ্রেরণার':'NN','অনুপ্রেরনাদায়ি':'VBG','অনুবচন':'NN','অনুবত্সর':'NN','অনুবন্ধ-পত্র':'NN','অনুবন্ধকারী':'JJ','অনুবন্ধিত':'JJ',
'অনুবর্তন':'NN','অনুবর্ধন':'VB','অনুবল':'NN','অনুবাক':'NN','অনুবাদ':'VB','অনুবাদক':'NN','অনুবাদযোগ্য':'JJ',
'অনুবাদিত':'NN','অনুবাদীর':'NN','অনুবাদ্য':'JJ','অনুবাসন-বস্তি':'NN','অনুবাসন':'NN','অনুবিন্দ':'NN','অনুবিভাগ':'NN',
'অনুবীক্ষণ':'NN','অনুবৃত্ত':'JJ','অনুবৃত্তি':'NN','অনুবেশ':'NN','অনুবোধক':'NN','অনুভক্তক':'NN','অনুভব':'VB',
'অনুভবকে':'NN','অনুভবসিদ্ধ':'JJ','অনুভবহীন':'NN','অনুভবুপূর্ণতা':'NN','অনুভবের':'NN','অনুভাজন':'NN','অনুভাবক':'JJ',
'অনুভাবনা':'VB','অনুভাবী':'JJ','অনুভুতিগুলি':'NN','অনুভূত':'VB','অনুভূতি':'NN','অনুভূতিগুলিকে':'NN','অনুভূতিতে':'NN',
'অনুভূতিপ্রবণ':'JJ','অনুভূতির':'VBG','অনুভূতিহীন':'NN','অনুভূমিক':'NN','অনুভোগ':'NN','অনুমতি':'NN','অনুমতিতে':'NN',
'অনুমতিপত্র':'NN','অনুমতিহীনতা':'NN','অনুমান':'VB','অনুমানই':'WP','অনুমানপত্র':'NN','অনুমানভিত্তিক':'JJ','অনুমানসিদ্ধ':'JJ',
'অনুমিত':'JJ','অনুমিতি':'NN','অনুমোদন':'NN','অনুমেয়ই':'WP','অনুমোদক':'NN','অনুমোদনহীন':'VBN','অনুমোদিত':'NN',
'অনুম্লোচা':'NN','অনুযাগ':'NN','অনুযাচন':'NN','অনুযায়ী':'NN','অনুযায়ি':'NN','অনুযায়ীই':'NN','অনুযোক্তা':'JJ',
'অনুযোগ':'NN','অনুযোজন':'NN','অনুরক্ত':'JJ','অনুরক্তি':'NN','অনুরক্ষণ':'NN','অনুরঞ্জক':'JJ','অনুরঞ্জন':'NN',
'অনুরণিত':'NN','অনুরত':'JJ','অনুরধ':'NN','অনুরাগ':'NN','অনুরাগী':'NNS','অনুরাগীদের':'NN','অনুরাধা':'NN',
'অনুরাধাপুর':'NNP','অনুরুদ্ধ':'JJ','অনুরূদ':'NN','অনুরূপ':'JJ','অনুরূপতা':'NN','অনুরূপী':'JJ','অনুরূপে':'NN',
'অনুরোধ-পত্র':'NN','অনুরোধ':'VB','অনুরোধও':'NN','অনুরোধকৃত':'JJ','অনুর্ধ':'VBN','অনুর্ধ১৫':'NN','অনুর্বর':'NN',
'অনুর্বরা':'NN','অনুলগ্নক':'NN','অনুলম্ব':'NN','অনুলাপ':'NN','অনুলিপিকর':'NN','অনুলিপ্ত':'JJ','অনুলেখ':'NN',
'অনুলেপন':'NN','অনুলোম-বিবাহ':'NN','অনুলোম':'NN','অনুলোমবিবাহ':'NN','অনুল্লেখ':'NN','অনুশাসক':'NN','অনুশাসনহীন':'JJ',
'অনুশাসনহীনতা':'NN','অনুশাসনাত্মক':'JJ','অনুশাসনীয়':'JJ','অনুশাসনে':'NN','অনুশাসিত':'JJ','অনুশিক্ষক':'NN','অনুশীলন':'NN',
'অনুশীলনী':'NN','অনুশীলনীয়':'JJ','অনুশীলনে':'NN','অনুশীলিত':'JJ','অনুশোচনা':'NN','অনুশোচনাহীন':'JJ','অনুশোচনায়':'NN',
'অনুশ্রুতি':'NN','অনুশয়':'NN','অনুশয়ী':'NN','অনুষক্তি':'NN','অনুষঙ্গ':'NN','অনুষদের':'NN','অনুষ্ঠাতা':'NN',
'অনুষ্ঠানকারী':'JJ','অনুষ্ঠানে':'NN','অনুষ্ঠাপক':'NN','অনুষ্ঠিত':'NNP','অনুষ্ঠুপ':'NN','অনুষ্ণ':'JJ','অনুসংগ':'JJ',
'অনুসন্ধান':'NN','অনুসন্ধানযোগ্য':'JJ','অনুসন্ধানী':'NN','অনুসন্ধানেও':'NN','অনুসন্ধেয়':'JJ','অনুসরণ':'VB','অনুসরণকারী':'NN',
'অনুসরণীয়':'VBN','অনুসরণে':'NN','অনুসরন':'VB','অনুসর্গ':'NN','অনুসার':'JJ','অনুসারতা':'NN','অনুসারী':'NN',
'অনুসারীদের':'NNS','অনুসারে':'RB','অনুসুয়া':'NN','অনুসূচিত-ক্ষেত্র':'NN','অনুসূচিত':'NN','অনুসূয়া':'NN','অনুস্নান':'NN',
'অনুস্বর':'NN','অনুৎসাহী':'VBN','অনুয়াজ':'NN','অনূঢ়া':'JJ','অনূদিত':'JJ','অনূযায়ী':'NN','অনূসরনীয়সব':'VBN',
'অনূঢ়া':'JJ','অনৃণতা':'NN','অনৃতভাষী':'JJ','অনেক':'NNS','অনেককে':'JJ','অনেকক্ষণ':'NN','অনেকক্ষেত্রেই':'PR',
'অনেকখানি':'NN','অনেকখানিই':'PR','অনেকগুলি':'JJ','অনেকজ':'JJ','অনেকটা':'NN','অনেকদিন':'NN','অনেকবার':'NNS',
'অনেকলোচন':'NN','অনেকস্থলে':'NN','অনেকা':'JJ','অনেকাংশে':'NN','অনেকাংশেই':'PR','অনেকান্তবাদ':'NN','অনেকান্তিকহেতু':'NN',
'অনেকে':'PR','অনেকের':'JJ','অনেঠ':'NN','অনেস্ট':'JJS','অনেহ':'NN','অনৈক্য':'NN','অনৈচ্ছিক':'NN',
'অনৈতিকতা':'NN','অনৈতিচ্য':'NN','অনৈতিহাসিক':'JJ','অনৈশ্বর্য':'NN','অনৈশ্বর্য্যপ্রদ':'JJ','অনৈসর্গিক':'NN','অনোট':'NN',
'অনোদ্বত্য':'NN','অনোদয়নাম':'NN','অনৌতিক':'JJ','অনৌপচারিক':'JJ','অন্ত-লঘু':'NN','অন্ত':'DM','অন্তঃ-পরিধি':'NN',
'অন্তঃ':'NN','অন্তঃকরণে':'NN','অন্তঃকোষ':'NN','অন্তঃক্রিয়া':'NN','অন্তঃপট':'NN','অন্তঃপুর':'NN','অন্তঃপুরের':'NN',
'অন্তঃপূজা':'NN','অন্তঃরাষ্ট্রীয়':'NN','অন্তঃশুদ্ধি':'NN','অন্তঃসজ্ঞা':'NN','অন্তঃসলিলবাহিনী':'JJ','অন্তঃসলিলা':'NN','অন্তঃসারযুক্ত':'JJ',
'অন্তঃসারশূণ্য':'JJ','অন্তঃস্রাবী-তন্ত্র':'NN','অন্তঃস্রাবীতন্ত্র':'NN','অন্তইন্দ্রিয়':'NN','অন্তজ':'NN','অন্ততঃ':'NN','অন্ততপক্ষে':'NN',
'অন্তবর্ণ':'NN','অন্তভ':'NN','অন্তমিল':'NN','অন্তমিলযুক্ত':'JJ','অন্তর':'NN','অন্তরঙ্গ':'JJ','অন্তরঙ্গতা':'NN',
'অন্তরটি':'NN','অন্তরণকারী':'NN','অন্তরদৃষ্টি':'NN','অন্তরবাসী':'JJ','অন্তরভূক্ত':'JJ','অন্তরমন':'NN','অন্তররাজ্যীয়':'JJ',
'অন্তরা':'NN','অন্তরানুভূতি':'NN','অন্তরাভিমুখী':'JJ','অন্তরাল':'NN','অন্তরায়':'NNS','অন্তরায়গুলি':'NN','অন্তরিক্ষ':'NN',
'অন্তরিত':'JJ','অন্তরীক্ষ':'NN','অন্তরীপ':'NN','অন্তরেই':'NN','অন্তর্গত':'NN','অন্তর্ঘাত':'NN','অন্তর্জাতীয়':'JJ',
'অন্তর্জ্ঞান':'NN','অন্তর্দশা':'NN','অন্তর্দায়':'NN','অন্তর্দৃষ্টি':'NN','অন্তর্দৃষ্টিসম্পন্ন':'JJ','অন্তর্দেশীয়':'NN','অন্তর্নিবিষ্ট':'JJ',
'অন্তর্নিহিত':'NN','অন্তর্পট':'NN','অন্তর্প্রদেশীয়':'JJ','অন্তর্বর্তী':'JJ','অন্তর্বর্তীকালীন':'NN','অন্তর্বস্তু':'NN','অন্তর্বাহিনী':'NN',
'অন্তর্বেদ':'NN','অন্তর্বোধ':'NN','অন্তর্ভুক্ত':'VBD','অন্তর্ভুক্তি':'NN','অন্তর্মনাঃ':'JJ','অন্তর্মুখ':'NN','অন্তর্মুখী':'VBN',
'অন্তর্যামী':'NN','অন্তর্রাষ্ট্রীয়':'NN','অন্তর্লম্ব':'NN','অন্তর্লাপিকা':'NN','অন্তর্লীন':'JJ','অন্তর্সংগঠন':'NN','অন্তর্হাস্য':'NN',
'অন্তর্হিত':'JJ','অন্তলঘু':'NN','অন্তস্তক':'NN','অন্তস্থঃ':'JJ','অন্তস্থল':'NN','অন্তহীন':'JJ','অন্তাক্ষরী':'NN',
'অন্তিক':'JJ','অন্তিম':'NN','অন্তুত':'NN','অন্তেবাসী':'NN','অন্ত্যজ':'NN','অন্ত্যবিপুলা':'NN','অন্ত্যাক্ষরী':'NN',
'অন্ত্যানুপ্রাস':'NN','অন্ত্যেষ্টি':'NN','অন্ত্র':'NN','অন্ত্রধান':'NN','অন্ত্রপ্রদাহ':'NN','অন্ত্রবৃদ্ধি':'NN','অন্ত্রভাব':'NN',
'অন্ত্রাণ্ডবৃদ্ধি':'NN','অন্দর':'NN','অন্দূ':'NN','অন্ধ-বিশ্বাস':'NN','অন্ধ':'NN','অন্ধকমুনি':'NN','অন্ধকার':'NN',
'অন্ধকারপূর্ণ':'JJ','অন্ধকারী':'NN','অন্ধকারেই':'NN','অন্ধকূপ':'NN','অন্ধতামিস্র':'NN','অন্ধত্ব':'NN','অন্ধদের':'NN',
'অন্ধপুতনাগ্রহ':'NN','অন্ধবিন্দু':'NN','অন্ধবিশ্বাস':'NN','অন্ধবিশ্বাসী':'NN','অন্ধব্যক্তি':'NN','অন্ধভাবে':'RB','অন্ধভৃত্য':'NN',
'অন্ধমহিলা':'NN','অন্ধরি':'NN','অন্ধানুযায়ি':'NN','অন্ধিকা':'NN','অন্ধের':'IN','অন্ধ্র প্রদেশ':'NN','অন্ধ্র-ভৃত্য':'NN',
'অন্ধ্র':'NN','অন্ধ্রপ্রদেশ':'NN','অন্ন-কূট':'NN','অন্ন-কোষ্ঠ':'NN','অন্ন-দাতা':'NN','অন্ন-দোষ':'NN','অন্ন-পাক':'NN',
'অন্ন-বিকার':'NN','অন্ন-ভাগ':'NN','অন্ন-মল':'NN','অন্ন-লিপ্সা':'NN','অন্ন-সংস্কার':'NN','অন্ন':'NN','অন্নকোষ্ঠ':'NN',
'অন্নচোর':'NN','অন্নজ':'JJ','অন্নজল':'NN','অন্নজাত':'JJ','অন্নদা':'NN','অন্নদান':'NN','অন্নদোষ-শূল':'NN',
'অন্নপাক':'NN','অন্নপূর্ণ':'NN','অন্নপূর্ণোপনিষদ':'NN','অন্নপ্রাশন':'NN','অন্নবিকার':'NN','অন্নভাগ':'NN','অন্নভূক':'JJ',
'অন্নমল':'NN','অন্নময়-কোষ':'NN','অন্নময়':'JJ','অন্নরস':'NN','অন্নলিপ্সা':'NN','অন্নসংস্কার':'NN','অন্না':'NNP',
'অন্নাভাব':'NN','অন্নে':'NN','অন্বষ্টকা':'NN','অন্বাচয়':'NN','অন্বাধাত':'NN','অন্বাধেয়':'NN','অন্বাহার্য':'NN',
'অন্বিচ্ছা':'NN','অন্বিতার্থ':'NN','অন্বীক্ষা':'NN','অন্বেষণ':'VB','অন্বেষণকারি':'NN','অন্বেষনীয়':'JJ','অন্বেষার':'NN',
'অন্বেষী':'JJ','অন্বয়':'NN','অন্বয়তিরেক':'NN','অন্বয়ী':'JJ','অন্য':'JJ','অন্যএকটি':'NN','অন্যকিছুতে':'JJ',
'অন্যকে':'NN','অন্যকেউ':'RB','অন্যকোন':'RB','অন্যগুলি':'NNS','অন্যগৃহের':'NN','অন্যগোত্রের':'JJ','অন্যজন':'DT',
'অন্যজনকেও':'NN','অন্যটা':'NN','অন্যটিতে':'PR','অন্যতম':'NN','অন্যতোপাক':'NN','অন্যত্নভাবনা':'NN','অন্যত্র':'RB',
'অন্যথানুপপত্তি':'NN','অন্যথাসিদ্ধি':'NN','অন্যথায়':'RB','অন্যদল':'NN','অন্যদিন':'NN','অন্যদের':'NNS','অন্যদেরও':'NN',
'অন্যদেরকেও':'NN','অন্যধর্ম':'NN','অন্যপথে':'NN','অন্যপুরুষ':'NN','অন্যপুষ্ট':'JJ','অন্যপূর্বা':'NN','অন্যপূর্বাস্ত্রী':'JJ',
'অন্যপ্রসঙ্গে':'RB','অন্যবাপ':'NN','অন্যভাবে':'RB','অন্যভাবেও':'PR','অন্যমনস্ক':'JJ','অন্যমনস্কতা':'NN','অন্যমনস্কতাবশত':'JJ',
'অন্যমনস্কতাবশতঃ':'RB','অন্যয্য':'NN','অন্যর':'NNS','অন্যরকম':'NN','অন্যরকমও':'RB','অন্যরা':'NNS','অন্যরাষ্ট্রীয়':'JJ',
'অন্যরূপ':'NN','অন্যসব':'RB','অন্যসম্ভোগদুখিতা':'NN','অন্যান্ন':'NNS','অন্যান্যগুলি':'PR','অন্যান্যরা':'NNS','অন্যাপদেশ':'NN',
'অন্যায়':'NN','অন্যায্য':'JJ','অন্যায়':'VB','অন্যায়কর্তা':'JJ','অন্যায়কারীর':'NN','অন্যায়ের':'NN','অন্যে':'JJ',
'অন্যের':'NNS','অন্যেরাই':'NNS','অন্যোন্যকলহ':'NN','অন্যোন্যবৃত্তি':'NN','অন্যোন্যশ্রয়':'NN','অন্যোন্যাভাব':'NN','অনড়':'JJ',
'অন‍্য':'JJ','অন‍্যায‍্যভাবে':'RB','অপকরমো':'NNS','অপকর্ম':'NN','অপকর্মীরা':'NNS','অপকর্মের':'NNS','অপকর্ষ':'NN',
'অপকর্ষকারী':'JJ','অপকর্ষণ':'NN','অপকলঙ্ক':'NN','অপকার':'NN','অপকারক':'JJ','অপকারি':'NN','অপকারী':'JJ',
'অপকীর্তি':'NN','অপকৃত':'JJ','অপকৃতি':'NN','অপকৌশল':'NNS','অপকৌশলের':'JJ','অপক্ক':'JJ','অপক্কতা':'NN',
'অপক্ক্বকলুষ':'NN','অপক্রম':'NN','অপক্ষ':'JJ','অপগত':'JJ','অপগমন':'NN','অপগ্রহ':'NN','অপঘন':'JJ',
'অপচয়':'NN','অপচয়কারী':'JJ','অপচার':'NN','অপচেষ্টা':'NN','অপচয়':'NN','অপচয়িত':'JJ','অপচয়ের':'NN',
'অপছন্দ':'NN','অপছন্দের':'JJ','অপছরা':'NN','অপটিক':'JJ','অপটিমালিটি':'NNP','অপটু':'JJ','অপটুতা':'NN',
'অপণ্য':'JJ','অপতন্ত্র':'NN','অপতানক':'NN','অপতিত':'JJ','অপতীর্থ':'NN','অপত্য':'NN','অপতৎপরতা':'NN',
'অপথ':'NN','অপদস্থ':'VBN','অপদার্থ':'JJ','অপদার্থের':'NN','অপদেবতা':'NN','অপদ্রব্য':'NN','অপনাম':'NN',
'অপনার':'NNS','অপপ্রচার':'NN','অপপ্রবৃত্তি':'NN','অপপ্রয়োগ':'NN','অপবচন':'NN','অপবর্তক':'NN','অপবাদ':'NN',
'অপবাহুক':'NN','অপবিত্র':'NN','অপবিত্রতা':'JJ','অপবিদ্ধ':'JJ','অপবিদ্যা':'NN','অপব্যবহারকারী':'NNP','অপব্যবহারে':'NN',
'অপব্যয়':'VB','অপব্যয়ী':'NN','অপভ্রংশ':'NN','অপভ্রষ্ট':'JJ','অপমর্শ':'NN','অপমাণ':'NN','অপমান':'VB',
'অপমানঅপদস্ত':'NN','অপমানকর':'JJ','অপমানজনক':'JJ','অপমানজনকনির্বাচন':'NN','অপমানিত':'NN','অপমানের':'VBG','অপমিশ্রণ':'NN',
'অপমৃত্যু':'NN','অপযশ':'NN','অপযশপ্রদানকারী':'JJ','অপযোগ':'NN','অপর':'NN','অপরচুনিটির':'NN','অপরজন':'NN',
'অপরটি':'PR','অপরত্ব':'NN','অপরদিকে':'NN','অপরপক্ষে':'RB','অপরব্যক্ত':'NN','অপরস':'NN','অপরসায়নবিদ':'NN',
'অপরা':'NN','অপরাক্রমী':'JJ','অপরাজনীতি':'NNS','অপরাজিত':'JJ','অপরাজিতা':'NN','অপরাজেয়':'JJ','অপরাতঙ্ক':'NN',
'অপরাধ-বিজ্ঞান':'NN','অপরাধ':'NN','অপরাধকে':'NN','অপরাধঢাকা':'NN','অপরাধপূর্ণতা':'NN','অপরাধপ্রবণতা':'JJ','অপরাধপ্রমাণ':'NN',
'অপরাধবি':'JJ','অপরাধবিজ্ঞান':'NN','অপরাধবৈজ্ঞানীক':'NN','অপরাধমূলক':'JJ','অপরাধি':'JJ','অপরাধী':'NN','অপরাধীই':'JJ',
'অপরাধীকে':'NN','অপরাধীদের':'NNS','অপরাধীর':'JJ','অপরাধীরাও':'NN','অপরাধে':'NN','অপরান্তিকা':'NN','অপরাপর':'JJ',
'অপরাবর্তী':'JJ','অপরাহ':'NNP','অপরাহ্ণ':'NN','অপরাহ্নের':'JJ','অপরিকল্পিত':'VBN','অপরিক্ষীত':'JJ','অপরিগৃহীত':'JJ',
'অপরিগ্রহ':'NN','অপরিচিত':'NN','অপরিচিতা':'JJ','অপরিচ্ছন্নতা':'NN','অপরিচয়':'NN','অপরিজ্ঞাত':'JJ','অপরিণত':'JJ',
'অপরিণামদর্শিতা':'NN','অপরিণামদর্শী':'JJ','অপরিণীতা':'NN','অপরিপক্ক':'JJ','অপরিপক্ষ':'NN','অপরিপূর্ণ':'JJ','অপরিবর্তনশীল':'JJ',
'অপরিবর্তিত':'JJ','অপরিমাপিত':'JJ','অপরিমিত':'NN','অপরিমেয়':'NN','অপরিশুদ্ধ':'JJ','অপরিশোধিত':'JJ','অপরিশ্রমী':'JJ',
'অপরিশ্রান্ত':'JJ','অপরিহার্য':'NN','অপরিহার্য্য':'JJ','অপরীক্ষিত':'JJ','অপরূপ':'JJ','অপরের':'NN','অপরোক্ষ':'JJ',
'অপর্ণা':'NN','অপর্ণার':'NNP','অপর্যাপ্ত':'JJ','অপর্যাপ্ততা':'NN','অপলক':'NN','অপলাপ':'NN','অপশক্তি':'NN',
'অপশক্তিকে':'NN','অপশন':'NNS','অপশব্দ':'NN','অপশাসনের':'NN','অপসংস্কৃতি':'NN','অপসদ':'NN','অপসব্য':'JJ',
'অপসরণের':'NN','অপসাংবাদিকতা':'NN','অপসারণ':'NN','অপসারন':'NN','অপসারী':'JJ','অপসিদ্ধান্ত':'NN','অপসৃত':'JJ',
'অপস্নান':'NN','অপস্মারী':'JJ','অপস্রিয়মাণ':'JJ','অপহত':'JJ','অপহরণ':'VB','অপহরণকারী':'NN','অপহারক':'NN',
'অপহৃত':'JJ','অপাঙ্গ':'NN','অপাঠযোগ্য':'JJ','অপাত্র':'JJ','অপাত্রতা':'NN','অপাত্রদায়ী':'JJ','অপাত্রীকরণ':'NN',
'অপাদান':'NN','অপাপবিদ্ধ':'JJ','অপাম্বত্স':'NN','অপার':'NN','অপারগ':'RB','অপারগতা':'NN','অপারিবারিক':'JJ',
'অপারেট':'NN','অপারেটর':'NN','অপারেটরকে':'NN','অপারেটরগুলো':'NNS','অপারেটরদের':'NNS','অপারেটররা':'NN','অপারেটরা':'NNS',
'অপারেটরে':'NN','অপারেটরেে':'NN','অপারেটাররাও':'NN','অপারেটিং':'NN','অপারেশন':'VB','অপারেশনের':'NN','অপার্থ':'NN',
'অপার্থিব':'NN','অপালা':'NN','অপাসন':'NN','অপি':'NN','অপিনিহিতি':'NN','অপিষাঁড়':'NN','অপু':'NN',
'অপুজ্য':'JJ','অপুত্র':'NN','অপুনরাবৃত্তি':'NN','অপুনর্ভব':'NN','অপুর':'NNP','অপুষ্ট':'JJ','অপুষ্টি':'NN',
'অপুষ্টিজনিত':'JJ','অপুষ্প':'NN','অপুয়':'NN','অপূজক':'NN','অপূজারী':'JJ','অপূজিত':'JJ','অপূরণীয়':'JJ',
'অপূর্ণ':'NN','অপূর্ণভূত':'NN','অপূর্ব':'NN','অপূর্ববিধি':'NN','অপূর্বরূপ':'NN','অপৃক্ত':'NN','অপৃথক':'JJ',
'অপেক্ষ':'NN','অপেক্ষমাণ':'NN','অপেক্ষাই':'VBG','অপেক্ষাকারী':'NN','অপেক্ষাকৃত':'RB','অপেক্ষাবুদ্ধি':'NN','অপেক্ষায়':'VBG',
'অপেরটারদের':'NNS','অপেরা':'NN','অপেশাদারী':'NN','অপেয়':'JJ','অপৈতৃক':'JJ','অপো':'NN','অপৌরুষ':'JJ',
'অপ্টিক':'NN','অপ্তোর্যাম':'NN','অপ্রকটিত':'JJ','অপ্রকাশনীয়':'JJ','অপ্রকাশ্য':'JJ','অপ্রকৃত':'JJ','অপ্রকৃতআশ্রিতশ্লেষ':'NN',
'অপ্রচলিত':'NN','অপ্রচার':'NN','অপ্রতিগ্রহণ':'NN','অপ্রতিদানযোগ্য':'JJ','অপ্রতিদ্বন্দ্বী':'JJ','অপ্রতিপত্তি':'NN','অপ্রতিপন্ন':'JJ',
'অপ্রতিবন্ধ':'NN','অপ্রতিবীর্য':'JJ','অপ্রতিভা':'NN','অপ্রতিম':'JJ','অপ্রতিরথ':'NN','অপ্রতিরূপ':'JJ','অপ্রতিরোধ্্য':'JJ',
'অপ্রতিষ্ঠিত':'JJ','অপ্রতীত':'JJ','অপ্রতীম':'NN','অপ্রত্যক্ষ':'NN','অপ্রত্যাশিত':'JJ','অপ্রত্যয়':'NN','অপ্রত্যয়িত':'JJ',
'অপ্রথা':'NN','অপ্রদত্ত':'JJ','অপ্রধান':'NN','অপ্রবাহিত':'JJ','অপ্রবিষ্ট':'JJ','অপ্রবীণতা':'NN','অপ্রবেশ্য':'JJ',
'অপ্রভাবিত':'JJ','অপ্রভুত্ব':'NN','অপ্রমত্ত':'JJ','অপ্রমা':'NN','অপ্রমাণিত':'JJ','অপ্রমুখ':'NN','অপ্রযত্ন':'NN',
'অপ্রযত্নশীল':'JJ','অপ্রয়োজনীয়':'JJ','অপ্রযুক্তিগত':'JJ','অপ্রশংসনীয়':'JJ','অপ্রশিক্ষিত':'JJ','অপ্রসঙ্গ':'NN','অপ্রসন্ন':'JJ',
'অপ্রসন্নতাপূর্বক':'RB','অপ্রসব':'NN','অপ্রসিদ্ধ':'JJ','অপ্রসিদ্ধি':'NN','অপ্রসূতু':'JJ','অপ্রস্তুতপ্রশংসা':'NN','অপ্রাকৃতিক':'NN',
'অপ্রাথমিকতা':'NN','অপ্রাধান্যতা':'NN','অপ্রাপ্ত':'JJ','অপ্রাপ্তকাল':'NN','অপ্রাপ্তযৌবন':'JJ','অপ্রাপ্তি':'NN','অপ্রাপ্য':'JJ',
'অপ্রামাণিক':'JJ','অপ্রাসঙ্গিক':'NN','অপ্রিয়':'NN','অপ্রিয়কর':'JJ','অপ্রিয়বাদী':'JJ','অপ্রিয়ভাজন':'NN','অপ্রিয়ভাষী':'JJ',
'অপ্রীতি':'NN','অপ্রীতিকর':'JJ','অপ্রেম':'NN','অপ্রোথিত':'JJ','অপ্রয়াস':'NN','অপ্রয়োজন':'RB','অপ্রয়োজনীয়':'JJ',
'অপ্রয়োজনীয়তবে':'NNS','অপ্সরা':'NN','অপ্সুদীক্ষা':'NN','অপয়া':'NN','অপ‌কর্মের':'NNS','অফ':'NN','অফনেট':'NN',
'অফনেটে':'NN','অফল':'NN','অফলপ্রসূ':'JJ','অফলা':'NN','অফসাইড':'IN','অফার':'NN','অফিস':'NN',
'অফিসআদালতে':'NN','অফিসগুলিতে':'NN','অফিসগুলো':'NNS','অফিসব্যাংকে':'NN','অফিসার':'NN','অফিসাররা':'NN','অফিসারি':'NN',
'অফিসারেরা':'NN','অফিসিয়ালদের':'NNS','অফিসিয়ালি':'NN','অফিসে':'NN','অফিসের':'NN','অফুরন্ত':'NN','অফেন':'JJ',
'অফেনডিং':'NNP','অব-হিমালয়':'NN','অব':'NN','অবইধ':'JJ','অবঊর্ধনুজ':'NN','অবকর্ষণ':'NN','অবকলিত':'JJ',
'অবকা':'NN','অবকাঠামো':'NN','অবকাশ':'NN','অবকাশগ্রহণ':'NN','অবকীর্ণ':'NN','অবকীর্ণী':'JJ','অবকৃষ্ট':'JJ',
'অবকেশী':'JJ','অবক্র':'JJ','অবক্রন্দন':'NN','অবক্ষয়':'NN','অবক্ষিপ্ত':'JJ','অবক্ষেপণ':'NN','অবক্ষয়ের':'NN',
'অবগণন':'NN','অবগত':'NN','অবগতনো':'VB','অবগতি':'NN','অবগতির':'VBN','অবগারি':'NN','অবগাহণ':'NN',
'অবগাহন':'VB','অবগাহিত':'JJ','অবগীত':'JJ','অবগুণ্ঠন':'NN','অবগুণ্ঠনমুদ্রা':'NN','অবগুণ্ঠিত':'JJ','অবগুন্ঠন':'NN',
'অবগ্বা':'NN','অবগ্রহ':'NN','অবঙ্যই':'RB','অবচলুক':'NN','অবচূড়':'NN','অবচেতন':'NN','অবচেতনা':'NN',
'অবচ্ছিন্ন':'JJ','অবচ্ছেদ':'NN','অবচ্ছেদক':'JJ','অবচ্ছেদন':'NN','অবচ্ছেদ্য':'JJ','অবজীহ্বী':'NN','অবজেকটিভ':'NN',
'অবজ্ঞা':'VB','অবজ্ঞাই':'NN','অবজ্ঞাকারী':'JJ','অবজ্ঞাতার্থ':'NN','অবজ্ঞাসূচক':'JJ','অবজ্ঞেয়':'JJ','অবতরণ':'VB',
'অবতরণিকা':'NN','অবতরণের':'NN','অবতল':'JJ','অবতলোত্তল':'JJ','অবতার':'NN','অবতারিত':'JJ','অবতারিতে':'NN',
'অবতীর্ণ':'VBN','অবদমিত':'JJ','অবদান':'NN','অবদানশ্রমঘাম':'NN','অবদারিতই':'JJ','অবদি':'IN','অবধ':'JJ',
'অবধান':'NN','অবধারণ':'NN','অবধারণীয়':'JJ','অবধারিত':'JJ','অবধি':'IN','অবধিহীন':'JJ','অবধুত':'NN',
'অবধুতোপনিষদ':'NN','অবধেশ':'NN','অবধ্য':'JJ','অবনত':'JJ','অবনতি':'NN','অবনতিকারী':'JJ','অবনদ্ধ':'NN',
'অবনমন':'NN','অবনমিত':'VBN','অবনম্র':'JJ','অবনি':'NN','অবনীশ':'NN','অবনেজন':'NN','অবন্টিত':'JJ',
'অবন্তিকা':'NN','অবন্তীর':'JJ','অবপাটিকা':'NN','অবপাত':'NN','অববাহিকা':'NN','অববোধক':'JJ','অবভাস':'NN',
'অবভৃত':'NN','অবম':'NN','অবমন্থ':'NN','অবমানন':'NN','অবমুক্তির':'NN','অবমূল্যায়ন':'NN','অবর':'NN',
'অবরস':'NN','অবরুদ্ধ':'VBN','অবরুদ্ধকরণ':'NN','অবরূদ্ধ':'JJ','অবরেণ্য':'JJ','অবরোধ':'NN','অবরোধপূর্ণ':'JJ',
'অবরোধহীন':'JJ','অবরোধাত্মক':'JJ','অবরোধী':'JJ','অবরোপণ':'NN','অবরোপিত':'JJ','অবরোহ':'NN','অবরোহণ':'NN',
'অবরোহণকারী':'JJ','অবরোহী':'NN','অবর্গ':'NN','অবর্জাভেটরি':'NN','অবর্ণ':'NN','অবর্ণনীয়':'JJ','অবর্ণিত':'JJ',
'অবর্তমান':'NN','অবলক':'NN','অবলম্বক':'NN','অবলম্বনযোগ্য':'JJ','অবলম্বনহীন':'JJ','অবলম্বনে':'NN','অবলম্বিত':'JJ',
'অবলা':'NN','অবলীঢ়':'JJ','অবলীলায়':'NN','অবলুণ্ঠিত':'JJ','অবলুন্ঠন':'NN','অবলুপ্ত':'NN','অবলেপন':'NN',
'অবলেহ্য':'NN','অবলোকন':'NN','অবলোকিত':'JJ','অবলোপন':'NN','অবলোহিত':'NN','অবশ':'NN','অবশিষ্ট':'NN',
'অবশিষ্টগুলো':'JJS','অবশীর্ষ':'JJ','অবশেষ':'NN','অবশেষে':'RB','অবশোষিত':'NN','অবশ্য':'NN','অবশ্যই':'RB',
'অবশ্যইগরীব':'NN','অবশ্যম্ভাবী':'JJ','অবশ্যা':'NN','অবষ্টম্ভ':'NN','অবসকাশগ্রহণ':'NN','অবসথা':'NN','অবসন্ন':'JJ',
'অবসন্নতা':'NN','অবসর':'NN','অবসরকালীন':'NN','অবসরগ্রহণ':'NN','অবসরপ্রাপ্ত':'JJ','অবসরপ্রাপ্তি':'NN','অবসরবাদ':'NN',
'অবসরভাতা':'JJ','অবসরভাতার':'JJ','অবসরে':'NN','অবসর্পিণী':'NN','অবসলেট':'NN','অবসাদ':'NN','অবসাদগ্রস্ত':'NN',
'অবসাদপূর্ণ':'NN','অবসাদহীনতা':'NN','অবসান':'NN','অবসৃত':'VBN','অবসেচন':'NN','অবস্কারক':'JJ','অবস্তা':'NN',
'অবস্তু':'JJ','অবস্থা':'NN','অবস্থাকে':'NN','অবস্থাগুলি':'NN','অবস্থাটা':'NN','অবস্থাটিকে':'NN','অবস্থাতেই':'NN',
'অবস্থাদৃষ্টে':'NN','অবস্থান':'NN','অবস্থানরত':'VBN','অবস্থানে':'NN','অবস্থান্তর':'NN','অবস্থায়':'NN','অবস্থায়':'NN',
'অবস্থিত':'VBN','অবস্থিতি':'NN','অবস্য':'NN','অবস্যু':'NN','অবস্হা':'NN','অবস্হান':'NN','অবস্হিত':'VBN',
'অবহ':'NN','অবহনযোগ্য':'JJ','অবহরণ':'NN','অবহিত':'VBN','অবহেলা':'NN','অবহেলিত':'JJ','অবহেলিতঐ':'VBN',
'অবা':'NN','অবাক':'NN','অবাকএতিমের':'NNS','অবাকপুষ্পী':'NN','অবাকসন্দেশ':'NN','অবাঙনরক':'NN','অবাঞ্ছনীয়':'JJ',
'অবাঞ্ছনীয়তা':'NN','অবাঞ্ছিত':'VBN','অবাদ':'JJ','অবাধ':'JJ','অবাধে':'RB','অবাধ্য':'JJ','অবাধ্যতা':'NN',
'অবান্তর':'NN','অবান্ধব':'RB','অবাপ্তি':'NN','অবারিত':'JJ','অবার্ণ':'NN','অবাল':'NN','অবালেন্দু':'NN',
'অবাস্তব':'JJ','অবিকল':'JJ','অবিকশিত':'NN','অবিকার':'NN','অবিকৃত':'JJ','অবিক্রেয়':'JJ','অবিক্রয়':'NN',
'অবিখ্যাত':'JJ','অবিঘ্ন':'NN','অবিচল':'JJ','অবিচার':'NN','অবিচারের':'NN','অবিচারেরমাননীয়':'NN','অবিচ্ছেদ্য':'JJ',
'অবিচ্যুয়ারি':'NN','অবিজিত':'JJ','অবিজ্ঞতা':'NN','অবিজ্ঞাত':'JJ','অবিতর্কিত':'JJ','অবিত্করণ':'NN','অবিদিত':'JJ',
'অবিদ্ধ':'JJ','অবিদ্ধকর্ণী':'NN','অবিদ্য':'JJ','অবিদ্যমানতা':'NN','অবিধান':'NN','অবিধিক':'NN','অবিনশ্বর':'JJ',
'অবিনাশ':'NN','অবিনাশী':'JJ','অবিনিমেয়':'NN','অবিনীত':'JJ','অবিনীতা':'NN','অবিন্ধ্য':'NN','অবিন্ম্র':'JJ',
'অবিপর্যয়':'NN','অবিপিত্তক':'NN','অবিবাদ':'JJ','অবিবাদী':'JJ','অবিবাহিত':'NN','অবিবাহিতাও':'JJ','অবিবেক':'NN',
'অবিবেচক':'JJ','অবিবেচকের':'RB','অবিবেচিত':'JJ','অবিভক্ত':'NN','অবিভাজ্য':'NN','অবিভাবকহীন':'NN','অবিভায্য':'JJ',
'অবিযান':'NN','অবিরত':'RB','অবিরতি':'NN','অবিরাম':'NN','অবিরোধী':'JJ','অবিলম্ব':'JJ','অবিলম্বে':'RB',
'অবিশুদ্ধতা':'NN','অবিশ্বস্ত':'JJ','অবিশ্বাস':'NN','অবিশ্বাসি':'NN','অবিশ্বাস্য':'JJ','অবিশ্বীসি':'NN','অবিশ্রান্ত':'RB',
'অবিষম':'JJ','অবিষা':'NN','অবিষয়':'JJ','অবিসংবাদী':'JJ','অবিস্তার':'NN','অবিস্তৃত':'JJ','অবিস্মরণীয়':'JJ',
'অবিহিত':'JJ','অবিয়োগ':'NN','অবীক্ষিত':'NN','অবীচি':'NN','অবীরা':'NN','অবুজা':'NN','অবুঝ':'JJ',
'অবুঝপনা':'NN','অবুদ্ধি':'NN','অবেদ্যা':'JJ','অবেধ':'JJ','অবেহেলিত':'VBN','অবোধ':'NN','অবৈজ্ঞানিক':'JJ',
'অবৈদিক':'JJ','অবৈদ্য':'JJ','অবৈধ':'JJ','অবৈধভাবে':'RB','অবৈধসব':'NNP','অবৈধ্য':'NN','অবৈরাগ্য':'NN',
'অবৈয়াকরণ':'JJ','অবোধ':'JJ','অবোধগম্য':'NN','অব্জ':'NN','অব্জকর্ণিকা':'NN','অব্জদ':'NN','অব্জেকশন':'NN',
'অব্দি':'NNP','অব্বাসী':'NN','অব্যক্ত':'NN','অব্যক্তক্রিয়া':'NN','অব্যক্তগতি':'JJ','অব্যক্তরাশি':'NN','অব্যক্তানুকরণ':'NN',
'অব্যক্তোপনিষদ':'NN','অব্যঞ্জন':'JJ','অব্যবধান':'NN','অব্যবসায়ী':'JJ','অব্যবস্থা':'NN','অব্যবস্থাপনার':'NN','অব্যবস্থিত':'JJ',
'অব্যবহার':'NN','অব্যবহারিক':'JJ','অব্যবহারিকতা':'NN','অব্যবহিত':'JJ','অব্যবহৃত':'NN','অব্যয়':'NN','অব্যর্থ':'JJ',
'অব্যর্থতা':'NN','অব্যহত':'JJ','অব্যাকৃত':'NN','অব্যাখ্যেয়':'JJ','অব্যাঘাত':'NN','অব্যাপকতা':'NN','অব্যাপ্তিশীল':'JJ',
'অব্যাপ্য':'JJ','অব্যাহত':'JJ','অব্যাহতি':'NN','অব্যুত্পন্ন':'JJ','অব্যূড়':'NN','অব্যয়':'NN','অব্যয়েত':'NN',
'অব্রণ':'NN','অব্রণশুক্র':'NN','অব্রত':'NN','অব্রতী':'JJ','অব্রহ্মণ্য':'NN','অব্রাহ্মণদের':'NN','অব্রাহ্মণ্য':'JJ',
'অবয়ব':'NN','অবয়বতন্ত্র':'NN','অবয়বযুক্ত':'JJ','অবয়বে':'NN','অভ':'NN','অভক্ত':'NN','অভক্তিমান':'NN',
'অভক্ষণীয়':'JJ','অভঙ্গপদ':'NN','অভঙ্গী':'JJ','অভঞ্জন':'NN','অভঞ্জনীয়':'JJ','অভঞ্জিত':'JJ','অভদ্র':'JJ',
'অভদ্রচিত':'NN','অভবিতব্য':'JJ','অভব্য':'NN','অভশঙ্কিত':'JJ','অভাগা':'NN','অভাজন':'NN','অভাব':'NN',
'অভাবগ্রস্ত':'JJ','অভাবগ্রস্ততা':'NN','অভাবগ্রস্থ':'JJ','অভাবটা':'NN','অভাবনা':'NN','অভাবনীয়':'JJ','অভাবনীয়সেরা':'NN',
'অভাবিত':'JJ','অভাবী':'NN','অভাবের':'NN','অভার':'IN','অভিকথন':'NN','অভিকল্পন':'NN','অভিক্রিয়া':'NN',
'অভিখ্যা':'NN','অভিগমন':'NN','অভিগামী':'JJ','অভিগ্যতার':'NN','অভিঘট':'NN','অভিঘাতহীন':'JJ','অভিচার':'NN',
'অভিচারী':'JJ','অভিজাত-ভবন':'NN','অভিজাত্য':'NN','অভিজিত্':'NN','অভিজ্ঞ':'NN','অভিজ্ঞতাই':'NN','অভিজ্ঞতার':'NN',
'অভিজ্ঞতালব্ধ':'JJ','অভিজ্ঞতাসম্পন্ন':'JJ','অভিজ্ঞতায়':'NN','অভিজ্ঞাত':'NN','অভিজ্ঞান':'NN','অভিতপ্ত':'JJ','অভিতোমুখ':'JJ',
'অভিধর্ষণ':'NN','অভিধা':'NN','অভিধেয়':'JJ','অভিধ্যা':'NN','অভিনন্দন':'NN','অভিনন্দনই':'NNS','অভিনন্দনটা':'NNS',
'অভিনন্দননাথ':'NN','অভিনন্দনীয়':'JJ','অভিনন্দনের':'NN','অভিনন্দিত':'JJ','অভিনব':'JJ','অভিনবত্ব':'NN','অভিনিবেশ':'NN',
'অভিনিবেশিত':'JJ','অভিনীত':'JJ','অভিনেতা':'NN','অভিনেত্রী':'NN','অভিনেয়':'JJ','অভিন্দন':'NN','অভিন্নতা':'NN',
'অভিন্নভাব':'NN','অভিন্নহৃদয়':'NN','অভিন্যাস':'NN','অভিনয়':'VBG','অভিনয়যোগ্য':'JJ','অভিনয়ের':'NN','অভিপ্রায়':'NN',
'অভিপ্রায়ের':'NN','অভিপ্রেত':'JJ','অভিপ্সু':'JJ','অভিবন্দনীয়':'JJ','অভিবাদক':'NN','অভিবাদন':'NNS','অভিবাদনকারী':'NN',
'অভিবাদনযোগ্য':'JJ','অভিবাদিত':'JJ','অভিবাসন':'NN','অভিবাসী':'NN','অভিব্যক্ত':'VBN','অভিব্যক্তিশীল':'JJ','অভিব্যঞ্জক':'JJ',
'অভিব্যঞ্জনা':'VB','অভিব্যাপক':'JJ','অভিব্যাপ্তি':'NN','অভিভবাত্':'NN','অভিভাবক':'NN','অভিভাবকের':'NN','অভিভাষণ':'NN',
'অভিভাষ্য':'JJ','অভিভূত':'NN','অভিমণ্ত্রণ':'NN','অভিমত':'NN','অভিমতের':'NN','অভিমন্ত্রিত':'JJ','অভিমন্যু':'NN',
'অভিমর্দন':'NN','অভিমানিনী':'NN','অভিমানী':'JJ','অভিমুখে':'NN','অভিযাত':'NN','অভিযান':'NN','অভিযানসহ':'NNS',
'অভিযানে':'NN','অভিযানের':'NNS','অভিযান্ত্রিকী':'NN','অভিযুক্ত':'NN','অভিযুক্তদের':'NNS','অভিযোগই':'NN','অভিযোক্তা':'JJ',
'অভিযোগ':'NN','অভিযোগকারী':'NN','অভিযোগগুলো':'NNS','অভিযোগপত্র':'NN','অভিযোগের':'NNS','অভিযোগ্য':'JJ','অভিযোজন':'NN',
'অভিরক্ষণ':'NN','অভিরক্ষিত':'JJ','অভিরতি':'NN','অভিরমণীয়':'JJ','অভিরম্য':'JJ','অভিরুচি':'NN','অভিরূপ':'NN',
'অভিরোগ':'NN','অভিলষিক':'NN','অভিলাষকে':'NN','অভিলাষপূর্ণ':'JJ','অভিলাষা':'NN','অভিলেখ':'NN','অভিলেখালয়':'NN',
'অভিশংসিত':'JJ','অভিশঙ্কা':'NN','অভিশঙ্কী':'JJ','অভিশপ্ত':'JJ','অভিশাপ':'NN','অভিশাস্তি':'NN','অভিষঙ্গ':'NN',
'অভিষদ':'NN','অভিষন্ধী':'NN','অভিষিক্ত':'JJ','অভিষেক':'NN','অভিষ্যন্দ':'NN','অভিষ্যন্দী':'JJ','অভিসন্ধি':'NN',
'অভিসরণ':'NN','অভিসাপেই':'NN','অভিসারক':'NN','অভিসারি':'JJ','অভিসারিকা':'NN','অভিসারী':'NN','অভিস্রাবণ':'NN',
'অভিহরণযোগ্য':'JJ','অভিহার':'NN','অভিহিত':'NN','অভীপ্সিত':'JJ','অভীবর্ত':'NN','অভীষণ':'JJ','অভীষ্ট':'NN',
'অভীসারে':'VB','অভুক্ত':'JJ','অভুক্তমূল':'NN','অভুঙ্গর':'JJ','অভুতপুর্ব':'VBN','অভুতোপমা':'NN','অভূতপূর্ব':'JJ',
'অভেদ':'NN','অভেদনীয়':'JJ','অভেদ্য':'JJ','অভোক্তা':'JJ','অভোজ্য':'JJ','অভৌতিক':'JJ','অভ্যঙ্গ':'NN',
'অভ্যঞ্জন':'NN','অভ্যণ্তরীণ':'NN','অভ্যন্তরস্থ':'JJ','অভ্যন্তরীণ':'NN','অভ্যন্তরীন':'NNP','অভ্যন্তরে':'NN','অভ্যন্তরের':'NNP',
'অভ্যর্থনা':'NN','অভ্যস্ত':'NNP','অভ্যস্থ':'NN','অভ্যাখ্যাত':'JJ','অভ্যাগত':'NN','অভ্যাঘাত':'NN','অভ্যাস':'NNS',
'অভ্যাসকলা':'NN','অভ্যাসটা':'NNS','অভ্যাসযোগ':'NN','অভ্যুক্ত':'JJ','অভ্যুচ্ছ্রয়':'NN','অভ্যুত্থান':'NN','অভ্যুত্থানকারী':'JJ',
'অভ্যুত্থানে':'NN','অভ্যুত্থানের':'JJ','অভ্যুথান':'NN','অভ্যুদিত':'JJ','অভ্যুদয়':'NN','অভ্যুদয়ের':'JJ','অভ্যুপগত':'JJ',
'অভ্যুপগন্তব্য':'NN','অভ্যুপগম':'NN','অভ্যেস':'NNS','অভ্র':'NN','অভ্রষ্ট':'JJ','অভ্রান্ত':'NN','অভয়-দক্ষিণা':'NN',
'অভয়':'NN','অভয়ঙ্কর':'JJ','অভয়দ':'JJ','অভয়দক্ষিণা':'NN','অভয়দান':'NN','অভয়প্রদ':'JJ','অভয়া':'NN',
'অভয়ারণ্য':'NN','অভ‍্যন্তরিন':'NNP','অমগ্ন':'JJ','অমঙ্গল':'NN','অমঙ্গলকারী':'JJ','অমঙ্গলসূচক':'NN','অমত':'JJ',
'অমধুর':'NN','অমন':'NN','অমনি':'NN','অমনুষ্য':'JJ','অমনোনিবেশ':'NN','অমনোযোগ':'NN','অমনোযোগী':'JJ',
'অমমতা':'NN','অমর':'NN','অমরকণ্টক':'NN','অমরকাষ্ঠ':'NN','অমরখ':'NN','অমরণশীল':'JJ','অমরতরু':'NN',
'অমরত্ব':'NN','অমরদাস':'NN','অমরদ্বিজ':'NN','অমরনাথ':'NN','অমরপক্ষ':'NN','অমরপুষ্প':'NN','অমরবেল':'NN',
'অমরশক্তি':'NN','অমরসিং':'NN','অমরা':'NN','অমরাপুরি':'NN','অমরাবতী':'NNS','অমরালয়':'NN','অমরী':'NN',
'অমরুক':'NN','অমরেন্দ্রনাথ':'NNP','অমরেলি':'NN','অমরেশ্বর':'NN','অমর্ত্য':'NN','অমর্দিত':'JJ','অমর্ষ':'NN',
'অমর্ষজাত':'JJ','অমল':'NN','অমলতাসের':'NN','অমলবেত':'NN','অমলিন':'JJ','অমলেন্দু':'NNP','অমলের':'NNP',
'অমহত্ব':'NN','অমাঘৌত':'NN','অমাঙ্গলিক':'JJ','অমাতাপুত্র':'NN','অমানবিক':'NN','অমানুষ':'NN','অমানুষিক':'JJ',
'অমান্য':'JJ','অমান্যকরণ':'NN','অমাবস্যা':'NN','অমাবস্যায়':'NN','অমার্জিত':'NN','অমাহাত্মাঙ্ক্ষা':'NN','অমায়িক':'JJ',
'অমায়িকভাবে':'NN','অমিত':'NN','অমিতবীর্য':'NN','অমিতব্যয়িতা':'NN','অমিতাভ':'NN','অমিত্র':'JJ','অমিলপট্টি':'NN',
'অমিলাল':'NNP','অমিশুকে':'JJ','অমিশ্রণ':'NN','অমিশ্রণীয়':'JJ','অমিশ্ররাশি':'NN','অমিশ্রিত':'JJ','অমিয়':'NN',
'অমীমাংসিত':'JJ','অমুক':'NN','অমুকের':'JJ','অমুক্তি':'NN','অমুক্তিযোদ্ধারাই':'NN','অমুসলিমদের':'NN','অমূর্ত':'JJ',
'অমূলক':'JJ','অমূল্য':'NN','অমৃত-নাদ':'NN','অমৃত-বিন্দু':'NN','অমৃত-মন্থন':'NN','অমৃত':'NN','অমৃতকুণ্ড':'NN',
'অমৃতক্ষার':'NN','অমৃতগতি':'NN','অমৃতদ্রব':'JJ','অমৃতধারা':'NN','অমৃতধ্বনি':'NN','অমৃতপ':'NN','অমৃতপানকারী':'JJ',
'অমৃতপুরুষ':'NN','অমৃতফল':'NN','অমৃতবল্লরী':'NN','অমৃতবাকা':'NN','অমৃতবিন্দু':'NN','অমৃতমতি':'NN','অমৃতমালিনী':'NN',
'অমৃতযোগ':'NN','অমৃতরসা':'NN','অমৃতরাজ':'NNP','অমৃতলতা':'NN','অমৃতসর':'NN','অমৃতাংশু':'NN','অমৃতি':'NN',
'অমৃতের':'NN','অমেরুদণ্ডী':'NN','অমোঘ':'JJ','অমোঘা':'NN','অমোচনীয়':'JJ','অমোয়া':'NN','অমৌলিক':'JJ',
'অম্বক':'NN','অম্বর':'NNP','অম্বরিষ':'NN','অম্বরীষ':'NNP','অম্বলের':'NN','অম্বা':'NN','অম্বাবাঈ':'NN',
'অম্বালিকা':'NN','অম্বাহল্দী':'NN','অম্বিকা':'FW','অম্বিকানাথ':'NN','অম্বিকাপুর':'NN','অম্বু':'NN','অম্বুজা':'NN',
'অম্বুদ':'NN','অম্মরস':'NN','অম্ল':'NN','অম্লজান':'NN','অম্লত্ব':'NN','অম্লরোগগ্রস্ত':'VB','অম্লসার':'NN',
'অম্লহরিদ্রা':'NN','অম্লাধ্যুষিত':'NN','অম্লান':'NN','অম্লীয়':'NN','অম্লোদ্গার':'NN','অযজ্ঞ':'JJ','অযত্ন':'NN',
'অযথা':'NN','অযথাযথ':'JJ','অযথার্থতা':'NN','অযথায়':'NN','অযশস্বী':'JJ','অয়ন':'NN','অযাচক':'JJ',
'অযাচার':'NN','অযাচিত':'JJ','অযাজ্য-যাজনকারী':'NN','অযুক্তি':'NN','অযুদ্ধ':'NN','অযুহাত':'NN','অযোগ্য':'NN',
'অযোগব':'NN','অযোগী':'JJ','অযোগ্য':'NN','অযোগ্যরাই':'NNS','অযোগ্যা':'JJ','অযোধ্যা':'NN','অযোনিজ':'NN',
'অযৌক্তিক':'NN','অযৌন':'JJ','অর':'CC','অরইল':'NN','অরক':'NN','অরকগীর':'NN','অরকনানা':'NN',
'অরক্তিম':'JJ','অরক্ষণীয়া':'NN','অরক্ষিত':'JJ','অরগজী':'NN','অরগজের':'JJ','অরগানিজিং':'VBG','অরঘা':'NN',
'অরচিত':'JJ','অরজন':'NN','অরট':'NN','অরণি':'NN','অরণ্য':'NN','অরণ্যকাণ্ড':'NN','অরণ্যগত':'JJ',
'অরণ্যগান':'NN','অরণ্যচন্দ্রিকা':'NN','অরণ্যবাস':'NN','অরণ্যবিনাশ':'NN','অরণ্যরোদন':'NN','অরণ্যা':'NN','অরণ্যাচ্ছাদিত':'JJ',
'অরণ্যে':'JJS','অরতি':'NN','অরথনীতিকে':'NNS','অরদণ্ড':'NN','অরদল':'NN','অরন':'NN','অরপা':'NN',
'অরফানেজ':'NN','অরব':'NN','অরবিন্দ':'NN','অররিয়া':'NN','অরল্যান্ডো':'NN','অরসাত':'NN','অরহন':'NN',
'অরাজক':'JJ','অরাজকতা':'NN','অরাজকতার':'NN','অরাজগতা':'NN','অরাজনৈতিক':'NN','অরাধ্য':'JJ','অরি':'NN',
'অরিআকন্ধ':'NN','অরিজিনাল':'NN','অরিঞ্জ':'NN','অরিত্র':'NN','অরিন্দম':'JJ','অরিপু':'NN','অরিমর্দন':'NN',
'অরিয়নিস':'NNP','অরিরাষ্ট্র':'NN','অরিল্ল':'NN','অরিষ্ট':'NN','অরিষ্টনেমী':'NN','অরিষ্টাসুর':'NN','অরিস্তুত':'JJ',
'অরিহন':'NN','অরীতি':'NN','অরুক্ষ':'JJ','অরুচি':'NN','অরুচিকর':'JJ','অরুণ-কমলদল':'NN','অরুণ':'NN',
'অরুণমল্লার':'NN','অরুণশিখা':'NN','অরুণাচলবাসী':'NN','অরুণাচলীয়':'NN','অরুণাত্মজ':'NN','অরুণাপ্রিয়া':'NN','অরুণাভ':'JJ',
'অরুণিমা':'NN','অরুণোদ':'NN','অরুণোদয়মসপ্তমী':'NN','অরুন্তুদ':'JJ','অরুন্ধতি':'NNS','অরুন্ধতী':'NN','অরুপক':'NN',
'অরুপাচার':'NN','অরুবা':'NN','অরূণাচল':'NN','অরূণ্ষিকা':'NN','অরূপতা':'NN','অরূরু':'NN','অরে':'NN',
'অরেকবার':'NN','অরোচক':'JJ','অরোড়া':'NN','অরোণ্যে':'JJS','অরোধ্য':'JJ','অরোষ':'NN','অরৌদ্র':'JJ',
'অর্ক':'NN','অর্কক্ষীর':'NN','অর্কজ':'NN','অর্কতনয়':'NN','অর্কনয়ন':'NN','অর্কপত্রা':'NN','অর্কপত্রী':'NN',
'অর্কপ্রিয়া':'NN','অর্কবৈধ':'NN','অর্কব্রত':'NN','অর্কভ':'NN','অর্কাডিয়ান':'NN','অর্কিড':'NN','অর্কেস্ট্রা':'NNP',
'অর্গল':'NN','অর্গলী':'NN','অর্গলের':'JJ','অর্গানাইজড':'VBN','অর্গানাইজেশন':'NN','অর্গ্যান':'NN','অর্ঘ':'NN',
'অর্ঘপাত্র':'NN','অর্ঘার্থ':'NN','অর্ঘ্যের':'NN','অর্চনা':'NN','অর্চিত':'JJ','অর্জণ':'NN','অর্জনকে':'VB',
'অর্জনীয়':'JJ','অর্জনে':'NN','অর্জনের':'VB','অর্জমা':'NN','অর্জিত':'NN','অর্জুন':'NN','অর্জুনায়ন':'NN',
'অর্জুনের':'NN','অর্ডার':'NN','অর্ণ':'NN','অর্থ-বর্ষ':'NN','অর্থ-ব্যঞ্জনা':'NN','অর্থ-ব্যবহার':'NN','অর্থ':'JJ',
'অর্থ':'NN','অর্থই':'VBG','অর্থও':'NN','অর্থকরী':'JJ','অর্থগত':'NN','অর্থদ':'NN','অর্থদাতা':'NN',
'অর্থনিতি':'NN','অর্থনীতি':'NN','অর্থনীতিএতেই':'NNS','অর্থনীতিকে':'NN','অর্থনীতিতে':'NN','অর্থনীতিতেও':'NN','অর্থনীতিবিদ্':'NN',
'অর্থনেতিক':'NN','অর্থনৈতিকভাবে':'NN','অর্থপিশাচ':'JJ','অর্থপূর্ণ':'JJ','অর্থপূর্নভাবে':'RB','অর্থপেডিক':'JJ','অর্থপ্রক্রিয়া':'NN',
'অর্থপ্রদানকারীকে':'NN','অর্থবছর':'NN','অর্থবছরের':'NN','অর্থবহ':'VB','অর্থবান':'NN','অর্থবিজ্ঞানী':'NN','অর্থবিদ':'NN',
'অর্থবেদ':'NN','অর্থব্যবস্থা':'NN','অর্থব্যবস্থায়':'NN','অর্থভাণ্ডার':'NN','অর্থমণ্ত্রীর':'NN','অর্থমন্ত্রণালয়কে':'NN','অর্থমন্ত্রি':'NN',
'অর্থমন্ত্রী':'NN','অর্থমন্ত্রীবাংলাদেশের':'NN','অর্থমন্ত্রীসহ':'NN','অর্থযন্ত্রী':'NN','অর্থযুক্ত':'JJ','অর্থরাজ্যমন্ত্রী':'NN','অর্থলালসা':'NN',
'অর্থলোভ':'NN','অর্থলোলুপতা':'NN','অর্থলোসুপ':'JJ','অর্থশালী':'JJ','অর্থশাস্ত্র':'NN','অর্থশাস্ত্রীয়':'JJ','অর্থশূণ্য':'JJ',
'অর্থসংকট':'NN','অর্থসংক্রান্ত':'JJ','অর্থসচিব':'NN','অর্থসমাহার':'NN','অর্থসম্পদের':'NN','অর্থহীন':'NN','অর্থাগম':'NN',
'অর্থাতরন্যাস':'NN','অর্থাত্':'RP','অর্থানুবাদ':'NN','অর্থান্তর':'NN','অর্থার্থী':'NN','অর্থালঙ্কার':'NN','অর্থাৎ':'NN',
'অর্থায়নে':'NN','অর্থিতা':'NN','অর্থে':'NN','অর্থের':'NN','অর্থোডক্স':'NNP','অর্থোপার্জন':'NN','অর্থোপিডিশিয়ন':'NN',
'অর্থোপেডিক্স':'NN','অর্থ্যাৎ':'NN','অর্থ‌নি‌তি‌তে':'NN','অর্দিত':'NN','অর্দ্ধ':'JJ','অর্ধ-নারাচ':'NN','অর্ধ':'NN',
'অর্ধগঙ্গা':'NN','অর্ধগুচ্ছ':'NN','অর্ধগোলাকার':'JJ','অর্ধচন্দ্র':'NN','অর্ধচন্দ্রিকা':'NN','অর্ধচেতন':'JJ','অর্ধচেতনা':'NN',
'অর্ধচোঙাকৃতি':'NN','অর্ধজল':'NN','অর্ধজাহ্নবী':'NN','অর্ধজ্যোতিকা':'NN','অর্ধদগ্ধ':'JJ','অর্ধদেশ':'NN','অর্ধনগ্ন':'NN',
'অর্ধনারাচ':'NN','অর্ধনারীশ্বর':'NN','অর্ধনয়ন':'NN','অর্ধপক্ক':'JJ','অর্ধপোহল':'NN','অর্ধপ্রদেশ':'NN','অর্ধবার্ষিকী':'JJ',
'অর্ধবিরাম':'NN','অর্ধবৃত্ত':'NN','অর্ধবৃত্তাকারে':'NN','অর্ধমর্দন':'NN','অর্ধমাগধী':'NN','অর্ধমাত্রা':'NN','অর্ধমুদিত':'JJ',
'অর্ধরতি':'NN','অর্ধশত':'JJ','অর্ধশতক':'NN','অর্ধশায়িত':'JJ','অর্ধশিক্ষিত':'NN','অর্ধসম':'JJ','অর্ধসমবৃত্ত':'NN',
'অর্ধসরকারী':'JJ','অর্ধসিদ্ধ':'JJ','অর্ধসেতু':'NN','অর্ধস্বচ্ছতা':'NN','অর্ধাঙ্গ':'NN','অর্ধাসন':'NN','অর্ধিক':'NN',
'অর্ধেকও':'NN','অর্ধেকের':'NN','অর্ধোদয়':'NN','অর্ন্তবর্গ':'NN','অর্ন্তবেগ':'NN','অর্পণ':'NN','অর্পণীয়':'JJ',
'অর্পিত':'VBN','অর্ফিউস':'NNP','অর্বাচিন':'NN','অর্বাচীনদের':'NN','অর্বুদ':'NNS','অর্বুদপতি':'JJ','অর্যমা':'NN',
'অর্শ':'NN','অর্শহর':'NN','অর্হণীয়':'NN','অর্হন':'NN','অল':'DT','অলংকরণ':'NN','অলংকৃত':'NN',
'অলআউট':'NN','অলওয়েজ':'NN','অলকট':'NNP','অলকপ্রভা':'NN','অলকাধিপতি':'NN','অলকানন্দা':'NNP','অলকাপতি':'NN',
'অলকেশ':'NN','অলক্তক':'NN','অলক্ষণ':'NN','অলক্ষিত':'JJ','অলখধারী':'NN','অলঙ্কণ্টকটা':'NN','অলঙ্করণ':'NN',
'অলঙ্কারপূর্ণ':'JJ','অলঙ্কারযুক্ত':'JJ','অলঙ্কারহীন':'JJ','অলঙ্কারের':'NN','অলঙ্কৃত':'VBN','অলঙ্ঘন':'NN','অলঙ্ঘনীয়':'JJ',
'অলঙ্ঘনীয়তা':'NN','অলঙ্ঘ্য':'JJ','অলজ':'NN','অলঝাইমার্স':'NN','অলপ্পুঝা':'NN','অলবর':'NNP','অলবান':'NN',
'অলব্ধ':'JJ','অলব্ধভূমিকত্ব':'NN','অলভ্য':'JJ','অলভ্যতা':'NN','অলমক':'NN','অলম্বস':'NN','অলম্বুষা':'NN',
'অলরাউন্ডার':'NN','অলরেডি':'NN','অলর্ক':'NN','অলস':'NN','অলহিষ্ণু':'JJ','অলহেরী':'NN','অলাগলাগ':'NN',
'অলাতচক্র':'NN','অলাবু':'NN','অলি':'NN','অলিকুল':'NN','অলিখিত':'JJ','অলিগলি':'NN','অলিঙ্গ':'NN',
'অলিদ':'NNP','অলিন্দ':'NN','অলিপিবদ্ধ':'JJ','অলিপ্রিয়':'NN','অলিবাগ':'NN','অলিম্পিক':'NNS','অলিম্পিয়াড':'NN',
'অলিল':'NN','অলিয়া':'NN','অলীক':'NN','অলীন':'JJ','অলুক':'NN','অলোকানন্দা':'NN','অলোপা':'NN',
'অলোলুপ':'NN','অলৌকিক':'NN','অল্টারনেটিভ':'NN','অল্প-বেশি':'JJ','অল্প-স্বল্প':'JJ','অল্প':'NNP','অল্পকাল':'NN',
'অল্পকিছু':'JJ','অল্পকেশবিশিষ্ট':'JJ','অল্পজ্ঞানী':'JJ','অল্পতা':'NN','অল্পদামে':'NN','অল্পপ্রাণ':'NN','অল্পবয়সী':'JJ',
'অল্পব্যয়':'NN','অল্পভাষিতা':'NN','অল্পভোজী':'JJ','অল্পমূল্য':'NN','অল্পসংখ্যক':'NN','অল্পসময়':'NN','অল্পস্বল্প':'JJ',
'অল্পাংশ':'NN','অল্পাহার':'NN','অল্পাহারী':'JJ','অল্পায়ু':'JJ','অল্পের':'RB','অশক্ত':'JJ','অশক্ততা':'NN',
'অশক্য':'NN','অশঙ্ক':'JJ','অশত্রু':'JJ','অশত্রুতা':'NN','অশনা':'NN','অশনীসংকেত':'NN','অশনীয়':'JJ',
'অশব্দ':'NN','অশরা':'NN','অশরীরী':'JJ','অশহায়ত্বের':'NN','অশান্ত':'NN','অশান্তি':'NN','অশান্তিপূর্ণ':'JJ',
'অশান্তিবাজ':'NN','অশালীনতা':'NN','অশাশ্বত.ক্ষণজীবী':'JJ','অশাসাবেদনীয়':'NN','অশিক্ষক':'NN','অশিক্ষিত':'NN','অশিত':'JJ',
'অশিশু':'NN','অশিষ্ট':'JJ','অশিষ্টভাবে':'RB','অশীল':'JJ','অশীলতা':'NN','অশুচি':'JJ','অশুদ্ধ':'NN',
'অশুদ্ধি':'NN','অশুভ':'NN','অশুভলক্ষণ':'NN','অশুভসূচক':'JJ','অশুভ্র':'JJ','অশূন্যশয়নদ্বিতীয়া':'NN','অশেষ':'NN',
'অশোক নগর':'NN','অশোক':'NN','অশোকপুষ্পমঞ্জরী':'NN','অশোকষষ্ঠী':'NN','অশোকস্তম্ভ':'JJ','অশোকাষ্টমী':'NN','অশোকের':'NNP',
'অশোধিত':'JJ','অশোভন':'NN','অশোভনীয়':'JJ','অশৌচ':'NN','অশ্কাবাদ':'NN','অশ্ব-যান':'NN','অশ্ব-রথ':'NN',
'অশ্বকর্ণ':'NN','অশ্বক্রান্তা':'NN','অশ্বগতি':'NN','অশ্বগন্ধা':'NN','অশ্বগ্রীব':'NN','অশ্বডিম্বে':'NN','অশ্বতর':'NN',
'অশ্বত্থমূল':'NN','অশ্বথামা':'NN','অশ্বদংশ':'NN','অশ্বপতি':'NN','অশ্বপালক':'NN','অশ্ববদন':'NN','অশ্ববন্ধন':'NN',
'অশ্ববাহিনী':'NN','অশ্বমুখ':'NN','অশ্বমেধীয়':'JJ','অশ্বযান':'NN','অশ্বরক্ষ':'NN','অশ্বরক্ষার':'NN','অশ্বরথ':'NN',
'অশ্বললিত':'NN','অশ্বশক্তি':'NN','অশ্বশাল':'NN','অশ্বশিরা':'NN','অশ্বশুক্ত':'NN','অশ্বস্তন':'NN','অশ্বহীন':'JJ',
'অশ্বাধ্যক্ষ':'NN','অশ্বাবতারী':'NN','অশ্বারোহণ':'NN','অশ্বিন':'NN','অশ্বিনীকুমার':'NN','অশ্বিনের':'NN','অশ্বেত':'NN',
'অশ্বেতাঙ্গ':'JJ','অশ্ম':'NN','অশ্মকুট':'NN','অশ্মন্তক':'NN','অশ্মভেদ':'NN','অশ্রদ্ধা':'NN','অশ্রদ্ধেয়':'JJ',
'অশ্রপ':'NN','অশ্রবণীয়':'JJ','অশ্রাব্য':'JJ','অশ্রী':'NN','অশ্রু':'NNS','অশ্রুকণা':'NN','অশ্রুপাত':'VB',
'অশ্রুপূর্ণ':'RB','অশ্রুরহিত':'JJ','অশ্রূধারা':'NN','অশ্রেষ্ঠ':'JJ','অশ্লীল':'NN','অশ্লেষা':'NN','অশ্লেষানক্ষত্রে':'NN',
'অষুধ':'NN','অষ্ট-ধাতু':'NN','অষ্ট':'NN','অষ্টআশিতম':'JJ','অষ্টক':'NN','অষ্টকা':'NN','অষ্টকূলজাত':'JJ',
'অষ্টকোণ':'NN','অষ্টগন্ধ':'NN','অষ্টচক্র':'NN','অষ্টছাপ':'NN','অষ্টতারিণী':'NN','অষ্টদল':'NN','অষ্টদলবিশিষ্ট':'JJ',
'অষ্টদ্রব্য':'NN','অষ্টধাতু':'NN','অষ্টপদী':'NN','অষ্টবংশ':'NN','অষ্টবর্গ':'NN','অষ্টভাব':'NN','অষ্টভুজ':'JJ',
'অষ্টভূজ':'NN','অষ্টভূজাস্ত্রী':'JJ','অষ্টম':'NN','অষ্টমবার':'RB','অষ্টমান':'NN','অষ্টমী':'NN','অষ্টসিদ্ধি':'NN',
'অষ্টাকপাল':'NN','অষ্টাক্ষরী':'NN','অষ্টাঙ্গ':'NN','অষ্টাদশ':'NN','অষ্টাধ্যায়ী':'NN','অষ্টাপদ':'NN','অষ্টাবক্র':'NN',
'অষ্টি':'NN','অষ্ট্যাধ্যায়ী':'JJ','অষ্ট্রেলিয়া':'NN','অষ্ঠীলা':'NN','অসংক্রামক':'JJ','অসংখ্য':'NN','অসংগ':'JJ',
'অসংগত':'JJ','অসংগতি':'NN','অসংগতিপূর্ণ':'JJ','অসংগতী':'NN','অসংপ্রজ্ঞাতসমাধী':'NN','অসংবদ্ধ':'JJ','অসংবধা':'NN',
'অসংযত':'JJ','অসংযম':'NN','অসংযমী':'JJ','অসংযুক্ত':'JJ','অসংযোগ':'NN','অসংযোজিত':'JJ','অসংলগ্ন':'NN',
'অসংশোধিত':'JJ','অসংশ্লিষ্ট':'JJ','অসংসদীয়':'JJ','অসংসর্গ':'NN','অসংস়ৃষ্ট':'JJ','অসংস্কৃত':'JJ','অসংহত':'NN',
'অসকন্না':'NN','অসগ্ন':'NN','অসঘন':'JJ','অসঙ্গ':'NN','অসঙ্গত':'JJ','অসঙ্গততা':'NN','অসচেতন':'NN',
'অসচেতনভাবে':'NN','অসঞ্চয়ী':'JJ','অসঢিয়া':'NN','অসততার':'NN','অসত্প্রতিগ্রাহী':'JJ','অসত্য':'NN','অসত্যবাদ':'NN',
'অসত্যের':'NN','অসদ':'JJ','অসদাচরন':'NN','অসদুপযোগ':'NN','অসদুপায়':'NN','অসদ্':'JJ','অসদ্ভাব':'NN',
'অসনা':'NN','অসন্তুষ্ট':'VBN','অসন্তুষ্টি':'NN','অসন্তুষ্টিকর':'JJ','অসন্তোষ':'NN','অসন্তোষজনক':'NN','অসন্তোষপ্রদ':'JJ',
'অসন্তোস':'NN','অসন্দিগ্ধ':'JJ','অসন্মান':'NN','অসফল':'NN','অসবরগ':'NN','অসভ্য':'JJ','অসভ্যতা':'NN',
'অসভ্যভাবে':'RB','অসম':'NN','অসমঞ্জ':'NN','অসমতল':'NN','অসমবর্তিত':'JJ','অসমর্থ':'JJ','অসমসত্ত্বা':'NN',
'অসমসাহসী':'NN','অসমাধিত':'JJ','অসমান':'NN','অসমাপ্ত':'NN','অসমাপ্য':'JJ','অসমাবৃত্ত':'JJ','অসমিয়া':'NN',
'অসমীয়াদের':'NN','অসমৃদ্ধিপ্রদ':'JJ','অসম্পর্ক':'NN','অসম্পূর্ণ':'RB','অসম্পূর্ণতার':'NN','অসম্ভব':'NN','অসম্ভবতা':'NN',
'অসম্ভার':'NN','অসম্ভাষ্য':'JJ','অসম্মত':'NN','অসম্মান':'NN','অসম্মানিত':'JJ','অসময়':'RB','অসর':'NN',
'অসর্তকতা':'NN','অসহনশীল':'JJ','অসহনশীলতা':'NN','অসহনীয়':'JJ','অসহমত':'VB','অসহযোগ':'NN','অসহযোগী':'NN',
'অসহায়':'NN','অসহায়তাকে':'NN','অসহায়তাপ্রাপ্ত':'JJ','অসহায়ত্ব':'NN','অসহিষ্ণু':'JJ','অসহিষ্ণুতা':'NN','অসহ্য':'NN',
'অসাংবিধানিক':'JJ','অসাক্ষী':'NN','অসাড়':'JJ','অসাঢ়া':'NN','অসাত্ম্য':'NN','অসাধারণ':'NN','অসাধারন':'NN',
'অসাধু':'NN','অসাধ্য':'NN','অসাধয়ারণ':'NN','অসানী':'NN','অসাবধাণতা':'NN','অসাবধান':'JJ','অসাবধানতঃ':'RB',
'অসামঞ্জস্য':'NN','অসামঞ্জস্যপূর্ণ':'JJ','অসামরিক':'NN','অসামর্থ্য':'NN','অসামাজিক':'NN','অসামান্য':'NN','অসামি':'NN',
'অসাম্প্রদায়িক':'JJ','অসার':'NN','অসারতা':'JJ','অসি':'NN','অসিত':'NN','অসিদ্ধ':'JJ','অসিদ্ধতা':'NN',
'অসিধারী':'JJ','অসিন্তাগ':'NN','অসিপত্র-বন':'NN','অসিরা':'NN','অসিলোমা':'NN','অসী':'NN','অসীমকৃষ্ণ':'NN',
'অসীমরাশি':'NN','অসীমাঙ্কিত':'JJ','অসুখ':'NN','অসুখের':'NN','অসুদপায়':'NN','অসুনসিয়ান':'NN','অসুন্দর':'NN',
'অসুবিধা':'NN','অসুবিধায়':'NN','অসুবিধে':'NN','অসুর':'NN','অসুরকুমার':'NN','অসুরক্ষিত':'NN','অসুরবধ':'NN',
'অসুরমায়া':'NN','অসুরসংহার':'NN','অসুরসেন':'NN','অসুরাচার্য':'NN','অসুরী':'NN','অসুস্থ':'JJ','অসুস্থতা':'NN',
'অসুস্থতায়':'NN','অসুস্হ':'NN','অসুস্হম্যাডাম':'NN','অসুয়া':'NN','অসূর্যপশ্যা':'NN','অসূর্যম্পশ্যা':'JJ','অসূয়া':'NN',
'অসূয়াহীনভাবে':'RB','অসেবনীয়':'JJ','অসেব্য':'JJ','অসৈনা':'NN','অসোম':'NN','অসৌজন্য':'NN','অস্কাবাদ':'NN',
'অস্কারের':'NN','অস্খাবাদ':'NN','অস্টিওপোরোসিস':'NN','অস্টেলিয়া':'NN','অস্টেলিয়ার':'NN','অস্ট্রালোপিথেকাস':'NNP','অস্ট্রিয়া':'NN',
'অস্ট্রিয়াবাসী':'NN','অস্ট্রিয়ার':'JJ','অস্ট্রেলা':'NN','অস্ট্রেলিয়া':'NN','অস্ট্রেলিয়া':'NN','অস্ট্রেলীয়':'JJ','অস্ত':'NN',
'অস্তগত':'JJ','অস্তগামী':'NN','অস্তমান':'NN','অস্তর':'NN','অস্তাচল':'NN','অস্তি':'NN','অস্তিত্ত্ববিহীন':'JJ',
'অস্তিত্ব':'NN','অস্তিত্ববাদ':'NN','অস্তিত্বমূল':'JJ','অস্তিত্বহীন':'NN','অস্তিত্বের':'NN','অস্তুত':'JJ','অস্তুতি':'NN',
'অস্ত্র-শস্ত্র':'NN','অস্ত্র':'NNS','অস্ত্রকার':'NN','অস্ত্রচালক':'JJ','অস্ত্রচিকিতসক':'NN','অস্ত্রজীবি':'NN','অস্ত্রধারী':'NN',
'অস্ত্রবিদ্':'NN','অস্ত্রবিরতি':'NN','অস্ত্রবেদ':'NN','অস্ত্রভান্ডার':'NN','অস্ত্রশস্ত্র':'NNS','অস্ত্রশস্ত্রসহ':'NN','অস্ত্রশালা':'NN',
'অস্ত্রসজ্জিতবাহন':'NN','অস্ত্রহীন':'NN','অস্ত্রাগার':'NN','অস্ত্রালয়':'NN','অস্ত্রের':'NN','অস্ত্রোপচারক':'NN','অস্থাবর':'JJ',
'অস্থায়ীত্ব':'NN','অস্থি-নির্মিত':'JJ','অস্থি':'NN','অস্থিকুন্ড':'NN','অস্থিতন্ত্র':'NN','অস্থিতিশীল':'NN','অস্থিনির্মিত':'JJ',
'অস্থিপঞ্জর':'NN','অস্থিবন্ধনী':'NN','অস্থিভঙ্গ':'NN','অস্থিমালা':'NN','অস্থিময়':'JJ','অস্থিরচিত্ত':'JJ','অস্থিরচিত্ততা':'NN',
'অস্থিরতার':'NN','অস্থিসঞ্চয়':'NN','অস্থিসন্ধি':'NN','অস্থিহার':'NN','অস্থিহীন':'JJ','অস্নিগ্ধদারু':'NN','অস্নেহ':'NN',
'অস্পর্শিত':'JJ','অস্পষ্ট':'NN','অস্পষ্টতঃ':'RB','অস্পষ্টতা':'NN','অস্পৃশ্য':'NN','অস্বচ্ছ':'NN','অস্বচ্ছলতায়':'NN',
'অস্বত্তিকর':'JJ','অস্বস্তি':'NN','অস্বস্তিকর':'JJ','অস্বাক্ষরিত':'JJ','অস্বাদ':'NN','অস্বাভাবিক':'JJ','অস্বার্থ':'JJ',
'অস্বাস্থ্য':'NN','অস্বাস্হ্যকর':'JJ','অস্বীকার':'NN','অস্বীকারকারী':'JJ','অস্বীকৃত':'VBN','অস্বীকৃতি':'NN','অস্মত':'NN',
'অস্মিত':'JJ','অস্মিতা':'NN','অস্হায়ী':'JJ','অসৎ':'NN','অহ':'NN','অহংকার':'NN','অহংকারশূণ্য':'JJ',
'অহংকারী':'JJ','অহংবোধ':'NN','অহংমত্যতা':'NN','অহঙ্কার':'NN','অহদী':'NN','অহদীখানা':'NN','অহমিকা':'NN',
'অহম্পূর্বিকা':'NN','অহরণীয়':'JJ','অহরদার':'NN','অহরহ':'RB','অহর্গণ':'NN','অহল্য':'JJ','অহল্যা':'NN',
'অহার্য':'JJ','অহি':'NN','অহিংস':'JJ','অহিংসবাদ':'NN','অহিংসা':'NN','অহিংস্র':'JJ','অহিক':'NNS',
'অহিক্ষেত্র':'NN','অহিগন্ধা':'NN','অহিত':'NN','অহিনগু':'NN','অহিবর':'NN','অহিমেধ':'NN','অহিরাবণ':'NN',
'অহির্বুঘ্ন':'NN','অহীর':'NN','অহেতু':'NN','অহেতুক':'RB','অহেরি':'NN','অহোরা-বহোরা':'NN','অহ্ণ':'NN',
'অুকরণীয়':'NN','অ্যডমিনিস্ট্রেশান':'NN','অ্যাকর্ড':'NN','অ্যাকশন':'NN','অ্যাকসিডেন্ট':'NN','অ্যাকসিডেন্টের':'NN','অ্যাকসেস':'NN',
'অ্যাকাউন্ট':'NN','অ্যাকাউন্টেন্ট':'NN','অ্যাকাডেমি':'NN','অ্যাকাডেমিশিয়ান':'NN','অ্যাকুয়ারিয়াম':'NN','অ্যাক্ট':'NN','অ্যাক্টিভিটি':'NN',
'অ্যাঙ্গেল':'NN','অ্যাঞ্জিওপ্লাস্টি':'NN','অ্যাটকিন্স':'NN','অ্যাটম':'NN','অ্যাটমিক':'JJ','অ্যাটর্নি':'NN','অ্যাটলান্টিক':'NN',
'অ্যাটলাস':'NN','অ্যাটলেটিকো':'NN','অ্যাটাকিং':'NN','অ্যাড':'NN','অ্যাডমিনিস্ট্রশান':'NN','অ্যাডমিরাল':'NN','অ্যাডরেস':'NN',
'অ্যাডলফ':'NN','অ্যাড্রিনাল':'NN','অ্যাড্রেস':'NN','অ্যাণ্টিস্টেরিলিটি':'NN','অ্যাণ্টিহিমোরেহিজক':'NN','অ্যাথলিট':'NN','অ্যাথলেটিক্স':'NN',
'অ্যানালগ':'NN','অ্যানিমিক':'NN','অ্যানিমেশন':'NN','অ্যানেস্থিসিয়া':'NN','অ্যান্টার্কটিকা':'NN','অ্যান্টি':'NN','অ্যান্টিগুয়া-বাসী':'NN',
'অ্যান্টিগুয়াবাসী':'NN','অ্যান্টিনা':'NN','অ্যান্টিসেপ্টিক':'NN','অ্যান্টেনা':'NN','অ্যান্ডি':'NN','অ্যান্ড্রু':'NN','অ্যান্তোনিও':'NN',
'অ্যাপ':'NN','অ্যাপটার':'NN','অ্যাপভিত্তিক':'NN','অ্যাপল':'NN','অ্যাপার্টমেন্ট':'NN','অ্যাপিল':'NN','অ্যাপেন্ডিক্স':'NN',
'অ্যাপের':'NN','অ্যাপোলো':'NN','অ্যাবাকাস':'NN','অ্যাভারেজ':'NN','অ্যাভিটামিনোসিস':'NN','অ্যামাইটল':'NN','অ্যামিবা':'NN',
'অ্যামেরিকাতে':'NN','অ্যামোনিয়া':'NN','অ্যাম্পিয়ার':'NN','অ্যাম্পুল':'NN','অ্যাম্প্লিফিকেশন':'NN','অ্যাম্ফিথিয়েটার':'NN','অ্যাম্বাস্যাডর':'NN',
'অ্যাম্বুলেন্স':'NN','অ্যারন':'NN','অ্যারামকোর':'NN','অ্যালকাটেল':'NN','অ্যালজীরিয়া':'NN','অ্যালবাম':'NN','অ্যালার্ম':'NN',
'অ্যালায়েন্স':'NN','অ্যালুমিনিয়াম':'NN','অ্যাশট্রে':'NN','অ্যাশোশিয়েশান':'NN','অ্যাসাঞ্জ':'NN','অ্যাসিড-খোদাই':'JJ','অ্যাসিড':'NN',
'অ্যাসিসটেন্ট':'NN','অ্যাসিস্ট্যান্ট':'NN','অ্যাসেজ':'NN','অ্যাসোসিয়েশন':'NNP','অ্যাস্থামা':'NN','অয়ঃশূল':'NN','অয়ন':'NN',
'অয়নসংক্রম':'NN','অয়নসম্পাত':'NN','অয়নাংশ':'NN','অয়নান্ত':'NN','অয়েলপেন্ট':'NN','অয়েলফেয়ার':'NN','অয়োভুজ':'NN',
'অয়োমুখ':'NN','অয়োস্কাম':'JJ','অ‌তিসম্প্র‌তি':'NN','অ‌নেক':'NN','অ‌ভিনন্দন':'NN','অ‌ারেক‌টি':'NN','আ':'NN',
'আঁক':'VB','আঁকড়া':'NN','আঁকরে':'NN','আঁকল':'NN','আঁকশি':'NN','আঁকা':'NN','আঁকাবাঁকা':'JJ',
'আঁকার':'NN','আঁকিয়েরা':'NN','আঁকু':'NN','আঁকড়ানো':'NNV','আঁকড়ে':'NN','আঁখ':'NN','আঁখের':'NN',
'আঁচ':'NN','আঁচল':'NN','আঁচানো':'NN','আঁচিয়ে':'VB','আঁজলা':'NN','আঁট':'NN','আঁটসাঁট':'NN',
'আঁটি':'NN','আঁড়ই':'NN','আঁতর':'NN','আঁতাত':'NN','আঁতুরঘর':'NN','আঁতুড়':'NN','আঁতে':'NN',
'আঁতেলগুলো':'NN','আঁধা':'NN','আঁধারে':'NN','আঁশ':'NN','আঁশযুক্ত':'JJ','আঁসুঢাল':'NN','আঁহা':'NN',
'আংকেল':'NN','আংগলাংগ':'NN','আংগুল':'NN','আংটা':'NN','আংটিটার':'NN','আংশিক':'RB','আংশিকগ্রহণ':'NN',
'আঃ':'UH','আঃলীগ':'NN','আঃলীগারদের':'NN','আই.':'FW','আই':'NN','আইইউটি':'NN','আইএএস':'NN',
'আইএফআইসি':'NN','আইএমএফ':'NN','আইএলও':'NN','আইএস':'NN','আইএসপিরাই':'NN','আইওয়াশ':'NN','আইকন':'NN',
'আইগত':'NN','আইচ':'NN','আইছে':'NN','আইজাক':'NNP','আইজোল':'NN','আইজ্যাক':'NN','আইট':'NN',
'আইটিসেকটরের':'NN','আইডি':'NN','আইডিয়ালিস্ট':'NNP','আইড্রপ':'NN','আইণ':'NN','আইন':'NN','আইনআনুগ':'NN',
'আইনও':'NN','আইনকানুন':'NNS','আইনকানুনের':'NN','আইনগত':'NN','আইনগুলিও':'NN','আইনজীবি':'NN','আইনজীবী':'NN',
'আইনজীবীরা':'NNS','আইনজ্ঞ':'NN','আইনটা':'NN','আইনত':'RB','আইননিপীড়িত':'NN','আইনপ্রয়গকারীদের':'NN','আইনশৃংখলা':'NN',
'আইনশৃঙ্খলার':'NN','আইনসম্মত':'JJ','আইনসিদ্ধশুধু':'RB','আইনস্টাইনের':'NN','আইনানুগ':'JJ','আইনাবন্দি':'NN','আইনি':'NN',
'আইনিব্যবস্থা':'NN','আইনী':'JJ','আইনে':'NN','আইনের':'NN','আইপি':'NN','আইপিএলএ':'NN','আইপিএস':'NN',
'আইপ্যাড':'NN','আইফেল':'NN','আইফোনের':'NN','আইফোন':'NN','আইবাঁধে':'NNP','আইবিআরডি':'NN','আইবুড়ো':'NN',
'আইভরি':'NN','আইলাইনার':'NN','আইলে':'NN','আইলো':'NN','আইল্যাণ্ড-এর':'NNP','আইল্যান্ড':'NN','আইসক্রিম':'NN',
'আইসল্যান্ড':'NN','আইসল্যান্ডিক':'NN','আইসিআইসিআই':'NN','আইসিউ':'NN','আইসিএবি':'NN','আইসিসি':'NN','আইসিসির':'NN',
'আইসোটোপ':'NN','আইয়াশি':'NN','আউট':'IN','আউটডোর':'NN','আউটসোর্সিং':'NN','আউটে':'IN','আউটের':'NN',
'আউন্স':'NN','আউপুট':'NN','আউলা':'NN','আউস':'NN','আউয়াল':'NN','আএ':'NN','আওআমীলীগ':'NN',
'আওড়ানো':'VB','আওতা':'NN','আওতাতে':'IN','আওতাভুক্ত':'VBN','আওতামুক্ত':'NN','আওতার':'NN','আওতায়':'IN',
'আওমিলিগকে':'NN','আওমীলীগের':'NN','আওয়াজটা':'NN','আওয়ামী':'NN','আওয়ামীলীগও':'NN','আওয়ামে':'NN','আওলাপাত্তি':'NN',
'আও্যামীলীগের':'NN','আওয়তায়':'NN','আওয়াজও':'NN','আওয়াঝ':'NN','আওয়ামি':'NN','আওয়ামিলিগ':'NN','আওয়ামিলিগের':'NN',
'আওয়ামিলীগও':'NN','আওয়ামিলীগের':'NN','আওয়ামীগ':'NN','আওয়ামীবিরোধীদের':'NNS','আওয়ামীরা':'NN','আওয়ামীরাজনীতি':'NNS','আওয়ামীলগের':'NN',
'আওয়ামীলীগ':'NN','আওয়ামীলীগককে':'NN','আওয়ামীলীগার':'NN','আওয়ামীলীগারদের':'NNS','আওয়ামীলীগে':'NN','আওয়ামীলেী‌গের':'NN','আওয়ার':'NN',
'আওয়ারে':'NN','আওয়ালী':'NN','আওয়াসী':'NN','আক':'NN','আকংশ':'NN','আকচার':'NN','আকটু':'NNP',
'আকতার':'NN','আকন্দের':'NN','আকবকের':'NN','আকবরনামা':'NN','আকবরপুর':'NN','আকবরি':'JJ','আকবরী':'NNP',
'আকবে':'NN','আকম্পন':'NN','আকর':'NN','আকরভাষা':'NN','আকরাম':'NN','আকরিক':'NN','আকর্ণ-ধনুরাসন':'NN',
'আকর্ণ':'RB','আকর্ণধনুরাসন':'NN','আকর্শনের':'NN','আকর্ষক':'NN','আকর্ষণশক্তি':'NN','আকর্ষণী':'NN','আকর্ষণীয়':'VBG',
'আকর্ষণীয়':'NN','আকর্ষণের':'NN','আকর্ষিক':'JJ','আকর্ষিত':'NN','আকলন-পক্ষ':'NN','আকলন':'NN','আকল্প':'NN',
'আকশি':'NN','আকস্মিক-তহবিল':'NN','আকস্মিক':'RB','আকস্মিত':'NN','আকাংখা':'NN','আকাঙ্ক্ষা':'NN','আকাঙ্ক্ষাহীন':'JJ',
'আকাঙ্খা':'NN','আকাট':'NN','আকামের':'NN','আকারগুপ্তি':'NN','আকারবিহীন':'JJ','আকারযুক্ত':'NN','আকারান্ত':'JJ',
'আকারে':'NN','আকারের':'VBN','আকাল-পীড়িত':'JJ','আকাশ-ছোঁয়া':'JJ','আকাশ-নিদ্রা':'NN','আকাশ-বৃত্তি':'NN','আকাশ':'NN',
'আকাশকক্ষ':'NN','আকাশকুসুম':'NN','আকাশগঙ্গা':'NN','আকাশচর':'JJ','আকাশছোঁয়া':'JJ','আকাশছোঁয়া':'VB','আকাশছোয়া':'JJ',
'আকাশনিদ্রা':'NN','আকাশপানে':'NN','আকাশপুষ্প':'NN','আকাশবচন':'NN','আকাশবাণী':'NN','আকাশবৃত্তি':'NN','আকাশভাষিত':'NN',
'আকাশভেদী':'JJ','আকাশমুখী':'NN','আকাশীয়':'JJ','আকাশে':'NN','আকিজের':'NN','আকিঞ্চনে':'NN','আকিনো':'NNP',
'আকুঞ্চনীয়':'JJ','আকুতি':'NN','আকুব':'NN','আকুল':'JJ','আকুলতা':'NN','আকৃতি':'NN','আকৃতিগত':'JJ',
'আকৃতিবিজ্ঞান':'NN','আকৃতিবিহীন':'JJ','আকৃষ্ট':'VBN','আক্কাছ':'NN','আক্কাদো-':'NNP','আক্কামেনিদীয়':'JJ','আক্কালবার':'NN',
'আক্কেল':'NN','আক্তার':'NN','আক্বাছ':'NN','আক্রন্দ':'NN','আক্রমক':'JJ','আক্রমণ':'NN','আক্রমণকারিরা':'NN',
'আক্রমণাত্মক':'JJ','আক্রমণীয়':'JJ','আক্রমণে':'NN','আক্রমন':'NN','আক্রমনাত্মক':'JJ','আক্রমিতা':'NN','আক্রান্ত':'NN',
'আক্রান্তদের':'VBN','আক্রান্তা':'NN','আক্রুর':'NN','আক্রোশ':'NN','আক্ষিপ্ত':'JJ','আক্ষেপ':'VB','আক্ষেপক':'NN',
'আক্সিকাঁথা':'NN','আকড়ে':'NN','আখ':'NN','আখড়া':'NN','আখফোড়টিড্ডা':'NN','আখরোট':'NN','আখাড়া':'NN',
'আখের':'NN','আখ্যা':'NN','আখ্যাত':'JJ','আখ্যান':'NN','আখ্যায়':'NN','আখ্যায়িত':'VBN','আখ্যায়িকা':'NN',
'আখড়া':'NN','আখড়ায়':'NN','আগ':'JJ','আগটায়':'NN','আগড়বাগড়':'NN','আগড়ম':'VB','আগড়া':'NN',
'আগডুম':'NN','আগত':'NN','আগতপতিকা':'NN','আগন্তুক':'NN','আগপিছ':'NN','আগফানিস্তানের':'NNP','আগম':'NN',
'আগমনা':'NN','আগমনে':'NN','আগমপতিকা':'NN','আগমবিদ্যা':'NN','আগমুহূর্তে':'NN','আগর':'NN','আগরতলা':'NN',
'আগল':'NN','আগলে':'JJ','আগষ্ট':'NNP','আগস্ট':'NNP','আগস্টের':'NNP','আগা':'NN','আগাছায়':'NNS',
'আগানো':'VBN','আগাবে':'NN','আগাম':'NN','আগামিতে':'JJ','আগামী':'JJ','আগামীকাল':'NN','আগামীতে':'NN',
'আগামীতেও':'JJ','আগারেবাগাড়ে':'NN','আগালেও':'JJ','আগায়':'NN','আগা‌মি':'NN','আগিবর্ত':'NN','আগিয়া':'NN',
'আগিয়ে':'RB','আগুণ':'NN','আগুনকলামিষ্টভাই':'NN','আগুনকে':'NN','আগুনশালা':'NN','আগুনে':'NN','আগুপিছু':'NN',
'আগুয়ান':'RB','আগে-আগে':'RB','আগে':'IN','আগেইরাবিস':'NNP','আগেও':'NN','আগেকার':'JJ','আগেরটা':'NN',
'আগেরদিন':'RB','আগেলা':'NN','আগোহী':'NN','আগ্নীধ্র':'NN','আগ্নেয়':'NN','আগ্নেয়গিরি-পর্বত':'NN','আগ্নেয়গিরি':'NN',
'আগ্নেয়পর্বত':'NN','আগ্নেয়শিলা':'NN','আগ্নেয়াস্ত্র':'NN','আগ্রহ':'NN','আগ্রহপূর্বক':'RB','আগ্রহী':'JJ','আগ্রহের':'JJS',
'আগ্রা':'NN','আগ্রার':'NNP','আগ্রাসনে':'NN','আগ্রাসী':'JJ','আগ্রয়ণ':'NN','আঘাট':'NN','আঘাতও':'NN',
'আঘাতকারী':'JJ','আঘাতপ্রাপ্ত':'JJ','আঘাতে':'NN','আঘাতের':'NNS','আঘার':'NN','আঘী':'NN','আঘ্রাণ':'NN',
'আঙট':'NN','আঙুর':'NN','আঙুরসম':'JJ','আঙুরের':'NN','আঙুল':'NN','আঙুলফোঁড়া':'NN','আঙুলে':'NN',
'আঙ্কিক':'JJ','আঙ্কোড়':'NN','আঙ্গট':'NN','আঙ্গলাঙ্গ':'NN','আঙ্গস্ট্রাম':'NN','আঙ্গামী':'NN','আঙ্গিক':'JJ',
'আঙ্গিকে':'NN','আঙ্গিরস':'NN','আঙ্গিরার':'JJ','আঙ্গীক':'NN','আঙ্গুঠ':'NN','আঙ্গুল':'NN','আঙ্গুলের':'NNS',
'আঙ্গোট':'NN','আঙ্গোলার':'JJ','আঙ্গৌরিয়া':'NN','আচকান':'NN','আচছা':'RB','আচণ্ডাল':'NN','আচমকা':'RB',
'আচমন':'NN','আচমনর':'JJ','আচরণ':'NN','আচরণকে':'NNP','আচরণসমূহ':'NN','আচরণীয়':'JJ','আচরণে':'NNP',
'আচরণের':'NN','আচরন':'NN','আচরনতো':'NN','আচরনবিধির':'NN','আচরনের':'NN','আচরিত':'NN','আচরে':'NN',
'আচর্য্য':'NNP','আচার-ব্যবহার':'NN','আচার':'NN','আচারবান':'JJ','আচারশাস্ত্র':'NN','আচারী':'NN','আচার্যতা':'NN',
'আচার্যা':'NN','আচার্য্যকে':'NNP','আচার্য্যের':'JJ','আচার্য্যেরা':'NN','আচি':'RB','আচিক':'JJ','আচিত':'NN',
'আচিরেই':'RB','আচে':'NN','আচ্চার':'NN','আচ্ছক':'NN','আচ্ছন্ন':'NN','আচ্ছা':'RB','আচ্ছাদক':'NN',
'আচ্ছাদনযুক্ত':'JJ','আচ্ছাদনীয়':'JJ','আচ্ছাদিত':'NN','আচ্ছাদ্য':'JJ','আছ':'NN','আছছেন':'VBG','আছড়ানো':'VB',
'আছাড়':'NN','আছার':'VB','আছি':'RB','আছিলো':'NN','আছে':'VB','আছেই':'UH','আছেএকজন':'NN',
'আছেএখনো':'NN','আছেএমবিএস':'NN','আছেকড়াই':'NNS','আছেজানতে':'NN','আছেঝামেলা':'JJ','আছেতাহলে':'NN','আছেদয়া':'NN',
'আছেন':'PR','আছেনকল':'NNS','আছেনতাঁদের':'NN','আছেনা':'DT','আছেপয়সা':'NN','আছেযা':'UH','আছেসে':'UH',
'আছেসেসব':'NN','আছোলা':'JJ','আছ্':'VB','আজ':'NN','আজও':'NN','আজকাল':'RB','আজকে':'NN',
'আজকেই':'RB','আজকের':'NN','আজগুবি':'JJ','আজন্ম':'JJ','আজব':'NN','আজম':'NN','আজমগড়':'NN',
'আজমত':'NN','আজমীড়':'NN','আজমীড়ের':'JJ','আজমীর':'NN','আজরবেজান':'NN','আজরবেজানি':'NN','আজরাইলের':'NN',
'আজাদ':'NN','আজাদের':'NNP','আজান':'NN','আজানুলম্বিত':'JJ','আজানেয়':'NN','আজাব':'NN','আজাবটা':'JJ',
'আজারবৈজানি':'NN','আজিজ':'NN','আজিজরা':'NN','আজিব':'JJ','আজিবন':'NN','আজিম':'NN','আজীজ':'NN',
'আজীবন':'NN','আজুবা':'NN','আজে-বাজে':'JJ','আজে':'NN','আজেরবৈজানী':'JJ','আজেরি':'NN','আজো':'NN',
'আজ্ঞপ্ত':'JJ','আজ্ঞপ্তি':'NN','আজ্ঞলিক':'JJ','আজ্ঞা':'NN','আজ্ঞাকর্তা':'JJ','আজ্ঞাচক্র':'NN','আজ্ঞানুগমন':'NN',
'আজ্ঞানুগামী':'JJ','আজ্ঞানুসরণ':'NN','আজ্ঞানুসার':'RB','আজ্ঞাপত্র':'NN','আজ্ঞাপালক':'JJ','আজ্ঞাপালন':'NN','আজ্ঞাপূর্বক':'RB',
'আজ্ঞাবহ':'JJ','আজ্ঞাভঙ্গ':'NN','আজ্ঞায়':'JJ','আজ্ঞে':'NN','আজ্যপা':'NN','আজ্যাদোহ':'NN','আজ্যাস্থালি':'NN',
'আজয়':'NNP','আঞ্চলিক':'NN','আঞ্ছর':'NN','আঞ্জনি':'NN','আট':'CD','আটক':'JJ','আটকা':'VBN',
'আটকাতে':'NN','আটকানো.':'NN','আটকানো':'VBN','আটকানোর':'NN','আটকাবে':'VB','আটকামো':'JJ','আটকালে':'RP',
'আটকায়':'NN','আটকে':'NN','আটকেছে':'NN','আটকৌড়ে':'NN','আটখানা':'CD','আটগুণ':'NNS','আটগূন':'NN',
'আটচল্লিশ':'NN','আটচল্লিশতম':'JJ','আটজন':'CD','আটটা':'CD','আটটায়':'NN','আটটি':'JJ','আটঠা':'NN',
'আটত্রিশ':'NN','আটত্রিশতম':'JJ','আটদিনব্যাপী':'JJ','আটপাল্লাইয়া':'JJ','আটবার':'JJ','আটবারের':'NN','আটরাশির':'NN',
'আটলান্টিক':'NN','আটষট্টি':'NN','আটষট্টিতম':'JJ','আটা':'NN','আটাত্তর':'NN','আটাত্তরতম':'JJ','আটানব্বই':'NN',
'আটানব্বইতম':'JJ','আটানো':'VB','আটান্ন':'NN','আটান্নতম':'JJ','আটাশে':'JJ','আটিজানের':'NN','আটেক':'JJ',
'আট্টোপ':'NN','আঠকে':'NN','আঠা':'NN','আঠারো':'NN','আঠারোতম':'JJ','আঠাল':'JJ','আঠাশ':'NN',
'আঠাশতম':'JJ','আঠোয়ারি':'NN','আঠৌরী':'NN','আড়':'NN','আড়ক':'NN','আড়গীর':'NN','আড়তের':'JJ',
'আড়মোড়া':'VB','আড়মোরা':'NN','আড়ম্বরপূর্ণ':'NN','আড়ষ্ট':'JJ','আড়া-খেমটা':'NN','আড়া-চৌতাল':'NN','আড়া-ঠেকা':'NN',
'আড়া-ত্যাড়া':'JJ','আড়া-পঞ্চতাল':'NN','আড়া':'NN','আড়াআড়ি':'NN','আড়াই':'NN','আড়াইশো':'JJ','আড়াইয়ের':'NN',
'আড়াকস':'NN','আড়ানা':'NN','আড়ি':'NN','আডাইশো':'VBN','আডি':'NN','আড্ডা':'NN','আড্ডাতে':'NN',
'আড্রিয়াটিক':'NN','আঢক':'NN','আঢ়িয়া':'NN','আঢাকা':'JJ','আঢ্যঙ্কর':'JJ','আণবিক':'NN','আণূমানিক':'NN',
'আণ্টার্কটিকার':'NNP','আতংকিত':'VBD','আতংকে':'JJ','আতংকের':'NN','আতঙ্ক':'NN','আতঙ্ককর':'JJ','আতঙ্কগ্রস্ত':'VB',
'আতঙ্কপূর্ণ':'JJ','আতঙ্কপূর্বক':'RB','আতঙ্কবাদী':'NN','আতঙ্কিত':'VBD','আতডি':'NN','আততায়ী':'NN','আততায়ী':'JJ',
'আতপ':'NN','আতর':'NN','আতরদান':'NN','আতর্গল':'NN','আতশ':'NN','আতশবাজি':'NN','আতশি':'JJ',
'আতসবাজি':'NN','আতা':'NN','আতাপি':'NN','আতাসন্দেশ':'NN','আতি':'NN','আতিথেয়তা':'NN','আতিথ্য':'NN',
'আতিথ্যপূর্ণ':'JJ','আতিপাতি':'NN','আতিবাহিক':'NN','আতিশয্য':'NN','আতুর':'NN','আতুরসন্যাস':'NN','আতেল':'NN',
'আত্তারি':'NN','আত্তীয়':'NN','আত্ন':'NN','আত্নসন্মান':'JJ','আত্নীয়':'NNS','আত্নীয়স্বজনারা':'NN','আত্ব':'NN',
'আত্বহত্যা':'NN','আত্ম':'NN','আত্মঅহমিকায়':'NN','আত্মকথন':'NN','আত্মকথামূলক':'JJ','আত্মকেন্দ্রিক':'JJ','আত্মক্ষমতা':'NN',
'আত্মগৌরব':'NN','আত্মঘাতক':'JJ','আত্মচরিত':'NN','আত্মজ':'NN','আত্মজিজ্ঞাসা':'NN','আত্মজীবনী':'NN','আত্মজীবনীমূলক':'JJ',
'আত্মজ্ঞ':'NN','আত্মজ্ঞানী':'NN','আত্মতত্ত্ব':'NN','আত্মতুষ্ট':'JJ','আত্মতুষ্টি':'NN','আত্মতৃপ্ত':'JJ','আত্মতৃপ্তি':'NN',
'আত্মত্যাগ':'NN','আত্মত্যাগী':'JJ','আত্মদর্শন':'NN','আত্মদান':'NN','আত্মদীপিত':'JJ','আত্মদ্রষ্টা':'NN','আত্মদ্রোহী':'JJ',
'আত্মনিবেদন':'NN','আত্মনিরীক্ষণ':'NN','আত্মনির্ভর':'JJ','আত্মনির্ভরতা':'NN','আত্মনিয়ন্ত্রণ':'NN','আত্মনিয়োগ':'NN','আত্মনেপদ':'NN',
'আত্মন্নোতি':'NN','আত্মপক্ষ':'VB','আত্মপক্ষীয়':'JJ','আত্মপরিত্যাগ':'NN','আত্মপ্রকাশ':'NN','আত্মপ্রবোধ':'NN','আত্মপ্রশংসা':'NN',
'আত্মবলি':'NN','আত্মবাহিক':'JJ','আত্মবিকাশ':'NN','আত্মবিজ্ঞান':'NN','আত্মবিশ্বাসী':'JJ','আত্মবিশ্বাসের':'NN','আত্মবিসর্জনকারী':'JJ',
'আত্মবৈশিষ্ট':'NN','আত্মবোধ':'NN','আত্মভূ':'NN','আত্মভোগের':'NN','আত্মমগ্ন':'JJ','আত্মমর্যাদা':'NN','আত্মমর্যাদাসম্পন্ন':'JJ',
'আত্মম্ভীর':'NN','আত্মরক্ষা':'NN','আত্মরক্ষার্তে':'NN','আত্মলাভের':'NN','আত্মশক্তি':'NN','আত্মশ্লাঘা':'NN','আত্মসংবেদন':'NN',
'আত্মসমর্থন':'NN','আত্মসমর্পণকারি':'NN','আত্মসমালোচনা':'NN','আত্মসমীক্ষা':'NN','আত্মসম্মানবোধ':'NN','আত্মসাক্ষাত্কার':'NN','আত্মসাত':'NN',
'আত্মসাত্':'NN','আত্মস্থ':'NN','আত্মহত্যা':'NN','আত্মহত্যার':'NN','আত্মহননের':'IN','আত্মা':'NN','আত্মানুভূতি':'NN',
'আত্মানুশাসন':'NN','আত্মাবলম্বী':'JJ','আত্মাবোধ':'NN','আত্মাভিমানজনিত':'JJ','আত্মার':'NN','আত্মাহারা':'VB','আত্মাহুতি':'NN',
'আত্মিক':'JJ','আত্মিয়':'NN','আত্মীয়-কুটুম্বদের':'NN','আত্মীয়':'NN','আত্মীয়তাবোধ':'NN','আত্মীয়স্বজনের':'NN','আত্মোত্সর্গ':'NN',
'আত্রমণ':'NN','আত্রেয়':'NN','আথর্বণ':'NN','আথিতেয়ত':'NN','আদপে':'NN','আদম':'NN','আদমচশ্ম':'NN',
'আদমজাত':'NN','আদমী':'JJ','আদমীর':'NN','আদমে':'NN','আদর':'NN','আদরণীয়া':'JJ','আদরে-বিগড়ানো':'JJ',
'আদরে':'NN','আদরের':'RB','আদর্শ':'NN','আদর্শগত':'NN','আদর্শবাদ':'NN','আদর্শে':'NN','আদলে':'NN',
'আদা':'NN','আদান-প্রদান':'NN','আদানি':'NN','আদাবেপারি':'NNP','আদায়':'NN','আদার':'NN','আদালত':'NN',
'আদালতসম্বন্ধীয়':'JJ','আদালতি':'JJ','আদালতে':'NN','আদালতের':'JJ','আদায়':'NN','আদায়কারি':'NN','আদায়কৃত':'VBN',
'আদায়ীকৃত':'JJ','আদায়ে':'NN','আদায়ের':'VB','আদি':'NN','আদিঅন্তকাল':'NN','আদিকবি':'NN','আদিকর্তা':'NN',
'আদিগ্রন্থ':'NN','আদিতে':'RB','আদিত্য':'NN','আদিনাথ':'NN','আদিপর্বের':'NN','আদিবাসি':'NN','আদিবাসীদের':'NN',
'আদিবিপুলা':'NN','আদিম':'NN','আদিমানব':'NN','আদিয়ার':'NN','আদিরস':'NN','আদিল':'NN','আদিলাবাদ':'NN',
'আদিষ্ট':'JJ','আদিস':'NN','আদুর':'NN','আদুরে':'JJ','আদুল':'JJ','আদৃত':'JJ','আদেশ':'NN',
'আদেশক':'JJ','আদেশদাতা':'JJ','আদেশনামা':'NN','আদেশপূর্বক':'RB','আদেশপ্রাপ্ত':'JJ','আদেশানুসার':'RB','আদেশে':'NN',
'আদেষ্টা':'JJ','আদেয়':'JJ','আদেয়কর্ম':'NN','আদো':'NN','আদৌ':'NN','আদ্দি':'NN','আদ্ধা':'NN',
'আদ্যক্ষর':'JJ','আদ্যন্ত':'JJ','আদ্যপান্তই':'NN','আদ্যপ্রান্ত':'VBG','আদ্যা':'NN','আদ্যান্ত':'JJ','আদ্যাশক্তি':'NN',
'আদ্যোপান্ত':'RB','আদ্রক':'NN','আদ্রানক্ষত্র':'NN','আদ্রাশনি':'NN','আধ':'NN','আধকপালি':'NN','আধকাঁচা':'JJ',
'আধখোলা':'JJ','আধখ্যাচড়া':'JJ','আধগলা':'JJ','আধঘণ্টা':'NN','আধটা':'JJ','আধটু':'NN','আধপাকা':'NN',
'আধপেষা':'JJ','আধপোড়া':'JJ','আধবোজা':'JJ','আধমরা':'JJ','আধশোয়া':'JJ','আধসিদ্ধ':'JJ','আধসেরের':'NN',
'আধা-খাজনা':'NN','আধা':'JJ','আধাঙ্গা':'NN','আধাত্মিক':'NN','আধাত্মিকতা':'NN','আধাত্ম্যবাদ':'NN','আধানা':'NN',
'আধার':'NN','আধারহীন':'JJ','আধারিত':'NN','আধারে':'NN','আধাসরকারী':'JJ','আধায়':'NN','আধিকার':'NNS',
'আধিকারিক':'NN','আধিকারিকবর্গ':'NN','আধিকারীক':'NN','আধিক্য':'NN','আধিদৈবিক':'JJ','আধিপত্য':'NN','আধিভোগ':'NN',
'আধিভৌতিক':'JJ','আধিয়া':'NN','আধুনকি':'JJ','আধুনিকতম':'JJ','আধুনিকতা':'NN','আধুনিকমনস্ক':'NN','আধুনিকরণ':'NN',
'আধুলি':'NN','আধেয়':'NN','আধো':'VB','আধোয়ারি':'NN','আধ্যত্মিক':'JJ','আধ্যাত্ম-বিদ্যা':'NN','আধ্যাত্মজ্ঞ':'NN',
'আধ্যাত্মিকতা':'NN','আনইনষ্টল':'NN','আনওয়াঁসা':'NN','আনওয়ার':'NNP','আনক':'NN','আনকোরা':'JJ','আনছে':'VBG',
'আনজান':'NN','আনটু':'NNP','আনত':'NN','আনতুলে':'VB','আনতে':'NN','আনতোষিকা':'NN','আনদোলনের':'NN',
'আনদ্ধ':'NN','আনদ্ধবাদ্য':'NN','আনন':'NN','আনন্ত্য':'NN','আনন্দ-ঘন':'JJ','আনন্দ':'NN','আনন্দচিত্তে':'RB',
'আনন্দদা':'NNP','আনন্দদায়ক':'JJ','আনন্দপূর্ণ':'JJ','আনন্দপ্রদ':'NN','আনন্দবাজার':'NN','আনন্দভৈরব':'NN','আনন্দমত্তা':'NN',
'আনন্দময়':'JJ','আনন্দসম্মোহিতা':'NN','আনন্দিত':'NN','আনন্দে':'NN','আনন্দোজ্জ্বল':'JJ','আনফা':'NN','আনবে':'VBG',
'আনবেন':'NN','আনবো':'NN','আনমনা':'NN','আনর্ত':'NN','আনল':'NNP','আনলাম':'VB','আনলিমিটেড':'VBN',
'আনলে':'NN','আনলেন':'VB','আনসান':'NN','আনসাবস্ক্রাইব':'NN','আনসারিকে':'NNP','আনা':'VB','আনাই':'NN',
'আনাইপাঠাই':'NN','আনাও':'VB','আনাচে':'NN','আনাচেকানাচে':'NN','আনাজ':'NN','আনাটা':'NNS','আনাড়ি':'NN',
'আনাড়ী':'NN','আনাতোলিয়া':'NNP','আনানো':'VBN','আনাম':'JJ','আনামী':'JJ','আনার':'VBG','আনারদানা':'NN',
'আনারস':'NN','আনারসি':'JJ','আনারসের':'NN','আনারী':'NN','আনাসতাশিয়া':'NN','আনাহত':'JJ','আনি':'NNP',
'আনিশা':'NN','আনিস':'NN','আনীত':'JJ','আনু':'CD','আনুক':'NN','আনুকূল্য':'NN','আনুগত্য':'NN',
'আনুতোষিক':'NN','আনুন':'NN','আনুপাতিক':'NN','আনুবংশিক':'NN','আনুভূমিক':'NN','আনুশাসনিক':'JJ','আনুষঙ্গিক':'NN',
'আনুষ্ঠানিক':'JJ','আনুষ্ঠানিকতা':'NN','আনুষ্ঠানিকভাবে':'VBP','আনৃশংস্য':'NN','আনে':'NN','আনেনা':'NN','আনোয়ার':'NN',
'আনোয়ারা':'NN','আন্টার্টিক':'NN','আন্ডা':'NN','আন্ডারওয়ার্ল্ড':'NN','আন্ডারগ্রউন্ড':'JJ','আন্ডারগ্রাউন্ডে':'IN','আন্ডারটেকিং':'NN',
'আন্ডাররেটেড':'VBN','আন্ত':'JJ','আন্তঃতলীয়':'JJ','আন্তঃশারীরিক':'NN','আন্তজাতিক':'NNP','আন্তজেলা':'NN','আন্তর':'JJ',
'আন্তরস্থল':'NN','আন্তরিক':'NN','আন্তরিকতায়':'NN','আন্তরের':'NN','আন্তর্জাতিক':'NN','আন্তর্জাতিকভাবে':'NN','আন্তর্বিষুববর্ষ':'NN',
'আন্তে':'NN','আন্তোনিও':'NN','আন্ত্র':'NN','আন্ত্রিক':'NN','আন্ত্রীয়':'JJ','আন্দলন':'NN','আন্দলনে':'NN',
'আন্দা':'NN','আন্দাজে':'NN','আন্দাবিল':'NN','আন্দামান':'NN','আন্দামানি':'JJ','আন্দামানিজ':'NN','আন্দালিব':'NN',
'আন্দালিবধিক':'NN','আন্দালিবরুপম':'NN','আন্দালিবের':'NN','আন্দালিব্দের':'NN','আন্দালীব':'NN','আন্দিজ':'NN','আন্দিল':'NNP',
'আন্দু':'NN','আন্দোলনতো':'NN','আন্দোলনকারি':'NN','আন্দোলনকারীদের':'NN','আন্দোলনকে':'NN','আন্দোলনটা':'NN','আন্দোলনমুখী':'NN',
'আন্দোলনের':'NN','আন্দোলোনে':'NN','আন্দ্রোমাক':'NN','আন্ধা':'NN','আন্নামালাই':'NN','আনয়ন':'NN','আপ-টু-ডেট':'NN',
'আপ':'NN','আপডেট':'NN','আপণ':'NN','আপতকালীন':'NN','আপতন':'NN','আপত্কাল':'NN','আপত্তি':'NN',
'আপত্তিকর':'JJ','আপদ':'NN','আপদকালীন':'JJ','আপদটা':'NN','আপদে':'NN','আপন':'NN','আপনজনের':'PR',
'আপনদের':'NN','আপনরা':'NN','আপনা':'PR','আপনাকে':'NN','আপনাকেও':'NN','আপনাদের':'PR','আপনাদেরই':'NN',
'আপনাদেরও':'NN','আপনার':'PR','আপনারা':'PR','আপনাা':'NN','আপনা‌কে':'NN','আপনি':'PR','আপনিই':'NN',
'আপনিতো':'NN','আপনে':'NN','আপবাদ':'NN','আপমানকর':'NN','আপষে':'NN','আপস':'NN','আপসহীন':'JJ',
'আপসোস':'NN','আপস্তন্ব':'JJ','আপস্তম্ব':'NN','আপা':'NN','আপাত-সম্পর্কশূন্য':'JJ','আপাত-সামান্য':'JJ','আপাত':'NN',
'আপাতকালিন':'NN','আপাতত':'RB','আপাতদৃষ্টিতে':'NN','আপাতনিরাপত্তা':'NN','আপাদমস্তক':'JJ','আপাদমস্তস্ক':'NN','আপান':'NN',
'আপানারাত':'NN','আপামর':'NN','আপা২০১৯':'NN','আপিল':'NN','আপু':'NN','আপূষ':'NN','আপেক্ষমান':'NN',
'আপেক্ষিকতা':'NN','আপেল':'NN','আপোর':'NN','আপোষ':'NN','আপোষহীনা':'NN','আপ্':'NN','আপ্ত':'JJ',
'আপ্নার':'NN','আপ্পম':'NN','আপ্লাবন':'NN','আপ্লুত':'NN','আফগান':'NN','আফগানি':'NN','আফগানিস্তানকে':'NN',
'আফগানিস্তানের':'NN','আফগানিস্থান':'NNP','আফগানিস্থানের':'NN','আফগানী':'NN','আফজাল':'NN','আফটার':'NN','আফতাবা':'NN',
'আফতাবী':'NN','আফরিদ':'NN','আফশোষ':'NN','আফসন্তিন':'NN','আফসোস':'NN','আফসোস':'VB','আফসোসে':'NN',
'আফিং':'NN','আফিম':'NN','আফিমবিজ':'NN','আফিমি':'JJ','আফিমের':'NN','আফ্রিকা-বাসী':'NN','আফ্রিকান':'NN',
'আফ্রিকাবাসী':'NN','আফ্রিকার':'NNP','আফ্রিকায়':'NN','আফ্রিকীয়':'NN','আব':'NN','আবকারি':'NN','আবগারি':'NN',
'আবজাল':'NN','আবত্সারক্ষ':'NN','আবদধো':'NN','আবদুল':'NN','আবদ্ধ':'NN','আবনীর':'NNP','আবন্টন':'NN',
'আবর':'NN','আবরণ':'NN','আবরণশক্তি':'NN','আবরণহীণ':'JJ','আবরণে':'NN','আবরন':'NN','আবরী':'NN',
'আবরো':'NN','আবর্জনা':'NN','আবর্ত':'NN','আবর্তক':'JJ','আবর্তণ':'NN','আবর্তনীয়':'JJ','আবর্তমণি':'NN',
'আবর্তিত':'VBG','আবর্ত্ত':'NN','আবলি':'NN','আবলুস':'NN','আবলুসী':'JJ','আবশ্যক':'RB','আবশ্যকতা':'NNS',
'আবশ্যিক':'JJ','আবসার':'NN','আবহনীয়':'NN','আবহাওয়ায়':'NN','আবহাওয়াবিজ্ঞান':'NN','আবহাওয়ার':'NN','আবহে':'NN',
'আবাদ':'VBG','আবাদকার':'NN','আবাদী':'NN','আবাবা':'NN','আবাম':'NN','আবারও':'NN','আবারো':'NN',
'আবাল':'NN','আবাসন':'NN','আবাসস্থল':'NN','আবাসহীন':'NN','আবাসিক':'NN','আবাসিত':'JJ','আবাসের':'NN',
'আবাহন':'NN','আবিদ্ধ':'NN','আবির':'NN','আবিরের':'JJ','আবির্ভাব':'NN','আবির্ভাবের':'NN','আবির্ভূত':'JJ',
'আবির্হোত্র':'NN','আবিষ্করণ':'NN','আবিষ্কার':'NN','আবিষ্কারকের':'NN','আবিষ্কারপ্রবণ':'JJ','আবিষ্কারে':'NN','আবিষ্কৃত':'JJ',
'আবিসিনিয়া':'NN','আবিস্কার':'NN','আবী':'NN','আবু':'NN','আবৃত':'VBN','আবৃত্তি':'NN','আবেগ':'NN',
'আবেগপ্রবণ':'NN','আবেগময়':'NN','আবেগাপ্লুত':'NN','আবেগী':'NN','আবেগের':'NN','আবেদক':'NN','আবেদন-পত্র':'NN',
'আবেদন':'NN','আবেদনকারী':'NN','আবেদনীয়':'JJ','আবেদনে':'NN','আবেদিন':'NN','আবেদ্য':'JJ','আবেবা':'NN',
'আবেশ':'NN','আবেশপূর্ণ':'JJ','আবেশিত':'JJ','আবেশে':'NN','আবেস্তা':'NN','আবোল':'NN','আবোল':'NN',
'আবোলতাবোল':'NN','আবোহাওয়ার':'NN','আবোয়োকুটা':'NN','আব্দার':'NN','আব্দুল':'NN','আব্বা':'NN','আব্বাস':'NN',
'আব্বুদ':'NNP','আব্রাহাম':'NN','আভা':'NN','আভামণ্ডল':'NN','আভার':'NN','আভাস':'NNS','আভাহীন':'JJ',
'আভিজাত্য':'NN','আভিজাত্যপূর্ণ':'JJ','আভিজাত্যে':'NN','আভিধানিক':'NN','আভিরি':'NN','আভির্বাবটাই':'NN','আভীর':'NN',
'আভীরী':'NN','আভূষণ':'NN','আভূষিত':'JJ','আভোগ':'NN','আভ্যন্তরিন':'NN','আভ্যন্তরীণভাবে':'NN','আভ্যুদায়িক':'JJ',
'আভ্যুদয়িক':'NN','আম':'NN','আমখাস':'NN','আমগাছে':'NN','আমগোতো':'NN','আমচুর':'NN','আমজনতা':'NN',
'আমজনতার':'NN','আমড়া':'NN','আমণ্ত্রণ':'NN','আমদাদেরকে':'NN','আমদানি-রপ্তানি':'NN','আমদানি':'NN','আমদানিকারক':'NN',
'আমদানিতে':'NN','আমদানী':'NN','আমদানীকারী':'NN','আমদানীকৃত':'JJ','আমদানীর':'NN','আমদের':'NN','আমন':'NN',
'আমন্ত্রণ':'NN','আমন্ত্রনে':'NN','আমন্ত্রিত':'VBN','আমন্ত্রয়িতা':'NN','আমবন':'NN','আমবাত':'NN','আমমোক্তারনামা':'NN',
'আমরণ':'RB','আমরস':'NN','আমরসের':'JJ','আমরা':'PR','আমরাও':'PR','আমরাতো':'NN','আমর্ষ':'NN',
'আমল':'NN','আমলকি':'NN','আমলকীর':'NN','আমলন':'NN','আমলাও':'NN','আমলাকল্যাণ':'NN','আমলাতন্ত্র':'NN',
'আমলাতান্ত্রিক':'NN','আমলাদের':'NN','আমলারা':'NN','আমলে':'NN','আমলেইতো':'NN','আমলেও':'NN','আমশি':'NN',
'আমসত্ত্ব':'NN','আমসি':'NN','আমস্টার্ডাম':'NN','আমহারিক':'JJ','আমহেরিক':'NN','আমা':'NN','আমাকে':'PR',
'আমাগো':'PR','আমাজন':'NN','আমাজীর্ণ':'NN','আমাদানি':'NN','আমাদের':'PR','আমাদেরও':'PR','আমাদেরকেও':'PR',
'আমাদেরতো':'PR','আমান':'NN','আমানতও':'NN','আমানতককারীদের':'NN','আমানতকারী':'NN','আমানতগুলো':'NN','আমানতজনিত':'NNS',
'আমানতদার':'NN','আমানতপ্রবাহ':'NN','আমানতী':'JJ','আমানতে':'NN','আমানা':'NN','আমানুর':'NN','আমাবট':'NN',
'আমামা':'NN','আমার':'PR','আমারঅনেক':'NN','আমারই':'PR','আমারতাই':'PR','আমারা':'PR','আমারিকান':'NN',
'আমারিকার':'NNP','আমারে':'PR','আমালনামা':'NN','আমাশা':'NN','আমাসা':'NN','আমাহ':'NN','আমায়':'PR',
'আমা‌দের':'PR','আমি':'PR','আমিও':'PR','আমিক্ষা':'NN','আমিতো':'PR','আমিন':'NN','আমিনপূনজন্মে':'NN',
'আমিনী':'NN','আমিনের':'NN','আমির':'PR','আমিরজাদা':'NN','আমিরতের':'NN','আমিরাতে':'NNS','আমিরী':'NN',
'আমিল':'NN','আমিলিয়াপাট':'NN','আমিষ':'NN','আমিষহারী':'JJ','আমিষাশী':'NN','আমিষাহার':'NN','আমী':'NN',
'আমীন':'NNS','আমীনের':'NN','আমুদে':'JJ','আমুরা':'NN','আমুল':'NN','আমূল':'JJ','আমৃত্যু':'NN',
'আমে':'NN','আমেদ':'NNP','আমেদাবাদ':'NN','আমেনেমহেট':'NNP','আমের':'NN','আমেরিকাই':'NNP','আমেরিকাও':'NN',
'আমেরিকাকে':'NNP','আমেরিকাতে':'NN','আমেরিকানরা':'NN','আমেরিকার':'NNP','আমেরিকায়':'NN','আমেরিকীয়':'JJ','আমেরিসিয়াম':'NN',
'আমেরীকি':'NN','আমোদ-প্রমোদ':'NN','আমোদ':'NN','আমোদিত':'JJ','আমোরিকার':'NNP','আম্নায়':'NN','আম্পায়ারদের':'NN',
'আম্পায়ারিং':'VBG','আম্পায়ার':'NN','আম্পায়ারকে':'NN','আম্পায়ারদেরই':'NN','আম্পায়ারিং':'NN','আম্পায়ারে':'NN','আম্পয়ায়ারা':'NN',
'আম্বর':'NN','আম্বানিদের':'NN','আম্বার':'NNP','আম্বাসা':'NN','আম্বিকেয়':'NN','আম্বেদকর':'NN','আম্বেদকার':'NN',
'আম্ম':'NN','আম্মাজী':'NN','আম্মি':'NN','আম্রকূট':'NN','আম্রপালী':'NN','আম্লান':'JJ','আম্লিক':'JJ',
'আম্লিকতা':'NN','আম্লিগের':'NN','আম‍ার':'NN','আয়':'NN','আয়ারল্যান্ড':'NN','আর-টু':'NN','আর.':'NNP',
'আর.এন.এ':'NNP','আর':'CC','আরএসএস':'NN','আরও':'RBR','আরক':'NN','আরকজনের':'NN','আরকি':'NN',
'আরকোল':'NN','আরক্ষক':'NN','আরক্ষা':'NN','আরগ্য':'NN','আরজেন্টিনা':'NNP','আরজেন্টিনার':'NNP','আরটিই':'NN',
'আরণ্য':'JJ','আরণ্যক':'NN','আরতি':'NN','আরনাল':'NN','আরব':'NN','আরবআমিরাতের':'NN','আরবদের':'NNP',
'আরবপতি':'NN','আরববাসী':'NN','আরবরা':'NNS','আরবি':'NNP','আরবিআই':'NN','আরবিস্তান':'NN','আরবী':'NN',
'আরবীর':'NNP','আরবে':'NN','আরবের':'NN','আরভটি':'NN','আরমেনিয়':'JJ','আরমেনিয়ান':'NN','আরম্ভ':'VBN',
'আরম্ভক':'JJ','আরম্ভে':'RB','আরম্ভের':'NNP','আরশি':'NN','আরশোলা':'NN','আরসিবি':'NN','আরা':'NN',
'আরাকান':'NN','আরাধনা':'NN','আরাধনাকারী':'JJ','আরাধ্য':'JJ','আরাফাতের':'NN','আরাবল্লী':'NN','আরাম':'NN',
'আরামকেদারা':'NN','আরামছে':'NN','আরামদায়ক':'JJ','আরামদায়ক':'NN','আরামপ্রিয়':'JJ','আরামপ্রিয়তা':'NN','আরামবাগ':'NNP',
'আরামবাগের':'NN','আরামসে':'NN','আরামেই':'NN','আরাস্ত':'NN','আরি':'NN','আরিফুলকে':'JJ','আরিয়া':'NN',
'আরী':'NN','আরুক':'NN','আরুঢ়যৌবনা':'NN','আরুণি':'NN','আরুণেয়োপনিষদ':'NN','আরূঢ়':'JJ','আরে!':'VB',
'আরে':'NN','আরেকজন':'DT','আরেকজনে':'DT','আরেকটা':'DT','আরেকটার':'NN','আরেকটি':'DT','আরেকটু':'RB',
'আরেকবার':'NN','আরেখ':'NN','আরেপের':'NN','আরো':'RBR','আরোহন':'NN','আরো':'RBR','আরোই':'CD',
'আরোও':'NN','আরোগ্য':'NN','আরোধক':'JJ','আরোপ':'VB','আরোপক':'JJ','আরোপণ':'NN','আরোপিত':'JJ',
'আরোপের':'NN','আরোপ্য':'JJ','আরোহ':'NN','আরোহক':'JJ','আরোহণ':'NN','আরোহনের':'NN','আরোহিত':'JJ',
'আরোহী':'NN','আর্ক':'NN','আর্কিটেক্চার':'NN','আর্কিমিডিস':'NNP','আর্কেটিক':'NN','আর্গন':'NN','আর্গুমেন্ট':'NN',
'আর্চ':'NN','আর্জি':'NN','আর্জুমন্দ':'NN','আর্জেটিনার':'NN','আর্জেনটিনার':'NNP','আর্জেন্টাইন':'NNP','আর্জেন্টিনা':'NN',
'আর্জেন্টিনাবাসী':'NN','আর্জেন্টিনার':'JJ','আর্জেন্টিনারি':'NNP','আর্জেন্টিনিয়ান':'NN','আর্জেন্টিনীয়':'JJ','আর্জেস':'NNS','আর্ট':'NN',
'আর্টিকুলেটেড':'NN','আর্টিকেল':'NN','আর্টিজান':'NNP','আর্টিফিসিয়াল':'JJ','আর্টিস্ট':'NN','আর্টিস্টরাও':'NNS','আর্ত-পীড়িতের':'NN',
'আর্ত':'JJ','আর্তনাদ':'NN','আর্তমানুষ':'NN','আর্তস্বর':'NN','আর্তি':'NN','আর্থ':'NN','আর্থনীতি':'NN',
'আর্থনৈতিক':'JJ','আর্থার':'NNP','আর্থিক':'NN','আর্দালী':'NN','আর্দ্র':'NN','আর্ধা':'NN','আর্নলড':'NNP',
'আর্ন্ত-জাতীয়':'NN','আর্ন্তজাতিক':'NNP','আর্বিয়াম':'NN','আর্মড':'JJ','আর্মি':'NN','আর্মিবিমানবাহিনিতে':'NN','আর্মিরা':'NNS',
'আর্মেনিয়া':'NN','আর্য-গীতি':'NN','আর্য-পুত্র':'NN','আর্য':'NN','আর্যগীতি':'NN','আর্যজাতীয়':'JJ','আর্যপত্নী':'NN',
'আর্যভাষাতত্ত্ব':'NN','আর্যসমাজ':'NN','আর্যসমাজের':'JJ','আর্যা':'NN','আর্যাবর্ত':'NN','আর্য্য':'NNP','আর্য্যে':'NN',
'আর্ষ-প্রয়োগ':'NN','আর্ষ':'NN','আর্ষকর্ম':'NN','আর্ষপ্রণীত':'JJ','আর্ষপ্রয়োগ':'NN','আর্সিকেরে':'NN','আর্সেনাইড':'NN',
'আর্হত-দর্শন':'NN','আল':'NN','আলআরাফাহ্‌':'NN','আলকাতরা':'NN','আলকাপ':'NN','আলকাপে':'NN','আলকায়দা':'NN',
'আলকী':'NNP','আলখাল্লা':'NN','আলগগীর':'NN','আলগা':'JJ','আলগিজা':'NNP','আলগোজা':'NN','আলঙ্কারিক':'JJ',
'আলজান্ডার':'NNP','আলজিরিয়':'NN','আলজীয়ার্স':'NN','আলজেরিয়ান':'JJ','আলটেকর':'NNP','আলতা':'NN','আলন':'NN',
'আলন্দী':'NN','আলপনা':'NN','আলপিন':'NN','আলপেটু':'NN','আলফাজ':'NN','আলফাডাঙ্গার':'NN','আলফান্সো':'NN',
'আলফালফা':'NN','আলবাই':'NN','আলবাতশকে':'NN','আলবিদা':'NN','আলবেনিয়ান':'NN','আলবেনীয়':'NN','আলম':'NN',
'আলমকে':'NN','আলমগির':'NN','আলমগীরের':'NN','আলমার':'NN','আলমিরাতে':'NN','আলমীঢ়':'NN','আলমের':'NN',
'আলমোড়া':'NNS','আলম্ব':'NN','আললাহ':'NN','আলসাস':'NNP','আলসে':'VB','আলসেমি':'NN','আলসেস':'NN',
'আলস্য':'NN','আলস্যপূর্ণ':'JJ','আলস্যহীন':'JJ','আলস্যের':'NN','আলহামদুলিল্লাহ':'NN','আলাই':'NN','আলাউদ্দিন':'NN',
'আলাউদ্দীন':'NNP','আলাউদ্দীনের':'JJ','আলাঙ্গ':'NN','আলাদ':'NN','আলাদাভবিষ্যতে':'NN','আলাদাভাবে':'RB','আলান':'NN',
'আলাপচারিতার':'NN','আলাপচারী':'JJ','আলাপনীয়':'JJ','আলাপর':'JJ','আলাপের':'NN','আলাবনী':'NN','আলাবর্ত্ত':'NN',
'আলাবাজ':'NN','আলামত':'NNS','আলামিন':'NN','আলাস্কা':'NN','আলাহিয়া':'NN','আলি':'NN','আলিগড়':'NN',
'আলিঙ্গন':'NN','আলিঙ্গিত':'JJ','আলিপুর':'RB','আলিপুরদুয়ার':'NN','আলিপুরের':'NNP','আলিমুদ্দিনে':'NN','আলিরাজপুর':'NN',
'আলিশান':'NN','আলিসনকে':'NN','আলিয়া':'NN','আলী':'NN','আলীগাররা':'NNS','আলীগের':'NN','আলীবাবা':'NN',
'আলু-বালু':'NN','আলু':'NN','আলুনি':'JJ','আলুপোড়া':'NNS','আলুবখরা':'NN','আলুর':'NN','আলেকজাণ্ডারের':'NNP',
'আলেকজান্ডারের':'NNP','আলেকজান্দ্রিয়া':'NN','আলেকজান্দ্রে':'NNP','আলেকিত':'JJ','আলেখ':'NN','আলেখ্য':'NN','আলেপন':'NN',
'আলেম':'NN','আলেসান্দ্রো':'NN','আলোচনা':'NN','আলেয়া':'NN','আলো':'NN','আলোওনা':'NN','আলোক-ভেদ্য':'JJ',
'আলোক':'NN','আলোকচিত্র':'NN','আলোকতরঙ্গের':'NN','আলোকপাত':'NN','আলোকপ্রবাহী':'JJ','আলোকবর্তিকা':'JJ','আলোকবর্ষ':'NN',
'আলোকভেদ্য':'JJ','আলোকরশ্মি':'NN','আলোকস্তম্ভ':'NN','আলোকিত':'VBN','আলোকে':'NN','আলোচ':'NN','আলোচনা':'NN',
'আলোচনাকারী':'JJ','আলোচনাত্মক':'JJ','আলোচনায়':'NN','আলোচনাসভা':'NN','আলোচিত':'JJ','আলোচ্য':'JJ','আলোড়ন':'NN',
'আলোড়নসৃষ্টিকারী':'JJ','আলোড়িত':'NN','আলোতে':'NN','আলোনিরোধক':'JJ','আলোপূর্ণ':'JJ','আলোর':'NN','আলোড়ন':'NN',
'আলোড়িত':'JJ','আলোয়':'NN','আল্জাইমার':'NN','আল্টিমেটাম':'NN','আল্পনা-শোভিত':'JJ','আল্পনা':'NN','আল্ফা':'NN',
'আল্বেসিলেস্তারা':'NN','আল্লাহ':'NN','আল্লাহই':'NNP','আল্লাহপাক':'VBG','আল্লাহর':'NN','আল্লাহ্':'NNP','আল্লায়':'NNP',
'আল্লায়ী':'NN','আল্হা':'NNP','আলয়':'NN','আশংকা':'NN','আশংকাজনক':'VBG','আশকারা':'NN','আশঙ্কা':'NN',
'আশঙ্কাজনকভাবে':'RB','আশঙ্কাপূর্ণ':'JJ','আশঙ্কাহীন':'JJ','আশঙ্কায়':'NN','আশঙ্কিত':'JJ','আশনা':'NN','আশপাশ':'NN',
'আশপাশের':'NN','আশরাফ':'NN','আশরাফরা':'NN','আশরাফুল':'JJ','আশরাফের':'NN','আশর্ফি':'NN','আশলেও':'NN',
'আশা-আকাঙ্খা':'NN','আশা-আকাঙ্খায়':'NN','আশা':'NN','আশাকরছি':'NN','আশাজনক':'JJ','আশাটা':'NN','আশাটুকু':'NN',
'আশাতীত':'JJ','আশাতেই':'RB','আশানুকূল':'JJ','আশানুরুপ':'VBN','আশানুরূপ':'JJ','আশান্বিত':'JJ','আশাপূর্ণ':'JJ',
'আশাপ্রদ':'VBG','আশাবরী':'NN','আশাবাদ':'NN','আশাবাদি':'JJ','আশাবাদী':'NN','আশাব্যঞ্জক':'JJ','আশাব্যঞ্জকভাবে':'RB',
'আশাভঙ্গের':'NN','আশাভরসার':'NN','আশায়':'RB','আশার':'NN','আশাহত':'JJ','আশায়':'RB','আশি':'NN',
'আশিতম':'JJ','আশির':'NN','আশির্বাদ':'NN','আশির্বাদপুষ্ট':'VBN','আশিষ':'NN','আশিষাক্ষেপ':'NN','আশীবিষ':'NN',
'আশীর্বাদ':'NNS','আশীর্বাদই':'NN','আশীর্বাদপুষ্ট':'VBN','আশীর্বাদি':'NN','আশীষ':'JJ','আশু':'NN','আশুকবি':'NN',
'আশুকারী':'JJ','আশুকার্য':'NN','আশুঙ্কজল':'NN','আশুতোষ':'NNP','আশুলিয়া':'NNS','আশে-পাশে':'RB','আশে':'NN',
'আশেপাশে':'RB','আশেপাশের':'NN','আশ্চর্য':'NN','আশ্চর্যচকিত':'JJ','আশ্চর্যজনক':'NN','আশ্চর্যান্বিত':'NN','আশ্চর্যের':'NN',
'আশ্চর্য্য':'JJ','আশ্চর্য্যরে':'NN','আশ্বস্ত':'NN','আশ্বাসক':'JJ','আশ্বাসনীয়':'JJ','আশ্বাসবাণী':'NN','আশ্বাসিত':'JJ',
'আশ্বাসের':'NN','আশ্বিন':'NN','আশ্বিনের':'JJ','আশ্রব':'NN','আশ্রমবাস':'NN','আশ্রমবাসী':'JJ','আশ্রয়':'NN',
'আশ্রিত':'NN','আশ্রিতা':'JJ','আশ্রেয়':'JJ','আশ্রয়':'NN','আশ্রয়দাতা':'JJ','আশ্রয়প্রশ্রয়':'NN','আশ্রয়প্রাপ্ত':'JJ',
'আশ্রয়শূণ্য':'JJ','আশ্রয়স্থল':'NN','আশ্রয়হীন':'JJ','আশ্রয়হীনতা':'NN','আশ্রয়ী':'JJ','আশ্রয়ে':'NN','আশয়':'NN',
'আষাঢ়':'NN','আষাঢ়জাত':'JJ','আষাঢ়মাস':'NN','আষাঢ়সম্বন্ধীয়':'JJ','আষাঢ়া':'NN','আষাঢ়ী':'NN','আষাঢ়ীয়':'JJ',
'আষ্টে':'RB','আষ্ফালন':'VBG','আস':'FW','আসংকাই':'NN','আসওয়ান':'NN','আসকারা':'NN','আসকে':'NN',
'আসক্ত':'VBN','আসক্তি':'NN','আসক্তিহীন':'NN','আসছ':'VB','আসছি':'VBG','আসছিলাম':'VBG','আসছে':'VB',
'আসছেনা':'VBG','আসঞ্জক':'NN','আসত':'VB','আসতরকতা':'NN','আসতাম':'VB','আসতে':'VB','আসতেই':'NNS',
'আসতেছে':'VBG','আসতেন':'VB','আসতো':'VB','আসন':'NNS','আসনটি':'NN','আসনে':'NN','আসনেও':'NN',
'আসন্ন':'NN','আসন্নপ্রসবা':'NN','আসন্নভূত':'NN','আসপারগার':'NNP','আসব':'NN','আসবন্দ':'NN','আসবাবপত্র':'NN',
'আসবার':'NNV','আসবে':'VB','আসবেএই':'VB','আসবেনা':'VB','আসবো':'VB','আসমান-খোঁচা':'NN','আসমান':'JJ',
'আসর':'NN','আসরে':'NN','আসল':'NN','আসলাম':'VB','আসলে':'RB','আসলেও':'RB','আসলো':'VB',
'আসলো':'VB','আসা':'NN','আসাওয়ারী':'NN','আসাটা':'NNV','আসাতে':'VB','আসাদুল':'NN','আসাধারণতা':'NN',
'আসাপালা':'NN','আসাম':'NN','আসামি':'VBN','আসামিদেরকে':'NN','আসামিরা':'NNS','আসামী':'NN','আসামীকে':'VBN',
'আসামীদের':'NNS','আসামীর':'NN','আসামের':'NN','আসাযাওয়া':'VB','আসার':'VB','আসারিত':'NN','আসালা':'NN',
'আসায়':'VB','আসি':'VB','আসিতেছে':'VBG','আসিনি':'VB','আসিফুর':'VB','আসিবে':'VB','আসিমভ':'NNP',
'আসিমভ্স':'NNP','আসিয়া':'VB','আসিরীয়রা':'NNP','আসিল':'VB','আসিয়া':'VB','আসিয়ান':'NN','আসীন':'VBN',
'আসু':'NN','আসুক':'VB','আসুরক্ষ্য':'JJ','আসুরিক':'JJ','আসুরী-বিবাহ':'NN','আসুরী':'NN','আসূতি':'NN',
'আসে':'VB','আসেইনি':'NN','আসেন':'NN','আসেননি':'VB','আসেনা':'NN','আসেনামনে':'NN','আসেনি':'VB',
'আসেবিবেক':'NNS','আসো':'NN','আস্কারা':'NNS','আস্কিং':'VBG','আস্চর্য':'VB','আস্ত':'NN','আস্তরণ':'NN',
'আস্তরন':'NN','আস্তাকুঁড়ে':'NN','আস্তানা':'NN','আস্তানাগুলোর':'NNS','আস্তাবল':'NN','আস্তার-পংক্তি':'NN','আস্তিক':'NN',
'আস্তিকতাবাদ':'NN','আস্তিন':'NN','আস্তে':'RB','আস্থা':'NN','আস্থাভাজন':'NN','আস্থার':'NN','আস্থাহীনতার':'NN',
'আস্থায়':'NN','আস্পদ':'NN','আস্ফারের':'NN','আস্ফালন':'VB','আস্ফালনটা':'VBG','আস্ফোট':'NN','আস্বস্ত':'JJ',
'আস্বস্থ':'VBN','আস্বাদন':'NN','আস্বাদনীয়':'JJ','আস্মারা':'NN','আস্রব':'NN','আস্রাবিত':'JJ','আস্রয়':'NN',
'আস্হা':'NN','আস্হারাখতে':'NN','আহ':'NN','আহত':'VBD','আহতদের':'VBN','আহতর':'VBD','আহব':'NN',
'আহবান':'VB','আহমদ':'NNP','আহমদনগর':'NN','আহমেদ':'NNP','আহমেদএর':'NN','আহমেদদের':'NNP','আহমেদনগর':'NN',
'আহমেদরা':'NNP','আহম্মদ':'NNP','আহরক':'NN','আহসান':'NNP','আহা':'NN','আহাএগুলো':'JJ','আহাজারি':'NNP',
'আহান':'NN','আহামরি':'NN','আহাম্মক':'NN','আহার-বিহার':'NN','আহার':'NN','আহারগ্রহণ':'NN','আহারপাক':'NN',
'আহারবিহার':'NN','আহারী':'NNS','আহারে':'NN','আহার্য্য':'NN','আহিটা':'NN','আহীরী':'NN','আহুত':'NN',
'আহুর':'NN','আহে':'NN','আহ্-আহ্':'VB','আহ্নিক':'NN','আহ্ববান':'VB','আহ্বানই':'VB','আহ্বানে':'NN',
'আহ্বায়ক':'NN','আহ্লাদিত':'JJ','আাকর্ষন':'NN','আাছি':'NN','আাজকেই':'NN','আার':'NN','আ্যাকাউন্টিং':'NN',
'আ্‌ঙ্গুল':'NNS','আড়ম্বর':'NN','আড়া':'NN','আড়াআড়ি':'NN','আড়াই':'NN','আড়ালে':'NN','আড়ালেই':'NNS',
'আড়ি':'NN','আড়িয়াল':'JJ','আয়':'NN','আয়ওতায়':'NN','আয়কর':'NN','আয়করদাতা':'NN','আয়করদিয়ে':'NN',
'আয়জন':'VBN','আয়টা':'NN','আয়ত':'NN','আয়তক্ষেত্রের':'NN','আয়তন':'NN','আয়তনে':'VB','আয়তনের':'NN',
'আয়তাকার':'NN','আয়ত্ত':'NN','আয়ত্বে':'NN','আয়না':'NN','আয়নাটির':'NN','আয়নাসাজ':'NN','আয়নায়':'NN',
'আয়ব্যয়':'NN','আয়রন':'NN','আয়সীমা':'NNP','আয়হীন':'NN','আয়া':'NN','আয়াক্সকে':'NN','আয়াত':'NNS',
'আয়ান':'NN','আয়ারল্যান্ড':'NN','আয়ারল্যান্ডীয়':'JJ','আয়ারল্যান্ডে':'NN','আয়ার্ল্যাণ্ড':'NN','আয়াস':'NN','আয়ু':'NN',
'আয়ুবর্ধক':'JJ','আয়ুর্বেদ':'NN','আয়ুষ্মান':'NN','আয়ুস্কাল':'NN','আয়ে':'NN','আয়েনউদ্দিন':'NN','আয়ের':'NN',
'আয়েশী':'JJ','আয়োজন':'VBN','আয়োগ':'NN','আয়োজক':'NN','আয়োজকরাই':'NNS','আয়োজন':'VBN','আয়োজনকারী':'NN',
'আয়োজনেই':'NN','আয়োজিত':'VBN','আয়োডিন':'NN','আয়োদ':'NN','আয়োনিত':'JJ','আ‌গের':'NN','আ‌ছে':'VBG',
'আ‌মি':'NN','ই-পত্র':'NN','ই-বা':'NNP','ই-বুক':'NN','ই-মেল':'NN','ই':'NN','ইঁট':'NN',
'ইঁটগাথা':'NN','ইঁটাই':'NN','ইঁটের':'NN','ইঁদারাদার':'NN','ইঁদুর':'NN','ইঁদুরটারও':'NN','ইঁদুরের':'NN',
'ইংকা':'NN','ইংগলিশ':'NN','ইংগিতও':'NN','ইংগিতে':'NNS','ইংরাজ':'NNP','ইংরাজী':'JJ','ইংরিজি':'NNP',
'ইংরেজ':'NN','ইংরেজদের':'NNP','ইংরেজরা':'NN','ইংরেজি':'JJ','ইংরেজিতে':'JJ','ইংরেজিয়ানা':'NN','ইংরেজী':'JJ',
'ইংরেজীতে':'JJ','ইংরেজীর':'NN','ইংলণ্ডে':'NNP','ইংলিশ':'NN','ইংলিশম্যান':'NNP','ইংলিশের':'JJ','ইংল্যাণ্ড':'NNP',
'ইংল্যাণ্ডের':'NNP','ইংল্যান্ড':'NN','ইংল্যান্ডের':'NN','ইই':'NN','ইউ':'NN','ইউএনওর':'NN','ইউএস':'NN',
'ইউএসটিসি':'NN','ইউওনো':'NN','ইউকো':'NN','ইউক্রেন':'NN','ইউক্রেনী':'NN','ইউক্লেডিস্':'NN','ইউজ':'NN',
'ইউটার্ন':'NN','ইউটিউব':'NN','ইউনাইটেড':'NN','ইউনান':'NN','ইউনিওন':'NN','ইউনিট':'NN','ইউনিটের':'NN',
'ইউনিফর্ম':'NN','ইউনিফাইড':'NN','ইউনিভারসিটি':'NN','ইউনিভার্সিটি':'NN','ইউনিয়ন':'NNP','ইউনিয়নের':'NN','ইউনিলিভার':'NN',
'ইউনিসেফ':'NN','ইউনিয়ন':'NN','ইউনিয়নের':'NN','ইউনুছ':'NN','ইউনুনকোয়াডিয়াম':'NN','ইউনুনট্রিয়াম':'NN','ইউনুনবিয়াম':'NN',
'ইউনুস':'NN','ইউনেস্কো':'NNP','ইউনেস্কোর':'NN','ইউপ':'NN','ইউপকর্ণ':'NN','ইউপাহুতি':'NN','ইউপি':'NN',
'ইউফ্রেতিস':'NNP','ইউভি':'NNP','ইউয়ান':'NN','ইউরাল':'NN','ইউরিপিদিসের':'NNP','ইউরিয়া':'NN','ইউরেনাস':'NN',
'ইউরেশিয়া':'NN','ইউরেশীয়':'JJ','ইউরো':'NN','ইউরোপিয়ান':'JJ','ইউরোপিয়াম':'NN','ইউরোপীয়':'NN','ইউরোপীয়':'JJ',
'ইউরোপীয়দের':'NN','ইউরোপের':'NN','ইউরোস্টিগ্মা':'NNP','ইউসার':'NN','ইউসিএল':'NN','ইউসিএলের':'NN','ইউসুফ':'NN',
'ইউয়ান':'NN','ইওমা':'NNP','ইওর':'NN','ইকওয়াই':'NN','ইকওয়েডর':'NN','ইকটু':'NN','ইকতারা':'NN',
'ইকপেচা':'NN','ইকবাল':'NN','ইকমার্স':'NN','ইকলাই':'NN','ইকার':'NN','ইকারান্ত':'JJ','ইকার্ডি':'NN',
'ইকাস':'NNP','ইকির':'NN','ইকুযেপমেন্ট':'NN','ইকুয়েডরীয়':'JJ','ইকেট':'NNP','ইকের':'NN','ইকেল':'NNP',
'ইকোনমিকাল':'NN','ইকোনমিষ্টের':'NN','ইকোনো':'NN','ইকোয়েটোরিয়াল':'NN','ইক্কট':'NN','ইক্যুয়াল':'JJ','ইক্ষণিক':'NN',
'ইক্ষু':'NN','ইক্ষুকাণ্ড':'NN','ইক্ষুগন্ধা':'NN','ইক্ষুজাত':'JJ','ইক্ষুদন্ড':'NN','ইক্ষুমতী':'NN','ইখরাজ':'NN',
'ইখানে':'RB','ইগনিশান':'NN','ইগো':'NN','ইঙ্গরেজের':'NN','ইঙ্গলা':'NN','ইঙ্গিত':'NN','ইঙ্গিতটা':'NN',
'ইঙ্গিনিয়াররা':'NN','ইঙ্গুদ':'NN','ইচ্চে':'NN','ইচ্ছা':'MD','ইচ্ছাই':'NN','ইচ্ছাকরে':'RB','ইচ্ছাকৃত':'NN',
'ইচ্ছাচারী':'JJ','ইচ্ছানুকুল':'RB','ইচ্ছানুযায়ী':'NN','ইচ্ছানুসারে':'RB','ইচ্ছাপত্রহীন':'JJ','ইচ্ছাপূর্ণ':'JJ','ইচ্ছাপূর্ণতা':'NN',
'ইচ্ছাপূর্বক':'RB','ইচ্ছাভেদী':'JJ','ইচ্ছাভোজন':'NN','ইচ্ছামত':'NN','ইচ্ছামতো':'RB','ইচ্ছামাফিক':'NN','ইচ্ছামূর্খ':'NN',
'ইচ্ছামৃগ':'NN','ইচ্ছার':'NN','ইচ্ছাশক্তি':'NN','ইচ্ছাহীন':'JJ','ইচ্ছাহীনতা':'NN','ইচ্ছায়':'NN','ইচ্ছু':'JJ',
'ইচ্ছুক':'NN','ইচ্ছেকৃত':'NN','ইচ্ছেটা':'NN','ইছেন':'VB','ইজ':'NN','ইজরা':'NN','ইজরান':'NN',
'ইজরায়েল':'NN','ইজাক':'NNP','ইজাফত':'NN','ইজার':'NN','ইজারাদার':'NN','ইজারাদারী':'NN','ইজি':'NN',
'ইজের':'NN','ইজ্জত':'NN','ইজ্জতদার':'JJ','ইঞ্চমনোতি':'NN','ইঞ্জিন':'NN','ইঞ্জিনিয়ারকে':'NN','ইঞ্জিনিয়ারিং':'VBG',
'ইঞ্জিনিয়ারের':'NN','ইঞ্জেকশন':'NN','ইঞ্জেক্ট':'NN','ইঞ্জেনিইয়ারিংযের':'NN','ইট':'NN','ইটখোলা':'NN','ইটফল':'NNP',
'ইটভাটা':'NN','ইটা':'NN','ইটাই':'NNP','ইটাবা':'NN','ইটার':'NNP','ইটারবিয়াম':'NN','ইটালিক':'JJ',
'ইটালিয়ান':'NN','ইটালী':'NNP','ইটালীবাসী':'JJ','ইটালীয়':'NN','ইটিং':'NNP','ইটির':'NN','ইটিস':'NNP',
'ইটেড':'NNP','ইটের':'NN','ইট্রিয়াম':'NN','ইডবিডা':'NN','ইডলী':'NN','ইড়া-পিঙ্গলা-সুষুম্না':'NN','ইড়া':'NN',
'ইডিস':'NNP','ইডিয়ট':'NN','ইডেন':'NN','ইডেনগার্ডেন':'NN','ইডেনে':'NNP','ইণ্ট':'NNP','ইণ্টারনেট':'NN',
'ইণ্টারন্যাশানাল':'NNP','ইণ্টারপ্রেটার্স':'NNP','ইণ্টারফেস':'NN','ইণ্টারভিউ':'NN','ইণ্টারমেডিয়েট':'NNP','ইণ্টিরিয়ার':'NN','ইণ্ডাট্রিয়্যাল':'NNP',
'ইণ্ডিক':'NN','ইণ্ডিয়ান':'NNP','ইণ্ডিয়ানা':'NN','ইণ্ডিয়ার':'NN','ইতঃপূর্বে':'NN','ইতরেতরাভাব':'NN','ইতরেতাশ্রয়':'NN',
'ইতলা':'NNP','ইতস্তত':'NN','ইতস্ততঃ':'RB','ইতালিয়ান':'NN','ইতালী':'NN','ইতি':'NN','ইতিপূর্বে':'RB',
'ইতিপূর্বেও':'NN','ইতিবাচক':'NN','ইতিবৃত্ত':'NN','ইতিম':'NN','ইতিমধ্যে':'NN','ইতির':'NN','ইতিহস':'NN',
'ইতিহাসই':'NN','ইতিহাসকে':'NN','ইতিহাসবিদ':'NN','ইতিহাসবোধ':'NN','ইতিহাসের':'NN','ইতু':'NN','ইতেই':'NN',
'ইতেন':'VB','ইতোমধ্যে':'NN','ইতোমধ্যেই':'NN','ইত্তাদি':'NN','ইত্যাদিএবং':'NN','ইত্যাদির':'NN','ইত্যাদিরও':'RP',
'ইত্যাদী':'NN','ইথর':'NN','ইথানল':'NN','ইথিওপিয়া':'NN','ইথিয়োপিয়ান':'NN','ইথিয়োপিয়ার':'JJ','ইথেন':'NNP',
'ইদনিং':'NN','ইদানীং':'NN','ইদামানে':'NN','ইদারাদার':'NN','ইদিন':'RB','ইদুক্কী':'NN','ইদ্দত':'NN',
'ইদ্রাবতী':'NN','ইন':'NN','ইনঅকুলাম':'NNP','ইনকা':'NN','ইনকামও':'NN','ইনকামভেন্সি':'NN','ইনকামের':'NN',
'ইনকিউবেশন':'NN','ইনকে':'NNP','ইনক্রিমেন্ট':'NN','ইনগত':'JJ','ইনজামাম':'NN','ইনজিন':'NN','ইনজুরড':'NN',
'ইনজুরিতে':'NN','ইনজুর্ড':'NN','ইনটা':'NN','ইনটারেসট':'NNP','ইনডাইরেক্ট':'NN','ইনডেমনিটি':'NN','ইনতঃ':'RB',
'ইনফর্মেশন':'NNP','ইনফোসিস':'NN','ইনফ্রারেড':'NN','ইনফ্রাস্ট্রাকচারে':'NN','ইনফ্লুয়েঞ্জা':'NN','ইনভলব':'NN','ইনভেস্ট':'NN',
'ইনভেস্টরস':'NN','ইনভয়েস':'NN','ইনরা':'NNP','ইনশা':'NN','ইনশাআল্লাহ':'NN','ইনশাললাহ':'NN','ইনশাহ্':'NN',
'ইনসার্ভিস':'NN','ইনসিওরেন্স':'NN','ইনস্টল':'NN','ইনস্টিঙ্কট':'NN','ইনস্টিটিউট':'NN','ইনস্টিটিউশনকে':'NN','ইনস্টিটিউশনের':'NNP',
'ইনস্ট্রুমেণ্টাল':'NN','ইনস্পেক্টর':'NN','ইনস্যুলেশন':'NNP','ইনাদের':'NN','ইনায়া':'NN','ইনার':'NN','ইনারু':'NN',
'ইনি':'PR','ইনিংস':'NN','ইনিংসকে':'NN','ইনিংসটা':'NN','ইনিংসেই':'NN','ইনিংসের':'NN','ইনিন':'NNP',
'ইনিষ্টিটিউট':'NN','ইনিয়াস্তাই':'NN','ইনু':'NN','ইনুওবায়দুল':'NN','ইনের':'NNP','ইনোভেশন':'NN','ইনোভেশনের':'NN',
'ইনোসিটাল':'NN','ইন্জিনিয়ারিং':'NN','ইন্জুরড':'NN','ইন্টার':'NN','ইন্টারনেটও':'NN','ইন্টারনেটের':'NN','ইন্টারন্যাশনাল':'NN',
'ইন্টারন্যাশানাল':'NNP','ইন্টারন্যাশেনাল':'NN','ইন্টারপোল':'NN','ইন্টারভিউ':'NN','ইন্টারেস্টিং':'NN','ইন্টার্নেট':'NN','ইন্টেনশনালি':'NN',
'ইন্টেলিজেন্স':'NN','ইন্ডস্ত্রি':'NN','ইন্ডাস্ট্রিকে':'NN','ইন্ডাস্ট্রির':'NN','ইন্ডাস্ট্রী':'NN','ইন্ডিজ':'NNS','ইন্ডিজকে':'NN',
'ইন্ডিয়ার':'NNP','ইন্ডিস':'NN','ইন্ডিয়াকে':'NN','ইন্ডিয়াতে':'NNP','ইন্ডিয়ান':'JJ','ইন্ডিয়ানদের':'NN','ইন্ডিয়ার':'NN',
'ইন্ডেক্সে':'NN','ইন্ড্রাসি':'NN','ইন্দও':'NN','ইন্দিজকে':'NN','ইন্দিবর':'NN','ইন্দিরাগান্ধীর':'NNP','ইন্দিরামুজিব':'NN',
'ইন্দীবর':'NN','ইন্দু-বদনা':'NN','ইন্দু':'NN','ইন্দুকর':'NN','ইন্দুপর্ণী':'NN','ইন্দুবদনা':'NN','ইন্দুমণি':'NN',
'ইন্দুরে':'NN','ইন্দো-আরিয়ান':'NNP','ইন্দো-আর্য':'NN','ইন্দো-ইউরেপীয়':'JJ','ইন্দোনেশিয়া':'NN','ইন্দোনেশিয়ার':'NN','ইন্দোনেশীয়':'JJ',
'ইন্দোনেশীয়াবাসী':'NN','ইন্দোর':'NN','ইন্দ্রকীল':'NN','ইন্দ্রকুমার':'NN','ইন্দ্রগিরি':'NN','ইন্দ্রচারুণী':'NN','ইন্দ্রজব':'NN',
'ইন্দ্রজিত্':'NN','ইন্দ্রজিত্্ও':'NNP','ইন্দ্রজিৎ':'NN','ইন্দ্রতরু':'NN','ইন্দ্রদমন':'NN','ইন্দ্রদেব':'NN','ইন্দ্রদ্যুম্ন':'NN',
'ইন্দ্রধানী':'NN','ইন্দ্রধ্বজ':'NN','ইন্দ্রপুরী':'NN','ইন্দ্রপ্রস্থ':'NN','ইন্দ্রফল':'NN','ইন্দ্রবংশা':'NN','ইন্দ্রবৃদ্ধ':'NN',
'ইন্দ্রভাষ':'NN','ইন্দ্রলুপ্ত':'NN','ইন্দ্রলোক':'NN','ইন্দ্রসভা':'NN','ইন্দ্রসেন':'NN','ইন্দ্রাণী':'NN','ইন্দ্রাশন':'NN',
'ইন্দ্রাস্ত্র':'NN','ইন্দ্রায়ণ':'NN','ইন্দ্রিয়গম্য':'JJ','ইন্দ্রিয়গ্রাহ্য':'JJ','ইন্দ্রিয়গ্রাহ্যতা':'NN','ইন্দ্রিয়জাত':'JJ','ইন্দ্রিয়জয়':'NN',
'ইন্দ্রিয়নিগ্রহ':'NN','ইন্দ্রিয়প্রবণ':'JJ','ইন্দ্রিয়বজ্রী':'NN','ইন্দ্রিয়হানি':'NN','ইন্দ্রিয়াতীত':'JJ','ইন্দ্রিয়ার্থ':'NN','ইন্দ্রিয়ের':'NN',
'ইন্দ্রীজুলাব':'NN','ইন্দ্রের':'NN','ইন্ধন':'NN','ইন্ধনে':'NN','ইন্না':'NN','ইন্নালিল্লাহি':'NN','ইন্নয়ন':'NN',
'ইন্ফেকশন':'NN','ইন্ফ্রারেড':'JJ','ইন্স':'NNP','ইন্সটিটিউট':'NN','ইন্সট্যান্ট':'NN','ইন্সপেকশনে':'NN','ইন্সপেক্টর':'NN',
'ইন্সিওরেন্সে':'NN','ইন্সুলিন':'NN','ইপার':'NNP','ইপিএস':'NN','ইপিজেড':'NN','ইপিনেফ্রিন':'NN','ইফ':'FW',
'ইফতার':'NN','ইফফাত':'NN','ইফফাতনুরুল':'NN','ইফিগেনি':'NNP','ইফো':'NNP','ইফ্ফাতকে':'NN','ইবাদত-খানা':'NN',
'ইবাদত':'NN','ইবাদান':'NNP','ইবার':'NNV','ইবেন':'VB','ইবেল':'NNP','ইব্রাহিম':'NN','ইভ':'NN',
'ইভিএম':'NN','ইভিএমে':'NN','ইভেট':'NNP','ইভেন্ট':'NN','ইমডেনিটি':'NN','ইমন-কল্যাণ':'NN','ইমন-রাগ':'NN',
'ইমন':'NN','ইমনকল্যাণ':'NN','ইমপেয়ারমেন্টস':'NNP','ইমপোর্ট':'NN','ইমপ্রুভ':'NN','ইমরান':'NN','ইমরানের':'NN',
'ইমরুল':'NN','ইমরুলকেই':'NN','ইমরুলের':'NN','ইমরোজ':'NN','ইমসে':'NNP','ইমাজ':'NN','ইমাম-বাড়া':'NN',
'ইমাম':'NN','ইমামবাড়া':'NN','ইমামী':'JJ','ইমারত':'NN','ইমারতী':'JJ','ইমিং':'NNP','ইমিগ্রেশন':'NN',
'ইমু':'NN','ইমেইল':'NN','ইমেইলের':'NN','ইমেজ':'NN','ইমেল':'NN','ইমো':'NN','ইমোশনাল':'NN',
'ইম্পোর্টেড':'JJ','ইম্ফল':'NN','ইম্যুন':'NN','ইয়া':'NNP','ইয়ুথ':'NNP','ইয়েরেভান':'NN','ইরকম':'NNP',
'ইরবিন':'NN','ইরা':'NN','ইরাকবাসি':'NN','ইরাকলিবিয়া':'NN','ইরাকি':'NN','ইরাকের':'NN','ইরাডিয়েটেড':'NN',
'ইরান':'NN','ইরানি':'JJ','ইরানী':'NN','ইরানের':'NN','ইরাবত':'NNP','ইরাবতী':'NN','ইরাবান':'NNP',
'ইরাম':'NNP','ইরাল':'NNP','ইরিডিয়াম':'NN','ইরিশ':'NNP','ইরুড়':'NN','ইরূপ':'NNP','ইরেও':'NNP',
'ইরেজ়ার':'NN','ইরের':'NNP','ইরোড':'NN','ইরোনমিককে':'NNP','ইর্শ':'NN','ইর্শিত্ব':'NN','ইর্শোপনিষদ':'NN',
'ইর্ষক':'NN','ইর্ষনীয়এটা':'NN','ইর্ষান্তিত':'NN','ইলবিলা':'NN','ইলা':'NN','ইলাইহি':'NN','ইলাচা':'NN',
'ইলাবর্ত্ত':'NN','ইলাবৃত':'NN','ইলাম':'NNP','ইলাস্টিক':'NN','ইলাস্ট্রেশনের':'NN','ইলাহী-গজ':'NN','ইলাহীগজ':'NN',
'ইলায়চা':'NN','ইলিগ্যাল':'JJ','ইলিচ':'NN','ইলিনয়':'NN','ইলিশ':'NN','ইলিয়াস':'NN','ইলুম':'NNP',
'ইলেও':'RP','ইলেকটোরাল':'JJ','ইলেকট্রন':'NN','ইলেকট্রনিক':'JJ','ইলেকট্রনিক্স':'NN','ইলেকট্রিক':'NN','ইলেকশন':'NN',
'ইলেকশনে':'NN','ইলেকশনের':'NN','ইলেক্ট':'NN','ইলেক্ট্রনিক্সের':'NNS','ইলেক্ট্রনের':'NN','ইলেক্ট্রিক':'JJ','ইলেন':'VB',
'ইলের':'NN','ইল্বল':'NN','ইল্ম-শাহী':'NN','ইল্মেনাইট':'NNP','ইল্যাস্টিক':'JJ','ইল্লব':'NN','ইশ':'NN',
'ইশমা্ম':'NN','ইশা':'NN','ইশারা':'NNS','ইশ্কপেচাঁ':'NN','ইশ্বরের':'NN','ইষ':'NN','ইষ্ট':'NN',
'ইষ্টতা':'NN','ইষ্টদেব':'NN','ইষ্টার্ণ':'NNP','ইস':'NN','ইসকোকে':'NN','ইসতেহার':'NN','ইসপরমূল':'NN',
'ইসবগুল':'NN','ইসমাইলী':'NN','ইসযদি':'NNS','ইসরাইল':'NN','ইসরাইলি':'JJ','ইসরাইলের':'NN','ইসরায়েল':'NNP',
'ইসরায়েলি':'JJ','ইসরায়েলিদের':'NNS','ইসরায়েলের':'NN','ইসরো':'NN','ইসলাম':'NN','ইসলামপন্থীরা':'NNS','ইসলামসহ':'NN',
'ইসলামাবাদ':'NN','ইসলামি':'NNP','ইসলামী':'NNP','ইসলামীক':'NN','ইসলামীর':'NNP','ইসলামে':'NN','ইসাওয়ার':'NN',
'ইসি':'NN','ইসিকে':'NNP','ইসিতে':'NN','ইসির':'NN','ইসু্':'NN','ইসেন':'NNP','ইস্কন':'NN',
'ইস্কুল':'NN','ইস্ট':'NN','ইস্টইন্ডিজ':'NN','ইস্টার':'NN','ইস্টের':'NN','ইস্ট্রোজেন':'NN','ইস্তখার':'NN',
'ইস্তানবুল':'NN','ইস্তাহার':'JJ','ইস্তাহারে':'NN','ইস্তোনিয়ান':'JJ','ইস্তোনীয়':'JJ','ইস্ত্রি':'JJ','ইস্ত্রী':'NN',
'ইস্পাত':'NN','ইস্যু':'NN','ইস্যুতে':'NN','ইস্রায়েল':'NNP','ইস্‌':'UH','ইহকাল':'NN','ইহলোক':'NN',
'ইহলৌকিক':'JJ','ইহা':'NN','ইহাকে':'PR','ইহাকেই':'NN','ইহাতে':'PR','ইহার':'PR','ইহুদি':'NN',
'ইহুদীগো':'NN','ইহুদীরা':'NNS','ইহ্':'DT','ইেতামধ্যে':'NN','ইয়ং':'NNP','ইয়ত্তা':'NN','ইয়রকার':'NN',
'ইয়র্কশায়ারের':'NNP','ইয়র্কার':'NN','ইয়াং':'NN','ইয়াউণ্ড':'NN','ইয়াঙ্গুন':'NN','ইয়াছমিন':'NN','ইয়াব':'NN',
'ইয়াবাই':'NN','ইয়ার':'NN','ইয়ারবুক':'NN','ইয়ারমেন্ট':'NN','ইয়ারের':'NN','ইয়ার্কি':'NN','ইয়ার্স':'NNS',
'ইয়াসমিনের':'NN','ইয়াহুর':'NN','ইয়ুনুসের':'NN','ইয়ুরোপীয়':'NN','ইয়ে':'NN','ইয়েন':'NN','ইয়েমান':'NNP',
'ইয়েমেন':'NN','ইয়েমেনের':'NNS','ইয়ের':'NNP','ইয়েলোহ্যামার':'NN','ইয়েস':'UH','ইয়োর':'NNS','ইয়োরুবা':'NNP',
'ইয়োরোপ':'NNP','ইয়োলো':'VB','ই‌সি':'NN','ঈ':'NN','ঈকারান্ত':'JJ','ঈকুল':'VB','ঈগল':'NN',
'ঈঙ্গিত':'NN','ঈজিপ্ট':'NN','ঈজিপ্সিয়ান':'NN','ঈড':'NN','ঈদ-উল-জোহা':'NN','ঈদ-উল-ফিতর':'NN','ঈদ':'NN',
'ঈদকে':'NN','ঈদগাহ':'NN','ঈদী':'NN','ঈদের':'NN','ঈপ্সিত':'JJ','ঈমান':'NN','ঈমানের':'NN',
'ঈর্ষণীয়':'JJ','ঈর্ষতঃ':'RB','ঈর্ষা':'NN','ঈর্ষান্বিত':'VB','ঈর্ষাপূর্ণ':'JJ','ঈর্ষাপূর্ণতা':'NN','ঈর্ষাপূর্বক':'RB',
'ঈর্ষাপ্রবণ':'JJ','ঈর্ষালুতা':'NN','ঈর্ষাহীন':'JJ','ঈর্ষাহীনতা':'NN','ঈর্ষাহীনভাবে':'RB','ঈল':'NN','ঈশ':'NN',
'ঈশান':'NN','ঈশামসী':'NN','ঈশারা':'NN','ঈশ্বর-প্রণিধান':'NN','ঈশ্বর':'NN','ঈশ্বরকে':'NN','ঈশ্বরচন্দ্র':'NN',
'ঈশ্বরত্ব':'NN','ঈশ্বরনিষ্ঠ':'JJ','ঈশ্বরপরায়ণ':'JJ','ঈশ্বরপুরীর':'NN','ঈশ্বরপ্রণিধান':'NN','ঈশ্বরপ্রদত্ত':'JJ','ঈশ্বরবাদ':'NN',
'ঈশ্বরসখ':'NN','ঈশ্বরহীন':'JJ','ঈশ্বরী':'NN','ঈশ্বরীয়':'JJ','ঈশ্বরে':'NN','ঈষত্':'RB','ঈষদচ্ছতা':'NN',
'ঈষদুষ্ণ':'NN','ঈষিকা':'NN','ঈষ্পাত':'JJ','ঈষ্পাতের':'JJ','ঈসায়ী':'JJ','ঈস্ট':'NN','উ':'NN',
'উlত্থান':'NN','উঁকি-ঝুকি':'NN','উঁকি':'NN','উঁকিঝুঁকি':'NN','উঁকোত':'NN','উঁগনী':'NN','উঁচনাও':'NN',
'উঁচিলে':'NN','উঁচিয়ে':'VB','উঁচু-নীচু':'JJ','উঁচু':'JJ','উঁচুনীচু':'NN','উঁচুমানের':'NN','উঁজ্জরী':'NN',
'উঁটকাঁটা':'NN','উঁড়ম্বরী':'NN','উঁনার':'NN','উঃ':'UH','উইকিলিকসের':'NN','উইকেট':'NN','উইকেটকিপিং':'NN',
'উইকেটটা':'NN','উইথ':'FW','উইথড্র':'VB','উইনফ্রের':'NNP','উইনস্টন':'NNP','উইনিং':'VBG','উইন্ডিজের':'NN',
'উইন্ডো':'NN','উইন্ডোজ':'NNS','উইপোকা':'NN','উইম্বিল্ডন':'NN','উইল':'MD','উইলকিন্স':'NNP','উইলবিহীন':'JJ',
'উইলি':'NNP','উইলিয়াম':'NN','উইলিয়ামসন':'NN','উইলিয়ামে':'NNP','উইড়া':'NN','উওম':'NN','উওর':'NN',
'উকবত':'NN','উকার':'NN','উকারান্ত':'JJ','উকারি':'NN','উকিল':'NN','উকুন':'NN','উকে':'NN',
'উকো':'NN','উক্ত':'NN','উক্তির':'NN','উখড়া':'NN','উখভোজ':'NN','উখরাজ':'NN','উখরুল':'NN',
'উখলি':'NN','উখা':'NN','উখালিয়া':'NN','উখেড়':'NN','উখ্য':'NN','উগদ':'NN','উগরানো':'NN',
'উগরে':'VB','উগানডা':'NN','উগান্ডান':'NN','উগান্ডার':'JJ','উগার':'NN','উগ্গাহ':'NN','উগ্র':'NN',
'উগ্রগন্ধা':'NN','উগ্রচণ্ডা':'JJ','উগ্রতা':'NN','উগ্রপন্থা':'NN','উগ্রপন্থীকে':'NN','উগ্রপন্থীসহ':'NN','উগ্রবাদ':'NN',
'উগ্রবাদীদের':'NNS','উগ্রশেখরা':'NN','উগ্রসেন':'NN','উগ্রা':'NN','উঙ্গনা':'NN','উচচতা':'NN','উচছ':'JJ',
'উচল':'NN','উচাটন':'NN','উচিত':'JJ','উচিতঅনুরোধ':'JJS','উচিতআবু':'NN','উচিতআর':'MD','উচিতএই':'MD',
'উচিতএতে':'NN','উচিতও':'MD','উচিততাদের':'NN','উচিতনাহলে':'NN','উচিতবিশ্বমানের':'NN','উচিতযেসকল':'NN','উচিতহিজরা':'NN',
'উচিত্':'NN','উচিৎ':'MD','উচিৎপরিবার':'RB','উচিৎভালো':'NN','উচু':'JJ','উচ্চ-স্তরীয়':'JJ','উচ্চ':'JJ',
'উচ্চউন্নত':'NNP','উচ্চকণ্ঠে':'NN','উচ্চগ্রহ':'NN','উচ্চচাপ':'NN','উচ্চতম':'NN','উচ্চতর':'JJR','উচ্চতা':'NN',
'উচ্চতার':'NN','উচ্চনাদ':'NN','উচ্চপদস্থ':'JJ','উচ্চপদাধিকারী':'JJ','উচ্চপদাধিষ্ঠিত':'JJ','উচ্চপদাসীন':'JJ','উচ্চপদে':'NN',
'উচ্চপর্যায়':'NN','উচ্চপর্যায়ের':'NN','উচ্চবংশজাত':'NN','উচ্চবংশীয়':'JJ','উচ্চবর্গীয়':'NN','উচ্চবিত্ত':'NN','উচ্চমাধ্যমিক':'NN',
'উচ্চশিক্ষা':'NN','উচ্চস্তরীয়':'JJ','উচ্চস্তরের':'NN','উচ্চহারে':'NN','উচ্চাকাঙ্ক্ষা':'NN','উচ্চাকাঙ্খী':'NN','উচ্চাটিত':'JJ',
'উচ্চাধিকারি':'NN','উচ্চারণ':'NN','উচ্চারণনো':'VB','উচ্চারণযোগ্য':'JJ','উচ্চারণে':'NN','উচ্চারন':'NN','উচ্চারিত':'VBD',
'উচ্চৈঃশ্রবা':'NN','উচ্ছল':'JJ','উচ্ছাস':'NN','উচ্ছিষ্ট':'NN','উচ্ছিষ্টটুকু':'NNS','উচ্ছিষ্টভোজী':'JJ','উচ্ছৃঙ্খল':'NN',
'উচ্ছে':'NN','উচ্ছেদন':'NN','উচ্ছেদবাদী':'NN','উচ্ছ্বাস':'VB','উছাল':'NN','উজবক':'NN','উজবেকি':'NN',
'উজবেকিস্তানবাসী':'NN','উজবেকিস্তানী':'JJ','উজলী':'NN','উজ়ানো':'VB','উজাড়':'NN','উজাড়কারী':'JJ','উজান':'NN',
'উজারী':'NN','উজাড়':'NN','উজিরালি':'NN','উজীর':'NN','উজেরা':'NN','উজ্জল':'NNP','উজ্জলতা':'NN',
'উজ্জ্বল':'NNP','উজ্জ্বলতম':'JJ','উজ্জ্বলতা':'NN','উজ্জয়ন':'NN','উজ্জয়িনী':'NN','উজ্জয়িনীর':'NNP','উজ্বল':'NNP',
'উজ্বলা':'NN','উঝিলা':'NN','উঞ্ছবৃত্তি':'NN','উট':'NN','উটকেও':'NN','উটকো':'JJ','উটচালক':'NN',
'উটছে':'VBG','উটপাখি':'NN','উটার':'NN','উটি':'NN','উটুন':'VB','উটে':'NN','উঠছিল':'VBG',
'উঠছে':'VBG','উঠতি':'NN','উঠতে-পড়তে':'RB','উঠতে':'NN','উঠবে':'NN','উঠবেন':'VB','উঠল':'NN',
'উঠলই':'VB','উঠলে':'NN','উঠলো':'VB','উঠা':'NN','উঠাননি':'NN','উঠানে':'NN','উঠানো':'VBG',
'উঠানো':'VB','উঠাবসা':'VB','উঠাবেন':'VB','উঠার':'VB','উঠিতে':'VB','উঠিয়া':'VB','উঠুক':'VB',
'উঠে':'VB','উঠেও':'VB','উঠেছিল':'VB','উঠেছিলেন':'VB','উঠেছেন':'NN','উঠোন':'NN','উড':'NN',
'উড়কি':'NN','উড়তে':'NN','উড়নচাকতি':'NN','উড়নফল':'NN','উড়ন্ত':'NN','উড়ন্তকেল্লা':'NN','উড়প':'NN',
'উড়া':'NN','উড়ান':'NN','উড়ানবিহীন':'NN','উড়ানো':'VB','উড়াল':'NN','উড়িয়ে':'VB','উড়িষ্যা':'NN',
'উড়িষ্যায়':'NN','উড়িয়া':'NN','উড়িয়ে':'NN','উড়ুক্কু':'NN','উড়ে':'NN','উড়েদণ্ড':'NN','উড়োজাহাজ':'NN',
'উডার':'NN','উড্ডীয়মান':'JJ','উড্ডুপি':'NN','উড্ডয়ন':'NN','উড্ডয়নশীল':'JJ','উণ্ড':'NN','উতক্ষেপণ':'NN',
'উতক্ষেপিত':'JJ','উতঙ্ক':'NN','উতথ্য':'NN','উতন্থ':'NN','উতপাটন':'NN','উতপাদন':'NN','উতরাই':'NN',
'উতরে':'NN','উতর্কষতা':'NN','উতলা':'JJ','উতস':'NN','উতসাহপূর্ণ':'JJ','উতসাহিত':'VBN','উত্কচ':'NN',
'উত্কণ্ঠিত':'JJ','উত্কর্ষ':'NN','উত্কর্ষকারী':'JJ','উত্কর্ষতা':'NN','উত্কল':'NN','উত্কারিকা':'NN','উত্কীর্ণ-প্রতিমা':'NN',
'উত্কীর্ণ':'VBN','উত্কীর্তন':'NN','উত্কৃষ্ট':'NN','উত্কৃষ্টতর':'VB','উত্কোচ':'NN','উত্ক্রম':'NN','উত্ক্ষিপ্ত':'JJ',
'উত্ক্ষেপ':'NN','উত্ক্ষেপিত':'NN','উত্তঙ্ক':'NN','উত্তঙ্গ':'JJ','উত্তপ্ত':'VBN','উত্তম':'NN','উত্তমনামটা':'NN',
'উত্তমর্ণ':'NN','উত্তমের':'NNP','উত্তমৌজা':'NN','উত্তর প্রদেশ':'NN','উত্তর-পশ্চিম':'NN','উত্তর-পূর্ব':'NN','উত্তর-ফাল্গুনি':'NN',
'উত্তর-মধ্যবর্তী':'JJ','উত্তর-রাঢ়':'NNP','উত্তর':'NN','উত্তরকাণ্ড':'NN','উত্তরজীবী':'JJ','উত্তরজীবীতা':'NN','উত্তরটা':'NN',
'উত্তরণের':'NN','উত্তরদাতা':'NN','উত্তরদায়িত্বহীন':'JJ','উত্তরন':'NN','উত্তরপত্র':'NN','উত্তরপুস্তিকা':'NN','উত্তরপূর্ব':'NN',
'উত্তরফাল্গুনী':'JJ','উত্তরবঙ্গ':'NN','উত্তরবঙ্গে':'NN','উত্তরবর্তী':'NN','উত্তরভাদ্রপদ':'NN','উত্তরমুখী':'JJ','উত্তরসরী':'NN',
'উত্তরসূরিদের':'NN','উত্তরস্নাতক':'NN','উত্তরহীন':'JJ','উত্তরা-ফাল্গুনী':'NN','উত্তরা':'NN','উত্তরাখণ্ড':'NN','উত্তরাখন্ডে':'NN',
'উত্তরাঙ্গ':'NN','উত্তরাঞ্চকের':'NN','উত্তরাঞ্চলে':'NN','উত্তরাধিকার':'NN','উত্তরাধিকারি':'NN','উত্তরাফাল্গুনি':'NN','উত্তরাভাদ্রপদ':'NN',
'উত্তরার':'NN','উত্তরাষাঢ়া':'NN','উত্তরায়':'NN','উত্তরিত':'JJ','উত্তরে':'NN','উত্তরোত্তর':'JJ','উত্তল':'JJ',
'উত্তলন':'NN','উত্তলাবতল':'JJ','উত্তানপাদ':'NN','উত্তারাধিকার':'NN','উত্তাল':'JJ','উত্তীর্ণ':'VBN','উত্তুরে':'JJ',
'উত্তেজক':'NN','উত্তেজনায়':'NN','উত্তেজিত':'JJ','উত্তোলক':'JJ','উত্তোলন':'NN','উত্তোলিত':'JJ','উত্ত্যক্ত':'VB',
'উত্থান-একদশী':'NN','উত্থান':'NN','উত্থাপন':'NN','উত্পত্তি':'NN','উত্পন্ন':'VBN','উত্পন্নকারী':'JJ','উত্পল':'NN',
'উত্পলবাবুর':'NNP','উত্পলা':'NN','উত্পাটনযোগ্য':'JJ','উত্পাটনীয়':'JJ','উত্পাটিত':'VBN','উত্পাত':'NN','উত্পাদন':'NN',
'উত্পাদনকারিগণকে':'NN','উত্পাদনমূলক':'JJ','উত্পাদনশীলতা':'NN','উত্পাদনে':'NN','উত্পাদিত':'JJ','উত্পীড়ক':'NN','উত্পীড়ণ':'VB',
'উত্পীড়ন':'NN','উত্প্রেক্ষা':'NN','উত্ফুল্ল':'JJ','উত্যক্তনো':'VB','উত্স':'NN','উত্সবকে':'NN','উত্সবপন্থী':'JJ',
'উত্সবমুখর':'JJ','উত্সবের':'NN','উত্সর্গর':'NN','উত্সাহ':'NN','উত্সাহজনক':'JJ','উত্সাহপূর্ণ':'NN','উত্সাহবর্ধক':'JJ',
'উত্সাহযুক্ত':'JJ','উত্সাহহীন':'JJ','উত্সাহহীনতা':'NN','উত্সাহিত':'VBN','উত্সাহী':'JJ','উত্সুক':'NN','উত্্সব':'NN',
'উথলানো':'IN','উথলিয়ে':'VB','উথলে':'NN','উথান':'NN','উথ্বান':'NN','উদক':'NN','উদকক্রিয়া':'NN',
'উদকদান':'NN','উদগার':'NN','উদঘাটন':'NN','উদঘোষ':'NN','উদযাপন':'NN','উদযাপনের':'NN','উদর-অগ্নি':'NN',
'উদর-সংক্রান্ত':'JJ','উদর':'NN','উদরশূল':'NN','উদরাময়':'NN','উদরু':'NN','উদল':'NN','উদহরণএতো':'NN',
'উদাত্ত':'NN','উদান':'NN','উদানবায়ু':'NN','উদার':'JJ','উদারচেতা':'JJ','উদারতা':'NN','উদারতাপূর্বক':'RB',
'উদারতাবাদ':'NN','উদারতার':'NN','উদারনৈতিক':'JJ','উদারপন্থী':'JJ','উদারমনস্ক':'JJ','উদারীকরণ':'NN','উদাস':'VBN',
'উদাসীন':'NN','উদাসীনতাই':'NN','উদাসীননো':'VB','উদাহরণ':'NN','উদাহরণে':'NN','উদাহরনের':'NN','উদিত':'NN',
'উদিয়মান':'VBG','উদীপ্ত':'VBN','উদীয়মান':'VBG','উদূখল':'NN','উদের':'NN','উদেশ্য':'NN','উদোক্তাগণকে':'NN',
'উদোর':'NN','উদ্গম':'NN','উদ্গাতা':'NN','উদ্গিরণ':'NN','উদ্ঘাটন':'NN','উদ্ঘাটনের':'NN','উদ্দশ্য':'NN',
'উদ্দালক':'NN','উদ্দিন':'NN','উদ্দিপক':'NN','উদ্দিপ্ত':'VBN','উদ্দিশ':'NN','উদ্দিষ্ট':'JJ','উদ্দীপক':'NN',
'উদ্দীপনা':'NN','উদ্দীপিত':'VBN','উদ্দীপ্ত':'NN','উদ্দেশ্য':'VB','উদ্দেশ্যটা':'VB','উদ্দেশ্যপূর্বক':'RB','উদ্দেশ্যপ্রণোদিত':'JJ',
'উদ্দেশ্যবিহীন':'NN','উদ্দেশ্যেই':'NN','উদ্দেশ্যেহীন':'RB','উদ্দোগতা':'NN','উদ্দৌলাকে':'NN','উদ্দ্যেগের':'NN','উদ্দ্যেশে':'VB',
'উদ্দ্যোগ':'NN','উদ্দ্রীজ':'NN','উদ্ধত':'NN','উদ্ধতন':'JJ','উদ্ধতভাষী':'JJ','উদ্ধার':'NN','উদ্ধারকারী':'NN',
'উদ্ধারকৃত':'VBN','উদ্ধারিত':'JJ','উদ্ধারিতে':'NN','উদ্ধারের':'NN','উদ্ধুত':'NN','উদ্ধৃত':'JJ','উদ্ধৃতি':'NN',
'উদ্ধোধন':'NN','উদ্বর্ত':'NN','উদ্বাসিত':'JJ','উদ্বাস্তু':'NN','উদ্বিগনতা':'NN','উদ্বিগ্ন':'JJ','উদ্বিগ্নতা':'NN',
'উদ্বিগ্নতার':'NN','উদ্বিড়াল':'NN','উদ্বুদ্ধ':'NN','উদ্বৃত্ত':'NN','উদ্বেগ':'NN','উদ্বেগপূর্ণ':'JJ','উদ্বেগহীনতা':'NN',
'উদ্বেগের':'JJ','উদ্বেলিত':'JJ','উদ্বোধন':'NN','উদ্বোধনের':'NN','উদ্ভট':'NNP','উদ্ভব':'NN','উদ্ভাবক':'NN',
'উদ্ভাবনী':'JJ','উদ্ভাবনে':'NN','উদ্ভাবিত':'JJ','উদ্ভাসিততাও':'NN','উদ্ভিজ্জ':'JJ','উদ্ভিদ-জগতে':'NN','উদ্ভিদকে':'NN',
'উদ্ভিদবিজ্ঞান':'NN','উদ্ভিদশাস্ত্র':'NN','উদ্ভিদে':'NN','উদ্ভুত':'JJ','উদ্ভোধন':'NN','উদ্যত':'NN','উদ্যমহীন':'JJ',
'উদ্যমহীনতা':'NN','উদ্যমে':'RB','উদ্যাগদার':'NN','উদ্যান':'NN','উদ্যানপালন':'NN','উদ্যােমে':'NN','উদ্যেগে':'NN',
'উদ্যেশ্য':'NN','উদ্যোক্তা':'NN','উদ্যোক্তা':'JJ','উদ্যোক্তাকে':'NN','উদ্যোক্তাদের':'NNS','উদ্যোক্তার':'NN','উদ্যোগ':'NN',
'উদ্যোগকে':'NN','উদ্যোগপতি':'NN','উদ্যোগহীন':'JJ','উদ্যোগী':'VBG','উদ্যোগে':'NN','উদ্যোমী':'NN','উদ্রেক':'NN',
'উদয়':'NN','উদয়পুর':'NN','উদয়াচল':'NN','উধগমণ্ডলম':'NN','উধমপুর':'NN','উধমসিংহ':'NN','উধরনী':'NN',
'উধাও':'NN','উন':'JJ','উনআশি':'NN','উনকে':'PR','উনচল্লিশ':'NN','উনচল্লিশতম':'JJ','উনত্রিশ':'NN',
'উনত্রিশতম':'JJ','উননয়নে':'NN','উননয়নের':'VBG','উনপঞ্চাশতম':'JJ','উনবিংশ':'CD','উনা':'NN','উনাদের':'NN',
'উনান':'NN','উনারই':'NN','উনারদের':'NN','উনারা':'NN','উনারাএভাবেই':'NN','উনারাও':'NN','উনিই':'PRP',
'উনিও':'NN','উনিশ':'NN','উনিশতম':'JJ','উনিশশ':'CD','উনুন':'NN','উনুস':'NNP','উনের':'NN',
'উন্টগন':'NN','উন্নত':'NNP','উন্নতকারী':'JJ','উন্নতমানের':'NN','উন্নতি':'NN','উন্নতিকর':'JJ','উন্নতিকল্পে':'NN',
'উন্নতিকারক':'JJ','উন্নতিতে':'NN','উন্নতিদায়ী':'JJ','উন্নতির':'NN','উন্নতিশীল':'JJ','উন্নতে':'NN','উন্নয়ন':'NNP',
'উন্নয়নের':'NN','উন্নশীল':'NN','উন্নাও':'NN','উন্নায়ন':'NNP','উন্নায়নের':'NN','উন্নিত':'NN','উন্নীত':'VBN',
'উন্নীতকরণ':'NN','উন্নয়ণ':'NN','উন্নয়ন':'NNP','উন্নয়নই':'NN','উন্নয়নকিসের':'NN','উন্নয়নগুলো':'NN','উন্নয়নবিষয়ক':'NN',
'উন্নয়নভিত্তিক':'NN','উন্নয়নমূলক':'NN','উন্নয়নশীল':'VBG','উন্নয়নসেটা':'NN','উন্নয়নের':'NN','উন্নয়ন্তত':'NNP','উন্নয়ের':'NN',
'উন্বাসীক':'NN','উন্মক্ত':'NN','উন্মত্ততা':'NN','উন্মাদ':'NN','উন্মাদআশ্রমে':'NN','উন্মাদনা':'NN','উন্মার্গগামী':'NN',
'উন্মীলন':'VB','উন্মুক্ত':'VB','উন্মুক্তকরণ':'NN','উন্মূলনযোগ্য':'JJ','উন্মূলিত':'JJ','উন্মেষ':'NN','উন্মোচক':'JJ',
'উন্মোচন':'NN','উপ-মুখ্যমন্ত্রী':'NN','উপ':'NN','উপকমিটির':'NN','উপকরণ':'NN','উপকাপ্তান':'NN','উপকার':'NNS',
'উপকারই':'NN','উপকারক':'JJ','উপকারিতা':'NN','উপকারী':'NN','উপকারের':'JJ','উপকূল':'NN','উপকূলবাসী':'JJ',
'উপকূলে':'NN','উপকৃত':'NN','উপক্রণ':'NN','উপক্রান্তীয়':'JJ','উপক্রিত':'NN','উপক্ষেত্র':'NN','উপগাছ':'NN',
'উপগিরি':'NN','উপগোত্র':'NN','উপগ্রহ':'NN','উপঘাত':'NN','উপচরমূলক':'NN','উপচার':'NN','উপচারিত':'JJ',
'উপচিত্র':'NN','উপচে':'IN','উপজাত':'NN','উপজাতিদের':'JJ','উপজাতির':'NN','উপজাতীয়':'JJ','উপজীবিকা':'NN',
'উপজীব্য':'NN','উপজেলা':'NN','উপজেলার':'NN','উপড়ানো':'VBN','উপড়ে':'VB','উপঢৌকন':'NN','উপত্যকা':'NN',
'উপদংশ':'NN','উপদিশা':'NN','উপদিষ্ট':'NN','উপদেবা':'NN','উপদেশও':'NN','উপদেশমূলক':'JJ','উপদেশের':'NN',
'উপদেষ্টা':'NN','উপদ্বীপ':'NN','উপদ্বীপীয়':'JJ','উপদ্বীপের':'NNP','উপদ্রব':'NN','উপদ্রবকারী':'JJ','উপদ্রুত':'JJ',
'উপধারা':'NN','উপনগর':'NN','উপনদী':'NN','উপনাহ':'NN','উপনিবেশ':'NN','উপনিবেশের':'NN','উপনিবেসিক':'NN',
'উপনিরবাচনও':'NN','উপনির্দেশক':'NN','উপনির্বাচন':'NN','উপনিষদ':'NN','উপনীত':'JJ','উপন্যাস-সম্পর্কিত':'JJ','উপন্যাস':'NN',
'উপন্যাসে':'JJ','উপনয়ন':'NN','উপপংক্তিটি':'NN','উপপঞ্চায়েত':'NN','উপপতী':'JJ','উপপত্নি':'NN','উপপাদনীয়':'JJ',
'উপপাদ্য':'NN','উপপ্রধানমন্ত্রী':'NN','উপপ্রবাহ':'NN','উপবন':'NN','উপবর্তী':'JJ','উপবাস':'NN','উপবাসের':'NN',
'উপবিধি':'NN','উপবিভাগ':'NN','উপবিষ্ট':'JJ','উপবীত':'NN','উপবৃত্ত':'NN','উপবেদ':'NN','উপভাগ':'NN',
'উপভূমি':'NN','উপভোক্তা':'NN','উপভোগ':'NN','উপভোগ্য':'NN','উপমন্ডলাধিকারি':'NN','উপমন্ত্রী':'NN','উপমন্যু':'NN',
'উপমহাদেশ':'NN','উপমহাদেশের':'NN','উপমা':'NN','উপমান':'NN','উপমার্গ':'NN','উপমিত':'JJ','উপমুখ্যমন্ত্রী':'NN',
'উপমেয়':'NN','উপযাজ':'NN','উপযুক্ত':'JJ','উপযুক্ততা':'NN','উপযোগ':'NN','উপযোগকর্তা':'JJ','উপযোগিতা':'NN',
'উপযোগী':'JJ','উপযোগীতা':'NN','উপযোজন':'NN','উপর-নীচ':'NN','উপর':'IN','উপরই':'NN','উপরওতো':'NN',
'উপরওয়ালার':'NN','উপরত':'NN','উপরত্ন':'NN','উপরনিচে':'NN','উপরন্তু':'NN','উপরাজধানী':'NN','উপরাজ্যপাল':'NN',
'উপরান্ত':'NN','উপরাষ্ট্রপতি':'NN','উপরিউক্ত':'NN','উপরিকথিত':'JJ','উপরিভাগ':'NN','উপরী':'NN','উপরে':'NNS',
'উপরেই':'NN','উপরের':'IN','উপরোক্ত':'NN','উপরোল্লিখিত':'NN','উপর্যপুরি':'NN','উপর্যুক্ত':'JJ','উপলক':'NN',
'উপলক্ষে':'NN','উপলবদি':'NN','উপলব্ধ':'JJ','উপলব্ধি':'NN','উপল্লা':'NN','উপশম':'NN','উপশহর':'NN',
'উপশাখা':'NN','উপশীর্ষক':'NN','উপশুল্ক':'NN','উপসংহার':'NN','উপসচিব':'NN','উপসচিবরা':'NN','উপসভাপতি':'NN',
'উপসমিতি':'NN','উপসর্গ':'NN','উপসাগর':'NN','উপসাগরে':'NNP','উপসুন্দ':'NN','উপসৃপ্তক':'JJ','উপস্তুত':'NN',
'উপস্থাপক':'NN','উপস্থাপন':'NN','উপস্থাপনার':'NN','উপস্থাপিত':'JJ','উপস্থিতি-তালিকাপুস্তক':'NN','উপস্থিতি-নামাবলী':'NN','উপস্থিতি':'NN',
'উপস্থিতিতেই':'NN','উপস্থের':'NN','উপস্হিত':'JJ','উপস্হিতি':'NN','উপহার':'NNS','উপহারজনমে':'NN','উপহারাদি':'NN',
'উপহাস':'NN','উপহাসাস্পদ':'JJ','উপহাসের':'JJ','উপহ্রদ':'NN','উপাখ্যান':'NN','উপাগত':'JJ','উপাঙ্গ':'NN',
'উপাচার':'NN','উপাচার্য':'NN','উপাচার্য্য':'NN','উপাত্ত':'NN','উপাদান':'NN','উপাদানগুলি':'NN','উপাদানের':'NN',
'উপাদেয়':'JJ','উপাধান':'NN','উপাধির':'NN','উপাধীতে':'NN','উপাধ্যক্ষ':'NN','উপান্ত':'NN','উপায়':'NN',
'উপার্জন':'NN','উপার্জি':'NN','উপাসক':'NN','উপাসনা':'NN','উপাসনালয়ে':'NN','উপাসিকা':'NN','উপায়':'NN',
'উপায়হীন':'JJ','উপায়হীনতা':'NN','উপায়ান্তর':'NN','উপায়ে':'NN','উপুড়':'IN','উপেক্ষক':'JJ','উপেক্ষনীয়':'JJ',
'উপেক্ষা':'NN','উপেন্দ্রবজ্রা':'NN','উপোস':'NN','উপড়ে':'NN','উফ':'NN','উফ্‌আন্দালিব':'NN','উবার':'NN',
'উবারপাঠাও':'NN','উভচর':'NN','উভয়':'JJ','উভয়ই':'CD','উভয়ের':'NN','উভলিঙ্গ':'NN','উভয়-সঙ্কট':'NN',
'উভয়':'DT','উভয়ই':'NN','উভয়কেই':'PR','উভয়চর':'JJ','উভয়তঃ':'RB','উভয়লিঙ্গ':'JJ','উভয়ে':'NN',
'উভয়েই':'PR','উভয়ের':'NN','উমরাহ':'NN','উমলোচা':'NN','উমা':'NN','উমেশচন্দ্র':'NNP','উম্নয়নের':'NN',
'উম্মাদনা':'NN','উম্মুক্ত':'JJ','উম্মে':'NN','উর':'NN','উরুকু':'NN','উরুক্রম':'NN','উরুগুয়ান':'NN',
'উরুগুয়েবাসী':'NN','উরুগুয়ের':'JJ','উরুচক্রি':'NN','উরোপ':'NN','উর্ণা':'NN','উর্ত্তীণ':'NN','উর্দু':'NN',
'উর্দুর':'NNP','উর্দ্ধে':'NN','উর্ধচরণ':'NN','উর্ধ্বগতি':'NN','উর্ধ্বগ্রীব':'NN','উর্ধ্বতনরা':'NN','উর্ধ্বে':'NN',
'উর্ধ্বোন্মুখ':'JJ','উর্বর':'NN','উর্বরতায়':'NN','উর্বশী':'NN','উর্মিকা':'NN','উর্স':'NN','উল':'NN',
'উলঙ্গ':'JJ','উলট':'NN','উলটো':'RB','উলপতৃণ':'NN','উলফ':'NNP','উলান':'NN','উলিং':'NNP',
'উলু':'NN','উলুখড়':'NN','উলুখাগড়া':'NN','উলুখাগড়ার':'NN','উলুপি':'NN','উলের':'NN','উল্কা':'NN',
'উল্কাপাত':'NN','উল্কাপিণ্ড':'NN','উল্কামুখী-প্রেত':'NN','উল্কি':'NN','উল্কিনো':'VB','উল্টা':'NN','উল্টাপাল্টা':'NN',
'উল্টাবে':'NN','উল্টে':'JJ','উল্টো':'NN','উল্টো-পাল্টা':'NN','উল্টো':'RB','উল্টোটা':'NN','উল্টোদিকে':'NN',
'উল্টোপাল্টা':'JJ','উল্টোভাবে':'RB','উল্লঙ্ঘন':'NN','উল্লঙ্ঘনীয়':'JJ','উল্লম্ব':'NN','উল্লসিত':'JJ','উল্লালা':'NN',
'উল্লাসপূর্ণ':'JJ','উল্লাসে':'NN','উল্লাহ':'NN','উল্লিখিত':'JJ','উল্লুখের':'NN','উল্লেখই':'NN','উল্লেখনীয়':'JJ',
'উল্লেখযোগ্য':'NN','উল্লেখিত':'NN','উল্লোখ':'NN','উশনাকাব্য':'NN','উশনি':'NN','উশীনর':'NN','উশুল':'NN',
'উশৃংখলতা':'NN','উশৃঙ্খল':'JJ','উষর':'NN','উষা':'NN','উষাকাল':'NN','উষ্কানি':'NN','উষ্কে':'NN',
'উষ্ট্র':'NN','উষ্ণ':'JJ','উষ্ণতা':'NN','উষ্ণমন্ডলীয়':'JJ','উষ্ণিক':'NN','উষ্ণীষ':'NN','উষ্মজ':'NN',
'উসকানি':'NN','উসকানিমূলক':'NN','উসকানী':'NN','উসকানো':'VB','উসকে':'VB','উসকো-খুসকো':'JJ','উসখুস':'VB',
'উসমান':'NN','উসল':'NN','উসুলস':'NN','উসের':'NN','উস্কানি':'NN','উস্কানিমূলক':'NN','উস্কানীদাতা':'NN',
'উস্কে':'VB','উস্তাদ':'NN','উস্মানাবাদ':'NN','উহা':'PR','উহাদের':'PR','উহারা':'NN','উহু':'NN',
'উহ্য':'NN','উ্ন্নয়নের':'NN','উৎকৃষ্ট':'NN','উৎকোচের':'NN','উৎক্ষাতের':'NN','উৎত্বপ্ত':'NN','উৎপত্তি':'NN',
'উৎপন্ন':'JJ','উৎপাটন':'NN','উৎপাদক':'NN','উৎপাদনকারী':'NN','উৎপাদনশীলতা':'NN','উৎপাদনে':'NN','উৎপাদিত':'NN',
'উৎপাধন':'NN','উৎফুল্ল':'NN','উৎযাপন':'NN','উৎলাইয়া':'NN','উৎস':'NN','উৎসগুলো':'NN','উৎসব':'NN',
'উৎসবমুখর':'NN','উৎসাহ':'NN','উৎসাহিত':'NN','উৎসাহীও':'NN','উৎসে':'NN','উড়ছেন':'NN','উড়তে':'NN',
'উড়তেছেমনে':'NN','উড়াইতাম':'NN','উড়াল':'NN','উড়ালসড়কও':'NN','উড়িয়ে':'NN','উড়েই':'NN','উড়োজাহাজ':'NN',
'উ‌নি':'NN','ঊ':'NN','ঊকারান্ত':'JJ','ঊগিয়া':'NN','ঊদ্ভব':'NN','ঊনআশি':'JJ','ঊনচল্লিশ':'NN',
'ঊনত্রিশ':'NN','ঊননব্বই':'NN','ঊনপঞ্চাশ':'NN','ঊনবাচক':'JJ','ঊনবিংশ':'CD','ঊনষাট':'NN','ঊনষাটতম':'JJ',
'ঊনষাঠ':'JJ','ঊনসত্তর':'NN','ঊনসত্তরতম':'JJ','ঊনা':'NN','ঊনি':'NN','ঊপর':'IN','ঊপসচিব':'NN',
'ঊরুর':'NN','ঊরুহীন':'JJ','ঊরূ':'NN','ঊর্ণনাভ':'NN','ঊর্ণামার্জনী':'NN','ঊর্দ্ধে':'NN','ঊর্ধ্বগতিতে':'NNS',
'ঊর্ধ্বতন':'JJ','ঊর্ধ্বাকাশে':'NN','ঊর্মি':'NN','ঊর্মিল':'JJ','ঊর্মিলা':'NN','ঊলু':'NN','ঊষা':'NN',
'ঊষানাথ':'NN','ঋ':'NN','ঋক':'NN','ঋগ':'NN','ঋগবেদ':'NN','ঋচা':'NN','ঋচীক':'NN',
'ঋজিস্বা':'NN','ঋজু':'NN','ঋজুকোণ':'NN','ঋজুতা':'NN','ঋজ্রাশ্ব':'NN','ঋণ':'NN','ঋণকারি':'NN',
'ঋণখেলাপি':'NN','ঋণগুলো':'NN','ঋণগ্রস্ততা':'NN','ঋণগ্রহণ':'VB','ঋণগ্রহিতা':'NN','ঋণচুক্তি':'NN','ঋণদাতা':'JJ',
'ঋণদানের':'NN','ঋণপত্র':'NN','ঋণমুক্ত':'JJ','ঋণমুক্তি-পত্র':'NN','ঋণরহিততা':'NN','ঋণাত্মক':'NN','ঋণী':'NN',
'ঋণে':'NN','ঋতু':'NN','ঋতুপর্ণ':'NN','ঋতুমতি':'JJ','ঋতুমতী':'NN','ঋতুরাজ':'NN','ঋতুহীন':'JJ',
'ঋত্বিক':'NNP','ঋদ্ধি-সিদ্ধি':'NN','ঋদ্ধি':'NN','ঋন':'NN','ঋনখেলাপি':'NN','ঋনী':'NN','ঋনের':'NN',
'ঋষভ':'NN','ঋষভদেব.':'NN','ঋষি':'NN','ঋষিকুল্যা':'NN','ঋষিপঞ্চমী':'NN','ঋষিপ্রণীত':'JJ','ঋষির':'NN',
'ঋষ্মমুখ':'NN','ঋষ্য':'NN','ঋষ্যশৃঙ্গ':'NN','ঋসভ':'NN','এ-কান':'NN','এ-দ্বীপটার':'NN','এ-পর্যন্ত':'NNP',
'এ-র':'NNP','এ.':'NNP','এ':'NN','এঁকে':'PR','এঁকেই':'NN','এঁটেলমাটি':'NN','এঁটো':'NNP',
'এঁড়ে':'NN','এঁদের':'NN','এঁদেরও':'PR','এঁর':'PR','এঁরাই':'NNS','এই':'DT','এইকালীন':'JJ',
'এইখানে':'RB','এইগুলা':'NN','এইগুলো':'DT','এইগুলোই':'DM','এইগুলোকে':'PR','এইচ':'NNP','এইচআইভি':'NN',
'এইচআরডব্লু':'NN','এইচএসসি':'NN','এইচটিএমএল':'NN','এইচডি':'NN','এইজন্য':'NN','এইটা':'NN','এইটাও':'NN',
'এইটার':'NN','এইটি':'NN','এইটুকু':'NN','এইটুকুই':'PR','এইটুকুতেই':'NN','এইড':'NN','এইতো':'NN',
'এইদিন':'NN','এইদেশ':'NN','এইপ্রকার':'JJ','এইবার':'NN','এইবারে':'NN','এইভাবে':'RB','এইভাবেই':'NN',
'এইভারত':'NN','এইমুহূর্তে':'NN','এইরকম':'NN','এইরূপ':'RB','এইসকল':'NN','এইসব':'NN','এইসবতো':'NN',
'এইসবের':'NN','এইসূত্রে':'NN','এই১':'NN','এঈ':'NN','এএন':'NN','এএরকম':'NN','এএস':'NN',
'এএিচ':'NN','এও':'RB','এওজি':'NN','এওয়ার্ড':'NN','এক-আয়োডিন':'NN','এক-একটি':'CD','এক-তৃতীয়াংশ':'JJ',
'এক-নিমেষ':'RB','এক':'CD','একই':'RB','একইটা':'CD','একইভাবে':'WRB','একইরকম':'NN','একক':'NN',
'এককথায়':'NN','এককভাবে':'RB','এককালীন':'NN','এককের':'NN','এককোষী':'NN','একখণ্ড':'JJ','একখান':'CD',
'একখানা':'NN','একখুঁটি':'NN','একগুঁয়েমি':'NN','একগ্রামী':'NN','একঘরে':'NN','একঘাত':'JJ','একঘেয়ে':'JJ',
'একঘেয়েমি':'NN','একচর':'NN','একচল্লিশ':'NN','একচল্লিশতম':'JJ','একচাকা':'NN','একচাকাবিশিষ্ট':'JJ','একচাকার':'JJ',
'একচারিণী':'JJ','একচুয়েলি':'NN','একচেটিয়া':'JJ','একচোখা':'JJ','একচৌদ্দাংশ':'NN','একচ্ছত্র':'NN','একচ্ছত্রাধিপত্য':'NN',
'একছত্র':'NN','একজন-দুজন':'JJ','একজন':'CD','একজনও':'NN','একজনকে':'NN','একজনের':'NN','একজন্য':'CD',
'একজিমা':'NN','একজোট':'NN','একটা':'NN','একটাই':'CD','একটাও':'NN','একটানা':'JJ','একটাবার':'RB',
'একটামাত্র':'NN','একটার':'CD','একটি':'DT','একটিই':'NN','একটিও':'JJ','একটিতে':'NN','একটিবার':'NN',
'একটিভ':'JJ','একটিমাত্র':'CD','একটির':'NN','একটু':'RB','একটুও':'NNP','একটুকু':'CD','একটুক্ষণ':'NN',
'একটুখানি':'CD','একটেল':'NN','একতন্ত্র':'NN','একতন্ত্রী':'NN','একতরফা':'JJ','একতরা':'NN','একতা':'NN',
'একতাবদ্ধ':'NNP','একতারা':'NN','একতাহীন':'JJ','একত্ব':'NN','একত্র':'RB','একত্রিকরণ':'NN','একত্রিশ':'NN',
'একত্রিশতম':'JJ','একত্রীকরণ':'NN','একত্রে':'RB','একথা':'NN','একদন্ত':'NN','একদম':'RB','একদল':'NN',
'একদলীয়':'NN','একদা':'RB','একদাম':'NN','একদিকে':'NN','একদিকের':'JJ','একদিন':'NN','একদিনের':'NN',
'একদিবসীয়':'JJ','একদৃষ্টি':'RB','একদৃষ্টিতে':'JJ','একদেশদর্শিতার':'NN','একদেশী':'JJ','একদেশে':'NN','একদ্রংস্ট্র':'NN',
'একধরণের':'NN','একধাপ':'NN','একধিক':'NN','একনও':'RB','একনড়ি':'NN','একনা':'NN','একনায়কতন্ত্র':'NN',
'একনায়কের':'NN','একনিষ্ট':'NN','একনেকের':'NN','একনয়':'NN','একপক্ষ':'IN','একপক্ষীয়':'JJ','একপর্যায়ে':'CC',
'একপা':'NN','একপাশে':'IN','একপেশে':'VBN','একপ্রকার':'NN','একফসলী':'NN','একবচন':'NN','একবছর':'IN',
'একবর্ষজীবি':'JJ','একবার':'NN','একবারও':'RB','একবারে':'NN','একবারের':'JJ','একবারো':'RB','একবিংশ':'NN',
'একবৃন্দ':'NN','একবেলা':'NN','একমত':'VB','একমনে':'NN','একমাএ':'NN','একমাত্র':'RB','একমাত্রিক':'JJ',
'একমাস':'NN','একমুখী':'NN','একমুটো':'NN','একমুঠো':'CD','একযুগে':'NN','একর':'NN','একরকমের':'JJ',
'একরাত্রী':'NN','একরাশ':'VBN','একরায়':'JJ','একরূপতা':'NN','একরোখা':'NN','একলব্য':'NN','একলসেঁড়ে':'NN',
'একলা':'RB','একশ':'NN','একশত':'JJ','একশন':'NN','একশৃঙ্গ':'NN','একশো':'NN','একশোবার':'CD',
'একশ্রেণীর':'NN','একষট্টি':'NN','একষট্টিতম':'JJ','একসঙ্গে':'RB','একসময়':'NN','একসময়ের':'NN','একসাগরের':'NN',
'একসাথে':'RB','একসূত্র':'JJ','একসেপ্ট':'IN','একসেস':'NN','একস্ব':'NN','একহারা':'JJ','একা':'RB',
'একাংশ':'CD','একাই':'RB','একাউন্ট':'NN','একাউন্টে':'NN','একাকার':'NN','একাকিত্ব':'NN','একাকী':'RB',
'একাক্ষ':'NN','একাক্ষরোপনিষদ':'NN','একাগ্রচিত্ত':'NN','একাগ্রতা':'NN','একাঙ্কী':'NN','একাচোরা':'JJ','একাজ':'DT',
'একাজটি':'NN','একাজের':'NN','একাট্টা':'RB','একাডেমি':'NN','একাডেমিশিয়ান':'JJ','একাণ্ডজ':'NN','একাত্তর':'NN',
'একাত্তরতম':'JJ','একাত্তরে':'NN','একাত্ম':'JJ','একাত্মতা':'NN','একাত্মবাদ':'JJ','একাত্মবাদী':'NN','একাদশ':'NN',
'একাদশে':'NN','একাদেমী':'JJ','একাদেমীর':'NNP','একাধারে':'CD','একাধিক':'CD','একাধিকবার':'NN','একাধিপতী':'JJ',
'একাধিপত্য':'NN','একানব্বই':'NN','একানব্বইতম':'JJ','একান্ত':'NN','একান্তবাসী':'NN','একান্ন':'CD','একাবলী':'CD',
'একার':'RB','একারণে':'NN','একারণেই':'JJ','একারনে':'NN','একারান্ত':'JJ','একার্থক':'JJ','একালে':'RB',
'একাশি':'NN','একাশিতম':'JJ','একাশী':'NN','একাশ্রয়তা':'NN','একাহ':'NN','একাহারি':'JJ','একি':'NN',
'একিরকম':'NN','একী':'NN','একীভবন':'NN','একীভূত':'JJ','একুনে':'RB','একুশ':'NN','একুশতম':'JJ',
'একে':'RB','একেই':'NN','একেক':'NN','একেকটা':'NN','একেবারই':'RB','একেবারেই':'NN','একের':'CD',
'একেশ্বরবাদ':'NN','একোনমিকেল':'JJ','এক্কা':'NN','এক্কাওয়ালা':'NN','এক্কাগাড়ী':'NN','এক্কী':'NN','এক্কেবারে':'RB',
'এক্জিকিউটিভ':'NN','এক্টিভিটি':'NN','এক্রা':'NN','এক্ষেত্রে':'NN','এক্স-রশ্মি':'NN','এক্স':'NN','এক্সএস':'NN',
'এক্সচেঞ্জ':'NN','এক্সচেন্জে':'NNP','এক্সট্রা':'NNS','এক্সট্রিম':'NN','এক্সপার্ট':'NN','এক্সপায়ার্ড':'JJ','এক্সপেক্টেড':'VBN',
'এক্সপেরিমেন্ট':'NN','এক্সপ্রেস':'NN','এক্সপ্রেসওয়ে':'RB','এক্সপ্রেসে':'NNP','এক্সপ্লোরার':'NN','এক্সময়':'NN','এক্সরে':'NN',
'এক্সাম':'NN','এক্সিকিউট':'NN','এক্সিক্যুটিভ':'NN','এক্সেস':'NN','এক্সোসরিজ':'NNS','এক্স্ট্রা':'NNS','এখটা':'CD',
'এখতিয়ার':'NN','এখন-এখন':'RB','এখন':'RB','এখনও':'RB','এখনকার':'RB','এখনতো':'NN','এখনি':'RB',
'এখনে':'NN','এখনো':'RB','এখনো':'RB','এখান':'NN','এখানকার':'RB','এখানে':'RB','এখানেও':'RB',
'এখানের':'NN','এখুনি':'VB','এখ‌নো':'RB','এগার':'NNP','এগারো':'NN','এগারোটায়':'RB','এগালিতে':'NNP',
'এগিয়ে':'VB','এগিয়েছি':'VBD','এগিয়ে':'RB','এগিয়েছ':'NN','এগিয়েছে':'NNP','এগীয়ে':'RB','এগুতে':'NN',
'এগুল':'DT','এগুলারে':'DT','এগুলি':'DT','এগুলিকে':'PR','এগুলেই':'NN','এগুলোর':'DT','এগুলো':'DT',
'এগুলোও':'NN','এগুলোর':'DT','এগোচ্ছে':'VB','এগোতে':'NN','এগোনো':'NN','এগোবে':'NN','এগোয়':'VB',
'এগোয়':'VB','এগ্রিমেন্টে':'NN','এছাড়া':'RP','এছাড়া':'IN','এছাড়াও':'RB','এজ':'NN','এজন্য':'NN',
'এজমালী':'JJ','এজরা':'NNP','এজলাস':'NN','এজাতীয়':'DM','এজারদের':'NN','এজেণ্ট':'NN','এজেন্টও':'NN',
'এজেন্টদের':'NNS','এজেন্টদেরকে':'NN','এজেন্ডা':'NN','এজেন্সী':'NN','এঞ্জিনিয়ারিং':'NN','এঞ্জিনীয়ারিং':'NNP','এঞ্জেল':'NNP',
'এঞ্জেলেস':'NN','এট':'NN','এটাই':'PR','এটাও':'PR','এটাকি':'PR','এটাকে':'NN','এটাকেই':'PR',
'এটাতবে':'PR','এটাতো':'PR','এটার':'PR','এটি':'PR','এটিএম':'NN','এটিও':'PR','এটিকে':'PR',
'এটির':'PR','এটুকু':'DT','এটুকুইযাই':'DT','এটুকুও':'DT','এটেনডেন্স':'NN','এটেনশন':'NN','এট্যাক':'NN',
'এড':'NN','এডওয়ার্ড':'NN','এডভান্স':'NN','এডমিট':'NN','এডস':'NN','এড়-গজ':'NN','এড়াতে':'VB',
'এড়ানো':'NN','এড়ায়ে':'VB','এডি':'NN','এডিনবরা':'NN','এডিপি':'NN','এডুইন':'NNP','এডুকেটর':'NN',
'এডেনিন':'NN','এডোয়ার্ড':'NNP','এড্রেসের':'NN','এণ্টিবডি':'NN','এণ্ট্রান্স':'NN','এণ্ডোথেলিয়ম':'NN','এণ্ডোরার':'JJ',
'এত':'JJ','এতই':'NN','এতএব':'RB','এতকাল':'RB','এতকিছু':'JJ','এতক্ষণ':'RB','এতক্ষণে':'NN',
'এতগুলি':'DT','এতটা':'JJ','এতটাই':'DT','এতটুক':'DT','এতটুকু':'RB','এতটুকুই':'DT','এতদিন':'DT',
'এতদ্রুত':'DT','এতবুদ্ধি':'DT','এতবড়':'DT','এতযুগ':'DT','এতরেয়':'NN','এতশ':'NN','এতাটা':'NN',
'এতিম':'NNS','এতিমখানা':'NN','এতিমদের':'NNS','এতে':'NN','এতেও':'PR','এতো':'NN','এতো':'NN',
'এতোকিছু':'JJ','এতোটা':'JJ','এতোটাই':'NN','এতোদিন':'NN','এতোদূর':'NN','এতোবড়':'NN','এত্ত':'NN',
'এত্তোবড়':'NN','এথন':'NN','এথেন্স':'NN','এদ':'NN','এদিক-ওদিক':'RB','এদিক':'NN','এদিকে':'RB',
'এদিন':'RB','এদের':'NN','এদেরকে':'RB','এদেশ':'NN','এদেশেই':'NN','এদেশেরই':'NN','এদ্দিন':'NN',
'এধরণের':'JJ','এধরনের':'NN','এধার':'NN','এধারে':'RB','এন.এ':'NNP','এন':'NN','এনং':'CC',
'এনআইডি':'NN','এনএভি':'NN','এনএসআই':'NN','এনওসি':'NN','এনকেফালাইটিস্':'NN','এনজিও':'NN','এনজয়':'NN',
'এনটিটিএন':'NN','এনডিটিভি':'NN','এনড্রোমিডামণ্ডল':'NNP','এননটেক্স':'NN','এনপি':'NN','এনবিআর':'NN','এনবিআরের':'NN',
'এনলিস্টমেন্ট':'NN','এনাদের':'NN','এনামুল':'NN','এনার':'NN','এনারা':'PRP','এনার্জি':'NN','এনালগ':'NN',
'এনালিস্ট':'NN','এনায়েত':'NN','এনিমা':'NN','এনিমেশন':'NN','এনে':'NN','এনেছিল':'NN','এনেছিলে':'NNP',
'এনেছেন':'NN','এন্জাইম':'NN','এন্টানানারিভো':'NN','এন্টারটেইনমেন্ত':'NN','এন্টি':'NNS','এন্টিগুয়া':'NN','এন্টিগুয়ার':'JJ',
'এন্টিবায়োটিক':'NNS','এন্ট্রপি':'NN','এন্ড':'NN','এন্ডোরবাসী':'NN','এন্ডোরান':'NN','এপর':'RP','এপর্যন্ত':'NN',
'এপস':'NN','এপাড়ে':'RB','এপার-ওপার':'RB','এপার':'RB','এপার্টমেন্ট':'NN','এপার্ট্মেন্ট':'NN','এপাশ-ওপাশ':'RB',
'এপাশ':'NN','এপাড়ে':'NN','এপিএসরা':'NN','এপিজে':'NN','এপিঠওপিঠকখনও':'NN','এপিথেলিয়ম':'NNP','এপিস্টেমিওলজি':'NNP',
'এপিয়া':'NN','এপোলজি':'NN','এপ্রিল':'NN','এপ্লায়েন্স':'NN','এপ্সর':'NN','এপয়েন্টমেন্ট':'NN','এফ.':'NNP',
'এফ':'NN','এফআইআর':'NN','এফআরএসএ':'FW','এফকে':'NN','এফপিও':'NN','এফিডেবিট':'NN','এফেক্ট':'NN',
'এফের':'NN','এব':'NNP','এবং':'CC','এবংমানুশের':'NN','এবংসেই':'NN','এবছর':'NN','এবড়ো-খেবড়ো':'JJ',
'এবস্ট্র্যাক্ট':'NN','এবার':'RB','এবারও':'NN','এবারে':'NN','এবারেও':'RB','এবারের':'NN','এবি':'NNP',
'এবিএম':'NN','এবেয়ং':'FW','এব্যাপারে':'NN','এভাবে':'RB','এভাবেই':'NN','এভারগ্রিন':'NN','এভারেজ':'NN',
'এভিএম':'NN','এভিয়েশন':'NN','এম-45':'NNP','এম.':'NNP','এম':'NN','এমএনপি':'NN','এমএলএম':'NN',
'এমটি':'PR','এমডি':'NN','এমডিদের':'NN','এমডিসহ':'NN','এমতবস্থায়':'NN','এমন':'JJ','এমনই':'NN',
'এমনকি':'NN','এমনটা':'NN','এমনটি':'NN','এমনতর':'NN','এমনভাবে':'NN','এমনি':'RB','এমনিই':'NN',
'এমনিতেই':'NN','এমনিভাবে':'RB','এমনে':'NN','এমপি':'NN','এমপিওভুক্তি':'NN','এমপিগণ':'NN','এমপিদের':'NN',
'এমপিমন্ত্রীদের':'NN','এমপির':'NN','এমপ্লয়মেনট':'NNP','এমবাপপেও':'NN','এমবাপের':'NN','এমবাপ্পের':'NN','এমবাবান':'NN',
'এমবি':'NN','এমবিএস':'NN','এমবোলাস':'NNP','এমব্রোস':'NN','এমাজ':'NN','এমাজউদ্দিন':'NN','এমাজউদ্দীন':'NN',
'এমার্জেন্সী':'NN','এমিশান':'NN','এমু':'NN','এমেকাকেই':'NN','এমের':'NNP','এমেরিটাস':'NNP','এম্নিতেই':'NN',
'এম্পারার':'NN','এম্পি':'NN','এম্পোরিয়াম':'NN','এম্বেসিতে':'NN','এম্ব্যাপে':'NN','এয়ার':'NN','এয়ারপোর্টে':'NN',
'এয়ার্কি':'NN','এযাবৎকালের':'NN','এর':'IN','এরই':'NN','এরও':'NN','এরকম':'JJ','এরকমভাবে':'RB',
'এরকমি':'NN','এরকা':'NN','এরচে':'NN','এরচেয়েও':'NN','এরণ্ড':'NN','এরপর':'NN','এরপরও':'NN',
'এরপরেই':'RB','এরপরেও':'NN','এরপরের':'PR','এরশাদ':'NN','এরশাদের':'NN','এরা':'NN','এরাই':'PR',
'এরাও':'NN','এরাকতবড়':'NN','এরাট্যাক্স':'NN','এরাতো':'NN','এরাযারা':'NN','এরিট্রিয়া':'NN','এরিট্রিয়ার':'JJ',
'এরিস':'NN','এরিসটোটেল':'NN','এরিস্টোটল':'NNP','এরিয়া':'NN','এরিয়ান্স':'NNP','এরুপ':'NN','এরেস্ট':'NN',
'এরোকম':'NN','এরোগেন্ট':'NN','এরোনটিক্স':'NN','এরোপ্লেন':'NN','এর্নাকুলম':'NN','এল.':'FW','এল':'NN',
'এলএনজি':'NN','এলকোভ':'NN','এলজি':'NN','এলটিইএর':'NN','এলডিসি':'NN','এলপিজি':'NN','এলফা':'NN',
'এলবিডাব্লু':'NN','এলসি':'NN','এলাইয়া':'VB','এলাউ':'NN','এলাকা':'NN','এলাকাগুলিতে':'NN','এলাকাতেই':'NN',
'এলাকাবাসীর':'NN','এলাকায়':'NN','এলাকায়':'NN','এলাকা—সেটা':'NN','এলাচ':'NN','এলাচদানা':'NN','এলান্সন':'NN',
'এলাম':'NN','এলার্জি':'NN','এলাহাবাদ':'NN','এলাহাবাদে':'NNP','এলাহীর':'NN','এলা‌হি':'NN','এলি':'VB',
'এলিজা':'NNP','এলিফেন্টা':'NN','এলিভেটেড':'NN','এলিমিনেট':'NN','এলিয়েনদের':'NN','এলিস':'NN','এলিয়ন':'NN',
'এলিয়ে':'VB','এলিয়েন':'NN','এলুম':'VB','এলে':'NN','এলেই':'RP','এলেও':'NN','এলো':'NN',
'এলোকেশী':'NNP','এলোপাথারি':'RB','এলোমেলো':'JJ','এলোমেলোভাবে':'RB','এলো৷':'VB','এল্ক':'NN','এশলে':'NN',
'এশা':'NN','এশিয়া':'NN','এশিশুর':'NN','এশিয়':'NN','এশিয়াটিক':'NNP','এশিয়াতে':'NN','এশিয়াবাসী':'NN',
'এশিয়ার':'NN','এশীয়':'NN','এষ':'NN','এস.':'NNP','এস':'NN','এসআই':'NN','এসইউভি':'NN',
'এসএমএস':'NN','এসএস':'NN','এসএসসি':'NN','এসকে':'NN','এসটিএফ':'NN','এসপার':'NN','এসপি':'NN',
'এসফাল্ট':'NN','এসব':'NN','এসবও':'NN','এসবকে':'NN','এসবগুজব':'NN','এসবে':'NN','এসবের':'NN',
'এসময়':'NN','এসময়ের':'NN','এসরাজ':'NN','এসসি':'NN','এসাজ':'NN','এসার':'NNP','এসি':'NN',
'এসিসিএ':'NN','এসিস্টেন্ট':'NN','এসে':'NN','এসেই':'VB','এসেছ':'VB','এসেছি':'RB','এসেছিল':'VB',
'এসেছিলে':'VB','এসেছে':'VB','এসেট':'NN','এসেন্সিয়াল':'JJ','এসেমব্লিজে':'NNP','এসো':'NN','এসোসিয়েশনের':'NNP',
'এসোসিয়েট':'NN','এস্কর্বিক':'NN','এস্কিমো':'NN','এস্টাটিন':'NN','এস্টারে':'NN','এস্টোনিয়া':'NN','এহছানুল':'NN',
'এহনই':'NN','এহসানুল':'NN','এহেন':'NN','এ়ক্ট':'NNP','এ্যকশনে':'NN','এ্যাডার':'NN','এ্যাণ্টিকিটিক':'NN',
'এ্যাণ্টিজেন':'NN','এ্যান্ড্রু':'NN','এ্যাপটি':'NN','এ্যাপল':'NNP','এ্যাম':'NN','এ্যালোপাথি':'NN','এ্যাসিস্ট':'NN',
'এড়াতে':'NN','এড়ানো':'NN','এড়িয়ে':'NN','এয়ার':'NN','এয়ারওয়েজ':'NN','এয়ারটেল':'NN','এয়ারপোর্ট':'NN',
'এয়ারলাইনস':'NN','এয়ারলাইন্সে':'NN','এয়ারলাইন্সের':'NNS','এয়ারের':'NN','এয়োরোনটিক্স':'NN','এয়োস্ত্রী':'JJ','এ‌কেবার':'NN',
'এ‌গি‌য়ে':'NN','এ‌দের':'NN','এ‌শিয়ার':'NN','ঐ':'DT','ঐকমতে':'NN','ঐকারান্ত':'JJ','ঐক্য':'NN',
'ঐক্যজোটের':'NN','ঐক্যফ্রড':'NN','ঐক্যফ্রন্টকে':'NN','ঐক্যফ্রন্টের':'NN','ঐক্যমতে':'NN','ঐক্যমত্য':'NN','ঐক্যসম্বন্ধীয়':'JJ',
'ঐক্যহীন':'JJ','ঐক্যের':'NN','ঐখান':'NN','ঐখানে':'RB','ঐগুলোর':'NN','ঐচ্ছিক':'NN','ঐটা':'NN',
'ঐটুকু':'NN','ঐতহাসিক':'NN','ঐতিহাসিক':'JJ','ঐতিহাসিকগণ':'NN','ঐতিহাসিকভাবেই':'RB','ঐতিহাসিকরাই':'NN','ঐতিহাসিকের':'NN',
'ঐতিহ্য':'NN','ঐতিহ্যবাদ':'NN','ঐতিহ্যবাহী':'JJ','ঐতিহ্যের':'NN','ঐদিন':'NN','ঐদেশে':'NN','ঐন্দ্রজালিক':'NN',
'ঐন্দ্রাণী':'NN','ঐরকম':'DM','ঐরাবত':'NN','ঐরূপ':'DM','ঐল':'NN','ঐশ্চর্য্যে':'NN','ঐশ্বর্যময়ী':'NN',
'ঐশ্বর্যশালী':'JJ','ঐশ্বর্যা':'NN','ঐশ্বর্য্যদায়ক':'JJ','ঐসব':'NN','ও-কার':'NN','ও.':'NNP','ও':'UH',
'ওঁ':'UH','ওঁকে':'NN','ওঁত্':'RB','ওঁদের':'PR','ওঁর':'NN','ওঁরা':'PR','ওঃ':'UH',
'ওআইসি':'NN','ওই':'RB','ওইখানে':'RB','ওইটা':'NN','ওইদিকটায়':'NN','ওইসব':'NN','ওউনারশিপ':'NN',
'ওক':'NN','ওকাপি':'NN','ওকারান্ত':'JJ','ওকালতনামা':'NN','ওকালতি':'NN','ওকি':'NN','ওকে':'NN',
'ওকেই':'PR','ওকোলেহাওয়া':'NN','ওখান':'NN','ওখানে':'RB','ওগুলি':'PR','ওগুলো':'NN','ওঙ্কার':'NN',
'ওজন':'NN','ওজনকাঁটা':'NN','ওজনদার':'JJ','ওজননো':'NN','ওজনর':'NN','ওজনের':'NN','ওজস্বী':'JJ',
'ওজিল':'NN','ওজোনদার':'VB','ওজোননোর':'NN','ওঝা':'NN','ওঝাগিরি':'NN','ওটা':'DT','ওটাই':'NN',
'ওটাবা':'NN','ওটার':'NN','ওঠ':'VB','ওঠবোস':'NN','ওঠা-নামা':'NN','ওঠা-পড়া':'NN','ওঠা':'NN',
'ওঠানো':'VBG','ওঠার':'NN','ওঠা‌চ্ছে':'VBG','ওঠিয়ে':'NN','ওঠেনি':'NN','ওঠো':'NN','ওড়নষষ্ঠী':'NN',
'ওড়না':'NN','ওড়পুষ্প':'NN','ওড়া':'NN','ওড়ানোর':'NN','ওড়িশি':'NN','ওড়িয়া':'NN','ওডিআই':'NN',
'ওণম':'NN','ওতপ্রোতভাবে':'RB','ওতার':'NN','ওতাল':'NNP','ওতায়':'NN','ওতো':'NN','ওদালিস্ক':'NNP',
'ওদিক':'RB','ওদিকের':'RB','ওদের':'NN','ওদেরও':'NN','ওদেরমতো':'NN','ওদেশে':'NN','ওধার':'NNV',
'ওনডুম্বারকে':'NNP','ওনরা':'PRP','ওনলি':'NN','ওনাকে':'NN','ওনাদেরই':'NN','ওনাম-বাসী':'NN','ওনাম':'NN',
'ওনামীজ':'NN','ওনার':'NN','ওনারা':'PRP','ওনি':'PRP','ওন্টারিও':'NN','ওপড়ানো':'NN','ওপর-নিচে':'RB',
'ওপর':'IN','ওপরও':'NN','ওপরচালাক':'JJ','ওপরে':'NNS','ওপরেই':'NN','ওপরের':'IN','ওপার':'NN',
'ওপারে':'IN','ওপারেই':'NN','ওপাশ':'NN','ওপাড়ে':'IN','ওপাড়েই':'NN','ওপেন':'VB','ওপেনার':'NN',
'ওপেনিং':'NN','ওপেনিংএ':'VBG','ওবামার':'NN','ওবায়দুল':'NN','ওবিই':'PR','ওবোফ্লেবিন':'NN','ওভাই':'NN',
'ওভারগুলোতে':'NN','ওভারটা':'NN','ওভারশিয়ার':'NN','ওভারে':'NN','ওভারেই':'IN','ওভারের':'NN','ওভেন':'NN',
'ওমন':'NN','ওমর':'NN','ওমলেট':'NN','ওমা':'NN','ওমানি':'NN','ওমায়ের':'NN','ওম্':'NN',
'ওয়া':'NNV','ওয়াংখেড়ের':'NN','ওয়াইম্যাক্স':'NN','ওয়াচ':'NNP','ওয়ার্ক':'NNP','ওয়ার্কাররা':'NN','ওয়ার্কারস্':'NNP',
'ওয়ার্নারের':'NN','ওয়ার্ল্ড':'NN','ওর':'NN','ওরই':'PR','ওরফে':'NN','ওরা':'PRP','ওরাই':'NN',
'ওরাঙ':'NN','ওরিলি':'NNP','ওরিয়েণ্ট্যাল':'NNP','ওরে':'NN','ওল':'NN','ওলচা':'NN','ওলজি':'NNP',
'ওলট':'NN','ওলনদড়ি':'NN','ওলন্দাজ':'NN','ওলা':'NN','ওলাবিবি':'NN','ওলামা':'NN','ওলার':'NNP',
'ওলারা':'NN','ওলারের':'NNP','ওলিন':'NNP','ওলিম্পিক':'NNP','ওলো':'NNP','ওল্টানো':'VB','ওশান':'JJ',
'ওশিয়ানিয়া':'NN','ওষুধ':'NN','ওষ্ঠ':'NN','ওস':'NN','ওসতাদ':'NN','ওসপার':'NN','ওসব':'NN',
'ওসমান':'NN','ওসমিয়াম':'NN','ওসর':'NN','ওসলো':'NN','ওসামা':'NN','ওসি':'NN','ওসির':'NN',
'ওসিলায়':'NN','ওসূজ':'NN','ওস্তাগর':'NN','ওস্তাদদের':'NNS','ওস্তাদলোক':'NN','ওস্মানাবাদ':'NN','ওহ':'NN',
'ওহাবী':'NN','ওহে':'NNS','ওহেনরি':'NNP','ওহ্‌':'NN','ওৎপেতে':'NN','ওড়না':'NN','ওড়ার':'NNV',
'ওয়রলি':'NN','ওয়র্মআপ':'NN','ওয়া':'NN','ওয়াইগাই':'NN','ওয়াইড':'NN','ওয়াইনকে':'NNP','ওয়াইপার':'NN',
'ওয়াইল্ড':'NN','ওয়াও':'NN','ওয়াকার':'NN','ওয়াকিফ্হাল-':'NN','ওয়াকিবহাল':'NNP','ওয়াকিল':'NN','ওয়াগন':'NN',
'ওয়াঘা':'NN','ওয়াচ':'NN','ওয়াজু':'NN','ওয়াজেদ':'VBN','ওয়াট':'NN','ওয়াদা':'NN','ওয়ান':'JJ',
'ওয়ানডে':'NN','ওয়ানডেটা':'NN','ওয়ানডেসুলভ':'NN','ওয়ানপিচ':'NN','ওয়ানপ্লাসের':'NN','ওয়ানের':'CD','ওয়ান্ডের':'NN',
'ওয়ার':'NN','ওয়ারকারদের':'NNS','ওয়ারঙ্গেল':'NN','ওয়ারধা':'NNP','ওয়ারলেস':'NN','ওয়ারশিখ':'NN','ওয়ারাড়ী':'NN',
'ওয়ারিসগন':'NNP','ওয়ারেন্ট':'NN','ওয়ারের':'NNP','ওয়ার্ক':'NN','ওয়ার্কস':'NNP','ওয়ার্কিং':'NN','ওয়ার্ডে':'NN',
'ওয়ার্ন':'JJ','ওয়ার্নার':'NNP','ওয়ার্নারের':'NNP','ওয়ার্ল্ড':'NN','ওয়াল':'NN','ওয়ালটন':'NNP','ওয়ালরাস':'NN',
'ওয়ালশ':'NN','ওয়ালশের':'NN','ওয়ালস':'NN','ওয়ালাদের':'NN','ওয়ালারা':'NN','ওয়াশ':'NN','ওয়াশিংটন':'NN',
'ওয়াস':'NN','ওয়াসার':'NN','ওয়াসিম':'NN','ওয়াসেল':'NN','ওয়াস্টার্ন':'NN','ওয়াহাবী':'NN','ওয়াহিদউজজামান':'NN',
'ওয়ায়':'NNP','ওয়ে':'NN','ওয়েগনার':'NN','ওয়েগাপিতিয়ার':'NN','ওয়েট':'NN','ওয়েটিংরুমের':'NN','ওয়েতে':'NN',
'ওয়েনারের':'NNP','ওয়েব':'NN','ওয়েবঠিকানাও':'NN','ওয়েবসাইট':'NNP','ওয়েবসাইটগুলো':'NNS','ওয়েবসাইটে':'NN','ওয়েল':'NNP',
'ওয়েলকাম':'NN','ওয়েলথএক্স':'NN','ওয়েলফেয়ার':'NN','ওয়েলশ':'NN','ওয়েলস':'NNP','ওয়েলিংটন':'NN','ওয়েল্ডিং':'VB',
'ওয়েল্স':'NN','ওয়েষ্টইন্ডিজকে':'NNS','ওয়েষ্টার্নের':'JJ','ওয়েস্ট':'NN','ওয়েস্টইন্ডিজ':'NN','ওয়েস্টার্ন':'JJ','ওয়্যাটসএপ':'NN',
'ওয়্যারলেস':'JJ','ওয়্যারহাউসের':'NN','ও‌সি‌দের':'NN','ঔ':'NN','ঔঁগাই':'NN','ঔকারান্ত':'JJ','ঔঙ্গোল':'NN',
'ঔঠাওয়ানী':'NN','ঔত্সর্গিক':'NN','ঔদরিক':'JJ','ঔদাসীন্য':'NN','ঔদিন':'NN','ঔদুম্বর':'NN','ঔদ্ধত্য':'NN',
'ঔপনিবেশিক':'JJ','ঔপন্যাসিক':'NN','ঔপাদানিক':'JJ','ঔরঙ্গজেব':'NN','ঔরছা':'NN','ঔরস':'JJ','ঔরাঙ্গাবাদ':'NN',
'ঔরৈয়া':'NN','ঔর্ব':'NN','ঔষদ':'NN','ঔষধ-বিক্রেতা':'NN','ঔষধ':'NN','ঔষধালয়':'NN','ঔষধি':'NN',
'ঔষধের':'NN','ঔষ্ঠ্য-সংক্রান্ত':'JJ','ঔষ্ঠ্য':'JJ','ক-বর্গীয়':'JJ','ক':'NN','কঁচামাল':'NN','কঁসুয়া':'NN',
'কং':'NN','কংক্রিটের':'NN','কংগ্রেস-নকশাল':'NNP','কংগ্রেস':'NN','কংগ্রেসই':'NNP','কংগ্রেসী':'JJ','কংগ্রেসে':'NNP',
'কংগ্রেসের':'NN','কংস':'NN','কংসাসুর':'NN','কংসের':'NNP','কই':'NN','কইছে':'VB','কইতাম':'VB',
'কইতে':'WRB','কইবেন':'VB','কইরা':'VB','কইরেন':'VBP','কইরো':'VB','কইল':'VB','কইয়া':'VB',
'কওমিরাও':'NN','ককটেল':'NN','ককুভ':'NN','ককের':'NN','ককেশাসে':'NNP','কক্':'NNP','কক্টেল':'NN',
'কক্টেলে':'NNS','কক্ষ':'NN','কক্ষনো':'RB','কক্ষপথ':'NN','কক্ষপুট':'NN','কক্ষপ্রধান':'NN','কক্ষসমষ্টি':'NN',
'কক্ষীবান':'NN','কক্ষে':'NN','কক্সবাজার':'NN','কক্সবাজারের':'NN','কক্সিস':'NN','কখন':'WRB','কখনই':'NN',
'কখনও-কখনও':'RB','কখনও':'RB','কখনো':'NN','কখনো-বা':'RB','কখনোই':'RB','কখোনই':'NN','কখোনো':'RB',
'কগমন':'NN','কগেড়ি':'NN','কঘাত':'NN','কঙ্ক':'NN','কঙ্কণাস্স্ত্র':'NN','কঙ্কন':'NN','কঙ্কপর্বা':'NN',
'কঙ্কপৃষ্ঠী':'NN','কঙ্কমালা':'NN','কঙ্কমুখ':'NN','কঙ্কর':'NNP','কঙ্কাল':'NN','কঙ্কালাস্ত্র':'NN','কঙ্গন':'NN',
'কঙ্গনী':'NN','কঙ্গুনি':'NNP','কঙ্গো':'NN','কচ':'NN','কচকে':'NNP','কচনার':'NN','কচরী':'NN',
'কচলাইয়েন':'NN','কচাটোর':'NN','কচালু':'NN','কচি-কাচা':'NN','কচি':'NN','কচিকাঁচাগুলো':'JJ','কচু':'NN',
'কচুগাঁও':'NNP','কচুড়ি':'NN','কচুর':'NN','কচুরিপানা':'NN','কচ্ছ':'NN','কচ্ছপিকা':'NN','কচ্ছপের':'NN',
'কচ্ছী':'NN','কছর':'NN','কজ':'NN','কজন':'WH','কজাক':'NN','কজূ':'NN','কজোট':'NN',
'কঝকে':'NN','কঞ্চি':'NN','কঞ্জী':'NN','কঞ্জুসি':'NN','কটক':'NN','কটকট':'VB','কটকটে':'NN',
'কটকি':'NN','কটা':'JJ','কটাই':'NN','কটাও':'NN','কটাকা':'NN','কটাচোখি':'NN','কটাচোখী':'JJ',
'কটার':'NN','কটায়':'NN','কটি':'NN','কটিদেশ':'NN','কটিন':'NN','কটিবস্ত্র':'NN','কটির':'NN',
'কটু':'NN','কটুকন্দ':'NN','কটুতা':'NN','কটুপত্রফলা':'NN','কটূ':'JJ','কটূকথা':'NN','কটূক্তি':'NN',
'কটূফল':'NN','কটূবচন':'NN','কটূভাষী':'JJ','কটের':'NN','কটোরা':'NN','কট্টর':'JJ','কট্টরতা':'NN',
'কট্টরপন্থী':'NN','কট্টরপন্থীদের':'NNS','কট্টরপন্হী':'NN','কট্টরবাদী':'JJ','কট্টুমরম':'NN','কট্ট্রর':'NN','কঠ':'NN',
'কঠরুদ্র':'NN','কঠরুদ্রোপনিষদ':'NN','কঠাক':'JJ','কঠিণ':'IN','কঠিনও':'NN','কঠিনতম':'JJS','কঠিনতর':'NN',
'কঠিনযেখানে':'NN','কঠিনহস্তে':'NNS','কঠুয়া':'NN','কঠোর':'NN','কঠোদর':'NN','কঠোপনিষদ':'NN','কঠোর':'NN',
'কঠোরতার':'NN','কঠোরভাবে':'RB','কড়কড়':'NN','কড়পা':'NN','কড়লুর':'NN','কড়া':'NN','কড়ায়':'NN',
'কড়ি':'NN','কড়ির':'NN','কড়ে':'NN','কডাক':'NN','কঢ':'NN','কণভক্ষ':'NNP','কণা':'NN',
'কণাদ':'NN','কণিকা':'NN','কণ্টকহীন':'JJ','কণ্টফলা':'NN','কণ্ঠ-মণি':'NN','কণ্ঠ':'NN','কণ্ঠতালব্য':'JJ',
'কণ্ঠবর্ণ':'JJ','কণ্ঠমণি':'NN','কণ্ঠশালুক':'NN','কণ্ঠশ্রী':'NN','কণ্ঠস্থ':'JJ','কণ্ঠস্বরও':'NN','কণ্ঠস্বরে':'NNP',
'কণ্ঠহার':'NN','কণ্ঠি':'NN','কণ্ঠে':'NN','কণ্ঠোষ্ঠ্য':'JJ','কণ্ডরা':'NN','কণ্ডুকতীর্থ':'NN','কণ্ডেন্সর':'NN',
'কণ্ডোম':'NN','কত':'NN','কতইনা':'NN','কতক':'CD','কতকগুলি':'CD','কতকাল':'RB','কতক্ষণ':'RB',
'কতখানি':'JJ','কতগুন':'NN','কতগুলি':'CD','কতগুলো':'NN','কতজন':'NN','কতটা':'NN','কতটুকু':'NN',
'কতটুকুই':'CD','কতদিন':'RB','কতদুর':'NN','কতদূর':'CD','কতদ‌িন':'NN','কতনা':'NN','কতবার':'NNS',
'কতবেল':'NN','কতরকমের':'IN','কতা':'NN','কতাই':'CD','কতাবার্তা':'NN','কতার':'NN','কতিপয়':'NN',
'কতিপয়':'JJ','কতিপয়ের':'DT','কতির':'NN','কতৃপক্ষ':'NN','কতৃপক্ষকে':'NNS','কতৃর্পক্ষও':'NN','কতৃৃপক্ষের':'NN',
'কতেই':'CD','কতেন':'VB','কতো':'NN','কতো':'NN','কতোগুলো':'NN','কতোটা':'NN','কতোটুকু':'NN',
'কত্ত':'NN','কত্তো':'NNP','কত্থক':'NN','কত্ব':'NN','কথ':'NN','কথন':'NN','কথনীয়':'JJ',
'কথা-শোনানো':'NN','কথা':'NN','কথাআসলেই':'NN','কথাই':'NN','কথাকলি':'NN','কথাগুলি':'NNS','কথাগুলোর':'NN',
'কথাটা':'NN','কথাটাও':'NN','কথাটার':'NN','কথাটি':'NN','কথাটিও':'NN','কথাতেই':'NN','কথানামা':'NN',
'কথানুসারে':'RB','কথাবলতেই':'VB','কথাবলার':'VB','কথাবার্তা':'NN','কথাবার্তায়':'NN','কথামতই':'NN','কথায়':'NN',
'কথার':'NN','কথায়':'NN','কথিত':'NN','কথিম':'NNP','কথোকতা':'NN','কথোপকথন':'NN','কথ্য':'NN',
'কদন্ন':'NN','কদম':'NN','কদমতাল':'VB','কদমা':'NN','কদম্ব':'NN','কদর':'NN','কদরহীন':'JJ',
'কদর্য':'NN','কদর্য্য':'JJ','কদলী':'NN','কদলীজঙ্ঘা':'JJ','কদলীর':'NN','কদাকার':'NN','কদাচন':'NN',
'কদাচিত':'RB','কদার্য':'NN','কদিন':'NNS','কদু':'NN','কদুই':'NNP','কদের':'NN','কদ্রু':'NN',
'কন':'NN','কনক-কলি':'NN','কনক':'NN','কনকচম্পা':'NN','কনকজিরা':'NN','কনকধ্বজ':'NN','কনকাচল':'NN',
'কনকুটকি':'NN','কনকোয়েস্ট':'NNP','কনছার্ট':'NN','কনজাংকটিভাইটিস':'NN','কনটেইনার':'NN','কনটেক্ট':'NN','কনদিন':'NNP',
'কনফারেন্স':'NN','কনফার্ম':'NN','কনফিডেন্স':'NN','কনভয়':'NN','কনভেনশন':'NN','কনভয়':'NN','কনরশ্যাম':'NN',
'কনলসিংহের':'NNP','কনসলাই':'NN','কনসালটেণ্টের':'NN','কনসুলেটে':'NN','কনস্টবেলটার':'NN','কনস্টিটুয়েন্সি':'NN','কনস্টেবল':'NN',
'কনস্ট্রাকশন':'NN','কনিনীকা':'NN','কনিষ্ক':'NN','কনিষ্টপাণ্ডব':'NN','কনিষ্ঠ':'NN','কনিয়ারি':'NN','কনী':'NN',
'কনুই':'NN','কনে':'NN','কনেযাত্রি':'NN','কনের':'NN','কনো':'NN','কনৌজ':'NNP','কনৌতি':'NN',
'কন্-এর':'NNP','কন্টক':'NN','কন্টকাকীর্ণ':'JJ','কন্টকারী':'NN','কন্টাক্ট':'NN','কন্টিনিউ':'NN','কন্টেইনার':'NN',
'কন্টেইনারে':'NNS','কন্ট্রল':'NN','কন্ট্রাক্টর':'NN','কন্ট্রোল':'NN','কন্ঠ':'NN','কন্ঠবন্ধনি':'NN','কন্ঠরোগ':'NN',
'কন্ঠা':'NN','কন্ঠি':'NN','কন্ঠের':'NN','কন্ঠ্য':'NN','কন্ডাকটর':'NN','কন্দ':'NN','কন্দবনট':'NN',
'কন্দসার':'NN','কন্দ্রীয়':'NN','কন্ধ':'NN','কন্নড়':'NNP','কন্নুর':'NN','কন্ফারেন্স':'NN','কন্ব':'NN',
'কন্যা':'NN','কন্যাকুমারী':'NNP','কন্যাকে':'NN','কন্যাটিও':'NN','কন্যাদান':'NN','কন্যারা':'NNS','কন্যারাশি':'NN',
'কন্সিডার':'VB','কন্সেন্ট্রেশন':'NN','কনড়':'NN','কপক':'NN','কপচাচ্ছেন':'VBG','কপট':'NN','কপটতাপূর্ণ':'JJ',
'কপটতাময়':'JJ','কপটতাশূণ্য':'NN','কপটতাহীন':'NN','কপটা':'NN','কপর্দিক':'NN','কপাটিকাগুলি':'NN','কপাত':'NN',
'কপাল':'NN','কপালউন্নতির':'NN','কপালে':'NN','কপালের':'NN','কপাসী':'NN','কপি':'NN','কপিঞ্জল':'NN',
'কপিপেস্ট':'NN','কপিরাইট':'NN','কপিল':'NNP','কপিলা':'NN','কপিলাবস্তু':'NN','কপীশ':'NN','কপুর':'NNP',
'কপুরি':'NN','কপোত':'NN','কপোতের':'NN','কপ্টিক':'JJ','কফ':'NN','কফজ্বর':'NN','কফি-হাউস':'NN',
'কফি':'NN','কফিনবন্দী':'VB','কফিনে':'NN','কফিহাউস':'NN','কফোদর':'NN','কবচ':'NN','কবচধারী':'JJ',
'কবচহীন':'JJ','কবছর':'IN','কবজ':'NN','কবনা':'NN','কবন্ধ':'NN','কবর':'VB','কবরী':'NN',
'কবরে':'NN','কবর্গ':'NN','কবল':'NN','কবাব':'NN','কবাবচিনি':'NN','কবার':'RB','কবি':'NN',
'কবিজীবনে':'NN','কবিতা':'NN','কবিতার':'NN','কবিত্বপূর্ণ':'JJ','কবিদের':'NN','কবিন্দ্রনাথ':'NN','কবির':'NN',
'কবিরপন্থী':'JJ','কবিরা':'NN','কবিরাজ':'NNP','কবিরুল':'NNP','কবিরের':'NNP','কবিলাসিকা':'NN','কবীর-পথ':'NN',
'কবীর':'NNP','কবীরদাস':'NN','কবীরপন্হী':'NN','কবুচী':'NN','কবুল':'VBN','কবে':'WRB','কবেই':'RB',
'কবেন':'VB','কবোধ':'NN','কব্জা':'NN','কব্জি':'NN','কব্জির':'NN','কবয়িত্রী':'NN','কভার':'NN',
'কভী':'NNP','কভুতর':'NN','কভূ':'NN','কম-বেশী':'RB','কম':'JJ','কমই':'RB','কমএ':'NN',
'কমখাব':'NN','কমছে':'NN','কমজোর':'NN','কমঠ':'NN','কমণ্ডুল':'NN','কমতি':'NN','কমতো':'NN',
'কমদামী':'JJ','কমদামে':'NNP','কমন':'NN','কমনওয়েলথের':'NNP','কমনসেন্স':'NN','কমনীয়তা':'NN','কমনে':'NN',
'কমন্দ':'NN','কমপক্ষে':'NN','কমপ্লান-এ':'NN','কমপ্লেক্স-39':'NNP','কমপ্লেক্স':'NN','কমপ্ল্যায়ান্স':'NN','কমবে':'NN',
'কমবেশি':'NN','কমবয়সী':'JJ','কমবয়েসীদের':'NN','কমমুল্যে':'NN','কমমূল্যের':'NN','কমযোগ্যতা':'NN','কমরেড':'NN',
'কমর্চারী':'NN','কমল':'NN','কমলকোষ':'NN','কমলগড়':'NN','কমললোচন':'JJ','কমলা':'NN','কমলাপতি':'NN',
'কমলালেবু':'NN','কমলাসন':'NN','কমলে':'NN','কমলেশ':'NNP','কমসে':'VB','কমহয়তো':'NN','কমা':'NN',
'কমাণ্ড':'NN','কমাতে':'NN','কমান':'NN','কমানোর':'NN','কমান্ড':'NN','কমান্ডার':'NN','কমাবার':'JJ',
'কমাবে':'NN','কমার':'NN','কমার্স':'NN','কমালে':'NN','কমায়':'NN','কমায়নি':'NN','কমি':'NN',
'কমিউটার':'NN','কমিউনিজম':'NN','কমিউনিটির':'NN','কমিউনিষ্ট':'JJ','কমিউনিস্ট':'NN','কমিকস্':'NN','কমিটমেন্টের':'NN',
'কমিটি':'NN','কমিটির':'NN','কমিপয়':'DT','কমিয়ে':'NN','কমিশন':'NN','কমিশনওয়ালা':'NN','কমিশনকে':'NN',
'কমিশনার':'NN','কমিশনারদের':'NNS','কমিশনারের':'NN','কমিশনের':'NN','কমিসনের':'NN','কমিয়া':'VB','কমিয়ে':'VBN',
'কমিয়েছে':'NN','কমী':'NN','কমু':'NN','কমে':'VBN','কমেছে':'NN','কমেডি':'NN','কমেডির':'NN',
'কমেণ্ট':'NN','কমেতো':'NN','কমেন্ট':'NN','কমেন্টটা':'NN','কমেন্টা':'NN','কমেন্ট্রি':'NN','কমের':'NN',
'কমেয়ে':'NN','কমোড':'NN','কমোদ':'NN','কমোরা':'NN','কম্কান্ড':'NN','কম্প':'NN','কম্পন':'NN',
'কম্পমান':'JJ','কম্পাঙ্ক':'NN','কম্পানিগুলির':'NN','কম্পানিতে':'NN','কম্পানী':'NN','কম্পালা':'NN','কম্পিউটার':'NN',
'কম্পিউটারকৃত':'JJ','কম্পিউটারগুলো':'NN','কম্পিউটারিকরণ':'NN','কম্পিউটারিকৃত':'JJ','কম্পিউটারে':'NN','কম্পিটেন্সি':'NN','কম্পিত':'VBG',
'কম্পিল':'NN','কম্পোজ':'NN','কম্পোস্ট':'NN','কম্প্যুটার':'NN','কম্প্রেসর':'NN','কম্বল':'NN','কম্বিকা':'NN',
'কম্বিনেশন':'NN','কম্বু':'NN','কম্বে':'NN','কম্বোডিয়া':'NN','কম্বোডিয়ার':'JJ','কম্মেন্টেরও':'NN','কম্যুনিস্ট':'NN',
'কয়টা':'WH','কয়েক':'CD','কয়েকবার':'RB','কয়েকশো':'CD','কয়েনচেক':'NN','কয়্যারেলসাম':'NN','কর-নির্ধারণ':'NN',
'কর':'NN','করও':'NN','করক':'NN','করকম':'VB','করকা':'JJ','করকায়ু':'NN','করখা':'NN',
'করগে':'VB','করগ্রহণ':'NN','করঙ্কুল':'NN','করচ্ছে':'VB','করছ':'VB','করছিএই':'VB','করছিনা':'VB',
'করছিলাম':'VB','করছিলে':'VB','করছিলো':'VB','করছিাম':'VB','করছে':'VB','করছেন':'VB','করঞ্জ':'NN',
'করঞ্জাস':'NN','করড়ী':'NN','করণ':'NN','করণই':'VB','করণিকবৃত্তি':'NN','করণী':'NNP','করণীয়':'JJ',
'করণে':'VB','করণের':'NN','করত':'VB','করতল':'NN','করতাছিলেন':'VB','করতাছেন':'VB','করতাম':'VB',
'করতাল':'NN','করতালি':'NN','করতিপক্ষের':'NN','করতে':'VB','করতেও':'VB','করতেছে':'VB','করতেন':'VB',
'করতো':'VB','করতো':'VB','করতোয়া':'NN','করত‌':'NN','করদ':'NN','করদাতা':'NN','করন':'NN',
'করনাল':'NNS','করনালী':'NN','করনে':'NN','করপাত্র':'NN','করপুট':'NN','করপৃষ্ঠ':'NN','করপোরেশন':'NN',
'করব':'VB','করবদ্ধ':'JJ','করবা':'NN','করবিহীন':'NN','করবে':'VB','করবেন':'VB','করবো':'VB',
'করবো':'VB','করভ':'NN','করমচা':'NN','করমচাঁদ':'NNP','করমালা':'NN','করমি':'NN','করমুক্ত':'NN',
'করমূল':'NN','করম্বর':'NN','করযোগ্য':'JJ','করল':'NN','করলমন্ত্রী':'NN','করলা':'NN','করলাম':'VB',
'করলে':'VB','করলেও':'VB','করলো':'VB','করলো':'VB','করল্লা':'NN','করল‌ে':'VB','করশূন্য':'NN',
'করস':'VB','করসেবক':'NN','করহার':'NN','করা':'VB','করাই':'NNP','করাইলে':'RP','করাএই':'NN',
'করাও':'NN','করাকস':'NN','করাকে':'NNV','করাচি':'NN','করাচীতে':'VB','করাছি':'NN','করাটা':'NN',
'করাটাই':'VB','করাত':'NN','করাতে':'VB','করাতো':'VB','করাধীন':'JJ','করান':'VB','করাপশন':'NN',
'করাপ্ট':'NNP','করাবার':'NNV','করাবে':'NN','করাম':'VB','করায়':'NNV','করার':'VB','করাল':'NN',
'করায়':'NN','করি':'VB','করিও':'VB','করিক':'JJ','করিডর':'NN','করিতে':'VB','করিতেছে':'VB',
'করিনা':'VB','করিব':'VB','করিবর':'NN','করিবা':'VB','করিবে':'VB','করিম':'NN','করিমগঞ্জ':'NN',
'করিমনগর':'NN','করিয়ে':'IN','করিল':'VB','করিলাম':'VB','করিলে':'RP','করিস':'VB','করিয়া':'VBG',
'করিয়াই':'VB','করিয়াছি':'VB','করিয়াছে':'VB','করিয়ে':'IN','করিয়েছে':'VBN','করিয়েছেন':'VB','করিয়েরা':'NN',
'করীষ':'NN','করুক':'VB','করুণ':'NN','করুণাধারায়':'VB','করুণানয়ীর':'NN','করুণাময়':'JJ','করুণার':'NN',
'করুণাহীন':'JJ','করুণী':'NN','করুন':'VB','করুনমুখ':'NN','করুনা':'NN','করুম':'NN','করে':'VB',
'করেইতো':'NN','করেএ':'VB','করেছ':'VB','করেছিএ':'VB','করেছিলাম':'VB','করেছিলেন':'VB','করেছিলো':'VB',
'করেছে':'VB','করেছেন':'NN','করেছো':'VB','করেণুকা':'NN','করেতাই':'NN','করেতৈলাক্ত':'RB','করেতো':'NN',
'করেন':'NN','করেনতারা':'NN','করেননি':'NN','করেনাই':'NNS','করেনি':'NN','করের':'NN','করেলই':'NN',
'করেলবন':'NNP','করেলা':'NN','করেশুধু':'RB','করেসন্দেহ':'NN','করেসাধারন':'NN','করো':'NN','করোনারি':'NNP',
'করোলা':'NN','করৌলী':'NN','কর্ক':'NN','কর্কটক':'NN','কর্কটরাশি':'NN','কর্করোগ':'NN','কর্কশ':'IN',
'কর্কশতা':'NN','কর্কশভাব':'NN','কর্কোটক':'NN','কর্চারীদের':'NNS','কর্টেক্স':'NN','কর্ড':'NN','কর্ডিটেণ্ডিনি':'VB',
'কর্ডিয়াল':'NN','কর্ণ-কুন্ডল':'NN','কর্ণ':'NN','কর্ণকসন্নিপাত':'NN','কর্ণকীট':'NN','কর্ণকুন্ডল':'NN','কর্ণধার':'NN',
'কর্ণপালি':'NN','কর্ণপূর্ব':'NN','কর্ণপূর্বগ্রন্থিশোথ':'NN','কর্ণফার্ম':'NN','কর্ণফুল':'NN','কর্ণফুলী':'NNP','কর্ণবধ':'NN',
'কর্ণভাষ':'NN','কর্ণভেদী':'JJ','কর্ণমল':'NN','কর্ণলতিকা':'NN','কর্ণাট':'NN','কর্ণাটকবাসী':'NN','কর্ণাটকি':'JJ',
'কর্ণাটকের':'NN','কর্ণালংকার':'NN','কর্ণিক':'NN','কর্ণিকার':'NN','কর্ণেল':'NNS','কর্ণোপকর্ণিকা':'NN','কর্তন':'NN',
'কর্তনালয়':'NN','কর্তব্য-কর্মের':'NN','কর্তব্য':'NN','কর্তব্যজ্ঞানহীন':'JJ','কর্তব্যপরায়ণ':'JJ','কর্তব্যপালন':'NN','কর্তব্যবিমুখতা':'NN',
'কর্তব্যের':'NN','কর্তা':'NN','কর্তাদের':'NNS','কর্তাধর্তা':'NN','কর্তাবান্ধব':'RB','কর্তাব্যক্তি':'IN','কর্তার':'NN',
'কর্তৃক':'IN','কর্তৃকারক':'NN','কর্তৃত্ব':'NN','কর্তৃত্বহীন':'JJ','কর্তৃপক্ষ':'NN','কর্তৃপক্ষকে':'NNS','কর্তৃপক্ষটার':'NN',
'কর্তৃবাচ্য':'NN','কর্ত্তা':'NN','কর্ত্রী':'NN','কর্দম':'NN','কর্দমাক্ত':'JJ','কর্নাটকী':'NN','কর্নাধারগণ':'NNS',
'কর্নাল':'NN','কর্নেল':'NN','কর্নেলিক':'NNP','কর্পুরনালিকা':'NN','কর্পুরের':'JJ','কর্পূর':'NN','কর্পূরমণি':'NN',
'কর্পোরেট':'JJ','কর্পোরেট':'NN','কর্পোরেশনকে':'NN','কর্বর':'NN','কর্ম-কোলাহল':'NN','কর্ম':'NN','কর্মকতার':'NN',
'কর্মকর্তাকে':'NN','কর্মকর্তাগণ':'NNS','কর্মকর্তাদের':'NNS','কর্মকর্তাদেরকেই':'NNS','কর্মকর্তার':'NN','কর্মকর্তারা':'NNS','কর্মকর্তারাই':'NN',
'কর্মকাণ্ড':'NN','কর্মকাণ্ডের':'NN','কর্মকান্ডে':'NN','কর্মকার':'NN','কর্মকারের':'NN','কর্মকৌশল':'NN','কর্মক্ষম':'NN',
'কর্মক্ষেত্রে':'NN','কর্মঘন্টা':'NNS','কর্মচারি':'NN','কর্মচারিদের':'NNS','কর্মচারিরাই':'NNS','কর্মচারী':'NN','কর্মচারীগণ':'NNS',
'কর্মচারীবৃন্দ':'NN','কর্মচারীরা':'NNS','কর্মচ্যুত':'NN','কর্মজিত':'NN','কর্মজীবী':'NN','কর্মঠ':'NN','কর্মদক্ষ':'JJ',
'কর্মদক্ষতা':'NN','কর্মদিবস':'NN','কর্মনাশও':'NN','কর্মনিষ্ঠ':'JJ','কর্মপঞ্চমী':'NN','কর্মপদ্ধতি':'NN','কর্মপরিকল্পনায়':'NN',
'কর্মপুস্তক':'NN','কর্মফল':'NN','কর্মবাচ্য':'NN','কর্মবাদী':'JJ','কর্মবিমুখ':'JJ','কর্মবিরতি':'NN','কর্মবীর':'JJ',
'কর্মমুখী':'JJ','কর্মমূলক':'JJ','কর্মযজ্ঞের':'NN','কর্মযোগ':'NN','কর্মরত':'VBG','কর্মলাভে':'NN','কর্মশ্রেষ্ঠ':'NN',
'কর্মসংস্তান':'NN','কর্মসংস্থানের':'NN','কর্মসুচি':'NN','কর্মসূচি':'NN','কর্মসূচিভিত্তিক':'JJ','কর্মসূচির':'NN','কর্মসূচীর':'NN',
'কর্মসৃজনের':'NN','কর্মস্থলে':'NN','কর্মহীন':'JJ','কর্মহীনতা':'NN','কর্মাধীন':'JJ','কর্মানুসারে':'RB','কর্মারম্ঙ':'NN',
'কর্মি':'NN','কর্মী':'NN','কর্মীকে':'NN','কর্মীদের':'NN','কর্মীবার':'NN','কর্মীরা':'NN','কর্মীরাও':'NN',
'কর্মীসহ':'NN','কর্মে':'NN','কর্মেন্দ্রিয়':'NN','কর্মের':'NN','কর্মোদ্যোগী':'JJ','কর্রক':'NN','কর্শিকাস্রাবী':'NN',
'কর্ষ':'NN','কর্ষণনো':'VB','কর্ষণর':'NN','কর্ষিত':'NN','কর‌ছে':'VBG','কর‌তে':'NN','কল-কব্জা':'NN',
'কল':'VB','কলংকময়':'JJ','কলংকিত':'VBN','কলকণ্ঠ':'NN','কলকল':'NN','কলকাঠি':'NNP','কলকাতা':'NN',
'কলকাতার':'NN','কলকারখানা':'NN','কলকারাখানা':'NN','কলকে':'NNP','কলগার্ল-এর':'NNP','কলগী':'NN','কলঙ্ক':'NN',
'কলঙ্কলেপন':'NN','কলঙ্কিত':'VBN','কলচার্জ':'NN','কলটোরা':'NN','কলড্রপ':'NN','কলতে':'NN','কলত্র':'NN',
'কলপ':'NN','কলপেট্টা':'NNP','কলবিঙ্ক':'NN','কলম':'NN','কলমকার':'NN','কলমজীবি':'NN','কলমতরাশ':'NN',
'কলমদান':'NN','কলমিস্ত্রী':'NN','কলমে':'VB','কলমের':'NN','কলম্বো':'NN','কলরব':'NN','কলরে':'NN',
'কলরেটের':'NN','কলশ':'NN','কলস':'NN','কলসপত্রী':'NN','কলসি':'NN','কলসী':'NN','কলসেন্টার':'NN',
'কলহ':'NN','কলহন্তারিতা':'NN','কলহপ্রিয়':'JJ','কলহারা':'NN','কলহিনী':'NN','কলহের':'NN','কলা-কৌশল':'NN',
'কলা':'NNP','কলাই-এর':'NN','কলাইম্বিং':'NN','কলাউদ্ভাবন':'NN','কলাকার':'NN','কলাকুশলীরা':'NN','কলাকৌশলগুলি':'NN',
'কলাগাছ':'NNP','কলাত্মক':'NN','কলাধর':'NN','কলাপ':'NN','কলাপস':'NNS','কলাপিনী':'NN','কলাপুর':'NN',
'কলাপূর্ণ':'JJ','কলাপ্রেমী':'NN','কলাবউ':'NN','কলামটিতে':'NN','কলাময়':'JJ','কলার':'NN','কলারসিক':'JJ',
'কলায়':'NN','কলি-সণ্টারণ':'NN','কলি':'NNP','কলিংয়ের':'NN','কলিউড':'NN','কলিকাতার':'NN','কলিঙ্গ':'VBG',
'কলিঙ্গড়া':'NN','কলিজটা':'NN','কলিত':'JJ','কলিন্দ':'NN','কলিন্দা':'NNP','কলিযুগ':'NN','কলিযুগাদ্ধ্যা':'NN',
'কলিযুগীয়':'JJ','কলিযুগে':'NN','কলিল':'NN','কলী':'NNP','কলু':'NN','কলুষ':'NN','কলুষিত':'JJ',
'কলেই':'NN','কলেও':'RP','কলেজ':'NN','কলেজগুলির':'NNS','কলেজগুলো':'NN','কলেজ়ের':'NN','কলেজিয়েট':'NNP',
'কলেজের':'NN','কলেন':'VB','কলেবর':'NN','কলেরা':'NN','কলোইবোড়া':'NN','কলোঞ্জী':'NN','কলোনি':'NN',
'কলোনীতে':'NN','কলোম্বাস':'NN','কলোম্বিয়ান':'NN','কলোম্বিয়ার':'JJ','কল্ক':'NN','কল্কিদ্বাদশী':'NN','কল্প':'NN',
'কল্পকাহিনী':'NN','কল্পতরু':'NN','কল্পনা':'NN','কল্পনাও':'NN','কল্পনাতেই':'NN','কল্পনাথ':'NNP','কল্পনাপ্রবণ':'JJ',
'কল্পনাভিত্তিক':'NN','কল্পনার':'NN','কল্পনাশক্তি':'NN','কল্পনায়':'NN','কল্পবৃক্ষ':'NN','কল্পলতা':'NN','কল্পসত্রেও':'NN',
'কল্পিত':'NN','কল্মাষপাদ':'NN','কল্যাণ':'NN','কল্যাণকর':'JJ','কল্যাণকামোদ':'NN','কল্যাণনট':'NN','কল্যাণমূলক':'JJ',
'কল্যাণার্থ':'RB','কল্যাণী':'NNP','কল্যাণে':'NN','কল্যাণের':'NN','কল্যানমুখী':'VBN','কল্যানে':'NN','কল্লোল':'NN',
'কশাই':'NN','কশাঘাত':'NN','কশাড়':'NN','কশান':'NNP','কশিত':'JJ','কশিস':'NNP','কশীট':'NN',
'কশেরুকযুক্ত':'JJ','কশেরুকা':'NN','কশ্যপ':'NNP','কষতে':'VB','কষলে':'NN','কষা':'NN','কষাকষি':'NN',
'কষাকষির':'VBG','কষার':'NN','কষালো':'NN','কষিয়ে':'VB','কষে':'NNP','কষ্ট':'JJ','কষ্টকর':'NN',
'কষ্টকরে':'NNS','কষ্টটা':'JJ','কষ্টপূর্ণ':'JJ','কষ্টসাধ্য':'JJ','কষ্টার্জিত':'JJ','কষ্টিপাথর':'NN','কষ্টে':'JJ',
'কষ্ঠের':'JJ','কসটন':'NNP','কসময়':'NN','কসরত':'NN','কসরতনো':'VB','কসরতবাজের':'NN','কসরতি':'NN',
'কসাই':'NN','কসাইখানা':'NN','কসান':'NN','কসারাগোড':'NN','কসি':'NN','কসুর':'VB','কসে':'NN',
'কস্ট':'JJ','কস্তুর':'NN','কস্তুরি':'NN','কস্সা':'NN','কহিল':'NN','কহিলেন':'VB','কহে':'NNS',
'কহোড়':'NN','কা':'NNP','কাঁ-কাঁ':'NN','কাঁই':'VB','কাঁক':'NN','কাঁকড়া':'NN','কাঁকন':'NN',
'কাঁকপাখি':'NN','কাঁকর':'NN','কাঁকরযুক্ত':'JJ','কাঁকরে':'NN','কাঁকুড়েভাব':'NN','কাঁকুরে':'NN','কাঁখ':'NN',
'কাঁখতলী':'NN','কাঁখের':'NN','কাঁগড়ি':'NN','কাঁচ':'NN','কাঁচতোলা':'NN','কাঁচবসানো':'NN','কাঁচযুক্ত':'JJ',
'কাঁচা':'NN','কাঁচাগোল্লা':'NN','কাঁচামাল':'NN','কাঁচামালের':'NNS','কাঁচামিঠে':'JJ','কাঁচারাস্তা':'NN','কাঁচালঙ্কা':'NN',
'কাঁচি':'NN','কাঁচুমাচু':'JJ','কাঁচুলি':'NN','কাঁচে':'NN','কাঁচেরা':'NN','কাঁজই':'NN','কাঁজরী':'NN',
'কাঁটলে':'NN','কাঁটাওয়ালা':'JJ','কাঁটাছেঁড়া':'NN','কাঁটাতারের':'NN','কাঁটাযুক্ত':'NN','কাঁটার':'NN','কাঁটাহীন':'JJ',
'কাঁটায়':'NN','কাঁঠলা':'NN','কাঁঠালি':'JJ','কাঁথা':'NN','কাঁদ-কাঁদ':'JJ','কাঁদ':'NN','কাঁদছ':'VB',
'কাঁদছে':'VBG','কাঁদতে':'RP','কাঁদলেন':'VB','কাঁদা':'VBG','কাঁদাতে':'VB','কাঁদানে':'NN','কাঁদানো':'VB',
'কাঁদার':'NN','কাঁদি':'VBG','কাঁদিতে':'NN','কাঁদুন':'NN','কাঁদুনে':'JJ','কাঁদে':'NNS','কাঁদো':'JJ',
'কাঁধ':'NNS','কাঁধবিশিষ্ট':'JJ','কাঁধে':'NN','কাঁপা':'JJ','কাঁপানো':'VBG','কাঁপিয়ে':'NN','কাঁপে':'NN',
'কাঁর':'NN','কাঁসা':'NN','কাঁসাই':'NNP','কাঁসার':'NN','কাঁসারী':'NN','কাঁসি':'NN','কাঁসুলা':'NN',
'কাঁহর':'NN','কাঁহুয়া':'NN','কাঁড়া':'NN','কাংকের':'NN','কাংখিত':'NN','কাংশ':'NN','কাই':'NN',
'কাইটা':'NNP','কাইত':'NNP','কাইলি':'NNP','কাইয়েন':'NN','কাউ':'NN','কাউঠা':'NN','কাউত্তর':'NNP',
'কাউন্টার':'NN','কাউন্সিল':'NN','কাউন্সিলিং':'VBG','কাউন্সিলিঙ':'NN','কাউয়া':'NNP','কাওকে':'NN','কাওছার':'NNP',
'কাওয়ালি':'NN','কাক':'NN','কাকওয়া':'NN','কাককঙ্গু':'NN','কাকচ্ছদি':'NN','কাকড়া':'NN','কাকতালীয়':'NN',
'কাকতালীয়ভাবে':'RB','কাকতুন্ড':'NN','কাকতুয়া':'NN','কাকনাসা':'NN','কাকনি':'NN','কাকভুষুন্ডি':'NN','কাকমারী':'NN',
'কাকলি':'VB','কাকলী':'NN','কাকসি':'NN','কাকা':'NN','কাকিণী':'NN','কাকিতার':'NNP','কাকিনাড়া':'NN',
'কাকিমা':'NN','কাকু':'NN','কাকুতি':'NNP','কাকুন':'NN','কাকুরে':'NN','কাকে':'WP','কাকেক্ষু':'NN',
'কাকেড়া':'NN','কাকের':'NN','কাকোলূকীয়':'JJ','কাক্কু':'NN','কাক্ষিত':'VBN','কাগজ':'NN','কাগজপত্র':'NN',
'কাগজপত্রে':'IN','কাগজপত্রের':'NNS','কাগজি':'NN','কাগজী':'JJ','কাগজে':'NN','কাগজের':'NN','কাগুজে':'JJ',
'কাগো':'NNP','কাঙাল':'JJ','কাঙালপনা':'NN','কাঙ্ক্ষিত':'VBN','কাঙ্খ':'NN','কাঙ্খিত':'JJ','কাঙ্গরা':'NNP',
'কাঙ্গাল':'VBG','কাঙ্গুর':'NN','কাচ':'NN','কাচতে':'VB','কাচনলের':'NN','কাচলবণ':'NN','কাচা':'JJ',
'কাচানো':'NN','কাচামালের':'NN','কাচুল্লা':'NN','কাচে':'NN','কাছ':'IN','কাছা':'RB','কাছাকাছি':'RB',
'কাছার':'NN','কাছারিবাড়ি':'NN','কাছি':'NN','কাছে':'IN','কাছেআর':'RB','কাছেএই':'IN','কাছেএগিয়ে':'RB',
'কাছেও':'IN','কাছেকামনা':'JJS','কাছেগনতন্ত্র':'NN','কাছেতো':'NN','কাছের':'RB','কাছে‌ও':'NN','কাজ-কর্ম':'NN',
'কাজ':'NN','কাজও':'VB','কাজকর্ম':'NN','কাজকর্মগুলো':'NNS','কাজকারবার':'NN','কাজকে':'NN','কাজগুলি':'NN',
'কাজগুলোতে':'NNS','কাজচালানোর':'JJ','কাজটা':'NN','কাজটায়':'NN','কাজটিই':'NN','কাজনো':'VB','কাজরাখার':'NN',
'কাজরি':'NN','কাজল-কালো':'JJ','কাজল':'NN','কাজলের':'NN','কাজসদা':'NN','কাজাকবাসী':'NN','কাজাকস্তান':'NN',
'কাজালাড্ডু':'NN','কাজি':'NN','কাজিরাঙা':'NN','কাজী':'NN','কাজু':'NN','কাজুবরফি':'NN','কাজে':'NN',
'কাজেআমরা':'NN','কাজেই':'RB','কাজেও':'VB','কাজেকর্মে':'VB','কাজেদয়া':'VB','কাজের':'NN','কাঞ্চন':'NN',
'কাঞ্চীপুরম':'NNP','কাঞ্জী':'NN','কাট':'NN','কাটকাট':'NN','কাটছে':'VB','কাটতি':'NN','কাটতে':'VB',
'কাটপিস':'NN','কাটবাঁশি':'NN','কাটবে':'VB','কাটরা':'NN','কাটলাম':'VB','কাটা-ছেঁড়া':'NN','কাটা':'NN',
'কাটাই':'VBG','কাটাক':'NN','কাটাকাটিই':'VBG','কাটাকে':'NN','কাটাঙ্গার':'NNP','কাটাচ্ছিলেন':'VB','কাটাছেঁড়ার':'JJ',
'কাটাত':'VB','কাটাতে':'NN','কাটানো':'NN','কাটাবে':'NN','কাটার':'NN','কাটালান':'NN','কাটায়':'NNS',
'কাটি':'NN','কাটিং':'VBG','কাটিতে':'VB','কাটিম':'NN','কাটিহার':'NN','কাটিয়া':'VB','কাটিয়ে':'NN',
'কাটিয়েছি':'VB','কাটিয়েছে':'NN','কাটিয়েছেন':'VB','কাটু':'NN','কাটেন':'NN','কাট্য':'JJ','কাঠ-কয়লা':'NN',
'কাঠ-ব্রীজ':'NN','কাঠ':'NN','কাঠগড়া':'NN','কাঠগোদাম':'IN','কাঠচিনার':'NN','কাঠঠোকরা':'NN','কাঠপিঁপড়ে':'NN',
'কাঠবিড়ালী':'NN','কাঠবেড়ালিমার':'NN','কাঠমান্ডু':'NNP','কাঠমিস্ত্রি':'NN','কাঠসেমুল':'NN','কাঠা':'NN','কাঠামোগত':'JJ',
'কাঠামোতে':'NN','কাঠামোর':'NN','কাঠাল':'NN','কাঠি':'NN','কাঠিনাচ':'NN','কাঠিয়াবাড়':'NN','কাঠিয়াবাড়ী':'JJ',
'কাঠুরা':'NN','কাঠের':'NN','কাডি':'NN','কাণ্ড':'NN','কাণ্ডকীর্তি':'NN','কাণ্ডব':'NN','কাণ্ডারী':'NN',
'কাতম':'JJ','কাতর':'NN','কাতরী':'NN','কাতলা':'NN','কাতাকানা':'NN','কাতাঙ্গায়':'NNP','কাতার':'NN',
'কাতারি':'NN','কাতারের':'NN','কাতালান':'JJ','কাতুকুতু':'NN','কাতে':'NN','কাত্থ':'NN','কাত্যায়ন':'NN',
'কাথ':'NN','কাদব':'NN','কাদবো':'NN','কাদম্বরী':'NN','কাদশ':'CD','কাদা':'NN','কাদাজলের':'NN',
'কাদামাটি':'NN','কাদাময়':'JJ','কাদাযুক্ত':'JJ','কাদার':'NN','কাদি':'NN','কাদের':'WH','কাদেরিয়া':'NNS',
'কাদেরের':'NN','কাদ্মবরী':'NN','কাধে':'NN','কান':'NNS','কানকাটা':'NN','কানকো':'NN','কানখুস্কি':'NN',
'কানঢাকা':'NN','কানতড়কা':'NN','কানন':'NN','কানপট্টী':'NN','কানপাকা':'NN','কানপুর':'NNP','কানফাটা':'NN',
'কানফেড়':'NN','কানবেঁধানো':'NN','কানভাঙ্গানি':'NN','কানভাঙ্গানে':'JJ','কানহর':'NN','কানা':'NN','কানাকানি':'NN',
'কানাকে':'NNP','কানাকড়িও':'NN','কানাচে':'NN','কানাডবাসী':'NN','কানাড়ী':'NN','কানাডাতে':'NN','কানাডায়':'NNP',
'কানাডিয়ান':'NN','কানাডীয়':'JJ','কানাত':'NN','কানাবেজ':'NN','কানামাছি':'NN','কানারে':'NN','কানাড়া':'NNP',
'কানায়':'RB','কানি':'NN','কানীন':'NN','কানে':'NN','কানেকশন':'NN','কানেক্শন':'NN','কানের':'NN',
'কানো':'NNV','কান্ট্রিগুলোর':'NN','কান্ড':'NN','কান্ডকারখানা':'NN','কান্ডটাই':'NN','কান্ডা':'NN','কান্ডের':'NN',
'কান্ত':'NN','কান্তার':'NN','কান্তিধর':'JJ','কান্তিমান':'JJ','কান্তিময়':'NN','কান্দ':'NN','কান্দি':'NNP',
'কান্ধামাল':'NN','কান্না':'VBG','কান্নাকাটি':'NN','কান্নাগুলি':'NN','কান্নায়':'NN','কান্যকুব্জ':'NN','কান্হড়া':'NN',
'কাপ':'NN','কাপট্যহীন':'NN','কাপড়':'NNS','কাপড়ের':'NN','কাপনি':'NN','কাপসা':'NN','কাপালি':'NNP',
'কাপালিক':'NN','কাপালির':'NNP','কাপি':'NN','কাপুরষতা':'NN','কাপুরুষ':'NN','কাপুরুষের':'NN','কাপুষরা':'NN',
'কাপে':'NN','কাপ্তান':'NN','কাপড়':'NN','কাপড়ের':'NN','কাফ':'NN','কাফফারা':'NN','কাফল':'NN',
'কাফির':'NN','কাফে':'NN','কাফেলা':'NN','কাফ্কা':'NN','কাফ্রি':'NN','কাব':'NN','কাবলি':'JJ',
'কাবা':'NN','কাবাড্ডী':'NN','কাবাব':'NN','কাবাবভোজী':'JJ','কাবালেরোকে':'NN','কাবিনহীন':'NN','কাবিলতি':'NN',
'কাবিস':'NN','কাবুল':'NN','কাবুলিওয়ালা':'NN','কাবুলী':'NN','কাবুলীওয়ালাদের':'NN','কাবে':'RB','কাবেরি':'NN',
'কাব্য':'NN','কাব্যগীতি':'NN','কাব্যগ্রন্হ':'NN','কাব্যপ্রেমী':'JJ','কাব্যরসিক':'JJ','কাব্যাত্মক':'JJ','কাব্যালঙ্কার':'NN',
'কাব্যে':'NN','কাব্যোপন্যাসের':'NN','কাভানি':'NN','কাভারত্তী':'NN','কাভারেজ':'NN','কাম-শর':'NN','কাম-সুত্র':'NN',
'কাম':'NN','কামকলার':'NN','কামড়':'NNP','কামড়ে':'NN','কামতরু':'NN','কামদা':'NN','কামদেবী':'NN',
'কামধেনু':'NN','কামনা-সিদ্ধি':'NN','কামনা':'NN','কামনাপূর্ণ':'JJ','কামনাপূর্ণতা':'NN','কামনারহিত':'JJ','কামনায়':'NN',
'কামবতী':'NN','কামবশে':'NN','কামবাণ':'NN','কামরা':'NN','কামরাজ':'NNP','কামরার':'NN','কামরুল':'NN',
'কামরূপ':'NN','কামলা':'NN','কামশক্তি':'NN','কামশর':'NN','কামশাস্ত্র':'NN','কামসখা':'NN','কামসুত্র':'NN',
'কামহীন':'JJ','কামাই':'VB','কামাইতেছে':'VB','কামাউ':'NN','কামাক্ষী':'NN','কামাচ্ছে':'VB','কামাঠী':'NN',
'কামাতুর':'JJ','কামাতে':'VB','কামান':'NN','কামানি':'NN','কামানো':'VB','কামান্ধ':'JJ','কামান্ধতা':'NN',
'কামাবে':'VB','কামাযুদ্ধ':'NN','কামার':'NN','কামারনি':'NN','কামারপুকুর':'NNP','কামারপুকুরের':'NNP','কামারের':'NN',
'কামাল':'VB','কামালরব':'NN','কামায়':'NN','কামায়ুধ':'NN','কামি':'NN','কামিনী':'NN','কামিয়ে':'VB',
'কামী':'JJ','কামীরা':'NN','কামুক':'NN','কামুকতাপূর্ণ':'JJ','কামে':'NN','কামেঙ্গ':'NNP','কামের':'NN',
'কামোত্তেজক':'NN','কামোদ-সামন্ত':'NN','কামোদ':'NN','কামোদকল্যাণ':'NN','কামোদতিলক':'NN','কামোদনট':'NN','কামোদী':'NN',
'কামোদ্বেগ':'NN','কাম্পিল':'NN','কাম্পুচিয়ার':'JJ','কাম্বোডিয়ানা':'NN','কাম্য':'NN','কামড়':'NN','কামড়াচ্ছি':'VB',
'কামড়ানোর':'NN','কামড়ায়ে':'NN','কামড়ে':'NN','কাযকে':'NN','কায়':'NN','কার':'NN','কারই':'PR',
'কারউ':'NN','কারক':'NN','কারকদীপক':'NN','কারখনা':'NN','কারখানাও':'NN','কারখানায়':'NN','কারগিল':'NNP',
'কারচুপি':'NN','কারজীপ':'NN','কারজ্যক্রম':'NN','কারণ':'IN','কারণও':'NN','কারণগুলো':'NN','কারণটা':'NN',
'কারণটি':'NN','কারণবশতঃ':'RB','কারণমালা':'NN','কারণে':'NN','কারণেনিজ':'NN','কারণেবিএনপির':'NN','কারণ্ডব':'NN',
'কারদুই':'NN','কারন':'NN','কারনগুলো':'NN','কারনটিই':'NN','কারনে':'NN','কারনেও':'NN','কারনেমূল্য':'NN',
'কারনের':'NN','কারনেস্থানীয়':'NN','কারন্ড':'NN','কারফিউ':'NN','কারবন':'NN','কারবার':'NN','কারবারী':'NN',
'কারবারের':'NN','কারবালা':'NN','কারলোটা':'NN','কারসাজ':'JJ','কারসাজি':'NN','কারসাজিবাজ':'NN','কারসাজির':'NN',
'কারা':'NN','কারাগারকর্মী':'NN','কারাগারাধিকারিক':'NN','কারাগারে':'NN','কারাঢাকা':'NN','কারাণ':'NN','কারাদণ্ডের':'NN',
'কারাধ্যক্ষ':'NN','কারান্তরালে':'NN','কারাবকাশ':'NN','কারাবন্দি':'NN','কারাবরণ':'NN','কারাবাসী':'NN','কারাভাঁ':'NN',
'কারারুদ্ধ':'JJ','কারি':'NN','কারিকুলাম':'NN','কারিগর':'NN','কারিগরী':'NN','কারিদের':'NN','কারিপাতা':'NN',
'কারির':'NN','কারিশমা':'NN','কারী':'NN','কারীগরী':'NN','কারীর':'NN','কারুকাজ':'VB','কারুকার্য':'NN',
'কারুকার্যখচিত':'JJ','কারুকার্য্যময়':'NN','কারুকে':'PR','কারুচি':'NN','কারুণ্য':'NN','কারুর':'PR','কারে':'NN',
'কারেখুজে':'NN','কারেণই':'NN','কারেনসি':'NN','কারেন্টের':'NN','কারেন্সিপেপাল':'NN','কারের':'NN','কারো':'NN',
'কারৈকল':'NN','কারো':'NN','কারোন':'NN','কারোরই':'PR','কার্টার':'NN','কার্ড':'NN','কার্ডবোর্ড':'NN',
'কার্ডিগান':'NN','কার্ডিন্যাল':'NN','কার্ডিফ':'NN','কার্ডে':'NN','কার্ডের':'NN','কার্ণিক':'NN','কার্তবীর্য':'NN',
'কার্তিক-কৃষ্ণ':'NN','কার্তিক':'JJ','কার্তিকরাম':'NN','কার্তুজ':'NN','কার্ত্তিক':'NN','কার্পণ্য':'NN','কার্পাস':'NN',
'কার্পেট':'NN','কার্ফু':'NN','কার্ব':'NNP','কার্বন-ডাই-অক্সাইড':'NN','কার্বন':'NN','কার্বনঘটিত':'JJ','কার্বনডাইঅক্সাইড':'NN',
'কার্বনিক':'NN','কার্বামাইড':'NN','কার্বি':'NNP','কার্বোহাইড্রেট':'NN','কার্মণোন্মাদ':'NN','কার্য-কাল':'NN','কার্য-পদ্ধতি':'NN',
'কার্য-প্রণালী':'NN','কার্য-বিধি':'NN','কার্য':'NN','কার্যকর':'NN','কার্যকরী':'NN','কার্যকরীযে':'NN','কার্যকলাপ':'NN',
'কার্যকলাপের':'NN','কার্যকারনে':'NN','কার্যকারিণী':'NN','কার্যকাল':'NN','কার্যক্রমসূচী':'NN','কার্যক্রমের':'NN','কার্যক্ষমতা':'NN',
'কার্যত':'NN','কার্যনির্বাহক':'NN','কার্যপদ্ধতি':'NN','কার্যপ্রণালী':'NN','কার্যবাহক':'JJ','কার্যবিধি':'NN','কার্যভার':'NN',
'কার্যমূলক':'JJ','কার্যর':'NN','কার্যসূচী':'NN','কার্যস্হল':'NN','কার্যাঙ্ক':'NN','কার্যান্তরাল':'NN','কার্যাবকাশ':'NN',
'কার্যারম্ভ':'NN','কার্যালয়':'NN','কার্যালয়গমণ':'NN','কার্যালয়সংক্রান্ত':'JJ','কার্যালয়ে':'NN','কার্যে-রূপায়িত':'JJ','কার্যে':'NN',
'কার্যোপলব্ধি':'NN','কার্য্য':'NN','কার্য্যকলাপের':'NN','কার্য্যধারার':'NN','কার্য্যে':'NN','কার্ল':'NNP','কার্শ্য':'NN',
'কার্ষ্ণি':'NN','কার্সার':'NN','কাল-রাত্রী':'NN','কাল':'NN','কালও':'RB','কালকন্ঠ':'NN','কালকা':'NN',
'কালকুট':'NNP','কালকুটের':'NN','কালকে':'NN','কালকেতু':'NN','কালকোঠরি':'NN','কালক্রম':'NN','কালক্রমে':'RB',
'কালক্ষেপণ':'NN','কালচক্র':'NNP','কালচার':'NN','কালজয়ী':'NN','কালদমনী':'NN','কালনাগ':'NN','কালনিশা':'NN',
'কালনেমী':'NN','কালপর্ণী':'NN','কালপুরুষ':'NNP','কালপ্রমেহ':'NN','কালবাচক':'JJ','কালবিলম্ব':'NN','কালবেলিয়া':'NN',
'কালবোস':'NN','কালভার্ট':'NN','কালমল্লিকা':'NN','কালমাপক':'NN','কালমুর্ঘ':'NN','কালযবন':'NN','কালরাত':'NN',
'কালরাত্রী':'NN','কালরূপে':'NN','কালশাক':'NN','কালসর্প':'NN','কালসিরী':'NN','কালসেন':'NN','কালহরণ':'NN',
'কালা':'NN','কালাকাঁদ':'NN','কালাগাঁড়া':'NN','কালাগ্নিরুদ্র':'NN','কালাচোর':'NN','কালাজ্বর':'NN','কালাদানা':'NN',
'কালানুক্রম':'NN','কালান্তর':'NN','কালান্তরে':'RB','কালাপানি':'NN','কালাম':'NN','কালাস্ত্র':'NN','কালাহাণ্ডী':'NN',
'কালি':'NN','কালিকা':'NNP','কালিকামুখ':'NN','কালিঞ্জর':'NN','কালিদাস':'NNP','কালিনতা':'NN','কালিন্দী':'NN',
'কালিমা':'NN','কালিমালেপন':'NN','কালিহাতী':'NN','কালী':'NN','কালীঘাটের':'NNP','কালীচরণ':'NNP','কালীদহ':'NN',
'কালীদাস':'NNP','কালীন':'NN','কালীপুজোর':'NNP','কালীপূজাও':'NN','কালীপূজোর':'NNP','কালীফুলিয়া':'NN','কালীমোহন':'NNP',
'কালীর':'NNP','কালীয়ক':'NN','কালে':'NNP','কালেই':'NN','কালেকশন':'NN','কালেক্টর':'NN','কালের':'NN',
'কালো':'NN','কালোচিত':'JJ','কালোধন':'NN','কালোবাজার':'NN','কালোবাজারীদের':'NN','কালোমোহরা':'NN','কালোয়াতি':'NN',
'কাল্পনিক':'NN','কাশ':'NN','কাশতৃণ':'NN','কাশন':'NN','কাশফুল':'NN','কাশর':'NN','কাশা':'VB',
'কাশি':'NN','কাশী':'NN','কাশীতে':'NNP','কাশীনাথ':'NNP','কাশীপুরে':'NNP','কাশীর':'NN','কাশে':'NN',
'কাশ্মরী':'NN','কাশ্মিরিরাও':'NN','কাশ্মিরের':'NNP','কাশ্মীর':'NN','কাশ্মীরা':'NN','কাশ্মীরিদের':'NN','কাশ্মীরী':'NN',
'কাশ্মীরের':'NN','কাশ্যপ':'NN','কাষ্টমসে':'NN','কাষ্ঠ':'NN','কাষ্ঠদণ্ড':'NN','কাষ্ঠল':'JJ','কাষ্ঠে':'NN',
'কাসনি':'NN','কাসর':'NN','কাসাই':'NNP','কাসাভুবু':'NNP','কাসার':'NN','কাসুন্দা':'NN','কাসে':'NN',
'কাসেম':'NNP','কাসেমিরো':'NN','কাস্টমস':'NNS','কাস্টমাইজেশন':'NN','কাস্টমার':'NN','কাস্টার্ড':'NN','কাস্ট্রিস':'NN',
'কাস্তে':'NN','কাহলা':'NN','কাহাকে':'PR','কাহার':'NN','কাহারও':'PR','কাহারবা':'NN','কাহারো':'NN',
'কাহিণী':'NN','কাহিনি':'NN','কাহিনীটি':'NN','কাহিনীর':'NN','কাহিয়া':'NN','কাহেনা':'NNP','কাড়ি':'NN',
'কাড়ে':'VB','কায়-চিকিত্সা':'NN','কায়দা':'NNS','কায়দায়':'NN','কায়ফল':'NN','কায়রো':'NN','কায়রোর':'JJ',
'কায়সার':'NN','কায়স্থ':'NN','কায়স্থিনী':'NN','কায়া-কল্প':'NN','কায়া':'NN','কায়াকল্প':'NN','কায়াপরিবর্তণ':'NN',
'কায়াবদল':'NN','কায়িক':'JJ','কায়েম':'JJ','কায়েমতো':'NN','কায়েস':'NNS','কা‌ছে':'NN','কা‌লো':'NN',
'কি.মি.':'FW','কি.মি':'NN','কি':'NN','কিংকর্তব্য-বিমূঢ়':'JJ','কিংকর্তব্যবিমূঢ়':'RB','কিংকর্তব্যম':'NN','কিংকিণী':'NN',
'কিংপুরুষ':'NN','কিংবদন্তি':'NN','কিংবা':'NN','কিংশাসা':'NN','কিংশুক':'NN','কিংসটাউন':'NN','কিঃ':'NN',
'কিঃমিঃ':'NNP','কিইবা':'NN','কিউই':'NN','কিউট':'NN','কিউবা':'NN','কিউবাবাসী':'NN','কিউবার':'JJ',
'কিউরেটর':'NN','কিউল':'NNP','কিএগুলা':'NN','কিকর':'NN','কিকরে':'RB','কিকে':'NN','কিগলী':'NN',
'কিঙ্কিণী':'NN','কিঙ্কিরাত':'NN','কিঙ্গ':'NN','কিচকিচ':'VB','কিচু':'NN','কিচ্ছু':'VBG','কিচ্ছুটি':'NN',
'কিছক্ষন':'NN','কিছু':'VBG','কিছুই':'NN','কিছুও':'VBG','কিছুকাল':'RB','কিছুকে':'PR','কিছুকেই':'NN',
'কিছুক্ষণ':'NN','কিছুক্ষণের':'RB','কিছুটা':'NN','কিছুতে':'NN','কিছুতো':'VBG','কিছুদিন':'NNS','কিছুদূর':'RB',
'কিছুনা':'NN','কিছুরই':'NN','কিছুরকারোর':'JJ','কিছুলোক':'NN','কিছ্ছু':'NN','কিঞ্চিৎ':'CD','কিঞ্চুলক':'NN',
'কিট':'NN','কিটকিট':'NNP','কিটা':'NN','কিটোন':'NN','কিডনি':'NN','কিডনী':'NN','কিডন্যাপ':'NN',
'কিড়মিড়':'VB','কিণ':'NN','কিণ্বক':'NN','কিতকিত':'NN','কিতান':'NN','কিতে':'NN','কিনছি':'NN',
'কিনছেন':'NN','কিনতাম':'NN','কিনতেই':'CC','কিনফু':'NNP','কিনব':'NN','কিনবে':'VB','কিনবো':'VB',
'কিনলাম':'VB','কিনলেই':'VB','কিনলেন':'NNP','কিনলো':'VB','কিনা':'NN','কিনারা':'NN','কিনারাওয়ালা':'JJ',
'কিনারায়':'NN','কিনি':'VB','কিনী':'NNP','কিনুন':'VB','কিনে':'NNP','কিনেছিলাম':'NN','কিনেছে':'NN',
'কিনেন':'VB','কিনো':'RP','কিন্ডারগার্টেন':'VB','কিন্ত':'NN','কিন্তু-কিন্তু':'VB','কিন্তু':'CC','কিন্তুকথা':'NN',
'কিন্নর':'NN','কিন্লে':'NN','কিপটামী':'NN','কিপটে':'JJ','কিপার':'NN','কিপিং':'VBG','কিপেরের':'NNP',
'কিপ্টে':'JJ','কিপ্রকারে':'RB','কিব':'NN','কিবং':'CC','কিবরিয়া':'NNS','কিবরিয়ার':'NN','কিবা':'NN',
'কিবিদেশে':'NN','কিবিদ্যুতের':'NN','কিবিশ্বাস':'NN','কিবে':'VB','কিবেআইনী':'JJ','কিবোর্ড':'NN','কিব্যপক':'JJ',
'কিভাবে':'NN','কিম':'NNP','কিমা':'JJ','কিমাম':'NN','কিমি':'NN','কিম্বা':'CC','কিযতই':'NN',
'কিরকম':'RB','কিরকুক':'NN','কিরগিজ':'NN','কিরগিজস্তানি':'NN','কিরগিজস্তানী':'JJ','কিরণ':'NN','কিরন্ডি':'NN',
'কিরা':'NN','কিরাঞ্চী':'NN','কিরাত':'NN','কিরি':'NN','কিরিবাটী':'NN','কিরুন্ডি':'NN','কিরূপ':'WH',
'কিরে':'WH','কিরৌলা':'NN','কির্ডান':'NN','কির্তী':'NN','কির্মির':'NN','কির্য়া':'NN','কিল':'NN',
'কিলকিলা':'NN','কিলকী':'NN','কিলকৈয়া':'NN','কিলবিল':'VB','কিলাঙ্গ':'NN','কিলায়':'NN','কিলিং':'NN',
'কিলিক':'NN','কিলে':'RP','কিলোমিটার':'NNS','কিলো':'NN','কিলোগ্রাম':'NN','কিলোবিট':'NNS','কিলোমিটার':'NN',
'কিশমিশ':'NN','কিশলয়':'NN','কিশিনেভ':'NN','কিশোরগঞ্জবাসী':'NN','কিশোর':'NN','কিশোরাবস্থা':'NN','কিশোরী':'NN',
'কিশোরীদের':'NN','কিশোরীরা':'NN','কিষানগঞ্জ':'NN','কিষ্কিন্ধ':'NN','কিষ্কিন্ধাপতি':'NN','কিষ্কিন্ধ্যাকাণ্ড':'NN','কিসমিস':'NN',
'কিসমিসযুক্ত':'JJ','কিসহিলি':'NN','কিসানগঞ্জে':'NNP','কিসু':'NN','কিসুতা':'NNP','কিসে':'NN','কিস্তি':'NN',
'কিস্তিতে':'RB','কিস্তিমুক্ত':'NN','কিস্তির':'NNS','কিড়িমিড়ি':'VBG','কিয়া':'VB','কিয়াহ':'NN','কিয়ে':'VB',
'কী':'NN','কীচক':'NN','কীট':'NN','কীটনাশক':'NN','কীটনাশকের':'NNS','কীটভোজী':'NN','কীটস':'NN',
'কীটো':'NN','কীডভক্ষী':'NN','কীতে':'NN','কীদা':'NNP','কীনা':'NN','কীপ':'NN','কীফলে':'NNS',
'কীভাবে':'WH','কীভাবেআবার':'NN','কীমা':'NN','কীমোথেরাপি':'NN','কীয়':'JJ','কীর্তন':'NN','কীর্তি':'NN',
'কীর্তিত':'JJ','কীর্তির':'NN','কীর্ত্তন':'VB','কীল':'NN','কীলাল':'NN','কীসব':'NN','কীসের':'NN',
'কীয়োটো':'NN','কু':'NN','কুঁকড়ি':'NN','কুঁচকানো':'NN','কুঁচি':'NN','কুঁজ':'NN','কুঁজি':'NN',
'কুঁড়া':'NN','কুঁড়েঘর':'NN','কুঁড়োজালি':'NN','কুঁদ':'NN','কুঁদন':'VB','কুঁদনা':'NN','কুঁদরু':'NN',
'কুঁদলী':'NN','কুঁদে':'VB','কুঁয়োর':'NN','কুংফু':'NNP','কুইক':'NN','কুইকরেন্টাল':'NN','কুইনসল্যান্ড':'NN',
'কুইনাইন':'NN','কুইন্টাল':'NN','কুইন্সল্যান্ড':'NN','কুক':'NN','কুকরোদ':'NN','কুকর্ম':'NN','কুকাম':'NN',
'কুকাল':'NN','কুকীর্তি':'NN','কুকুভ':'NN','কুকুভা':'NN','কুকুর-কাশি':'NN','কুকুর':'NN','কুকুরকে':'NNS',
'কুকুরমাছি':'NN','কুকুরমুত্তা':'NN','কুকুরে':'NN','কুকুস্থ':'NN','কুকের':'NN','কুক্কুট':'NN','কুক্রিয়াসক্তা':'NN',
'কুক্ষ':'NN','কুক্ষিগত':'NNP','কুখ্যাত':'JJ','কুখ্যাতি':'NN','কুগ':'NN','কুঙ্কুমে':'NN','কুচ':'NN',
'কুচকাওয়াজ':'NN','কুচকুচে':'JJ','কুচক্রী':'JJ','কুচাল':'NN','কুচি':'NN','কুচিন্তা':'NN','কুচিপুড়ি':'NN',
'কুচেষ্টা':'NN','কুচো':'NN','কুচ্ছ':'NN','কুজন':'NN','কুঞ্চন':'NN','কুঞ্চনশীল':'JJ','কুঞ্চনসাধ্য':'JJ',
'কুঞ্চিত':'NN','কুঞ্জ':'NN','কুঞ্জবন':'NN','কুঞ্জময়':'JJ','কুঞ্জর':'NN','কুঞ্জরী':'NN','কুঞ্জলতা':'NN',
'কুট':'NN','কুটকচালী':'NN','কুটকি':'NN','কুটকুট':'VB','কুটচালের':'JJ','কুটনহারী':'NN','কুটনাপনা':'NN',
'কুটনি':'NN','কুটনৈতিক':'JJ','কুটা':'NN','কুটির':'NN','কুটিরশিল্পের':'NN','কুটিরে':'NN','কুটিল':'JJ',
'কুটিলতা':'NN','কুটীর':'NN','কুটু':'NN','কুটুম্ব':'NN','কুটো':'NN','কুট্টা':'NN','কুঠরি':'NN',
'কুঠারিকা':'NN','কুঠুরি':'NN','কুডলোর':'NN','কুড়মুড়ানি':'NN','কুড়মুড়ে':'JJ','কুড়া':'NN','কুড়াল':'NN',
'কুড়িতম':'JJ','কুড়ুপ':'NN','কুডাল':'NN','কুণবী':'NN','কুণার':'NNP','কুণ্ঠিত':'JJ','কুণ্ড':'NN',
'কুণ্ডভেদী':'NN','কুণ্ডল':'NN','কুণ্ডলিয়া':'NN','কুণ্ডি':'NN','কুণ্ডিকোপনিষদ':'NN','কুণ্ডে':'NN','কুতকুত':'NN',
'কুতর্ক':'NN','কুতসিত':'NN','কুতার':'NN','কুতুব':'NN','কুতূপ':'NN','কুত্তা':'NN','কুত্সিত':'NN',
'কুত্সীত':'NN','কুত্সের':'JJ','কুথায়':'WRB','কুথোদরী':'NN','কুদরতি':'NN','কুদর্শন':'NN','কুদিন':'NN',
'কুদৃষ্টি':'NN','কুদ্রতি':'NN','কুনকে':'NN','কুনজরে':'NNP','কুনলই':'NN','কুনা':'NN','কুনি':'NN',
'কুনীতি':'NN','কুন্ঠা':'NN','কুন্ঠিত':'VBN','কুন্ডল':'NN','কুন্তল':'NN','কুন্তিভোজ':'NN','কুন্তী':'NN',
'কুন্থুনাথ':'NN','কুন্দ':'NN','কুন্দনসাজ':'NN','কুন্দু':'NN','কুন্ধী':'NN','কুপওয়াড়া':'NN','কুপথ':'NN',
'কুপন':'NN','কুপফের':'NN','কুপবাহ':'NN','কুপমন্ডুক':'NN','কুপরামর্শ':'NN','কুপরিবাহী':'NN','কুপাকুপি':'NNP',
'কুপাত্র':'JJ','কুপাত্রতা':'NN','কুপি':'NN','কুপিত':'JJ','কুপিয়ে':'NNP','কুপী':'NN','কুপুত্র':'NN',
'কুপোকাত':'NNP','কুপ্পক':'NN','কুপ্রচার':'NN','কুপ্রবৃত্তি':'NN','কুপ্রভাব':'NN','কুপ্রসিদ্ধ':'JJ','কুপ্রসিদ্ধি':'NN',
'কুফরি':'JJ','কুফরী':'NNP','কুফল':'NN','কুফলগুলি':'NN','কুবচন':'NN','কুবর':'NN','কুবলযাশ্ব':'NN',
'কুবল্যাপীড়':'NN','কুবিচার':'NN','কুবিদ্যা':'NN','কুবুদ্ধি':'NN','কুবুদ্ধিসম্পন্ন':'JJ','কুবের':'NN','কুবেরসখা':'NN',
'কুবেরাদ্রি':'NN','কুব্জ':'NN','কুব্যবস্থা':'NN','কুভাণ্ডু':'NN','কুমকুম':'NN','কুমড়ো':'NN','কুমন্ত্রণাদাতা':'NN',
'কুমরি':'NN','কুমা':'NNP','কুমার':'NN','কুমারঘটক':'NNP','কুমারলসিতা':'NN','কুমারী':'NN','কুমারের':'NN',
'কুমাল':'NN','কুমায়ুন':'NN','কুমির':'NN','কুমিল্লা':'NN','কুমিল্লার':'NN','কুমীর':'NN','কুমুদ':'NN',
'কুমে':'NNP','কুমেরুতে':'NNP','কুমোর':'NN','কুমোরশালা':'NN','কুমোরের':'NN','কুম্বলের':'JJ','কুম্ভ':'NN',
'কুম্ভকর্ণ':'NN','কুম্ভকর্ণের':'JJ','কুম্ভকার':'NN','কুম্ভদাসী':'JJ','কুম্ভনাথ':'NN','কুম্ভলগড়':'NN','কুম্ভানসী':'NN',
'কুম্ভিনাসি':'NN','কুম্ভীনাশি':'NN','কুম্ভীরাশ্রুবর্ষণ':'JJ','কুম্ভীরাসন':'NN','কুয়েট':'NN','কুরআন':'NN','কুরগি':'NN',
'কুরড়া':'NN','কুরন্টক':'NN','কুরব':'NN','কুরভঞ্জী':'NNP','কুররী':'NN','কুরসি':'NN','কুরাজ্য':'NN',
'কুরাল':'NNP','কুরাসওয়া':'NNP','কুরিয়ার':'NN','কুরু':'NN','কুরুক্ষেত্র':'NN','কুরুঙ্গ':'NN','কুরুচির':'NNP',
'কুরুবংশীয়':'NN','কুরুস্তত':'NN','কুরূপ':'NN','কুরে':'NNP','কুরেড':'NN','কুর্গ':'NN','কুর্তা':'NN',
'কুর্দিশকেও':'NNP','কুর্নুল':'NN','কুর্ম':'NN','কুর্সি':'NN','কুল-তারণ':'JJ','কুল':'NN','কুলকুচি':'NN',
'কুলক্ষণযুক্ত':'JJ','কুলক্ষণা':'NN','কুলক্ষণে':'JJ','কুলঙ্গ':'NN','কুলচা':'NN','কুলটাবৃত্তি':'NN','কুলতারণ':'NN',
'কুলত্থ':'NN','কুলত্রাতা':'NN','কুলদা':'NNP','কুলদীপ':'VB','কুলপতি':'NN','কুলপ্রদীপ':'NN','কুলফা':'NN',
'কুলশীলের':'NN','কুলসিল':'NNP','কুলাঙ্গার':'NN','কুলায়':'NNP','কুলি':'NN','কুলিগিরি':'NN','কুলিপ':'NN',
'কুলিশ':'NN','কুলীন':'NN','কুলু':'NN','কুলুঙ্গি':'NN','কুলুপ':'NN','কুলুরবলদ':'NNP','কুলুস':'NN',
'কুলে':'VB','কুলেসির':'NN','কুল্চা':'NN','কুল্ফি':'NN','কুল্লা':'NN','কুশ':'NN','কুশদ্বীপ':'NN',
'কুশধ্বজ':'NN','কুশনাভ':'NN','কুশপুত্তলিকা':'NN','কুশমুদ্রিকা':'NN','কুশল':'NN','কুশলতাপূর্বক':'RB','কুশলতার':'NN',
'কুশলভাবে':'RB','কুশলিব':'NN','কুশলীকে':'NN','কুশাগ্রবুদ্ধি':'JJ','কুশারণি':'NN','কুশাশ্ব':'NN','কুশাসন':'NN',
'কুশি':'NN','কুশীনগর':'NN','কুশীলবরা':'NNP','কুশের':'NN','কুষাণ':'NN','কুষুম্ভ':'NN','কুষ্টিয়ার':'NNP',
'কুষ্ঠ':'NN','কুষ্মাণ্ড':'NN','কুষ্মাণ্ডিনী':'NN','কুষ্মান্ড':'NN','কুসংস্কারাচ্ছন্ন':'JJ','কুসঙ্গ':'NN','কুসমি':'NNP',
'কুসময়':'NN','কুসর':'NN','কুসুম':'NN','কুসুমবিচিত্রা':'NN','কুসুমরেণু':'NN','কুসুমরোহিত':'JJ','কুসুমসৌরভ':'NN',
'কুসুমস্তবক':'NN','কুসুমহীন':'JJ','কুসুমাকার':'NN','কুসুমালয়':'NN','কুসুমিত':'JJ','কুসুমিতলতাবেল্লিতা':'NN','কুসুমোদ্দ্যান':'NN',
'কুসুম্ব':'NN','কুসুম্ভা':'NN','কুসেবা':'NN','কুস্তি':'NN','কুস্তিগীর':'NN','কুস্তিবাজি':'VB','কুস্তির':'NN',
'কুস্বভাব':'NN','কুস্বভাবী':'JJ','কুহকবাণ':'NN','কুহপ':'NN','কুহি':'NN','কুহু':'NN','কুৎসায়':'NN',
'কুৎসিত':'RB','কুড়া':'NNP','কুড়াল':'NN','কুড়ি':'NN','কুড়িগ্রামে':'NN','কুড়িয়ে':'NN','কুড়োতো':'VB',
'কুয়ালিটির':'NN','কুয়াশা':'NN','কুয়াশাচ্ছন্ন':'NN','কুয়েট':'NN','কুয়েত-বাসী':'NN','কুয়েত':'NN','কুয়েতের':'NNP',
'কুয়ো':'NN','কূকরচন্দী':'NN','কূজন':'NN','কূট':'NN','কূটকৌশলের':'NN','কূটচালে':'VBG','কূটতাপূর্ণ':'JJ',
'কূটনীতি':'NN','কূটনৈতিক':'NN','কূটহন্তা':'NN','কূন্দ':'NN','কূপ':'NN','কূপমন্ডুক':'NN','কূর্ম':'NN',
'কূর্মদ্বাদশী':'NN','কূর্মপুরাণ':'NN','কূর্মাবতার':'NN','কূর্মিকা':'NN','কূল':'NN','কূলকলঙ্ক':'NN','কূলগার্ড':'NN',
'কূলদেবতা':'NN','কূলপ্রদীপ':'NN','কূলভূষণ':'NN','কূলহীন':'JJ','কূলাচার':'NN','কূলীন':'NN','কূলে':'NN',
'কৃকলাস':'NN','কৃকেট':'NN','কৃত':'JJ','কৃতকর্মের':'NN','কৃতঘ্ন':'JJ','কৃতঘ্নতা':'NN','কৃতঙ্ক':'NN',
'কৃতজ্ঞ':'NN','কৃতজ্ঞতাপূর্বক':'RB','কৃতজ্ঞতার':'NN','কৃতবীর্য':'NN','কৃতসপত্নী':'NN','কৃতার্থ':'JJ','কৃতি':'NN',
'কৃতিত্বের':'NN','কৃতী':'JJ','কৃতে':'NNP','কৃত্তিকা':'NN','কৃত্য':'NN','কৃত্যা':'NN','কৃত্রিম':'NN',
'কৃত্রিমভাবে':'RB','কৃদন্ত':'NN','কৃপ':'NN','কৃপণতা':'NN','কৃপাচার্য':'NN','কৃপাণ':'NN','কৃপাদৃষ্টি':'NN',
'কৃপানিধি':'NN','কৃপাপাত্র':'JJ','কৃপাপূর্বক':'RB','কৃপারহিত':'NN','কৃপাসিন্ধু':'NN','কৃপাহীনতা':'NN','কৃপায়':'RB',
'কৃপী':'NN','কৃমি':'NN','কৃমিভোজন':'NN','কৃর্তী':'NN','কৃশ':'NN','কৃশকায়':'JJ','কৃশতা':'NN',
'কৃশোদর':'JJ','কৃশোদরী':'JJ','কৃষক-বিপ্লব':'NN','কৃষক':'NN','কৃষকও':'NN','কৃষকদল':'NN','কৃষকদিগকে':'NN',
'কৃষকবর্গ':'NN','কৃষকরা':'NNS','কৃষকশ্রমিকের':'NN','কৃষকের':'NN','কৃষি-বিভাগ':'NN','কৃষি':'NN','কৃষিকর্ম':'NN',
'কৃষিকাজ':'NN','কৃষিক্ষেত্র':'JJ','কৃষিক্ষেত্রে':'NN','কৃষিজমি':'NN','কৃষিতে':'NN','কৃষিদল':'NN','কৃষিপরিবেশ':'NN',
'কৃষিবান্ধব':'RB','কৃষিবিজ্ঞান':'NN','কৃষিবিদ':'NN','কৃষিমন্ত্রী':'NN','কৃষিযোগ্য':'NN','কৃষির':'NN','কৃষ্ণ':'NN',
'কৃষ্ণচুড়া':'NN','কৃষ্ণচূড়ার':'NN','কৃষ্ণচৈতন্য':'NN','কৃষ্ণছন্দ':'NN','কৃষ্ণনাম':'NN','কৃষ্ণপক্ষ':'NN','কৃষ্ণবর্ণ':'NN',
'কৃষ্ণভক্ত':'JJ','কৃষ্ণমূর্তির':'NN','কৃষ্ণমৃগ':'NN','কৃষ্ণসাপ':'NN','কৃষ্ণসারিকা':'NN','কৃষ্ণাঙ্গ':'NN','কৃষ্ণাচতুর্থী':'NN',
'কৃষ্ণান':'NNP','কৃষ্ণাভিসারিকা':'NN','কৃষ্ণের':'NNP','কৃষ্ণোপনিষদ':'NN','কৃসকের':'NN','কে.':'NNP','কে':'WH',
'কেঁচো':'NN','কেঁদরাই':'NN','কেঁদে':'VBG','কেঁপে':'NN','কেঅর্ডিনেটর':'NN','কেআশা':'NN','কেই-বা':'PR',
'কেই':'NN','কেউ':'NN','কেউকি':'NN','কেউকেটা':'NN','কেউটে':'NN','কেও':'NN','কেওলিন':'NNP',
'কেওস':'NN','কেক':'NN','কেকাধ্বনি':'VB','কেকী':'NN','কেচুক':'NN','কেচো':'NNS','কেছে':'VB',
'কেজি':'NNP','কেজিতে':'NN','কেজির':'NNP','কেট':'NN','কেটও':'PR','কেটজল':'NN','কেটসল':'NN',
'কেটাগরির':'NN','কেটে':'NN','কেঠো':'NN','কেণ':'NN','কেণ্ডাই':'NN','কেতকী':'NN','কেতন':'NN',
'কেতাদুরস্ত':'NN','কেতাব':'NN','কেতাবী':'JJ','কেতাবে':'NN','কেতু':'NN','কেতুবীর্য':'NN','কেতুর':'NNP',
'কেতে':'VB','কেদার':'NN','কেদারগঙ্গা':'NN','কেদারনট':'NN','কেদারা':'NN','কেন':'NN','কেনআপনি':'NN',
'কেনই':'WRB','কেনইবা':'NN','কেনবার':'NNV','কেনবেরা':'NN','কেনরাশিয়া':'NN','কেনসিঙ্গটন':'NN','কেনহয়তো':'NN',
'কেনা-বেচা':'VB','কেনা':'NN','কেনাকাটা':'VBG','কেনাটা':'NN','কেনানো':'VB','কেনাবেচা':'NN','কেনার':'NN',
'কেনিয়ান':'NN','কেনিয়ার':'JJ','কেনীয়':'JJ','কেনে':'VB','কেনেডির':'NN','কেনো':'WH','কেনো':'NN',
'কেনোধনীরা':'JJ','কেনোপনিষদ':'NN','কেন্ট':'NN','কেন্টিনে':'NN','কেন্দ':'NN','কেন্দ্র':'NN','কেন্দ্রক':'NN',
'কেন্দ্রপাড়া':'NN','কেন্দ্রবিন্দু':'NN','কেন্দ্রভূমি':'NN','কেন্দ্রশাসিত':'NN','কেন্দ্রস্থল':'NN','কেন্দ্রিক':'NN','কেন্দ্রিকসুতরাং':'VBN',
'কেন্দ্রীকরণ':'NN','কেন্দ্রীণ':'NNP','কেন্দ্রীণে':'NN','কেন্দ্রীত':'JJ','কেন্দ্রীভূত':'NN','কেন্দ্রে':'NN','কেন্দ্রেও':'NN',
'কেন্নুই':'NN','কেপ':'NN','কেপটাউন':'NN','কেপিএল':'NNP','কেপিটা':'NNP','কেপ্টেইন':'NN','কেব':'WRB',
'কেবকি':'NN','কেবটীমোথা':'NN','কেবল':'NN','কেবলই':'RB','কেবলমাত্র':'RB','কেবি':'NNP','কেবিন':'NN',
'কেবির':'NNP','কেমন':'NN','কেমিক্যাল':'NNP','কেমিক্যালের':'NN','কেমিস্ট্রি':'NN','কেমুক':'NN','কেমেন':'NN',
'কেম্নে':'WRB','কেম্নেকিন্তু':'NN','কেম্ব্রিয়া':'NN','কেয়ার':'NN','কেরই':'PR','কেরমুটিয়া':'NN','কেরল':'NN',
'কেরানি':'NN','কেরানির':'NN','কেরানিরাই':'NNS','কেরাবাও':'NN','কেরামতি':'NN','কেরালায়':'NNP','কেরিয়ার':'NN',
'কেরে':'NN','কেরোসিন':'NN','কেলপ্':'NN','কেলভিনে':'NN','কেলাঙ্গ':'NN','কেলাস':'NN','কেলাসিত':'JJ',
'কেলি':'NN','কেলেংকারি':'NN','কেলেংকারির':'NN','কেলেংকারীর':'JJ','কেলেঙ্কারি':'NN','কেলেঙ্কারির':'NN','কেলেছি':'NN',
'কেলোর':'NN','কেল্লা':'NN','কেল্লায়':'NN','কেশ':'NN','কেশগুচ্ছ':'NN','কেশব':'NN','কেশবচন্দ্র':'NNP',
'কেশবতী':'JJ','কেশবপ্রিয়া':'NN','কেশর':'NN','কেশরঞ্জন':'NN','কেশরাশি':'NN','কেশরী':'NN','কেশরীনন্দন':'NN',
'কেশাগ্র':'NN','কেশি':'NN','কেশী':'JJ','কেশে':'NN','কেশ্য':'NN','কেষ্ট':'NNP','কেস':'NN',
'কেসগুলো':'NN','কেসর':'NN','কেসীপুরা':'NN','কেসে':'NN','কেহ':'NN','কেহই':'PR','কেহা':'NN',
'কোটা':'NN','কোটি':'NNS','কোণ':'NN','কোথাও':'NN','কোথায়':'WRB','কোন':'NN','কোনও':'DT',
'কোনদলই':'NN','কোনো':'DT','কোম্পানিটি':'NN','কোমড়':'NN','কোরিয়া':'NN','কোর্ট':'NN','কোল':'NN',
'কোহ‌লির':'NN','কোয়া':'NNP','কোয়ালিটির':'NN','কো‌নো':'NN','কো‌হলির':'NNP','কে্উ':'NN','কেড়ে':'VBN',
'কেয়ামত':'NN','কেয়ারটেকার':'NN','কেয়ারে':'NN','কেয়ালিটি':'NN','কেয়ূর':'NN','কেয়োস':'NN','কৈ':'NN',
'কৈকেয়ী.':'NN','কৈটভ':'NN','কৈতুন':'NN','কৈথল':'NN','কৈবর্তিকা':'NN','কৈবল্য':'NN','কৈবল্যোপনিষদ':'NN',
'কৈমা':'NN','কৈমুর':'NN','কৈরাত':'NN','কৈরি':'NN','কৈলাশ':'NN','কৈলাসমের':'NNP','কৈশোরে':'NN',
'কো':'NNP','কোঁকানো':'VB','কোঁচকানো':'NN','কোঁড়ক':'NN','কোঁত্':'VB','কোঁদন':'VB','কোঁদা':'JJ',
'কোঃ':'NNP','কোঅপরেশন':'NN','কোই':'NNP','কোক-শাস্ত্র':'NN','কোক':'NN','কোকদেব':'NN','কোকব':'NN',
'কোকরই':'NN','কোকরাঝাড়':'NN','কোকশাস্ত্র':'NN','কোকাবেরী':'NN','কোকাম':'NN','কোকাহ':'NN','কোকিণী':'NN',
'কোকিলকণ্ঠী':'JJ','কোকেন':'NN','কোকো':'NN','কোকোবাবা':'NN','কোঙ্কণ':'NN','কোঙ্কণী':'NN','কোঙ্কান':'NN',
'কোচ':'NN','কোচকে':'NN','কোচন':'NN','কোচবিহার':'NN','কোচমুলক':'NN','কোচরা':'NN','কোচি':'NN',
'কোচিংএ':'NN','কোচের':'NN','কোচোয়ান':'NN','কোচোয়ানি':'NN','কোজাগরী':'NN','কোঝিকোড':'NN','কোট-প্যাণ্ট':'NN',
'কোট':'NN','কোটা':'NN','কোটাচেক':'NN','কোটাধারী':'NN','কোটানি':'NN','কোটায়':'NNS','কোটি':'NN',
'কোটিকে':'VB','কোটিখানেক':'NNS','কোটিতম':'JJ','কোটিপতি':'NN','কোটিপতিরা':'NN','কোটির':'NNS','কোটু':'NN',
'কোটোরা':'NN','কোট্টায়াম':'NN','কোঠা':'NN','কোঠাকুচাল':'NN','কোঠার':'NN','কোঠি':'NN','কোঠোর':'NN',
'কোড':'NN','কোড়ানী':'NN','কোড়িয়া':'NN','কোডাগু':'NN','কোডারমা':'NN','কোডেগু':'NN','কোণ':'NN',
'কোণবিশিষ্ট':'JJ','কোণা':'NN','কোণাকুনি':'RB','কোণার্ক':'NN','কোণিকা':'NN','কোণী':'NN','কোণ্ডাই':'NN',
'কোতওয়াল':'NN','কোতে':'VB','কোতোয়াল':'NN','কোত্থেকে':'RB','কোথা':'WRB','কোথাও-কোথাও':'RB','কোথাও':'NN',
'কোথাকার':'NN','কোথায়':'WRB','কোথায়':'NN','কোথায়ও':'WRB','কোদানো':'VB','কোদাল':'NN','কোন':'NN',
'কোনও':'RB','কোনকালে':'NN','কোনকিছু':'NN','কোনক্রমেই':'NNS','কোনগুলো':'NN','কোনটা':'NN','কোনটীর':'NN',
'কোনঠাসা':'NN','কোনদিক':'NN','কোনদিকেই':'RB','কোনদিন':'NN','কোনদিনও':'NN','কোনপ্রকার':'NN','কোনভাবে':'WRB',
'কোনভাবেই':'NN','কোনরকম':'DM','কোনরকমে':'NN','কোনা':'NN','কোনাক্রি':'NN','কোনিয়া':'NN','কোনো':'NN',
'কোনোও':'DT','কোনোকিছুতে':'NN','কোনোক্রমে':'RB','কোনোটাই':'NN','কোনোদিন':'NN','কোনোভাবেই':'RB','কোনোমতে':'VB',
'কোনোরকম':'NN','কোনোরূপ':'DM','কোন্':'NN','কোন্দলে':'NN','কোপ':'NN','কোপদৃষ্টি':'NN','কোপলতা':'NN',
'কোপানো':'JJ','কোপার্নিকাস':'NNP','কোপীন':'NN','কোপে':'NN','কোপেনহেগেন':'NN','কোপেশ্বর':'NN','কোপ্তা':'NN',
'কোপ্পল':'NN','কোবারি':'NN','কোবাল্ট':'NN','কোবিদ':'NN','কোবেলমিন':'NN','কোব্বাদ':'NN','কোমর':'NN',
'কোমরবন্ধ':'NN','কোমরভাঙা':'JJ','কোমরযুক্ত':'JJ','কোমরে':'NN','কোমল':'NN','কোমলগান্ধার':'NN','কোমলতা':'NN',
'কোমলহৃদয়যুক্ত':'JJ','কোমলাঙ্গিনী':'JJ','কোমা':'NN','কোমোরিয়ান':'JJ','কোমোরোজ':'NN','কোমোরোজি':'NN','কোমোরোসি':'JJ',
'কোম্পানি':'NN','কোম্পানিগুলা':'NN','কোম্পানিগুলোর':'NN','কোম্পানিতে':'NN','কোম্পানী':'NN','কোম্পানীগুলোকে':'NN','কোম্পানীর':'NN',
'কোম্বুজ':'NN','কোমড়':'NN','কোর':'NN','কোরআনের':'NN','কোরক':'NN','কোরচি':'NN','কোরবা':'NN',
'কোরম':'NN','কোরসে':'NN','কোরা':'JJ','কোরাইগড়':'NN','কোরাজন':'NNP','কোরান':'NN','কোরাপুট':'NN',
'কোরিল্লা':'NN','কোরিয়নের':'NNP','কোরিয়া':'NN','কোরিয়ান':'NN','কোরিয়ার':'NN','কোরিয়াল':'NN','কোরীগড়':'NN',
'কোরুনা':'NN','কোরো':'VB','কোর্ট':'NN','কোর্টে':'NN','কোর্মা':'NN','কোর্সে':'NN','কোল':'NN',
'কোলকাতা':'NN','কোলকাতাবাসী':'NN','কোলন':'NN','কোলম':'NN','কোলহাপুর':'NN','কোলাইড':'NN','কোলাঘাট':'NNP',
'কোলাপুর':'NN','কোলাপুরী':'JJ','কোলাবা':'NN','কোলাসিব':'NN','কোলাহল':'NN','কোলিন':'NN','কোলী':'NN',
'কোলেস্টেরল':'NN','কোলোনিয়া':'NN','কোলোবাস':'NN','কোল্ড':'NN','কোল্হাড়':'NN','কোশল':'NN','কোশিকা':'NN',
'কোশী':'NN','কোষ-ভিত্তি':'NN','কোষ':'NN','কোষকলা':'NN','কোষাগার':'NN','কোষাধ্যক্ষ':'NN','কোষিকা':'NN',
'কোষীয়':'JJ','কোষে':'NN','কোষ্টা':'NN','কোষ্ঠি':'NN','কোসলী':'NN','কোসা':'NN','কোস্ট':'NN',
'কোস্টারিকা':'NN','কোহল':'NN','কোহলিঅভিনন্দন':'NN','কোহলিই':'NN','কোহলিতারপর':'NN','কোহলিদের':'NN','কোহলিরা':'NN',
'কোহলী':'NN','কোহাসা':'NN','কোহিনুর':'NN','কোহিমা':'NN','কোহেলীকে':'NN','কোয়া':'NN','কোয়াঞ্জা':'NN',
'কোয়ার্ক':'NN','কোয়ার্টার':'NN','কোয়ালিটি':'NN','কোয়ালিফায়েড':'NN','কোয়ালিশন':'NNP','কোয়াশিওরকোর':'NN','কোয়েটা':'NN',
'কোয়েম্বাটুর':'NN','কৌঁসুলি':'NN','কৌচুমার':'NN','কৌটা':'NN','কৌটিনহোর':'NN','কৌটো':'NN','কৌড়না':'NN',
'কৌড়ীজূডা':'NN','কৌডিন্য':'NN','কৌণিক':'JJ','কৌতিল্য':'NN','কৌতুক':'NN','কৌতুকবাস্তব':'NN','কৌতুকবোধ':'NN',
'কৌতুকময়':'NN','কৌতুহল':'NN','কৌতুহলকর':'JJ','কৌতুহলোদ্দীপক':'JJ','কৌতূহল':'NN','কৌত্স':'NN','কৌন্তেয়':'NN',
'কৌম':'NN','কৌমদকী':'NN','কৌমারভৃত্য':'NN','কৌমারিক':'NN','কৌমার্যভঞ্জিত':'JJ','কৌমার্য্য':'NN','কৌমুদ':'NN',
'কৌম্ভ':'NN','কৌরব':'NN','কৌলীন্য':'NN','কৌশল':'NN','কৌশলগতভাবে':'NN','কৌশলগুলি':'NN','কৌশলী':'NN',
'কৌশলের':'NN','কৌশল্যা':'NN','কৌশানী':'NN','কৌশিক':'NN','কৌশিকী-কানাড়া':'NN','কৌশিকী':'NN','কৌশিকীকানাড়া':'NN',
'কৌশীতকী':'NN','কৌষীতাকি':'NN','কৌষ্ঠকাঠিন্য':'NN','কৌষ্ঠবদ্ধতা':'NN','কৌষ্ঠ্য':'NN','কৌসীদ':'NN','কৌসুম্ভ':'NN',
'ক্কা':'NN','ক্কো':'NNP','ক্টর':'NN','ক্তন':'NN','ক্তি':'NN','ক্বাইকাম':'NN','ক্বাইজ্বান':'NN',
'ক্বাইতুই':'NN','ক্বাচা':'NN','ক্যমেরার':'NN','ক্যাঁচক্যাঁচ':'NN','ক্যাওড়া':'NN','ক্যাকটাস':'NN','ক্যাঙ্গারু':'NN',
'ক্যাচ':'NN','ক্যাচালের':'NN','ক্যাট':'NN','ক্যাটাগরিতে':'NN','ক্যাটারাক্ট':'NN','ক্যাডমিয়াম':'NN','ক্যাডারকে':'NNP',
'ক্যাডারকেও':'NN','ক্যাডারভুক্ত':'NN','ক্যাডাররা':'NN','ক্যাডেট':'NN','ক্যাণ্ডি':'NN','ক্যাণ্ডিতে':'NNP','ক্যাথলিক':'NNP',
'ক্যাথোড':'NN','ক্যান':'NN','ক্যানক্রাই':'NNP','ক্যানটিন':'NN','ক্যানটিনের':'NNP','ক্যানভাস':'NN','ক্যানাল':'NN',
'ক্যানেস্তারা':'NN','ক্যান্টিন':'NN','ক্যান্ডি':'NN','ক্যান্দালাইচি':'NN','ক্যান্সার':'NN','ক্যাপ':'NN','ক্যাপটেনের':'NN',
'ক্যাপসিকাম':'NN','ক্যাপসুল':'NN','ক্যাপাবিলিটি':'NN','ক্যাপিটাল':'NN','ক্যাপুচীন':'NN','ক্যাপের':'NN','ক্যাপ্টেনসি':'NN',
'ক্যাপ্টেন্সি':'NN','ক্যাবল':'NN','ক্যাবলা':'NNP','ক্যাবিনেট':'NN','ক্যামপেসট্রিস':'NNP','ক্যামবাইসেস':'NNP','ক্যামিকেলের':'NN',
'ক্যামেরার':'NN','ক্যামেরায়':'NN','ক্যামেরুনের':'NN','ক্যাম্প':'NN','ক্যাম্পাসগুলো':'NN','ক্যাম্পাসে':'NN','ক্যাম্পিং':'NN',
'ক্যারা':'NN','ক্যারামতি':'NN','ক্যারিবিয়':'NN','ক্যারিবিয়ান':'NN','ক্যারিশমাটিক':'NN','ক্যারিয়ার':'NN','ক্যারিয়ারে':'NN',
'ক্যারেট':'NN','ক্যালকাটার':'NN','ক্যালকেরিয়া':'NNP','ক্যালরি':'NN','ক্যালাইডোস্কোপ':'NN','ক্যালিফোর্নিয়া':'NN','ক্যালিফোর্নিয়ায়':'NN',
'ক্যালিস':'NN','ক্যালেংকারিকে':'NN','ক্যালেন্ডার':'NN','ক্যাশ-রিজার্ভ-রেশিওর':'NN','ক্যাশ':'NN','ক্যাসিনোতে':'NN','ক্যাসেটটি':'NN',
'ক্যাস্পিয়ান':'NN','ক্যে':'NN','ক্রটিপূর্ণ':'NN','ক্রণ':'NN','ক্রণিকার':'NN','ক্রতু':'NN','ক্রথন':'NN',
'ক্রন্দন':'NN','ক্রন্দনরত':'JJ','ক্রন্দসী':'NNP','ক্রম':'NN','ক্রমবদ্ধ':'NN','ক্রমবর্ধপরিমণে':'NN','ক্রমবিকাশ':'NN',
'ক্রমবিবর্তনের':'NN','ক্রমভঙ্গ':'NN','ক্রমরহিত':'JJ','ক্রমশ':'NN','ক্রমশঃ':'RB','ক্রমশ‍':'NN','ক্রমসারণী':'NN',
'ক্রমহীন':'RB','ক্রমহীনতা':'NN','ক্রমাগত':'NN','ক্রমাগতই':'RB','ক্রমাঙ্ক':'NN','ক্রমানুবর্তী':'JJ','ক্রমানুযায়ী':'NN',
'ক্রমানুসারিতা':'NN','ক্রমান্বয়ে':'NN','ক্রমিক':'JJ','ক্রমে':'NN','ক্রমোন্নতি':'NN','ক্রমোলঙ্ঘনকারী':'JJ','ক্রস':'NN',
'ক্রসফায়ার':'NN','ক্রসফায়ারের':'NN','ক্রসিং-ওভারের':'NN','ক্রসিং':'NN','ক্রা':'NN','ক্রাইমস':'NNP','ক্রাউন':'NN',
'ক্রাঙ্কল':'NNP','ক্রাচ':'NN','ক্রান্তিবাদী':'NN','ক্রান্তীয়':'NN','ক্রাশ':'NN','ক্রাস্ট':'NN','ক্রি':'NN',
'ক্রিংক্রিং':'NN','ক্রিকইনফো':'NN','ক্রিকবাজ':'NN','ক্রিকেট':'NN','ক্রিকেটটা':'NN','ক্রিকেটপ্রেমী':'NN','ক্রিকেটভক্তরা':'NN',
'ক্রিকেটার':'NN','ক্রিকেটারদের':'NN','ক্রিকেটারের':'NN','ক্রিকেটীয়':'NN','ক্রিকেটেই':'NN','ক্রিকেটের':'NN','ক্রিজে':'NN',
'ক্রিপ্টন':'NN','ক্রিম':'NN','ক্রিমিনালদের':'NN','ক্রিয়া':'NN','ক্রিয়ার':'NN','ক্রিশিয়ানো':'NN','ক্রিসেন্টকে':'NN',
'ক্রিস্টিনিয়া':'NN','ক্রিস্টোফার-নেবিস':'NN','ক্রিড়া':'NN','ক্রিয়া-কলাপ':'NN','ক্রিয়া-বিশেষণ':'NN','ক্রিয়া':'NN','ক্রিয়াকর্ম':'NN',
'ক্রিয়াকলাপ':'NN','ক্রিয়াবিশেষণ':'NN','ক্রিয়ার':'NN','ক্রিয়াশূণ্য':'JJ','ক্রিয়েট':'NN','ক্রিয়োল':'NN','ক্রী':'NN',
'ক্রীড়া':'NN','ক্রীড়ামন্ত্রী':'NN','ক্রীড়াস্থল':'NN','ক্রীত':'JJ','ক্রীতদাস':'NN','ক্রীপট':'NNP','ক্রীম':'NN',
'ক্রীড়াঙ্গনের':'NN','ক্রু':'NN','ক্রুজার':'NN','ক্রুটি':'NN','ক্রুটিবিচ‍্যুতি':'NN','ক্রুদ্ধ':'NN','ক্রুন':'NN',
'ক্রূড়':'NN','ক্রূর':'JJ','ক্রূরতা':'NN','ক্রূরতাপূর্বক':'RB','ক্রে':'NN','ক্রেটিয়েগস':'NN','ক্রেডিট':'NN',
'ক্রেডিটের':'NN','ক্রেণ':'NN','ক্রেতাকে':'NN','ক্রেতাদের':'NN','ক্রেতাপ্রতিষ্ঠান':'NN','ক্রেতার':'NN','ক্রেতারাই':'NN',
'ক্রেন':'NN','ক্রেপ':'NN','ক্রোড়':'NN','ক্রোধবশা':'NN','ক্রোধহীন':'JJ','ক্রোধা':'NN','ক্রোধী':'JJ',
'ক্রোন':'NN','ক্রোনার':'NN','ক্রোম':'NN','ক্রোমোজোম':'NN','ক্রোল':'NNP','ক্রোশ':'NN','ক্রোষ্টশীর্ষক':'NN',
'ক্রোষ্টু':'NN','ক্রোয়েশিয়া':'NN','ক্রোয়েশিয়াবাসী':'NN','ক্রোয়েশিয়ার':'JJ','ক্রোয়েশীয়':'NN','ক্রৌঞ্চাদন':'NN','ক্রৌন্চদ্বীপ':'NN',
'ক্র্যাক':'NN','ক্র্যানবেরি':'NN','ক্র্যাশ':'NN','ক্রয়-বিক্রয়কারী':'NN','ক্রয়':'NN','ক্রয়ক্ষমতার':'NN','ক্রয়সীমার':'NN',
'ক্রয়ের':'NN','ক্লপ':'NN','ক্লমল':'NN','ক্লাউড':'NN','ক্লাচ':'NN','ক্লান্ত':'NN','ক্লান্তিকর':'NN',
'ক্লান্তিব্যঞ্জক':'JJ','ক্লান্তির':'NN','ক্লাব':'NN','ক্লাবে':'NN','ক্লারনেট':'NN','ক্লার্ক':'NN','ক্লাশ':'NN',
'ক্লাস':'NN','ক্লাসিক':'JJ','ক্লাসিকো':'NN','ক্লাসিকোএকটু':'JJ','ক্লাসিকোর':'NN','ক্লাসিক্যাল':'NNP','ক্লাসে':'NN',
'ক্লায়েন্ট':'NN','ক্লিওপেট্রা':'NNP','ক্লিক':'NN','ক্লিটোরেস':'NN','ক্লিন':'NN','ক্লিনার':'NN','ক্লিপ':'NN',
'ক্লিয়ার':'JJ','ক্লু':'NN','ক্লুলেস':'NNS','ক্লেমেণ্ট':'NNP','ক্লেশ':'NN','ক্লেশস্বীকার':'NN','ক্লোজ':'NN',
'ক্লোডিয়াস':'NNP','ক্লোরিন':'NN','ক্লোরোপ্লাস্ট':'NNP','ক্লোরোফর্ম':'NN','ক্লোরোমাইসেটিনের':'NNP','ক্শা':'NN','ক্ষ':'NN',
'ক্ষণ':'NN','ক্ষণদ্যুতি':'NN','ক্ষণপ্রভা':'NN','ক্ষণভঙ্গুর':'JJ','ক্ষণভঙ্গুরতা':'NN','ক্ষণমুক্ত':'JJ','ক্ষণস্থায়ী':'NN',
'ক্ষণিক':'JJ','ক্ষণে':'RB','ক্ষত':'NN','ক্ষতব্রত':'JJ','ক্ষতি':'NN','ক্ষতিকর':'JJ','ক্ষতিকারক':'NN',
'ক্ষতিগ্রস্ত':'VBN','ক্ষতিগ্রস্থ':'NN','ক্ষতিটা':'NN','ক্ষতিপুরণ':'NN','ক্ষতিপূরণে':'NN','ক্ষতিপূর্তি':'VB','ক্ষতির':'NN',
'ক্ষতিসাধন':'NN','ক্ষতে':'NN','ক্ষত্রসব':'NN','ক্ষত্রিয়রা':'NN','ক্ষত্রিয়াণী':'NN','ক্ষন':'NN','ক্ষপণক':'NN',
'ক্ষবর':'NN','ক্ষম':'NN','ক্ষমতাএ':'NN','ক্ষমতাকে':'NN','ক্ষমতাচ্যুত':'NN','ক্ষমতাটা':'NN','ক্ষমতাধর':'NN',
'ক্ষমতাধরের':'NN','ক্ষমতাধারী':'JJ','ক্ষমতাপূর্ণতা':'NN','ক্ষমতাবান':'JJ','ক্ষমতাবানদের':'NN','ক্ষমতাবানরাই':'NN','ক্ষমতায়':'NN',
'ক্ষমতাযুক্ত':'JJ','ক্ষমতাযে':'JJR','ক্ষমতার':'NN','ক্ষমতারূঢ়':'JJ','ক্ষমতাশালী':'NN','ক্ষমতাসম্পন্ন':'JJ','ক্ষমতাসীন':'NN',
'ক্ষমতাসীনদের':'NN','ক্ষমতাহীন':'JJ','ক্ষমতাহীনতা':'NN','ক্ষমতায়':'NN','ক্ষমা-যাচনা':'NN','ক্ষমা':'NN','ক্ষমাপ্রার্থী':'JJ',
'ক্ষমাযাচনা':'NN','ক্ষমাযোগ্য':'JJ','ক্ষমার':'JJ','ক্ষমাহীন':'JJ','ক্ষর':'NN','ক্ষরন':'NN','ক্ষরিত':'JJ',
'ক্ষস':'NN','ক্ষাতে':'NN','ক্ষাত্র':'JJ','ক্ষান্ত':'NN','ক্ষাপ্পা':'NN','ক্ষার':'NN','ক্ষারযুক্ত':'JJ',
'ক্ষারীয়':'NN','ক্ষালন':'NN','ক্ষিতি':'NN','ক্ষিতিজ':'JJ','ক্ষিতিজা':'NN','ক্ষিদে':'NN','ক্ষিপ্ত':'NN',
'ক্ষিপ্রকারী':'JJ','ক্ষিপ্রগতি':'NN','ক্ষী':'NN','ক্ষীণ-রোগ':'NN','ক্ষীণকণ্ঠে':'NN','ক্ষীণকায়':'NN','ক্ষীর-নিধি':'NN',
'ক্ষীর-সাগর':'NN','ক্ষীর':'NN','ক্ষীরবিদারী':'NN','ক্ষীরমোহন':'NN','ক্ষীরসাগর':'NN','ক্ষু':'NN','ক্ষুণ্ণিবৃত্তিকারী':'JJ',
'ক্ষুদিরাম':'NNP','ক্ষুদিরামের':'NN','ক্ষুদ্র':'NN','ক্ষুদ্রতর':'JJ','ক্ষুদ্রতা':'NN','ক্ষুদ্রান্ত্র':'NN','ক্ষুদ্রিকা':'NN',
'ক্ষুধা':'NN','ক্ষুধাতুর':'JJ','ক্ষুধাবর্ধক':'JJ','ক্ষুধার্ত':'NN','ক্ষুধিত':'JJ','ক্ষুন্ন':'VB','ক্ষুন্নস্বরেই':'NN',
'ক্ষুবধ':'JJ','ক্ষুব্ধ':'NN','ক্ষুর':'NN','ক্ষুরিক':'NN','ক্ষুরিকোপনিষদ':'NN','ক্ষু‌দে':'NN','ক্ষেত':'NN',
'ক্ষেতমজুরী':'NN','ক্ষেতে':'NN','ক্ষেত্র':'NN','ক্ষেত্রফল':'NN','ক্ষেত্রবিশেষে':'RB','ক্ষেত্রি':'NN','ক্ষেত্রেই':'NN',
'ক্ষেত্রের':'NN','ক্ষেপক':'JJ','ক্ষেপণাস্ত্র':'NN','ক্ষেপন':'VB','ক্ষেপনাস্ত্র':'NN','ক্ষেপবেসেদিন':'NN','ক্ষেপিয়া':'JJ',
'ক্ষেপে':'NN','ক্ষেমা':'NN','ক্ষোভ':'NN','ক্ষোভটা':'NN','ক্ষৌম':'NN','ক্ষৌরকার':'NN','ক্ষ্যাপাঠাকুর':'NNP',
'ক্ষ্যাপার':'NN','ক্ষ্যামা':'NN','ক্ষয়':'NN','ক্ষয়ক্ষতি':'NN','ক্ষয়চক্র':'NN','ক্ষয়প্রাপ্ত':'JJ','ক্ষয়রাত':'NN',
'ক্ষয়রোগী':'JJ','ক্ষয়শীল':'JJ','ক্ষয়হীনতা':'NN','ক্ষয়ী':'JJ','ক্ষয়ীভবনের':'NN','ক্ষয়ে':'NN','ক্ষ‌েত্রেও':'NN',
'ক্সন':'NN','ক্সি':'NNP','ক্সে':'NN','কড়র্সার':'NNP','কড়া':'NN','কড়াকড়ি':'RB','কড়ার':'NN',
'কড়ায়গণ্ডায়':'NNP','কড়ের':'NN','কয়':'NN','কয়কি':'NN','কয়জন':'NN','কয়টা':'NN','কয়টাকার':'NN',
'কয়টি':'NN','কয়দিন':'NNS','কয়পুতি':'NN','কয়লা':'NN','কয়লাখাতের':'NN','কয়লাদ্বারা':'NN','কয়াধু':'NN',
'কয়ার-ফড়িং':'NN','কয়ালা':'NN','কয়ে':'VB','কয়েক':'NN','কয়েকখানা':'CD','কয়েকগুণ':'NNS','কয়েকজন':'NN',
'কয়েকজনের':'NN','কয়েকটা':'NN','কয়েকদিন':'NNS','কয়েকবার':'NNS','কয়েকমাস':'NNS','কয়েকশ':'NNS','কয়েথবেল':'NN',
'কয়েদ':'NN','কয়েদিদের':'NNS','কয়েন':'NNS','কয়েমের':'NN','কয়েল':'NN','কয়্যারেলসাম':'NN','ক‌মে‌ডি‌য়িান':'JJ',
'ক‌রে':'NN','ক‌রে‌ছেন':'NN','ক‌ি':'NN','ক‌ীভাব‌ে':'NN','খ':'NN','খঁড়বানী':'NN','খঁড়সার':'NN',
'খআঁটি':'VB','খই':'NN','খইচুর':'NN','খইভাজা':'NN','খইমোয়া':'NN','খইল':'NN','খকরা':'NN',
'খকেও':'NN','খখোণ্ডর':'NN','খগ':'NN','খগপতি':'NN','খগম':'NN','খগরাজ':'NN','খগাধিপ':'NN',
'খগেন্দ্র':'NN','খঙ্গোরিয়া':'NN','খচিত':'JJ','খচিয়ে':'VB','খচ্চর':'NN','খছেন':'VB','খজরি':'NN',
'খজলিয়া':'NN','খজাকা':'NN','খজুরছড়ী':'NN','খঞ্জত্ব':'NN','খঞ্জন':'NN','খঞ্জনী':'NN','খঞ্জর':'NN',
'খটকা':'NN','খটখট':'NN','খটখটানো':'VB','খটখটিয়া':'NN','খটবাং':'NN','খটলর':'NN','খটাখটি':'NN',
'খট্':'VB','খট্টি':'NN','খড়':'NN','খড়কুটো':'NN','খড়খড়':'NN','খড়গী':'NN','খড়ম':'NN',
'খড়ীণ্ডকী':'NN','খড়ের':'NN','খড়্গবন্ধ':'NN','খড্গ':'NN','খণিজ':'NN','খণিজবিজ্ঞানী':'NN','খণ্ড-কাব্য':'NN',
'খণ্ড':'NN','খণ্ডকাব্য':'NN','খণ্ডকারী':'JJ','খণ্ডচিত্র':'NN','খণ্ডটি':'NN','খণ্ডনকারী':'JJ','খণ্ডপুরি':'NN',
'খণ্ডবা':'NN','খণ্ডসর':'NN','খণ্ডাকতো':'NN','খণ্ডের':'NN','খত':'NN','খতঙ্গ':'NN','খতনা':'NN',
'খতম':'NN','খতাম':'VB','খতি':'NNP','খতিগ্রস্থ':'VBN','খতিপুরন':'NN','খতিয়ান':'NN','খতিয়ে':'VB',
'খতুম':'VB','খতেও':'NN','খতেন':'VB','খত্তাল':'NN','খত্রী':'NN','খদির':'NN','খদ্দর':'NN',
'খনখন':'NN','খননকারী':'JJ','খননকার্য':'NN','খননকৃত':'JJ','খনি-শ্রমিক':'NN','খনি':'NN','খনিজদ্রব্য':'NN',
'খনিজবিজ্ঞান':'NN','খনিজলবণ':'NN','খনিজসম্পদ':'NNS','খনিত':'JJ','খনিতে':'NN','খনোই':'NN','খন্ড-কথা':'NN',
'খন্ড':'NN','খন্ডকালীন':'NN','খন্ডন':'NN','খন্ডরা':'NN','খন্ডসার':'NN','খন্ডিত':'NN','খন্তী':'NN',
'খন্দকার':'NN','খপ':'NN','খপ্পডের':'NN','খপ্পরে':'NN','খবর':'NN','খবরও':'NNS','খবরকে':'NN',
'খবরগুলো':'NN','খবরটা':'NN','খবরটি':'NN','খবরদারিটা':'NN','খবরদারী':'NN','খবরে':'NN','খবরেই':'NNS',
'খবরের':'NN','খবার':'NN','খবেন':'VB','খমতার':'NN','খমা':'NN','খমির':'NN','খমুখ':'NN',
'খম্ভাবতী':'NN','খম্মম':'NN','খর':'NN','খরকে':'NN','খরখরে':'NN','খরগোন':'NN','খরগোশের':'NN',
'খরচ':'NN','খরচও':'NN','খরচকৃত':'JJ','খরচটা':'NN','খরচনো':'VB','খরচা':'NN','খরচাপাতি':'NN',
'খরচার':'NN','খরচে':'NN','খরচের':'NN','খরছ':'NN','খরজ':'NN','খরবাস':'NN','খরমুজ':'NN',
'খরসান':'NN','খরসাবাঁ':'NN','খরা-গ্রস্থ':'JJ','খরা':'NN','খরাগ্রস্থ':'JJ','খরাজ':'NN','খরারি':'NN',
'খরুচে':'JJ','খরুচেপনা':'NN','খরোষ্ঠী':'NN','খর্জুর':'NN','খর্ব':'NN','খল':'NN','খলতা':'NN',
'খলনায়ক':'NN','খলশে':'NN','খলাম':'VB','খলার':'NN','খলিবর্ধন':'NN','খলীকুজ্জামান':'NNP','খলেই':'NN',
'খলেন':'VB','খলের':'NN','খল্লারী':'NN','খশা':'NN','খসখস':'NN','খসড়া':'NN','খসড়াকৃত':'JJ',
'খসরুকে':'NNP','খস্':'NN','খস্ত':'JJ','খা':'NN','খাঁই':'NN','খাঁকারি':'NN','খাঁকে':'NNP',
'খাঁচ':'NN','খাঁচার':'NN','খাঁটি':'NN','খাঁটিত্বের':'NN','খাঁড়':'NN','খাঁড়ি':'NN','খাঁদে':'NNS',
'খাঁর':'NNP','খাই':'VB','খাইকো':'NN','খাইছিলো':'VB','খাইছে':'VB','খাইছেতারপরও':'NN','খাইজ্বর':'NN',
'খাইতে':'NN','খাইব':'VB','খাইরান':'NN','খাইরানের':'NNP','খাইরুল':'NNP','খাইলকার':'NN','খাইলে':'VB',
'খাইয়া':'VB','খাইয়েছে':'NNS','খাইয়েপড়িয়ে':'VBN','খাও':'VB','খাওয়া':'NN','খাওয়ার':'VBG','খাওয়া-দাওয়া':'NN',
'খাওয়া':'NN','খাওয়াইবেন':'VB','খাওয়াচ্ছে':'VBG','খাওয়াতে':'NN','খাওয়ান':'VB','খাওয়ানো':'NN','খাওয়ানোর':'VBG',
'খাওয়াবে':'VB','খাওয়ার':'NN','খাক':'NNS','খাকরা':'NN','খাকী':'NN','খাকে':'NN','খাখরা':'NN',
'খাগ':'NN','খাগড়া':'NN','খাগরাছড়ি':'NNP','খাচায়':'NNP','খাচ্ছি':'VBG','খাচ্ছেন':'VBG','খাজনা':'NN',
'খাজা':'NN','খাজাঞ্চি':'NN','খাজুর':'NN','খাজুলি':'NN','খাট':'NN','খাটখোড়':'NNS','খাটত':'VB',
'খাটপুরা':'NN','খাটা':'VB','খাটাচ্ছে':'VBG','খাটান':'VB','খাটানো':'NN','খাটারা':'NN','খাটায়':'VB',
'খাটি':'NN','খাটিয়ে':'VB','খাটুনি':'NN','খাটুলি':'NN','খাটে':'NN','খাটো':'NN','খাটোবুদ্ধির':'JJ',
'খাড়া':'NN','খাড়ি':'NN','খাড়ুয়া':'NN','খাণ্ডব':'NN','খাত':'NN','খাতকে':'NN','খাতজ্বর':'NN',
'খাতটা':'NN','খাতটি':'NN','খাতযা':'NN','খাতাদার':'JJ','খাতির':'NN','খাতুন':'NN','খাতে':'NN',
'খাতের':'NN','খাদ':'NN','খাদহীন':'JJ','খাদান':'NN','খাদি':'NN','খাদিম':'NNP','খাদী':'NN',
'খাদ্য':'NN','খাদ্যগ্রহণ':'NN','খাদ্যজ':'NN','খাদ্যদ্রব্য':'NN','খাদ্যনলে':'NN','খাদ্যপণ্য':'NNS','খাদ্যপদার্থ':'NN',
'খাদ্যবঞ্চিত':'NN','খাদ্যভাতা':'NN','খাদ্যমন্ত্রী':'NN','খাদ্যরসিক':'JJ','খাদ্যশষ্য':'NNS','খাদ্যশস্য':'NN','খাদ্যসূচী':'NN',
'খাদ্যান্বেষণের':'NN','খাদ্যাভাব':'NN','খাদ্যাভ্যাস':'NNS','খাদ্যে':'NN','খাদ্যোপাদান':'NN','খান':'NN','খানকে':'NNP',
'খানদানি':'JJ','খানদের':'NN','খানম':'NN','খানি':'VB','খানিক':'NN','খানে':'RB','খানেক':'CD',
'খানেকের':'NNP','খানের':'NN','খানো':'NNV','খাপ':'NN','খাপরিয়া':'NN','খাপা':'VB','খাপুসে':'NN',
'খাপুয়া':'NN','খাফরে':'NNP','খাব':'NN','খাবাইছেন':'NNS','খাবার-দাবার':'NN','খাবার':'NN','খাবারদাবারে':'NN',
'খাবারের':'NN','খাবি':'VBP','খাবে':'VB','খাবেনআর':'VB','খাবো':'VB','খাবো':'VB','খাম':'NN',
'খামখেয়ালিপনা':'NN','খামটা':'NN','খামরে':'NN','খামসামা':'NN','খামার':'NN','খামারবাড়ির':'NN','খামারিদের':'NNS',
'খামারীই':'NN','খামারীদের':'NNS','খামারের':'NN','খামি':'NN','খামিরা':'NN','খামু':'NNP','খামোখা':'NN',
'খামোস':'NN','খাম্বা':'NN','খাম্বাজ-কানাড়া':'NN','খাম্বাজ':'NN','খাম্বাতন্ত্র':'NNS','খাম্বাতারেকের':'NN','খাম্বাবতী-কানাড়া':'NN',
'খাম্বাবতী':'NN','খাম্বায়':'NN','খায়':'NN','খার':'NN','খারপ':'NN','খারাপঅন্ধ':'IN','খারাপটা':'NNP',
'খারাপতর':'JJ','খারাপদের':'NNS','খারাপসব':'NN','খারি':'NN','খারিফ':'NN','খারী':'NN','খার্তুম-এর':'NNP',
'খার্তুম':'NN','খাল':'NN','খালাস':'NN','খালাসকারীকে':'NN','খালি':'NN','খালুই':'NN','খালে':'NN',
'খালেক':'NNP','খালেদ':'VBN','খালেদা':'NN','খালেদাকে':'NNP','খালেদাজিয়ার':'NNP','খালেদার':'NN','খালেদারজামাত':'NNP',
'খালের':'JJ','খালো':'NNP','খালো':'JJ','খাশগি':'NNP','খাস':'NN','খাসজমির':'NNP','খাসা':'NN',
'খাসাগিরের':'NN','খাসি':'NN','খাসৈাগির':'NN','খাসোগি':'NNP','খাসোগিকে':'NN','খাস্তা':'NN','খাড়া':'NN',
'খাড়িয়ে':'NN','খায়':'NN','খা‌দ্যে':'NN','খিঁচুনি':'NN','খিকা':'NN','খিচির':'NN','খিচুড়ি':'NN',
'খিচুরি':'NN','খিটখিট':'NN','খিটমিট':'VB','খিটে':'JJ','খিড়কি':'NN','খিতে':'NN','খিদা':'JJ',
'খিদে':'NN','খিদ্রাপুর':'NN','খিনি':'VB','খিবে':'VB','খিরগিজ':'NN','খিরনী':'NN','খিরি':'NN',
'খিল':'VB','খিলখিল':'VB','খিলজি':'NN','খিলা':'NN','খিলান':'NN','খিলানমার্গ':'NN','খিলি':'NN',
'খিলোরী':'NN','খিস্তি':'NN','খিয়া':'VB','খীকে':'NN','খুঁজছিল':'NN','খুঁজছে':'NN','খুঁজছেন':'VB',
'খুঁজতেছে':'VB','খুঁজলেই':'VB','খুঁজুন':'VB','খুঁট':'NN','খুঁটিনাটি':'NN','খুঁটিযুক্ত':'JJ','খুঁটিয়ে':'VB',
'খুঁটে':'NN','খুঁড়তে':'VB','খুঁড়া':'NN','খুঁত':'NN','খুউউব':'NN','খুখি':'NN','খুঙ্গী':'NN',
'খুচরা':'NN','খুচাখুচি':'VBG','খুজ':'NN','খুজতে':'NN','খুজবে':'NN','খুজিশ':'NN','খুজে':'NN',
'খুঝে':'NN','খুটি':'NNS','খুড়তুতো':'NN','খুড়িয়ে':'NN','খুত':'NN','খুদ':'NN','খুদিত':'JJ',
'খুদে':'NN','খুন':'NN','খুনখারাবি':'NN','খুনধর্ষনব্যাংকশেয়ার':'NNS','খুনসন্ত্রাসী':'NN','খুনাখুনি':'NN','খুনি':'NN',
'খুনিদরকার':'NN','খুনিদের':'NNS','খুনির':'NN','খুনিরা':'NNS','খুনিয়া':'FW','খুনী':'NN','খুনীদেরকে':'NN',
'খুনীরা':'NN','খুনে':'NN','খুনোখুনি':'NN','খুনোখুনিটাকে':'NN','খুন্তি':'NN','খুপড়ি':'NN','খুপিযুক্ত':'JJ',
'খুফুর':'NNP','খুব':'NN','খুবতো':'NN','খুবনিজেকে':'NN','খুবলে':'VB','খুবসুরত':'NNP','খুবানি':'NN',
'খুবি':'RB','খুবী':'NN','খুভ':'NN','খুমানি':'NN','খুমী':'NN','খুর':'NN','খুরপা':'NN',
'খুরপী':'VB','খুরপেষণ':'NN','খুরপোকা':'NN','খুরফ':'NN','খুরমা':'NN','খুরশাশুড়ি':'NN','খুরশ্বশুর':'NN',
'খুরি':'NN','খুরুচনী':'NN','খুরের':'NN','খুর্দা':'NN','খুর্রম':'NN','খুলছি':'VB','খুলতে':'NN',
'খুলনা':'NNP','খুলনার':'NN','খুলনায়':'NNP','খুলনা২':'NN','খুলবার':'NNV','খুললেই':'NN','খুললো':'VB',
'খুলি':'NN','খুলিয়ে':'VB','খুলুন':'VB','খুলে':'NN','খুলেছে':'VBN','খুলেন':'VB','খুশ':'JJ',
'খুশকি':'NN','খুশিও':'NN','খুশিতেই':'NN','খুশিতো':'JJ','খুশির':'NN','খুশী':'NN','খুশীচালিয়ে':'NN',
'খুশীর':'NN','খুসকি':'NN','খুসিতে':'RB','খুড়তে':'NN','খুড়া':'NN','খূব':'NN','খূশীতে':'NN',
'খৃঃ':'NNP','খৃষ্টধর্মের':'NN','খৃষ্টাব্দ':'NN','খৃষ্টাব্দের':'NN','খেঁটে':'NN','খেঁদিয়ে':'VB','খেই':'NN',
'খেকসা':'NN','খেকো':'NN','খেচর':'NN','খেছি':'VB','খেজুর':'NN','খেজুরের':'NN','খেটক':'NN',
'খেটে':'NNP','খেটেছেন':'VB','খেড়া':'NN','খেত':'VB','খেতমজুর':'NN','খেতাব':'NN','খেতাবে':'NN',
'খেতেন':'VB','খেতের':'NN','খেদ':'NN','খেনি':'VB','খেপ':'NN','খেপাইছিল':'NN','খেপে':'VB',
'খেমকারী':'NN','খেমের':'NN','খেয়ে':'VB','খেরি':'NN','খেরুয়া':'NN','খেরো':'NN','খেল':'NN',
'খেলছিলেন':'VB','খেলছে':'VB','খেলতে':'VB','খেলতেছে':'VBG','খেলতেন':'NN','খেলনি':'VB','খেলবে':'VB',
'খেলল':'VB','খেললেই':'VB','খেলসে':'VB','খেলসেকিন্তু':'NN','খেলা':'NN','খেলাইফি':'NN','খেলাও':'NN',
'খেলাগুলোতে':'NNS','খেলাচ্ছে':'VB','খেলাটা':'VB','খেলাটাই':'NN','খেলাতে':'NN','খেলাধুলা':'NN','খেলাধুলায়':'NNS',
'খেলাধূলা':'NN','খেলাধূলায়':'NN','খেলানো':'NN','খেলাপি':'NN','খেলাপিরা':'NN','খেলাপীদের':'NN','খেলাফতকে':'NN',
'খেলাম':'NN','খেলায়':'VB','খেলার':'NN','খেলাররোগে':'NN','খেলারাম':'NN','খেলালে':'NN','খেলাসে':'VB',
'খেলিই':'VB','খেলিলাম':'VB','খেলিয়ে':'VB','খেলুক':'VB','খেলে':'NN','খেলেই':'VB','খেলেছিলাম':'VB',
'খেলেছে':'NN','খেলেছেন':'NN','খেলেন':'NN','খেলোয়াড়':'NN','খেলেয়ার':'NN','খেলো':'NN','খেলোয়াড়':'NN',
'খেলোয়াড়':'NN','খেলোয়ার+সেরা':'NN','খেলোয়ারকে':'NN','খেলোয়ারদের':'NN','খেলোয়ারের':'NN','খেলোয়াড়ই':'NN','খেলোয়াড়দের':'NN',
'খেলোয়াড়বান্ধব':'NN','খেলোয়াড়শফিউল':'NN','খেলোয়াড়ের':'NN','খেলয়াড়':'NN','খেসারত':'NN','খোঁজ':'NN','খোলা':'NN',
'খোয়াতে':'NN','খেয়া-পারাপার':'NN','খেয়া':'NN','খেয়ানতকারি':'NN','খেয়াপারাপার':'NN','খেয়ামাঝি':'NN','খেয়াল':'NN',
'খেয়ালী':'JJ','খেয়ালীপনা':'NN','খেয়ালে':'NN','খেয়ে':'NN','খেয়েও':'NN','খেয়েছিল':'NN','খেয়েছেন':'NN',
'খৈনি':'NN','খো-খো':'NN','খো':'NN','খোঁচা':'NN','খোঁচাখুঁচি':'NN','খোঁচানো':'NN','খোঁজ-খবর':'NN',
'খোঁজ':'NN','খোঁজা':'VB','খোঁজানো':'VB','খোঁজার':'NN','খোঁজেনএটা':'NN','খোঁটা':'VB','খোঁটাবাজ':'JJ',
'খোঁটে':'JJ','খোঁড়ল':'NN','খোঁড়ানো':'NN','খোঁপা':'NN','খোঁড়াক':'NN','খোঁয়াড়':'NN','খোই':'NN',
'খোকলি':'NN','খোকা':'NN','খোকার':'NN','খোকোন–এর':'NN','খোখর':'NN','খোখলা':'VB','খোখো':'NN',
'খোজ':'NN','খোজা':'NN','খোটা':'VB','খোটানী':'JJ','খোড়ানো':'NN','খোদ':'NN','খোদক':'NN',
'খোদা':'NN','খোদাইকারী':'NN','খোদাইনো':'VB','খোদাইর':'NN','খোদার':'JJ','খোদিত':'JJ','খোন্দকার':'NN',
'খোপ':'NN','খোব':'NN','খোবানি':'NN','খোয়ালাম':'NN','খোর':'NN','খোরপোষ':'NN','খোরা':'NN',
'খোরাকি':'NN','খোর্মা':'NN','খোল':'NN','খোলশা':'VB','খোলস':'NN','খোলা;২':'VB','খোলাখুলিভাবে':'RB',
'খোলানো':'VB','খোলাভাব':'NN','খোলামেলা':'NN','খোলী':'NN','খোলেনি':'NN','খোলোস':'NN','খোশমেজাজী':'JJ',
'খোশমেজাজে':'NN','খোশামদী':'JJ','খোসা':'NN','খোড়া':'NN','খোয়াতে':'VB','খোয়ানো':'NN','খোয়াবে':'NN',
'খোয়ার':'NN','খ্যক':'JJ','খ্যা':'NN','খ্যাঁচ-খ্যাঁচানি':'NN','খ্যাত':'NN','খ্যাতিমান':'NN','খ্যাতিসম্পন্ন':'JJ',
'খ্যাপা':'JJ','খ্যাসারি':'NN','খ্রিষ্টান':'NN','খ্রিষ্টীয়':'JJ','খ্রিসমাস':'NN','খ্রিস্টপূর্ব':'JJ','খ্রিস্টান':'NN',
'খ্রী':'FW','খ্রীতেই':'NN','খ্রীর':'NN','খ্রীশ্চান':'NN','খ্রীষ্ট':'NN','খ্রীষ্টধর্মাবলম্বী':'JJ','খ্রীষ্টপূর্ব':'NN',
'খ্রীষ্টান':'NN','খ্রীষ্টাব্দে':'NN','খ্রীষ্টিয়':'JJ','খ্রীস্টানদের':'NN','খ্রীস্টিয়':'NN','খড়খড়িয়া':'VB','খড়গ':'NN',
'খড়ি':'NN','খয়রা':'NN','খয়রাতি':'JJ','খয়ের':'NN','খয়েরি':'JJ','গ':'NN','গঁদ':'NN',
'গঁদপঞ্জীরী':'NN','গঁদপাগ':'NN','গঁদমাখানা':'NN','গং':'NN','গওয়ালা':'NN','গগনচুম্বী':'NN','গগনভেদী':'JJ',
'গগনস্পর্শী':'NN','গগনাংনগ':'NN','গগল্স':'NN','গঙ্গ':'NN','গঙ্গা':'NN','গঙ্গাকে':'NNP','গঙ্গাজল':'NN',
'গঙ্গাজলিয়া':'JJ','গঙ্গাজলে':'NN','গঙ্গাতিরিয়া':'NN','গঙ্গাতীরবর্তী':'JJ','গঙ্গাতীরে':'NN','গঙ্গাদত্ত':'NN','গঙ্গাধর':'NN',
'গঙ্গামাটি':'NN','গঙ্গার':'NN','গঙ্গারামের':'NNP','গঙ্গাসাগর':'NN','গঙ্গাস্নানে':'NN','গঙ্গায়':'NNP','গঙ্গোত্রী':'NN',
'গঙ্গোদক':'NN','গঙ্গোপাধ্যায়':'NNP','গঙ্গৌলিয়া':'NN','গচ্ছা':'NN','গছেন':'VB','গজ':'NN','গজকর্ণ':'NN',
'গজকা':'NN','গজকুম্ভ':'NN','গজগজ':'VB','গজগামিনী':'NN','গজগামীনী':'JJ','গজচর্ম':'NN','গজদন্ত':'NN',
'গজদন্তী':'JJ','গজদাঁত':'NN','গজনাল':'NN','গজনের':'NN','গজপতি':'NN','গজপাঁও':'NN','গজপিপ্পলী':'NN',
'গজপুর':'NN','গজমতি':'NN','গজমুক্তা':'NN','গজল':'NN','গজশালা':'NN','গজসেনা':'NN','গজানন':'NN',
'গজারোহী':'NN','গজাল':'NN','গজাস্য':'NN','গজায়':'NN','গজিয়ে':'VB','গজেন্দ্র':'NN','গজের':'NN',
'গঞ্জ':'NNP','গঞ্জন':'NN','গঞ্জিফা':'NN','গঞ্জে':'NN','গটার':'NN','গঠইবন':'NN','গঠনকারী':'NN',
'গঠনতন্ত্রের':'NN','গঠনপ্রণালী':'NN','গঠনমূলক':'NN','গঠনশৈলীর':'JJ','গঠনাকৃতিই':'NN','গঠনে':'NN','গঠনের':'NN',
'গঠিত':'NN','গঠেছে':'NN','গড':'NN','গডচিরোলি':'NN','গডফাদার':'NN','গড়':'NN','গড়খাই':'NN',
'গড়গড়':'NN','গড়ছে':'NN','গড়দার':'NN','গড়বড়':'NN','গড়া':'NN','গড়াগড়ি':'NN','গড়ানো':'NN',
'গড়ার':'NN','গড়িয়ে':'NN','গড়ু':'NN','গণ':'NN','গণঅভ্যূথানের':'NN','গণআন্দোলন':'NN','গণক':'NN',
'গণগৌর':'NN','গণচিটিং':'NN','গণছুটি':'NN','গণজোয়ার':'NN','গণতন্':'NN','গণতন্ত্রকে':'NN','গণতন্ত্রযা':'NN',
'গণতন্ত্রের':'NN','গণতন্ত্র–দুটোই':'NNP','গণতান্তিক':'JJ','গণতান্ত্রিক':'NN','গণতামাসা':'NN','গণত্কার':'NN','গণদেব':'NN',
'গণধর্ষন':'NN','গণধোলাই':'NN','গণনা':'NN','গণনামূলক':'JJ','গণনার':'VBG','গণনায়':'NN','গণনীয়':'JJ',
'গণপতি':'NN','গণপরিবহন':'NN','গণফোরামের':'NN','গণবান্ধব':'NN','গণভিত্তিকে':'NN','গণভোট':'NN','গণমাধ্যমেও':'NN',
'গণমাধ‍্যম':'NNP','গণমান্য':'JJ','গণরাজ্য':'NN','গণরুমে':'NN','গণরোষ':'NN','গণশত্রুতে':'NN','গণসংহার':'NN',
'গণসাক্ষরতা':'NN','গণহত্যা':'NN','গণহত্যাঅবিলম্বে':'NN','গণহত্যার':'NN','গণাগ্রণা':'NN','গণাধিপ':'NN','গণায়':'NN',
'গণিকা':'NN','গণিত':'NN','গণিতবিদ':'NN','গণিতশাস্ত্র':'NN','গণিতে':'NN','গণীদের':'NN','গণেই':'NN',
'গণেশ':'NN','গণেশচতুর্থী':'NN','গণেশমামা':'NNP','গণেশের':'NNP','গণেশোত্সব':'NN','গণ্ড':'NN','গণ্ডগোল':'NN',
'গণ্ডদেশের':'NN','গণ্ডমূর্খ':'NN','গণ্ডস্হল':'NN','গণ্ডা':'NN','গণ্ডার':'NN','গণ্ডি':'NN','গণ্ডী':'NN',
'গণ্ডুপদ':'NN','গণ্ডূষ':'NN','গণ্য':'NN','গণ্যমান্য':'JJ','গত':'NN','গতকাল':'NN','গতদশ':'VB',
'গতপাঁচ':'NN','গতবছরও':'NN','গতবারের':'NN','গতানুগতিক':'NN','গতি':'NN','গতিক':'NNP','গতিকে':'NN',
'গতিতেই':'NN','গতিধারাকে':'NN','গতিনির্ধারক':'NN','গতিপ্রকৃতি':'NN','গতিপ্রবাহকে':'NN','গতিবিধি':'NN','গতিবেগ':'NN',
'গতিমান':'JJ','গতিময়':'NN','গতির':'NN','গতিরুদ্ধ':'VB','গতিরোধ':'NN','গতিশক্তি':'NN','গতিশীল':'NN',
'গতিশীলতায়':'NN','গতিহীন':'NN','গতু':'NN','গতেও':'NN','গত্য':'NN','গথিক':'NN','গদগদ':'NN',
'গদর্ভবাহিনী':'NN','গদা':'NN','গদাধরকে':'NNP','গদাধারী':'JJ','গদান':'NN','গদি.':'NN','গদিওয়ালা':'JJ',
'গদিচ্যূত':'JJ','গদিধারী':'NN','গদিনসীন':'NN','গদীশ':'NNP','গদ্য-পদ্য':'NN','গদ্য':'NN','গদ্যশৈলী':'NN',
'গদ্যাত্মক':'JJ','গধূলী':'NN','গন':'NN','গনকে':'NN','গনকেরুয়া':'NN','গনজমায়েত':'NNP','গনততন্ত্র':'NN',
'গনতন্ত্র':'NN','গনতন্ত্রহীন':'NN','গনতন্ত্রে':'NN','গনতন্র':'NN','গনতান্ত্রিক':'JJ','গননা':'NN','গননার':'VBG',
'গননায়':'NN','গনপরিবহন':'NN','গনমাধ্যমে':'NNP','গনহত্যার':'NN','গনার':'NN','গনিত':'NNS','গনের':'NN',
'গন্ডগোল':'NN','গন্ডগোলের':'NN','গন্ডা':'NN','গন্ডি':'NN','গন্ত':'JJ','গন্তত্রের':'NN','গন্তব্য':'NN',
'গন্দম':'NN','গন্ধ-পত্র':'NN','গন্ধ':'NN','গন্ধকাম্ল':'NN','গন্ধকের':'NN','গন্ধজাত':'NN','গন্ধদ্রব্য':'NN',
'গন্ধনাই':'NN','গন্ধপলাশী':'NN','গন্ধপ্রসারিণী':'NN','গন্ধবণিকের':'NN','গন্ধবাবুল':'NN','গন্ধবিরোজা':'NN','গন্ধমাদন':'NN',
'গন্ধমূষিক':'NN','গন্ধযুক্ত':'NN','গন্ধর্ব':'NN','গন্ধর্বলোক':'NN','গন্ধলেবু':'NN','গন্ধহীন':'JJ','গন্ধাষ্টক':'NN',
'গন্ধে':'NN','গপ্পবাজ':'JJ','গপ্পো':'NN','গফরগাঁও':'NN','গব':'NN','গবাক্ষ':'NN','গবাদনী':'NN',
'গবাদিপশুর':'NNS','গবান':'NN','গবিনী':'JJ','গবির':'NN','গবিষ্ঠ':'NN','গবীর':'NNP','গবুনিস':'JJ',
'গবুমামা':'NNP','গবেশনা':'NN','গবেষক-ছাত্র':'NN','গবেষক':'NN','গবেষকছাত্র':'NN','গবেষকদলের':'NN','গবেষকদের':'NNS',
'গবেষক–বিজ্ঞানী':'JJ','গবেষণা':'NN','গবেষণাকে':'NN','গবেষণাগারে':'NN','গবেষণাপত্র':'NN','গবেষণায়':'NN','গবেষণার':'NN',
'গবেষণায়':'NN','গবেষনার':'NN','গবেষিত':'JJ','গবেষ্ঠি':'NN','গবোরোন':'NN','গব্য':'JJ','গবয়':'NN',
'গভর্ণর':'NN','গভর্ণরের':'NN','গভর্নমেণ্ট':'NN','গভর্নর':'NN','গভর্নরের':'NN','গভস্থি':'NN','গভার':'NN',
'গভার্নমেন্টের':'NN','গভীর':'NN','গভীরতার':'NN','গভীরতী':'VB','গভীরভাবে':'NN','গভীরে':'RB','গভেষনা':'NN',
'গম':'NN','গমকযুক্ত':'JJ','গমন':'NN','গমনীয়':'JJ','গমনে':'NN','গম্বুজ':'NN','গম্বুজদার':'JJ',
'গম্ভারী':'NN','গম্ভীর':'JJ','গম্ভীরতা':'NN','গম্য':'JJ','গম্যাই':'NN','গর':'NN','গরকে':'NN',
'গরজ':'NN','গরদব':'NN','গরবা':'NN','গরম':'NNP','গরমমাইরে':'NN','গরমিল':'NN','গরমে':'NN',
'গররাজি':'JJ','গরল':'NN','গরহাজির':'JJ','গরিব':'VBG','গরিবআবার':'NN','গরিবই':'VBG','গরিবদের':'NN',
'গরিবি':'NN','গরিবের':'NN','গরিমসি':'NN','গরিমাহীন':'JJ','গরিলা':'NN','গরিষ্ঠ':'NN','গরীক':'JJ',
'গরীব':'NN','গরীবমানুষদের':'NN','গরীবরা':'NN','গরীবে':'VBG','গরীবের':'NN','গরীর':'NN','গরীয়':'JJ',
'গরু-চোর':'NN','গরু':'NN','গরুছাগল':'NNS','গরুড়-গঙ্গা':'NN','গরুড়':'NN','গরুড়ঘন্টা':'NN','গরুড়ধ্বজ':'NN',
'গরুড়পক্ষ':'NN','গরুড়পুরাণ':'NN','গরুড়ফাঁস':'NN','গরুড়রুত':'NN','গরুড়াস্ত্র':'NN','গরুত্মান':'NN','গরুর':'NN',
'গরুরগাড়ি-যাত্রা':'NN','গরের':'NN','গর্গ':'NN','গর্জন':'NN','গর্জে':'VB','গর্জ্জনের':'NN','গর্ত':'NN',
'গর্তবাসি':'NN','গর্তে':'NN','গর্দভ':'NN','গর্দভী':'NN','গর্দান':'NN','গর্ব':'NN','গর্বতাঁর':'NN',
'গর্ববোধ':'NN','গর্বভরে':'RB','গর্বশূণ্য':'JJ','গর্বহীন':'JJ','গর্বিত':'NN','গর্বে':'RB','গর্বের':'NN',
'গর্ভ':'NN','গর্ভগৃহ':'NN','গর্ভজ':'NN','গর্ভথলি':'NN','গর্ভদংশ':'NN','গর্ভদণ্ড':'NN','গর্ভধারণ':'NN',
'গর্ভধারিণী':'JJ','গর্ভধারিণীরা':'NN','গর্ভনালি':'NN','গর্ভনিরোধক':'NN','গর্ভপাত':'NN','গর্ভমুণ্ড':'NN','গর্ভস্খালন':'NN',
'গর্ভাধান':'NN','গর্ভাবস্থা':'NN','গর্ভাশয়':'NN','গর্ভাষ্টম':'NN','গর্ভেপরিস্রব':'NN','গর্ভোপনিষদ':'NN','গর্মপাই':'NN',
'গর্হিত':'JJ','গলকম্বল':'NN','গলগণ্ড':'NN','গলগ্রহ':'NNS','গলচর্ম':'NN','গলটন':'NN','গলদঘর্ম':'NN',
'গলদের':'NN','গলন':'NN','গলনশীল':'JJ','গলপ':'NN','গলবন্ধনরজ্জু':'NN','গলশোথ':'NN','গলস্তন':'NN',
'গলা':'NN','গলাকাটা':'NN','গলাগলি':'VBG','গলাজোড়':'NN','গলাদ্ধকরণ':'NN','গলাধঃকরণ':'VBG','গলাধাক্কা':'NN',
'গলানী':'NN','গলানো':'NN','গলাবন্ধ':'NN','গলাবাজি':'VBG','গলাভাত':'NN','গলাম':'NN','গলায়':'NN',
'গলার':'NN','গলাসী':'NN','গলায়':'NN','গলি':'NN','গলিত-কুষ্ট':'NN','গলিত':'JJ','গলিতকুষ্ট':'NN',
'গলুই':'NN','গলে':'NN','গলেন':'VB','গলের':'NN','গল্ডেন':'NN','গল্প-কাহিনীর':'NN','গল্প':'NN',
'গল্পকেও':'NN','গল্পগাথা':'NN','গল্পগুজব':'NN','গল্পটা':'NN','গল্পটি':'NN','গল্পরসিক':'JJ','গল্পে':'NN',
'গল্পের':'NN','গল্ফ':'NN','গষ্ট':'JJ','গসুখ':'NN','গস্ট':'NNP','গহন':'NN','গহনে':'NN',
'গহ্বর':'NN','গা':'NN','গাঁইগোত্র':'NN','গাঁও':'NN','গাঁজা':'NN','গাঁজাখোর':'NN','গাঁট':'NN',
'গাঁটওলা':'JJ','গাঁটছড়া':'NN','গাঁটযুক্ত':'NN','গাঁটের':'NN','গাঁঠ':'NN','গাঁঠকাটা':'NN','গাঁঠবন্ধন':'NN',
'গাঁথন':'NN','গাঁথানো':'VB','গাঁথিয়াছে':'VBN','গাঁদা':'NN','গাঁয়':'NN','গাং':'NN','গাংচিল':'NN',
'গাংশালিক':'NN','গাই-':'NN','গাইছো':'VB','গাইড':'NN','গাইতে':'NN','গাইতেন':'VB','গাইবান্দা৫':'NN',
'গাইবেন':'VBG','গাইল':'NN','গাইয়ার':'NN','গাউন':'NN','গাওসুম্মা':'NN','গাওয়া':'NN','গাকে':'NN',
'গাগর':'NN','গাগি':'NN','গাঙ্গকুরিয়া':'NN','গাঙ্গরেন':'NN','গাঙ্গলা':'NN','গাঙ্গুলী':'NNP','গাঙ্গেঠী':'NN',
'গাঙ্গেরুয়া':'NN','গাঙ্গেয়':'JJ','গাচ':'NN','গাছ-পালা':'NN','গাছ-প্রতি':'NN','গাছ':'NN','গাছগুরো':'NNS',
'গাছগুলো':'NN','গাছপালা':'NN','গাছপিছু':'NN','গাছে':'NN','গাছেরও':'NNS','গাছেরা':'NN','গাজ':'NN',
'গাজর':'NN','গাজা':'NN','গাজিয়াবাদ':'NN','গাজী':'NN','গাজীপুরে':'NN','গাটা':'NN','গাঠরি':'NN',
'গাঠরেওয়াঁ':'NN','গাড়ি':'NN','গাড়িওয়ালা':'NN','গাড়িটির':'NN','গাড়িতে':'NN','গাড়ী-রাস্তা':'NN','গাড়ী':'NN',
'গাড়ীর':'NN','গাড়োয়ান':'NN','গাডোলিনিয়াম':'NN','গাঢ়':'NN','গাঢ়োয়াল':'NN','গাঢাকা':'NNP','গাণনিক':'NN',
'গাণিতিক':'JJ','গাণ্ডিব':'NN','গাতে':'NN','গাত্রদাহ':'NN','গাত্ররুহ':'NN','গাত্রোথ্থান':'NN','গাথা':'NN',
'গাদাগাদি':'NN','গাদি':'NN','গাদ্দাফিকে':'NN','গাদ্দার':'NN','গাধর':'NN','গাধি':'NN','গান':'NN',
'গানগুলো':'NN','গানবাজনার':'NN','গানিতিক':'JJ','গানিয়ারী':'NN','গানে':'NN','গানেওয়ালে':'NN','গানের':'NN',
'গানো':'NNV','গান্টম':'NN','গান্দিনী':'NN','গান্ধর্ব':'NN','গান্ধার':'NN','গান্ধারবাসী':'NN','গান্ধারী':'NN',
'গান্ধারীকেই':'NNP','গান্ধিপোকা':'NN','গান্ধী':'NN','গান্ধীজি':'NNP','গান্ধীজীর':'NNP','গান্ধীনগর':'NN','গান্ধীবাদ':'NN',
'গাপটিলও':'NN','গাফিলতি':'NN','গাফিলতির':'NN','গাব':'NN','গাবান':'NN','গাবাবাসী':'NN','গাবার':'JJ',
'গাবুন':'NN','গাবোরোন':'NN','গাভাসকার':'NN','গাভি':'JJ','গাভী':'NN','গাম':'NN','গামছা':'NN',
'গামলা':'NN','গামিনী':'NN','গামী':'JJ','গামেনটস':'NN','গামেন্টসগুলো':'NNS','গাম্বিয়া':'NN','গাম্বিয়ার':'JJ',
'গাম্ভীর্য':'NN','গায়ে':'NN','গারণ্ড':'NN','গারদুয়া':'NN','গারমেন্টেসে':'NN','গারস্থ':'NN','গারাকানাড়া':'NN',
'গারি':'NN','গারিবানা':'VBG','গারুড়':'NN','গারুড়িক':'NN','গারুড়োপনিষদ':'NN','গারুঢ়':'JJ','গারুত্মত':'NN',
'গারে':'NN','গারেয়':'NNP','গারো':'NN','গার্গী':'NN','গার্জিয়ানের':'JJ','গার্ড':'NN','গার্ডেন':'NN',
'গার্ডেনে':'NNP','গার্দিওলা':'NNP','গার্মেন্টশিল্পের':'NN','গার্মেন্টস':'NNS','গার্মেন্টসশিল্প':'NN','গার্মেন্টসে':'NNS','গার্মেন্টেস':'NNS',
'গাল-মন্দ':'NN','গাল':'NN','গালগপ্পো':'NN','গালগোঁফ':'NN','গালচে':'NN','গালথলি':'NN','গালনহাঁ':'NN',
'গালফোলা':'JJ','গালব':'NN','গালবালিশ':'NN','গালভরা':'JJ','গালমসুরি':'NN','গালশূণ্ডী':'NN','গালসিরী':'NN',
'গালা':'VB','গালাগাল':'NN','গালাগালি':'VBG','গালাগালির':'NN','গালি-গালাজ':'NN','গালি':'VBG','গালিগালাজ':'NN',
'গালিচা':'NN','গালিব':'NNP','গালী':'NN','গালের':'NN','গালয়':'NN','গাস':'NNP','গাহকের':'NN',
'গাহণ':'NN','গাহনী':'NN','গাড়ি':'NN','গাড়িওয়ালা':'NN','গাড়িগুলো':'NNS','গাড়িটা':'NN','গাড়িতে':'NN',
'গাড়িবাড়ি':'NN','গাড়িমুক্ত':'JJ','গাড়ির':'NN','গাড়ী':'NN','গাড়ীগুলো':'NNS','গাড়ীতে':'NN','গাড়ীতেও':'NN',
'গাড়ীদহ':'NN','গাড়ীবাড়ীর':'NN','গাঢ়তর':'JJ','গায়':'VB','গায়ক-গায়িকাদের':'NN','গায়ক':'NN','গায়কী':'NN',
'গায়ত্রী':'NN','গায়না':'NN','গায়িকা':'NN','গায়ে':'NN','গায়েবি':'NN','গায়ের':'NN','গা‌য়ে':'NN',
'গিঁট':'NN','গিগাবাইট':'NN','গিগাবিট':'NN','গিজগিজে':'NN','গিজা':'NN','গিটার':'NN','গিটি':'NN',
'গিট্টী':'NN','গিঠম':'NN','গিণী':'NNP','গিতা':'NN','গিনি':'NN','গিনিস':'NN','গিনিহার':'NN',
'গিনী-বিসোব':'NN','গিনী':'NN','গিনেজ':'NN','গিবন':'NN','গিবসন':'NNP','গিয়ে':'VBG','গিয়েছিল':'NN',
'গিরংট':'NN','গিরগিটি':'NN','গিরগিরী':'NN','গিরদালী':'NN','গিরমিট':'NN','গিরি':'NN','গিরিডি':'NN',
'গিরিপথ':'NN','গিরিমাটি':'NN','গিরিরাজ':'NN','গিরিশ':'NN','গিরিসুত':'NN','গিরীশ':'NN','গির্জা':'NN',
'গির্জার':'NN','গিলছে':'VBG','গিলটি-করা':'JJ','গিলতে':'VB','গিলহারা':'NN','গিলাচ্ছে':'VB','গিলায়ু':'NN',
'গিলিম':'NN','গিলে':'VBN','গিল্টী':'NN','গিল্ডর':'NN','গিয়া':'VB','গিয়াছে':'VB','গিয়ানা':'NN',
'গিয়ারে':'NN','গিয়ে':'VBG','গিয়েও':'VB','গিয়েওঅষ্টম':'NN','গিয়েছি':'VB','গিয়েছিল':'NN','গিয়েছিলাম':'NN',
'গিয়েছিলো':'NN','গিয়েছেন':'NN','গিয়ৈ':'NN','গীঃপতি':'NN','গীকে':'NN','গীত-সঙ্গীত':'NN','গীত':'NN',
'গীতহার':'JJ','গীতা':'NN','গীতি':'NN','গীতিকবিতা':'NN','গীতিকাব্য':'NN','গীতিনাট্য':'NN','গীতিরূপক':'NN',
'গীতে':'NN','গীদড়রুখ':'NN','গীবত':'VBG','গীরা':'NN','গীষ্পতি':'NN','গীয়ারে':'NN','গু':'NN',
'গুঁজ':'NN','গুঁজে':'VB','গুঁঠ':'NN','গুঁড়ি':'NN','গুঁড়িয়ে':'VBN','গুঁড়ো':'NN','গুঁতো':'VB',
'গুঁড়াগুলি':'NN','গুঁড়ে':'NN','গুগরল':'NN','গুগলই':'NN','গুগলের':'NN','গুগ্গুল':'NN','গুঙ্গী':'NN',
'গুচ্ছ':'NN','গুছিয়ে':'NN','গুজ-রাটি':'NN','গুজগুজ':'VB','গুজব':'NN','গুজবই':'NNS','গুজবটি':'NN',
'গুজবে':'NNS','গুজরাট':'NN','গুজরাটি':'JJ','গুজরাত':'NNP','গুজরাতী':'NN','গুজরি':'NN','গুজা':'NN',
'গুজে':'NN','গুজ্জর':'NN','গুঝই':'NN','গুঞ্জন':'NN','গুঞ্জা':'NN','গুটখা':'NN','গুটানো':'VB',
'গুটি':'NN','গুটিকা':'NN','গুটিজ্বর':'NN','গুটিবসন্ত':'NN','গুটির':'NN','গুড':'NN','গুড়গাঁও':'NN',
'গুড়গুড়':'NN','গুড়ধনে':'NN','গুড়া':'NN','গুড়ি':'NN','গুড়ের':'NN','গুডাদুধের':'NN','গুডুচি':'NN',
'গুঢ়':'JJ','গুণ':'NN','গুণকীর্তন':'NN','গুণকীর্ত্তন':'NN','গুণক্রিয়া':'NN','গুণগত':'JJ','গুণগান':'NN',
'গুণগ্রাহী':'NN','গুণতে':'NN','গুণন':'NN','গুণনাঙ্ক':'NN','গুণনিধি':'JJ','গুণনীয়ক':'NN','গুণপনা':'NN',
'গুণফল':'NN','গুণবত্তা':'NN','গুণবত্তারহিত':'JJ','গুণবন্তা':'NN','গুণবান':'JJ','গুণমান':'NN','গুণসম্পন্ন':'NN',
'গুণসাগর':'NN','গুণহীন':'JJ','গুণাকর':'JJ','গুণান্বিত':'VBN','গুণাবলি':'NN','গুণাবলী':'NNS','গুণালংকার':'NN',
'গুণী':'JJ','গুণীজনকে':'NN','গুণীদের':'NNS','গুণীমানুষের':'NN','গুণে':'NN','গুণেই':'IN','গুণেন':'NN',
'গুণ্টুর':'NN','গুণ্ডা':'NN','গুণ্ডামিতে':'NN','গুণ্ডু':'NN','গুতায়':'NN','গুতেরেস':'NNS','গুত্সমদ':'NN',
'গুদাম':'NN','গুন':'NN','গুনকীর্তনও':'NN','গুনগত':'NN','গুনগুন':'NN','গুনণীয়ক':'NN','গুনতি':'VBG',
'গুনতে':'NN','গুনা':'NN','গুনায়':'NN','গুনি':'NN','গুনী':'JJ','গুনে':'NN','গুনের':'NN',
'গুন্':'NN','গুন্ডাগিরি':'NN','গুন্ডাপান্ডা':'NN','গুন্ডামী':'NN','গুন্ডারা':'NNS','গুন্নী':'NN','গুপ-চুপ':'NN',
'গুপ্ত':'NN','গুপ্তকে':'NN','গুপ্তক্রিয়া':'NN','গুপ্তচর':'NN','গুপ্তচরবৃত্তি':'NN','গুপ্তদান':'NN','গুপ্তপথ':'NN',
'গুপ্তভাবে':'RB','গুপ্তযুগ':'NN','গুপ্তি':'NN','গুপ্তের':'NNP','গুবরে':'NN','গুম':'NN','গুমখুন':'NN',
'গুমগুম':'VB','গুমগুমানি':'NN','গুমটি':'NN','গুমলা':'NN','গুমেজ':'NN','গুমোট':'NN','গুম্পা':'NN',
'গুম্বজ':'NN','গুরগুর':'NN','গুরতর':'JJ','গুরতেছে':'NN','গুরত্ব':'NN','গুরবাণী':'NN','গুরসুম':'NN',
'গুরুঅস্ত্র':'NN','গুরুঋণ':'NN','গুরুও্বপূর্ণ':'NN','গুরুকুল':'NN','গুরুগৃহবাসী':'JJ','গুরুগৃহে':'NN','গুরুগ্রান্থসাহেব':'NN',
'গুরুচ-খাপ':'NN','গুরুজন':'NN','গুরুত':'NN','গুরুতর':'JJ','গুরুত্ব':'NN','গুরুত্বপুর্ন':'NN','গুরুত্বপূর্ন':'NN',
'গুরুত্ববহ':'NN','গুরুত্বের':'NN','গুরুদণ্ড':'NN','গুরুদাস':'NNP','গুরুদাসপুর':'NN','গুরুদেবের':'NN','গুরুপত্নী':'NN',
'গুরুপাক':'JJ','গুরুপ্তপূর্ণ':'NN','গুরুবচনই':'NNP','গুরুবাণী':'NN','গুরুভাই':'NN','গুরুমন্ত্র':'NN','গুরুমশাই':'NN',
'গুরুমা':'NN','গুরুযষ্টী':'NN','গুরুর':'NN','গুরূ':'NN','গুরেজ':'NN','গুর্জরী':'NN','গুর্বঙ্গনা':'NN',
'গুর্বী':'NN','গুল-আজায়ব':'NN','গুল-নার':'NN','গুল-বকাবলী':'NN','গুল':'NN','গুলকন্দ':'NN','গুলখেরু':'NN',
'গুলগীর':'NN','গুলগুলিয়া':'NN','গুলচাঁদনি':'NN','গুলচী':'NN','গুলজারীলাল':'NN','গুলতরাশ':'NN','গুলতি':'NN',
'গুলতিবাজ':'NN','গুলতে':'NN','গুলথুথনা':'NN','গুলদুপাহারিয়া':'NN','গুলনার':'NN','গুলপাপড়ি':'NN','গুলপেয়াদা':'NN',
'গুলফানুস':'NN','গুলফিকরি':'NN','গুলফ্':'NN','গুলবকাবলী':'NN','গুলবার্গ':'NN','গুলমেখ':'NN','গুলমেহেন্দি':'NN',
'গুলশান':'NN','গুলশানবনানীতে':'NN','গুলসুম':'NN','গুলা':'NN','গুলাকে':'VB','গুলাতে':'NN','গুলানো':'NN',
'গুলাবাঁস':'NN','গুলাম':'NNP','গুলার':'NN','গুলি':'NNS','গুলিই':'NN','গুলিকে':'NN','গুলিচালনা':'NN',
'গুলিতে':'NNS','গুলির':'NNS','গুলিস্তান':'NN','গুলিয়ে':'NN','গুলী':'JJ','গুলু':'NN','গুলুবৃক্ষ':'NN',
'গুলে':'NN','গুলো':'DT','গুলো':'CD','গুলোই':'DT','গুলোকে':'NN','গুলোতে':'NN','গুলোর':'NN',
'গুল্দুম':'NN','গুল্মরোগ':'NN','গুল্লি':'NN','গুষ্টি':'NN','গুহ':'NNP','গুহষষ্ঠী':'NN','গুহা':'NN',
'গুহানিবাসী':'JJ','গুহায়':'NN','গুহ্য':'NN','গুড়':'NN','গুড়া':'NNP','গুড়াদুধ':'NN','গুড়েবালি':'NN',
'গুয়না':'NN','গুয়াইদকে':'NN','গুয়াতেমালান':'JJ','গুয়ানা':'NN','গুয়ানার':'JJ','গুয়ানিয়ান':'NN','গুয়ানীয়':'JJ',
'গুয়াহাটী':'NN','গুয়েনা':'NN','গুয়েমির':'NN','গূডতৃণ':'NN','গূঢ়':'NN','গূঢ়ার্থ':'NN','গূণ্ড':'NN',
'গৃত্সমদ':'NN','গৃধ্র':'NN','গৃহ-প্রবেশ':'NN','গৃহ-যুদ্ধ':'NN','গৃহ-রাজ্যমন্ত্রী':'NN','গৃহ-সম্পর্কিত':'JJ','গৃহ':'NN',
'গৃহকর্তা':'NN','গৃহকর্মী':'NN','গৃহত্যাগ':'NN','গৃহনগর':'NN','গৃহনির্মাণ':'NN','গৃহনির্মিত':'JJ','গৃহপালিত':'NN',
'গৃহপ্রবেশ':'NN','গৃহবধু':'NN','গৃহবাসী':'JJ','গৃহমন্ত্রক':'NN','গৃহযুক্ত':'JJ','গৃহযুদ্ধ':'NN','গৃহরক্ষক':'NN',
'গৃহলক্ষ্মী':'NN','গৃহসচিব':'NN','গৃহস্থ':'NN','গৃহস্থালির':'NN','গৃহস্থী':'NN','গৃহস্বামী':'NN','গৃহহীন':'JJ',
'গৃহহীনতা':'NN','গৃহিণী':'NN','গৃহিনী':'NN','গৃহীত':'NN','গৃহীতাদের':'JJ','গৃহে':'NN','গৃহোপযোগী':'JJ',
'গে':'VB','গেঁজিয়ে':'VB','গেঁট':'NN','গেঁটেবাত':'NN','গেঁথে':'VBN','গেঁথেছি':'VB','গেঁয়ে':'VB',
'গেঁয়োখালিতে':'NNP','গেইম':'NN','গেইলের':'NN','গেছ':'NN','গেছি':'VB','গেছে':'VB','গেছেএখন':'NNP',
'গেছেদেশের':'NN','গেছেন':'VB','গেজ':'NN','গেজিঙ্গ':'NN','গেজেট':'NN','গেজেটেড':'JJ','গেঞ্জি':'NNP',
'গেঞ্জিতে':'NN','গেট':'NN','গেটওয়ে':'NN','গেটস':'NNS','গেটসই':'NNP','গেটার':'NN','গেড়ি':'NN',
'গেনি':'VB','গেন্জি':'NN','গেম':'NN','গেমিং':'NN','গেরি':'NN','গেরুয়া':'NN','গেল':'NN',
'গেলা':'NN','গেলাস':'NN','গেলিয়াম':'NN','গেলে':'NN','গেলেআমার':'NN','গেলেই':'NN','গেলেতো':'NN',
'গেলেনআমাদের':'NN','গেলেননা':'NN','গেলো':'NN','গেলোএগিয়ে':'NN','গেলোকম':'NN','গেলোহা':'NN','গেসিলো':'NN',
'গেসে':'NN','গেস্ট':'NN','গোবর':'NN','গোল':'NN','গোষ্ঠীকে':'NN','গোসল':'NN','গোয়ালে':'NN',
'গোয়েবলসীয়':'NN','গেড়ে':'VB','গেয়ে':'NN','গেয়েছিলেন':'VB','গৈবর':'NN','গৈর':'NN','গো-ধন':'NN',
'গো-বন্দনায়':'NN','গো-শাবক':'NN','গো':'NN','গোঁজা':'VB','গোঁজার':'NN','গোঁড়':'NN','গোঁড়ামি':'NN',
'গোঁদরী':'NN','গোঁফ':'NN','গোঁফওয়ালা':'NN','গোঁফরেখা':'NN','গোঁসা':'NN','গোঁড়া':'NN','গোঁয়ার্তুমির':'NN',
'গোউড়া':'NN','গোকণী':'NN','গোকন্যা':'NN','গোকুল':'NN','গোখরা':'NN','গোখরো':'NN','গোগ্রাস':'NN',
'গোগ্রাসে':'VB','গোঙ্গেরুক':'NN','গোচন্দনা':'NN','গোচর':'JJ','গোচরপিন্ড':'NN','গোচর্ম':'NN','গোছ':'NN',
'গোছগাছ':'VB','গোছগোছ':'NN','গোছা':'NN','গোছানো':'VB','গোছের':'NN','গোজামিল':'NN','গোটা':'NN',
'গোটানো':'VB','গোঠ':'NN','গোড়বাঁশ':'NN','গোড়সঙ্কর':'NN','গোড়হরা':'NN','গোড়ালির':'NN','গোডাউন':'NN',
'গোড্ডা':'NN','গোণা':'NNP','গোণী':'NN','গোণ্ডা':'NN','গোতে':'NN','গোত্র-প্রবর্তক':'NN','গোত্র':'NN',
'গোত্রজ':'JJ','গোত্রীয়':'NN','গোথ':'NN','গোদ':'NN','গোদরেজের':'NN','গোদরোগী':'JJ','গোদা':'NN',
'গোদাবরি':'NN','গোধন':'NN','গোধরা':'NN','গোধূম':'NN','গোনরা':'NN','গোনা':'VBG','গোনানো':'VB',
'গোনি':'NN','গোনোরিয়া':'NN','গোন্ডকিরি':'NN','গোন্দিয়া':'NN','গোন্স':'NN','গোপ':'NN','গোপন':'JJ',
'গোপনকারী':'JJ','গোপনীয়তা':'NN','গোপনে':'NN','গোপপাণি':'NN','গোপাঙ্গনা':'NN','গোপাল-তপণি':'NN','গোপাল':'NNP',
'গোপালগঞ্জ':'NN','গোপি':'NN','গোপিনী':'NN','গোপীকামোদী':'NN','গোপীকৃষ্ণের':'NNP','গোপীচন্দন':'NN','গোপুর':'NN',
'গোপেশ্বর':'NN','গোবত্স':'NN','গোবধ':'NN','গোবরমাখা':'JJ','গোবরশকুন':'NN','গোবরি':'NN','গোবরের':'JJ',
'গোবর্ধন':'NN','গোবিন্দ':'NN','গোবিন্দদ্বাদশী':'NN','গোবিন্দরাও':'NN','গোবিয়া':'NN','গোব্রজ':'NN','গোভক্ষক':'NN',
'গোভিল':'NN','গোমড়া':'NN','গোমতি':'NN','গোমর':'NN','গোমস্তা':'NN','গোমাংস':'NN','গোমুখ':'NN',
'গোমুখী':'NN','গোমুত্র':'NN','গোমূত্র':'NN','গোমেজ':'NN','গোমেধ':'NN','গোময়':'NN','গোয়':'NN',
'গোর':'NN','গোরওয়া':'NN','গোরখধাঁধা':'NN','গোরখনাথ':'NN','গোরখনাথপন্থী':'JJ','গোরখপন্থ':'NN','গোরখপুর':'VB',
'গোরখমুণ্ডী':'NN','গোরখা':'NN','গোরচকরা':'NN','গোরচন':'NN','গোরল':'NN','গোরস':'NNP','গোরস্থান':'NN',
'গোরা':'NN','গোরাচাঁদ':'NNP','গোরাডু':'NN','গোরোয়া':'NNP','গোল':'NN','গোলক':'NN','গোলকাকৃতি':'NN',
'গোলকিপার':'NN','গোলকের':'NN','গোলগাল':'JJ','গোলটা':'NN','গোলদাতা':'NN','গোলন্দাজ':'NN','গোলপাতা':'NN',
'গোলপোস্ট':'NN','গোলমরিচ':'NN','গোলমাল':'NN','গোলমেলে':'JJ','গোলযোগ':'NN','গোলরক্ষক':'NN','গোলরা':'NN',
'গোলা':'NNP','গোলাকার':'NN','গোলাঘড়':'NN','গোলাঘাট':'NN','গোলাঙ্গুল':'NN','গোলাপ':'NN','গোলাপচশম':'NN',
'গোলাপজল':'NN','গোলাপপাশ':'NN','গোলাপাভ':'JJ','গোলাপি':'NN','গোলাপের':'NN','গোলাবর্ষণ':'NN','গোলাবাড়ি':'NN',
'গোলাবারুদ':'NN','গোলাম':'NN','গোলারুটি':'NN','গোলার্ধ':'NN','গোলার্ধেই':'NN','গোলায়':'NN','গোলে':'NN',
'গোলোক':'JJ','গোলোকদা':'NNP','গোল্ড':'NN','গোল্লা':'NN','গোশশা':'NN','গোষুক্তি':'NN','গোষ্ঠ':'NN',
'গোষ্ঠর':'NNP','গোষ্ঠী':'NN','গোষ্ঠীবদ্ধ':'NN','গোসলখানা':'NN','গোসাঘর':'NN','গোস্ঠি':'NN','গোস্বামী':'NN',
'গোস্বামীর':'NNP','গোহত্যা':'NN','গোহারা':'NN','গোড়া':'NN','গোড়ায়':'NN','গোয়া-আল্ফান্সো':'NN','গোয়া':'NN',
'গোয়াতেমালা':'NN','গোয়াবন্দর':'NN','গোয়ারনট':'NN','গোয়ার্তুমির':'NN','গোয়াল':'NN','গোয়ালঘরে':'NNP','গোয়ালপাড়া':'NN',
'গোয়ালিনী':'NN','গোয়ি':'NN','গোয়েটেমালা':'NN','গোয়েনান':'NN','গোয়েন্দাগিরি':'NN','গোয়েন্দারা':'NN','গোয়েন্দাসম্পর্কিত':'JJ',
'গোয়েল':'NNP','গৌড়':'NN','গৌড়মল্লার':'NN','গৌড়সারং':'NN','গৌড়ী':'NN','গৌণ':'NN','গৌণ্য':'NN',
'গৌতম':'NN','গৌতমবুদ্ধ':'NN','গৌতমী':'NN','গৌন':'NN','গৌবর':'NN','গৌর':'NNP','গৌরচন্দ্র':'NNP',
'গৌরব':'NN','গৌরবপূর্ণতা':'NN','গৌরবময়':'JJ','গৌরবযুক্ত':'JJ','গৌরবর্ণ':'JJ','গৌরবর্ণা':'NN','গৌরবশালী':'JJ',
'গৌরবহীন':'JJ','গৌরবহীনতা':'NN','গৌরবান্বিত':'NN','গৌরবার্থে':'NN','গৌরবের':'NN','গৌরলীলা':'NN','গৌরাঙ্গ':'NN',
'গৌরান্বয়ন':'NN','গৌরি':'NN','গৌরিশঙ্কর':'NN','গৌরী':'NN','গৌরীপট্ট':'NN','গৌহাটী':'NN','গৌড়-বঙ্গের':'NNP',
'গৌড়':'NNP','গৌড়চন্দ্র':'NNP','গৌড়ে':'NNP','গৌড়েয়':'NNP','গ্নি':'NN','গ্বানি':'NN','গ্মা':'NN',
'গ্যস':'NN','গ্যাঁজলা':'NN','গ্যাঁটের':'NN','গ্যাংগ্রীনের':'NN','গ্যাংটক':'NN','গ্যাঙর':'VB','গ্যাঙ্গস্টার':'NN',
'গ্যাটিং':'NN','গ্যাপ':'NN','গ্যারাজ':'NN','গ্যারেজ':'NN','গ্যারেন্টি':'NN','গ্যালন':'NN','গ্যালভ্যানাইজশেন':'NN',
'গ্যালাক্টিক':'JJ','গ্যালারি':'NN','গ্যালারী':'NN','গ্যালিলিও':'NNP','গ্যালিয়াম':'NNP','গ্যাল্লে':'NNP','গ্যাস':'NN',
'গ্যাসগুলির':'NN','গ্যাসপিন্ড':'NN','গ্যাসপিন্ডটির':'NN','গ্যাসপূর্ণ':'JJ','গ্যাসীয়':'JJ','গ্যাসের':'NN','গ্যাসোলিন':'NN',
'গ্যাস্ট্রো':'NN','গ্যাড়াকলে':'NN','গ্যে':'NN','গ্যেটে':'NNP','গ্রজম্যানের':'NN','গ্রণযোগ্যতা':'NN','গ্রত':'NN',
'গ্রথিত':'JJ','গ্রন্তের':'NN','গ্রন্থকর্তার':'NN','গ্রন্থগুলির':'NN','গ্রন্থডিঙি':'NN','গ্রন্থবাঁধাইকারি':'NN','গ্রন্থাগার':'NN',
'গ্রন্থালয়':'NN','গ্রন্থিত':'NN','গ্রন্থে':'NN','গ্রন্হি':'NN','গ্রফিতি':'NN','গ্রস্ত':'JJ','গ্রহ':'NN',
'গ্রহকদের':'NN','গ্রহটা':'NN','গ্রহণকারী':'NN','গ্রহণক্ষমতা':'NN','গ্রহণযোগ্য':'NN','গ্রহণযোগ্যতার':'NN','গ্রহণীয়':'NN',
'গ্রহণের':'NN','গ্রহদশা':'NN','গ্রহন':'NN','গ্রহনক্ষত্রাদি':'NN','গ্রহনযোগ্য':'NN','গ্রহনযোগ্যতাটা':'NN','গ্রহনান্ত':'NN',
'গ্রহনের':'NN','গ্রহপীড়া':'NN','গ্রহবাধা':'NN','গ্রহযোগ':'NN','গ্রহরাজ':'NN','গ্রহস্থের':'NN','গ্রহাকযন্ত্র':'NN',
'গ্রহাণু':'NN','গ্রহিকার':'NN','গ্রহীতা':'NN','গ্রহে':'NN','গ্রা':'NN','গ্রাঁদ':'NNP','গ্রাউন্ড':'NN',
'গ্রাওহক':'NN','গ্রাজুয়েট':'NN','গ্রাণ্ট-ইন-এড':'NN','গ্রানাইট':'NN','গ্রানাডীয়':'JJ','গ্রান্ট':'NN','গ্রান্ড':'NN',
'গ্রান্থ':'NN','গ্রাফ':'NN','গ্রাফিক':'JJ','গ্রাফিক্স':'NN','গ্রাফিতি':'NN','গ্রাবারকে':'NN','গ্রাম-দেবীরা':'NN',
'গ্রাম-প্রধান':'NN','গ্রাম':'NN','গ্রামজাত':'JJ','গ্রামণী':'NN','গ্রামদেবতা':'NN','গ্রামপঞ্চায়েত':'NN','গ্রামপ্রধান':'NN',
'গ্রামবাসী':'NN','গ্রামবাসীরা':'NN','গ্রামম':'NN','গ্রামসহায়ক':'NN','গ্রামাঞ্চলে':'NN','গ্রামিনের':'NN','গ্রামীণ':'NN',
'গ্রামীণফোনকে':'NN','গ্রামীন':'NN','গ্রামীনফোনকে':'NN','গ্রামে':'NN','গ্রামের':'NN','গ্রামোফোন':'NN','গ্রাম্য':'NN',
'গ্রাস':'NN','গ্রাসিত':'NN','গ্রাহক':'NN','গ্রাহকগণ':'NN','গ্রাহকরা':'NN','গ্রাহকসংখ্যায়':'NN','গ্রাহকের':'NN',
'গ্রাহ্য':'NN','গ্রি':'NN','গ্রিক':'JJ','গ্রিজমেনকে':'NN','গ্রিড':'NN','গ্রিনউইচ':'NN','গ্রিফনশকুন':'NN',
'গ্রিল':'NN','গ্রিসম':'NNP','গ্রী':'NN','গ্রীক':'JJ','গ্রীটিং':'NN','গ্রীন':'NN','গ্রীনরুমের':'NN',
'গ্রীনল্যাণ্ডীয়':'JJ','গ্রীনল্যান্ড':'NN','গ্রীনল্যান্ডিক':'NN','গ্রীনল্যান্ডীয়':'JJ','গ্রীবা':'NN','গ্রীবাযুক্ত':'JJ','গ্রীবাস্থি':'NN',
'গ্রীল':'NN','গ্রীষ্মকাল':'NN','গ্রীষ্মকালীন':'RB','গ্রীষ্মকালে':'NN','গ্রীষ্মনিদ্রা':'NN','গ্রীষ্মে':'NN','গ্রীস':'NN',
'গ্রুপ':'NNP','গ্রুপই':'NN','গ্রুপের':'NN','গ্রূপের':'NN','গ্রেট':'NN','গ্রেডিং':'NN','গ্রেন':'NN',
'গ্রেনেডবোমা':'NN','গ্রেনেডিজ':'NN','গ্রেনেডে':'NN','গ্রেপ্তার':'VB','গ্রেপ্তারি':'NN','গ্রেপ্তারের':'NN','গ্রেফতার':'VBN',
'গ্রেফতারতীব্র':'NN','গ্রেফতারের':'NN','গ্রেস':'NN','গ্রো':'NN','গ্রোথের':'NN','গ্রোভস':'NN','গ্র্যাচুইটি':'NN',
'গ্র্যাজুয়েটরা':'NN','গ্র্যান্ড':'NN','গ্লাইড':'NN','গ্লানি':'NN','গ্লাভস':'NN','গ্লাসগো':'NNP','গ্লাসের':'NN',
'গ্লিসারল':'NN','গ্লুকোজ':'NN','গ্লুকোস':'NN','গ্লুসিনিয়াম':'NN','গ্লেসিয়র্':'NN','গ্লোব':'NN','গ্ল্যাণ্ড':'NN',
'গ্ল্যামার':'NN','গ্ৰুপে':'NN','গড়':'NN','গড়গড়':'RB','গড়ছে':'NN','গড়ন':'NN','গড়পড়তা':'NN',
'গড়বে':'NN','গড়া':'NN','গড়াগড়ি':'NN','গড়ার':'NN','গড়ালে':'NN','গড়ায়':'VB','গড়িমসি':'NN',
'গড়িয়ে':'NN','গড়িয়েছে':'VB','গড়ে':'NN','গড়েন':'NN','গড়েহাতের':'NN','গয়':'NN','গয়না':'NN',
'গয়ালককড়ীর':'NN','গয়েশবর':'NN','গয়েশ্বরের':'NN','গ‍্যাস':'NN','ঘ':'NN','ঘকাল':'NN','ঘগ্গর':'NN',
'ঘঘরবেল':'NN','ঘচড়ঘচড়':'NN','ঘট':'NN','ঘটকর্কট':'NN','ঘটকালি':'NN','ঘটকে':'VB','ঘটছিল':'VB',
'ঘটছে':'VB','ঘটতো':'NN','ঘটনা':'NN','ঘটনাই':'RB','ঘটনাকে':'NN','ঘটনাগুলো':'NNS','ঘটনাগুলোই':'NN',
'ঘটনাচক্র':'NN','ঘটনাটা':'NN','ঘটনাটিকে':'NN','ঘটনাতেও':'NN','ঘটনাবলী':'NN','ঘটনায়':'NN','ঘটনার':'NNS',
'ঘটনাসঙ্গত':'JJ','ঘটনাস্থল':'NN','ঘটনায়':'NN','ঘটনীয়':'JJ','ঘটবে':'NN','ঘটবেই':'VB','ঘটবেনা':'NN',
'ঘটল':'VB','ঘটলে':'NN','ঘটলেই':'NNS','ঘটলো':'VB','ঘটা':'VB','ঘটাইয়া':'VB','ঘটাকালীন':'RB',
'ঘটাচ্ছে':'VB','ঘটাতে':'VB','ঘটান':'VB','ঘটানোর':'NNV','ঘটাবে':'VB','ঘটায়':'VB','ঘটার':'NN',
'ঘটি':'NN','ঘটিয়ে':'VB','ঘটিয়া':'VB','ঘটিয়ে':'VB','ঘটিয়েছে':'VBN','ঘটিয়েছেন':'NN','ঘটুক':'NN',
'ঘটে':'NNS','ঘটেছিল':'NN','ঘটেছিলো':'VBD','ঘটেছে':'VBD','ঘটেনা':'VB','ঘটেযদি':'NN','ঘটের':'NN',
'ঘটোতকচ':'NN','ঘট্ঠা':'NN','ঘড়া':'NN','ঘড়িঘর':'NN','ঘড়িসারাইকারি':'NN','ঘড়িয়াল':'NN','ঘড়ী':'NN',
'ঘণ্টা':'NN','ঘণ্টায়':'NN','ঘদিন':'NN','ঘন':'NN','ঘনক.':'NN','ঘনকাকার':'JJ','ঘনকাকৃতি':'JJ',
'ঘনগড়':'NN','ঘনঘটা':'NN','ঘনঘন':'RB','ঘনঘোর':'NN','ঘনচুল':'NN','ঘনত্ব':'NN','ঘননো':'VB',
'ঘনফল':'NN','ঘনবসতিপূর্ণ':'VBN','ঘনবাণ':'NN','ঘনাদ':'NN','ঘনান্ধকার':'NN','ঘনারামের':'NN','ঘনিষ্ট':'JJ',
'ঘনিষ্ঠ':'NN','ঘনিষ্ঠভাবে':'RB','ঘনিয়ে':'VB','ঘনীভবন':'NN','ঘনীভূত':'NN','ঘন্টা':'NN','ঘন্টায়':'NN',
'ঘন্টার':'NNS','ঘন্টায়':'NN','ঘর-বাড়ি':'NN','ঘর':'NNP','ঘরকুনো':'RB','ঘরকে':'NN','ঘরঘর':'NN',
'ঘরজামাই':'NN','ঘরটা':'NN','ঘরনী':'NN','ঘরবাড়ি':'NN','ঘরবাড়ি':'NN','ঘরভাঙানি':'JJ','ঘররে':'NN',
'ঘরাঞ্চি':'NN','ঘরানা':'NN','ঘরানার':'NN','ঘরে':'NN','ঘরেতো':'NN','ঘরের':'NN','ঘরোয়া':'NN',
'ঘর্ঘরা':'NN','ঘর্ম':'NN','ঘর্মাক্ত':'JJ','ঘর্ষ':'NN','ঘর্ষণকারী':'NN','ঘষটানো':'VB','ঘষটে':'VBG',
'ঘষা':'NN','ঘষানো':'VB','ঘষার':'NN','ঘষে':'VB','ঘস':'NN','ঘসময়':'NN','ঘা':'NN',
'ঘাঁটাঘাঁটি':'NN','ঘাঁটি':'NN','ঘাউরা':'NN','ঘাঘ':'NN','ঘাট':'NN','ঘাটটা':'NN','ঘাটতি':'NN',
'ঘাটন':'NN','ঘাটবার':'NN','ঘাটাঘাটি':'VB','ঘাটাল':'NNP','ঘাটি':'NN','ঘাটে':'NN','ঘাড়নৈল':'NN',
'ঘাড়ে':'NN','ঘাত':'NN','ঘাতকতা':'NN','ঘাতকদের':'NNS','ঘাতাত্':'NN','ঘাতী':'JJ','ঘাতে':'NN',
'ঘানা':'NN','ঘানাবাসী':'NN','ঘানার':'JJ','ঘানি':'NN','ঘান্টিয়ার':'NN','ঘাপটি':'NN','ঘাবড়ানো':'NN',
'ঘাবিহীন':'JJ','ঘাবড়াবার':'NNV','ঘাম':'NN','ঘামতে':'VB','ঘামাচি':'NN','ঘামানোর':'NN','ঘামাবে':'NN',
'ঘামূহ':'NN','ঘামে':'NN','ঘামোই':'NN','ঘারন':'NN','ঘারাপুরি':'NN','ঘারে':'NN','ঘাষে':'NN',
'ঘাস.':'NN','ঘাসিয়ারা':'NN','ঘাসুড়ে':'NN','ঘাসের':'NN','ঘাড়':'NN','ঘাড়িয়ে':'NN','ঘাড়েই':'NN',
'ঘাঢ়ত্যাড়া':'NN','ঘায়ত':'JJ','ঘায়ে':'NN','ঘায়েল':'VBD','ঘি':'NN','ঘিঞ্জি':'NN','ঘিনঘিন':'NN',
'ঘিনী':'NN','ঘিমা':'NN','ঘিরে':'VBN','ঘিলু':'NN','ঘী':'NN','ঘুঁঙুর':'NN','ঘুঁটি':'NN',
'ঘুঁটে':'NN','ঘুঁমুর':'NN','ঘুঁসা':'NN','ঘুইরা':'NN','ঘুকা':'NN','ঘুগে':'NN','ঘুঘঞ্চি':'NN',
'ঘুঘু':'NN','ঘুঙুর':'NN','ঘুঙুরযুক্ত':'JJ','ঘুঙ্ঘচী':'NN','ঘুচবে':'NN','ঘুচে':'VB','ঘুটি':'NN',
'ঘুড়ি':'NN','ঘুড়িবাজী':'NN','ঘুণ্ডী':'NN','ঘুন':'NN','ঘুনপোকা':'NN','ঘুনি':'NN','ঘুনে':'NNP',
'ঘুন্ডী':'NN','ঘুন্সি':'NN','ঘুম':'NN','ঘুমনাই':'NN','ঘুমন্ত':'VBG','ঘুমন্তপুরী':'NN','ঘুমাই':'NN',
'ঘুমাচ্ছে':'VBG','ঘুমাছিলেন':'NN','ঘুমানোর':'NN','ঘুমাবে':'NN','ঘুমিয়ে':'NN','ঘুমের':'NN','ঘুরঘুর':'VB',
'ঘুরছে':'NN','ঘুরত':'NN','ঘুরতেন':'NN','ঘুরপাক':'NN','ঘুরলে':'NN','ঘুরা':'NN','ঘুরাচ্ছে':'VBG',
'ঘুরাতে':'NN','ঘুরি':'NN','ঘুরুওয়া':'NN','ঘুরে':'NN','ঘুরেছি':'VB','ঘুরেফিরে':'NN','ঘুর্ণিকা':'NN',
'ঘুলঘুলি':'NN','ঘুষ':'NN','ঘুষখোর':'NN','ঘুষখোরী':'NN','ঘুষচাঁদাবাজ‌ি':'NN','ঘুষতো':'NN','ঘুষি':'NN',
'ঘুষের':'NN','ঘুস':'NN','ঘুসঘুসে':'NN','ঘুসি':'NN','ঘুসোঘুসি':'NN','ঘুয়া':'NN','ঘূম্র':'NN',
'ঘূর্ণণ':'NN','ঘূর্ণনের':'NN','ঘূর্ণায়মান':'JJ','ঘূর্ণিঝড়':'NN','ঘূর্ণিঝড়ের':'NNP','ঘূর্ণিবায়ু':'NN','ঘৃণা':'NN',
'ঘৃণাভরে':'RB','ঘৃণার':'NN','ঘৃণিত':'JJ','ঘৃণ্য':'NN','ঘৃত-পুর':'NN','ঘৃত':'NN','ঘৃতকুমারির':'NN',
'ঘৃতদেবা':'NN','ঘৃতপাত্র':'NN','ঘৃতমণি':'NN','ঘৃতাচী':'NN','ঘৃনা':'NN','ঘৃনায়':'VBN','ঘৃষ্ণেশ্বর':'NN',
'ঘেঁঘ':'NN','ঘেঁটে':'NNP','ঘেওর':'NN','ঘেগ':'NN','ঘেটাল':'NN','ঘেটে':'NNP','ঘেতলা':'NN',
'ঘেন্না':'VB','ঘেমে':'VB','ঘের':'NN','ঘেরা':'VBN','ঘেরাও':'NN','ঘেরাটোপে':'NN','ঘেরানো':'VB',
'ঘেসোড়ি':'NN','ঘোরাফেরা':'VBG','ঘোলা':'NN','ঘোষনা':'NN','ঘেয়ে':'VB','ঘোঁচওয়া':'NN','ঘোঁচী':'NN',
'ঘোগুর':'NN','ঘোঘ':'NN','ঘোঙ্ঘিল':'NN','ঘোচিল':'NN','ঘোটক':'NN','ঘোটাধৌবা':'NN','ঘোড়দৌড়':'NN',
'ঘোড়বচ':'NN','ঘোড়সওয়ার':'NN','ঘোড়সহিস':'NN','ঘোড়া-গাড়ি':'NN','ঘোড়া':'NN','ঘোড়াপলাস':'NN','ঘোড়ামানব':'NN',
'ঘোড়ার':'NN','ঘোড়ারোজ':'NN','ঘোড়াশাল':'NN','ঘোড়ি':'NN','ঘোনঘীলা':'NN','ঘোমটা':'NN','ঘোর':'NN',
'ঘোরতর':'JJ','ঘোরা-ফেরা':'NN','ঘোরা':'NN','ঘোরানোর':'NNV','ঘোরাফেরা':'NN','ঘোরালে':'RP','ঘোরে':'NN',
'ঘোল':'NN','ঘোলে':'NN','ঘোষ':'NNP','ঘোষক':'NN','ঘোষণা':'NN','ঘোষণার':'NN','ঘোষনা':'NN',
'ঘোষপত্র':'NN','ঘোষবর্ণ':'JJ','ঘোষস':'NN','ঘোষাল':'NNP','ঘোষিত':'NN','ঘোষে':'NNS','ঘোসি':'NN',
'ঘোড়া':'NNS','ঘোড়াগুলোর':'NN','ঘোড়াটি':'NN','ঘোড়ায়':'NN','ঘোড়েল':'JJ','ঘ্যাঁও':'NN','ঘ্যাঙর':'NN',
'ঘ্যান':'FW','ঘ্যানঘ্যানানি':'NN','ঘ্রাণেন্দ্রিয়':'NN','ঘড়ির':'NN','ঘড়ে':'NN','ঙ':'NN','চ-বর্গীয়':'JJ',
'চ':'NN','চওড়া':'NN','চওড়া':'JJ','চক':'NN','চকচক':'NNP','চকটি':'NN','চকনিকাস':'NN',
'চকবঁড়':'NN','চকবাজার':'NN','চকমকি':'NN','চকমকে':'JJ','চকমা':'VB','চকরা':'NN','চকলে':'NN',
'চকসহ':'NNP','চকান':'NN','চকোতরী':'NN','চকোর':'NN','চকোলেট':'NN','চক্':'NN','চক্র':'NN',
'চক্রকে':'VB','চক্রচক্র':'NN','চক্রদন্তী':'NN','চক্রধর':'NN','চক্রপাণি':'NN','চক্রবর্তী':'NN','চক্রবর্ত্তী':'NNP',
'চক্রবর্মা':'NN','চক্রবাক্':'NN','চক্রবৃদ্ধি':'NN','চক্রব্যুহ':'NN','চক্রাকার':'JJ','চক্রান্ত':'NN','চক্রান্তের':'NN',
'চক্রে':'NN','চক্ষু':'NN','চক্ষুর':'JJ','চক্ষুষ':'NN','চঙ্গবাই':'NN','চচাপ':'NN','চচ্চড়ি':'NN',
'চঞ্চল':'JJ','চঞ্চলতা':'NN','চঞ্চু':'NN','চট':'WDT','চটক-বিলসিত':'JJ','চটক':'NN','চটকদার':'NN',
'চটকল':'NN','চটকানো':'NN','চটকারা':'NN','চটচট':'JJ','চটচটে':'NN','চটপট':'RB','চটপটি':'NN',
'চটার':'NN','চটি':'NN','চটুল':'JJ','চটে':'VB','চটের':'NN','চট্টগ্রাম':'NN','চট্টগ্রামভিত্তিক':'VBN',
'চট্টগ্রামে':'NN','চট্টগ্রামের':'RB','চট্টান':'NN','চট্টোপাধ্যায়':'NNP','চট্রগ্রাম':'NN','চট্রগ্রামের':'RB','চড়':'NN',
'চড়কগাছ':'NN','চড়চড়':'NN','চড়া':'NN','চড়াইপাখি':'NN','চড়াও':'NN','চড়াত্':'VB','চড়ান':'JJ',
'চড়ানো':'NN','চড়ুই':'NN','চণক':'NN','চণ্ড':'NN','চণ্ডকালী':'NN','চণ্ডকৌশিক':'NN','চণ্ডরব':'NNP',
'চণ্ডরসা':'NN','চণ্ডাল-চুল':'NN','চণ্ডাল-বীণা':'NN','চণ্ডালিকা':'NN','চণ্ডালের':'NN','চণ্ডিকা':'JJ','চণ্ডী':'NN',
'চণ্ডীকুসুম':'NN','চণ্ডীগড়':'NN','চণ্ডীগড়':'NNP','চণ্ডীতলা':'NNP','চণ্ডীদাসবাবুর':'NNP','চণ্ডীপুষ্প':'NN','চণ্ডীবাবুর':'NNP',
'চণ্ডীমণ্ডপ':'NN','চণ্ডু':'NN','চণ্ডুখোর':'NN','চণ্ডেল':'NN','চণ্ডোদরী':'NN','চতরভঙ্গ':'NN','চতরা':'NNP',
'চতার':'NN','চতুর':'NN','চতুরঙ্গিনী':'NN','চতুরতা':'NN','চতুরাশ্রম':'NN','চতুরাহ':'NN','চতুর্গুণ':'RB',
'চতুর্গুন':'NN','চতুর্থপাণ্ডব':'NN','চতুর্থবার':'RB','চতুর্থবারের':'NN','চতুর্থাংশ':'NN','চতুর্থী':'NN','চতুর্দশী':'NN',
'চতুর্পদ':'NN','চতুর্বাহী':'NN','চতুর্ভুজ':'JJ','চতুর্মাস':'NN','চতুষ্পদ':'NN','চতুস্তম্ভ':'NN','চতেন':'VB',
'চত্তগ্রাম':'NN','চত্বরে':'NN','চথম':'NN','চদিন':'NN','চনকে':'NNP','চনচনা':'NN','চনাও':'NN',
'চনায়':'NN','চনিয়ারি':'NN','চনেঠ':'NN','চনেষ্ঠ':'NN','চন্ড':'NNP','চন্ডি':'NN','চন্ডিকা':'NNP',
'চন্ডী':'NN','চন্দকপুষ্প':'NN','চন্দন':'NN','চন্দনতেল':'NN','চন্দননগর':'NNP','চন্দননগরের':'NNP','চন্দনপিড়ি':'NN',
'চন্দনসার':'NN','চন্দাবতী':'NN','চন্দিম':'NN','চন্দেল':'NN','চন্দোডরী':'NN','চন্দৌলি':'NN','চন্দ্র-বিন্দু':'NN',
'চন্দ্র':'NN','চন্দ্রকান্ত':'NN','চন্দ্রকান্তমণি':'NNP','চন্দ্রকান্তা':'NN','চন্দ্রকিরণ':'NN','চন্দ্রকেতু':'NN','চন্দ্রগুপ্ত':'NN',
'চন্দ্রগুপ্তের':'NNP','চন্দ্রগ্রহণ':'NN','চন্দ্রঘন্টা':'NN','চন্দ্রচূড়ও':'NN','চন্দ্রজ':'NN','চন্দ্রতুল্যা':'NN','চন্দ্রদ্বীপে':'NNP',
'চন্দ্রপুর':'NN','চন্দ্রপুলী':'NN','চন্দ্রপ্রভনাথ':'NN','চন্দ্রবংশ':'NN','চন্দ্রবংশীয়':'JJ','চন্দ্রবদনা':'JJ','চন্দ্রবর্ত্ম':'NN',
'চন্দ্রবল্লরী':'NN','চন্দ্রবাহু':'NN','চন্দ্রবিজয়':'NN','চন্দ্রবিম্ব':'NN','চন্দ্রভবন':'NN','চন্দ্রভানু':'NN','চন্দ্রমণি':'NN',
'চন্দ্রমা-গ্রাহয়ে':'NNP','চন্দ্রমা':'NN','চন্দ্রমাস':'NN','চন্দ্রমুখী':'JJ','চন্দ্রমোহন':'NN','চন্দ্ররশ্মি':'NN','চন্দ্ররেখা':'NN',
'চন্দ্রশালা':'NN','চন্দ্রশেখর':'NN','চন্দ্রশোভিত':'JJ','চন্দ্রসূর':'NN','চন্দ্রহাঁস':'NN','চন্দ্রাকার':'NN','চন্দ্রালোক':'NN',
'চন্দ্রালোকিত':'JJ','চন্দ্রায়ণ':'NN','চন্দ্রিকা':'NNP','চন্দ্রিমা':'NN','চন্দ্রোদয়':'NN','চন্নন':'NN','চন্সুর':'NN',
'চপল':'JJ','চপলতা':'NN','চপস্টিক':'JJ','চপ্পল':'NN','চফাল':'NN','চবটী':'JJ','চবর্গ':'NN',
'চবি':'NN','চব্বিশ':'NN','চব্বিশতম':'JJ','চব্বিশে':'CD','চমক':'NN','চমকপ্রদ':'JJ','চমকিত':'VBN',
'চমকে':'VBN','চমচম':'NN','চমতঃ':'RB','চমতকার':'NN','চমত্কৃত':'JJ','চমরবকুলিয়া':'NN','চমরি':'NN',
'চমরোধা':'NN','চমাউ':'NN','চমোয়া':'NN','চম্পক':'NN','চম্পলা':'NNP','চম্পা':'NN','চম্পারণ':'NN',
'চম্ফাই':'NN','চম্বল':'NN','চম্বাবত':'NN','চম্স্কি':'NNP','চম্স্কীয়':'JJ','চমৎকার':'NN','চর':'NN',
'চরকা':'NN','চরকায়':'NN','চরকি':'NN','চরখ':'NN','চরগ':'NN','চরচর':'VB','চরচরানি':'NN',
'চরণ':'NN','চরণধূলি':'NN','চরণযুক্ত':'NN','চরণযুগলের':'NN','চরণামৃত':'NN','চরণে':'NN','চরণোদক':'NN',
'চরম':'JJ','চরমপন্থা':'NN','চরমাবস্থা':'NN','চরমে':'NN','চররা':'NNS','চরস':'NN','চরসখোর':'NN',
'চরা':'NN','চরাচর':'JJ','চরাচরব্যাপী':'JJ','চরানে':'NN','চরানো':'VB','চরানোর':'VBG','চরার':'NN',
'চরিত':'NN','চরিতকারদের':'NN','চরিতার্থ':'NN','চরিত্রগুলি':'NN','চরিত্রটি':'NN','চরিত্রনায়ক':'NN','চরিত্রবতী':'JJ',
'চরিত্রবান্':'JJ','চরিত্রহীনতা':'NN','চরিত্রহীনদের':'NNS','চরিত্রহীনা':'JJ','চরিত্রে':'NN','চরে':'NN','চরোম':'NN',
'চর্চা':'NN','চর্চার':'NN','চর্চিত':'NN','চর্তুগুণ':'JJ','চর্তুদশী':'NN','চর্তুমাস':'NN','চর্তুর্থ':'NN',
'চর্বণ':'NN','চর্বন':'VB','চর্বি':'NN','চর্বিতচর্বন':'NN','চর্বিদার':'JJ','চর্বিযুক্ত':'NN','চর্বিহীন':'JJ',
'চর্ম':'NN','চর্মজ':'JJ','চর্মবন্ধনী':'NN','চর্মরোগ':'NN','চর্মশোধন':'NN','চর্মাবতী':'NN','চর্মাবৃত':'JJ',
'চর্য':'NN','চল':'JJ','চলকে':'NN','চলচিত্ততা':'VB','চলচিত্র':'NN','চলচিত্রগৃহ':'NN','চলচিত্রপ্রেমিক':'NN',
'চলচিত্রাল':'NN','চলচ্চিত্র-নির্মাতা':'NN','চলচ্চিত্র':'NN','চলচ্চিত্রগুলোর':'NNS','চলচ্চিত্রায়ণ':'NN','চলচ্চিত্রায়িত':'VB','চলচ্চিত্রে':'NN',
'চলছি':'VBG','চলছিল':'VB','চলছে':'VB','চলছেআর':'VBG','চলছেআরেকজন':'NN','চলছেই':'VBG','চলছেন':'VB',
'চলছেনতুন':'NN','চলত':'NN','চলতে':'NN','চলতেই':'VBG','চলন':'NN','চলন্ত':'VBG','চলবে':'NN',
'চলবেতা':'VBG','চলবেদাম':'NN','চলবেন':'NN','চলবেসরকারের':'NN','চলভাষ':'NN','চলমান':'NN','চলমান১৯':'NN',
'চলরে':'NN','চলল':'VB','চললে':'NN','চললেও':'RP','চললেন':'VB','চললো':'NN','চলা':'NN',
'চলাকালিন':'IN','চলাচল':'NN','চলাচলের':'NN','চলাটা্ও':'VB','চলাতঙ্ক':'NN','চলাফেরা':'NN','চলাম':'VB',
'চলার':'NN','চলি':'NN','চলিক':'JJ','চলিতেছে':'NN','চলিতেছেন':'VBG','চলিবে':'VB','চলিল':'VB',
'চলিষ্ণু':'JJ','চলিয়া':'VB','চলুক':'NN','চলুনকেলেঙ্কারির':'NN','চলুনবিজয়':'VB','চলে':'NN','চলেছি':'VBG',
'চলেছে':'NN','চলেছেন':'VBG','চলেন':'NN','চলেনা':'VB','চলের':'NN','চলো':'NN','চলোতরা':'NN',
'চল্লিশ':'NN','চল্লিশতম':'JJ','চল্লিশের':'NN','চল‌ছে':'NN','চশমা':'NN','চশমাটা':'NNS','চষা':'NN',
'চষানো':'VB','চষার':'NN','চা':'NN','চাঁচর.':'NN','চাঁচরি':'NN','চাঁছনি':'NN','চাঁছা':'VB',
'চাঁটা':'NN','চাঁদ':'NN','চাঁদওয়ারি':'NN','চাঁদকে':'NN','চাঁদতারা':'NN','চাঁদনি':'NN','চাঁদপুরে':'NN',
'চাঁদসূর্য':'NN','চাঁদা':'NN','চাঁদাবাজি':'NN','চাঁদামামা':'NN','চাঁদি':'NN','চাঁদির':'NN','চাঁদের':'NN',
'চাঁদোয়া':'NN','চাঁপা-কদলী':'NN','চাঁপা':'NN','চাঁপাইনবাবগঞ্জ':'NN','চাঁপাকলা':'NN','চাই':'NN','চাইএটাই':'NN',
'চাইএমন':'IN','চাইকরতো':'NNS','চাইছি':'NN','চাইছিল':'VBD','চাইছিলাম':'VB','চাইছে':'VBG','চাইত':'VBD',
'চাইতার':'NNP','চাইতে':'NN','চাইতেন':'VB','চাইনা':'NNP','চাইনিজ':'JJ','চাইবহুদিন':'NN','চাইবাংলাদেশে':'NN',
'চাইবার':'NN','চাইবে':'IN','চাইবেনা':'NN','চাইবো':'NN','চাইল':'VBD','চাইলনা':'NN','চাইলেই':'NN',
'চাইলেতো':'NN','চাইলোযারা':'NN','চাইল্ড':'NN','চাইশুভ':'NN','চাইয়া':'NN','চাই–':'NN','চাউল':'NN',
'চাউল​':'NN','চাঊল':'NN','চাও':'VB','চাওয়া':'VBD','চাওলা':'NNP','চাওয়া':'VBD','চাওয়াই':'NN',
'চাওয়াটা':'VBD','চাওয়াতে':'NN','চাওয়ালা':'NN','চাক':'NNS','চাককরিটিই':'NN','চাকচিক্য':'NN','চাকট':'NN',
'চাকতি':'NN','চাকমা':'NN','চাকর':'NN','চাকরাণীকে':'NN','চাকরানি':'NN','চাকরি':'NNS','চাকরিই':'NN',
'চাকরিও':'NNS','চাকরিচ্যুত':'VBN','চাকরিজিবীদের':'NN','চাকরিজীবিদের':'NNS','চাকরিজীবিদেরও':'NN','চাকরিজীবীদের':'NNS','চাকরিজীবীর':'NN',
'চাকরিজীবীরা':'NNS','চাকরিটা':'NN','চাকরিদাতার':'NN','চাকরির':'NN','চাকরী':'NNS','চাকরীটা':'NN','চাকরীর':'NNS',
'চাকলাদার':'NN','চাকলি':'NN','চাকা':'NN','চাকাকেবল':'NN','চাকার':'NN','চাকায়':'NNS','চাকি':'NN',
'চাকিং':'VBG','চাকী':'NN','চাকুদা':'NN','চাকুরি':'NNS','চাকুরিজিবীদের':'NN','চাকুরিজীবির':'NN','চাকুরিজীবী':'NN',
'চাকুরিজীবীদের':'NNS','চাকুরিটা':'NN','চাকুরির':'NN','চাকুরিরত':'VBN','চাকুরী':'NN','চাকুরীজিবীদের':'NNS','চাকুরীজীবি':'NN',
'চাকুরীজীবিদেরও':'NNS','চাকুরীজীবিরা':'NN','চাকুরীজীবী':'JJ','চাকুরীজীবীগন':'NNS','চাকুরীজীবীরা':'NNS','চাকুরীটা':'NN','চাকুরীর':'NN',
'চাকুরীরত':'JJ','চাকুরীশেষে':'NN','চাকুরেদের':'NNS','চাকুিরচূত':'VBN','চাকে':'NN','চাক্ষুষ':'NN','চাখোর':'NN',
'চাঙা':'NN','চাঙ্গলাঙ্গ':'NN','চাঙ্গা':'JJ','চাচা':'NN','চাচাজান':'NN','চাচাত':'NN','চাচাদের':'NNS',
'চাচারা':'NN','চাচ্ছি':'NN','চাচ্ছিল':'VBD','চাচ্ছিলাম':'NN','চাচ্ছে':'NN','চাচ্ছেনা':'NN','চাছেন':'VBG',
'চাঞ্চল্য':'NN','চাঞ্চল্যকর':'VBG','চাঞ্চল্যের':'NN','চাট':'NN','চাটা':'NN','চাটাইয়ে':'NN','চাটানো':'VB',
'চাটু':'JJ','চাটুকার':'NN','চাটুকারিতার':'NN','চাটুকারী':'JJ','চাটুকারের':'NN','চাড়াগাছ':'NN','চাণ্ডালিনী':'NN',
'চাতক':'NN','চাতাল':'NN','চাতুরি':'NN','চাতুর্জাত':'NN','চাতুর্থক':'JJ','চাতুর্দশ':'NN','চাতুর্ভদ্রক':'NN',
'চাতুর্মাস':'NN','চাতুর্মাসিক':'JJ','চাতুর্মাস্য':'NN','চাতুর্যের':'NN','চাতুর্হোত্র':'NN','চাতে':'VB','চাত্':'NN',
'চাদ':'NN','চাদবাসী':'NN','চাদর':'NN','চাদরে':'NNS','চাদা':'NN','চাদাবাজদের':'NNS','চাদাবাজি':'NN',
'চাদীয়':'JJ','চাদের':'NN','চান':'VB','চানক':'NN','চানন':'NN','চাননি':'NN','চানসেল':'NN',
'চানা':'NN','চানো':'NNV','চান্দনৌতা':'NN','চান্দাবাজীর':'NN','চান্দে':'NN','চান্দ্র':'JJ','চান্দ্রমাস':'NN',
'চান্স':'NN','চান্সে':'NN','চাপ':'NN','চাপকান':'NN','চাপটাই':'NN','চাপড়':'NN','চাপড়ানো':'VB',
'চাপড়ে':'NN','চাপদণ্ড':'NN','চাপনী':'NN','চাপমুক্ত':'NN','চাপযুক্ত':'JJ','চাপরাশি':'NN','চাপরাস':'NN',
'চাপরৈলা':'NN','চাপা':'NN','চাপাকল':'NN','চাপাচাপি':'NN','চাপাচ্ছে':'VBG','চাপাতি':'NN','চাপানো':'VBN',
'চাপাবাজি':'NN','চাপাবে':'NN','চাপালে':'NN','চাপায়':'NNS','চাপায়ে':'VBN','চাপিয়ে':'NN','চাপু':'NN',
'চাপের':'NN','চাপড়ানো':'NN','চাফাঁদ':'NN','চাবড়ানো':'NN','চাবাবেন':'NN','চাবি':'NN','চাবিকাঠিঅন্য':'NN',
'চাবিস্কিট':'NN','চাবুক':'NN','চাবেন':'NN','চাভা':'NN','চাম':'NN','চামচা':'NN','চামচিকা':'NN',
'চামচী':'NN','চামটি':'NN','চামড়া':'NN','চামপোকা':'NN','চামর':'NN','চামরধারী':'NN','চামরাজানগর':'NN',
'চামরের':'NN','চামান্ডা':'NN','চামার':'NN','চামারনী':'NN','চামারের':'JJ','চামিন্ডা':'NN','চামুকন':'NN',
'চামুণ্ডারা':'NN','চামুণ্ডেশ্বরী':'NN','চামুন্ডা':'NN','চামুন্ডেশ্বরী':'NN','চামেলি':'NN','চামোই':'NN','চাম্বা':'NN',
'চামড়ায়':'NN','চায':'NN','চায়':'NNS','চায়ের':'NN','চার-পঞ্চমাংশ':'NN','চার':'CD','চারআনা':'NN',
'চারই':'NN','চারক':'NN','চারকোল':'NN','চারখানা':'NN','চারগুণ':'NN','চারচাকা':'NN','চারচাকাবিশিষ্ট':'JJ',
'চারচাকার':'JJ','চারচালা':'NN','চারছড়া':'NN','চারছয়':'NN','চারজন':'CD','চারটা':'NN','চারটে':'CD',
'চারণ':'NN','চারণভূমি':'NN','চারতলার':'NNS','চারদলীয়':'NN','চারদিক':'JJ','চারদিকে':'NN','চারদিন':'NNS',
'চারদিনের':'NN','চারদেওয়াল':'NN','চারনেতার':'NN','চারপাঁচটা':'NN','চারপাশ':'NN','চারপাশের':'NN','চারবন্ধু':'NN',
'চারবাগ':'NN','চারবার':'NNS','চাররঙা':'JJ','চারশো':'JJ','চারা':'NN','চারাগুলোকে':'NN','চারাটিকে':'NN',
'চারানা':'NN','চারি':'NNP','চারিত্রিক':'NN','চারিদিকে':'NN','চারী':'NN','চারুকলা':'NN','চারুকেশী':'NN',
'চারুচিত্র':'NN','চারুবাহু':'NN','চারুরুপ':'NN','চারে':'NN','চারেক':'JJ','চার্কাস':'NN','চার্চ':'NN',
'চার্চিলকে':'NNP','চার্চিলের':'NN','চার্চের':'NNP','চার্জ':'NN','চার্টার':'NN','চার্বী':'NN','চার্লস':'NNP',
'চাল-চলন':'NN','চাল':'NN','চালককে':'NN','চালকদল':'NN','চালকুমড়োর':'NN','চালকের':'NN','চালচলন':'NN',
'চালনা':'NNV','চালনাকারী':'NN','চালনি':'NN','চালবাজ':'JJ','চালবাজি':'NN','চালবাজীচলিতেছে':'NN','চালবাজ‌ি':'NN',
'চালবে':'NN','চালমাত':'NN','চালযুক্ত':'NN','চালা':'VBN','চালাই':'NN','চালাইলে':'RP','চালাইলেই':'NN',
'চালাক':'NN','চালাকি':'NN','চালাচ্ছে':'NN','চালাতাম':'NN','চালান':'NN','চালানোর':'NN','চালানো':'VB',
'চালানোর':'NN','চালাব':'NN','চালাবে':'NN','চালাবো':'NN','চালালে':'NN','চালায়া':'NN','চালি':'NN',
'চালিত':'NN','চালিয়ে':'NN','চালিসা':'NN','চালিয়াতি':'VB','চালিয়েছিল':'VB','চালিয়েছে':'NN','চালু':'IN',
'চালুনি':'NN','চালে':'NN','চাষ-বাস':'NN','চাষ':'NN','চাষও':'NN','চাষনো':'VB','চাষবাস':'VB',
'চাষযোগ্য':'NN','চাষর':'NN','চাষহত':'NN','চাষাবাদের':'NN','চাষাভুষারাও':'NN','চাষি':'NN','চাষিনি':'NN',
'চাষিরা':'NN','চাষী':'NN','চাষীদেরও':'NN','চাষে':'NN','চাস':'NN','চাহনি':'NN','চাহলুম':'NN',
'চাহিদা':'NN','চাহিদাকে':'NN','চাহিদাগুলি':'NN','চাহিবা':'NN','চাহিয়া':'VB','চাহিয়াকরিতে':'NN','চাহে':'NN',
'চাুকরীর':'NN','চা্ওয়া':'NN','চাড়া':'NN','চায়':'NN','চায়ক':'NN','চায়না':'NN','চায়নাতবে':'NN',
'চায়নারা':'NN','চায়নি':'NN','চায়িদা':'NN','চায়ে':'NN','চা‌লি‌য়ে‌ছে':'NN','চা–এর':'NN','চি':'NN',
'চিঁড়া':'NN','চিঁহিঁ':'NN','চিঁহিচিঁহি':'VB','চিংএ':'NN','চিংড়ি':'NN','চিংস':'NN','চিউলি':'NN',
'চিক':'NN','চিকড়ী':'NN','চিকন':'NN','চিকনকারী':'NN','চিকনে':'NN','চিকপি':'NN','চিকমাগালুর':'NN',
'চিকা':'NN','চিকিতসক':'NN','চিকিতসকীয়':'JJ','চিকিতসা':'NN','চিকিত্সা':'NN','চিকিত্সাতীত':'JJ','চিকিত্সাবিদ্যা':'NN',
'চিকিত্সার':'NN','চিকিত্সাশাস্ত্রে':'NN','চিকিত্স্য':'JJ','চিকিত্্সকরা':'NN','চিকিৎশা':'NN','চিকিৎসা':'NN','চিকিৎসাটুকুও':'NN',
'চিকিৎসাপ্রযুক্তি':'NN','চিকিৎসার':'NN','চিকুনগুনিয়া':'NN','চিকুর':'NN','চিকে':'NN','চিক্':'NN','চিক্কা':'NN',
'চিক্চিক্':'NN','চিঙ্কারা':'NN','চিঙ্গট':'NN','চিচিংফাক':'NN','চিজ':'NN','চিট':'NN','চিটচিট':'VB',
'চিটচিটে':'NN','চিটাগাং':'NN','চিটারি':'NN','চিটিংবাজ':'JJ','চিঠি-পত্র':'NN','চিঠি':'NN','চিঠিখানা':'NN',
'চিঠিগুলো':'NN','চিঠিটা':'NN','চিঠিতে':'NN','চিঠির':'NN','চিড়':'NN','চিড়িতন':'NN','চিড়িয়াখানা':'NN',
'চিড়ী':'NN','চিত':'NN','চিতকার':'NN','চিতবন':'NNP','চিতরা':'NN','চিতরোয়া':'NN','চিতল':'NN',
'চিতা':'NN','চিতাগ্নি':'NN','চিতাটার':'NN','চিতাবাঘিনী':'NN','চিতাভস্ম':'NN','চিতার':'NN','চিতি':'NN',
'চিতিয়ে':'NN','চিতুইপিঠে':'NN','চিতে':'NN','চিতোড়':'NN','চিত্':'NN','চিত্কারচ্ছ':'VB','চিত্ত':'NN',
'চিত্তগ্রাহী':'JJ','চিত্তপাপড়া':'NN','চিত্তবিক্ষেপ':'NN','চিত্তবৈকল্য':'NN','চিত্তরঞ্জন':'NN','চিত্তাকর্ষক':'JJ','চিত্তি':'NN',
'চিত্তে':'NN','চিত্রও':'NN','চিত্রকলা':'NN','চিত্রকাব্য':'NN','চিত্রকূট':'NN','চিত্রক্ষেপক':'NN','চিত্রগন্ধ':'NN',
'চিত্রগ্রহণ':'NN','চিত্রজগতে':'NN','চিত্রণ':'NN','চিত্রতারকার':'NN','চিত্রদূর্গ':'NN','চিত্রধর্মা':'NN','চিত্রনাট্য':'NN',
'চিত্রপক্ষ':'NN','চিত্রপটমহর্ষি':'NN','চিত্রপত্রিকা':'NN','চিত্রপদা':'NN','চিত্রপর্ণী':'NN','চিত্রপলশিল্প':'NN','চিত্রবর্মা':'NN',
'চিত্রবাহন':'NN','চিত্রবিচিত্র':'NN','চিত্রভানু':'NN','চিত্রভাস্কর্য্য':'NN','চিত্রমণ্ডলা':'NN','চিত্ররথ':'NN','চিত্ররেফ':'NN',
'চিত্রলিপি':'NN','চিত্রলেখা':'NN','চিত্রশির':'NN','চিত্রশিল্পী':'NN','চিত্রসেন':'NN','চিত্রাকারে':'NN','চিত্রাঙ্কন':'VBG',
'চিত্রাঙ্কিত':'JJ','চিত্রাঙ্গ':'NN','চিত্রাঙ্গদা':'NN','চিত্রাবর্তী':'NN','চিত্রায়িত':'VB','চিত্রায়ুধ':'NN','চিত্রিত':'NN',
'চিত্রোপম':'JJ','চিদম্বরম':'NN','চিন':'NN','চিনচিন':'VB','চিনচিনে':'NN','চিনত':'NN','চিনতে':'VB',
'চিনতো':'NN','চিনবে':'NN','চিনা':'NN','চিনারাই':'NN','চিনি-বীট':'NN','চিনি':'NN','চিনিযুক্ত':'JJ',
'চিনির':'NN','চিনে':'NN','চিনেবাদাম':'NN','চিনের':'NN','চিন্তন-প্রক্রিয়ার':'NN','চিন্তন-মনন':'NN','চিন্তনীয়':'JJ',
'চিন্তা-ভাবনা':'NN','চিন্তা':'NN','চিন্তাও':'NN','চিন্তাগুলি':'NN','চিন্তাগ্রস্ত':'NN','চিন্তাচেতনার':'NN','চিন্তাজনক':'JJ',
'চিন্তাধারা':'NN','চিন্তাধারার':'NN','চিন্তাবিদদের':'NN','চিন্তাবিহীনভাবে':'RB','চিন্তাভাবনা':'NN','চিন্তামণি':'NN','চিন্তামুক্ত':'JJ',
'চিন্তার':'NN','চিন্তারহিত':'JJ','চিন্তাশীল':'JJ','চিন্তাহীন':'NN','চিন্তিত':'JJ','চিন্তে':'NN','চিন্ত্য':'JJ',
'চিপ':'NN','চিপকানো':'VB','চিপচিপে':'NN','চিপসের':'NN','চিপা':'NN','চিফের':'NN','চিবর':'NN',
'চিবলী':'NN','চিবানো':'VB','চিবুক':'NN','চিবুকের':'JJ','চিবুচ্ছে':'VB','চিম':'NN','চিমটে':'NN',
'চিমনি':'NN','চিমী':'JJ','চিমে':'NN','চিম্পা':'NN','চির-অভ্রান্ততা':'NN','চির':'NN','চিরকাল':'NN',
'চিরকালের':'NN','চিরকুট':'NN','চিরগামী':'JJ','চিরচির':'RB','চিরজীবনের':'NN','চিরঞ্জী':'NN','চিরঞ্জীবী':'JJ',
'চিরতরে':'NN','চিরদিন':'NN','চিরন্তন':'RB','চিরপরিচিত':'JJ','চিরযুবা':'JJ','চিরযৌবনসম্পন্ন':'JJ','চিরসবুজ':'NN',
'চিরসাধ':'NN','চিরস্থায়ি':'NN','চিরস্থায়ী':'JJ','চিরস্থায়ীত্ব':'NN','চিরস্মরণীয়':'JJ','চিরস্রোতা':'JJ','চিরস্হায়ী':'JJ',
'চিরহরিত্':'NN','চিরাগ':'NN','চিরাচরিত':'JJ','চিরায়তা':'NN','চিরুনি':'NN','চিরোটা':'NN','চিল':'NNP',
'চিলগোঞ্জা':'NN','চিলচিত্কার':'NNS','চিলবন':'NN','চিলা':'NN','চিলারায়':'NNP','চিলি':'NN','চিলিবাসী':'NN',
'চিলিম':'NN','চিলিমিলিকা':'NN','চিলির':'JJ','চিলিয়ান':'NN','চিলী':'NN','চিলীয়':'JJ','চিলে':'NN',
'চিলেকোঠা':'NN','চিলের':'NN','চিলোআমার':'NN','চিল্কা':'NNP','চিল্ল':'NN','চিল্লরপার্টি':'NN','চিল্লা':'NN',
'চিল্লাচ্ছে':'NN','চিল্লানি':'NN','চিল্লাপাল্লা':'NN','চিল্লামিল্লি':'NN','চিল্লালো':'VB','চিল্লায়':'NN','চিল্লীকা':'NN',
'চিহ্ন.':'NN','চিহ্ন':'NN','চিহ্নবিহীন':'JJ','চিহ্নসিনিয়র':'NN','চিহ্নিত':'VBN','চিহ্নিতকরণ':'NN','চিহ্নের':'NN',
'চিৎকার':'NN','চিৎকারবুকের':'NN','চিড়া':'NN','চিড়িয়াখানার':'NN','চিড়ে':'NN','চিয়ে':'VB','চি‌নে':'NN',
'চীতে':'NNP','চীদি':'NNP','চীন-জাপান':'NNP','চীন':'NN','চীনওতো':'NNP','চীনকে':'NN','চীনপন্থী':'NN',
'চীনপাকিস্তান':'NN','চীনভারতরাশিয়া':'NN','চীনা':'NN','চীনামাটি':'NN','চীনাশুক':'NN','চীনীমোর':'NN','চীনে':'NN',
'চীনেতেই':'NNP','চীনের':'NN','চীনেরও':'NNP','চীপ':'NN','চীরকালীন':'JJ','চীরা':'NN','চু':'NN',
'চুঁইয়ে':'NN','চুঁচুঁ':'NN','চুইংগাম':'NN','চুক':'NN','চুকচুক':'NN','চুকন্দর':'NN','চুকা':'NN',
'চুকিয়ে':'JJ','চুকে':'VB','চুক্কি':'VB','চুক্তি':'NN','চুক্তিতে':'NN','চুক্তিবদ্ধ':'JJ','চুক্তিভিত্তিক':'JJ',
'চুক্তির':'NN','চুঙ্গী':'NN','চুচুক':'NN','চুছতে':'NN','চুঞ্চুল':'NN','চুটক':'NN','চুটিয়ে':'VB',
'চুড়ি':'NN','চুড়িওয়ালা':'NN','চুড়িদার':'NN','চুন-সুরকির':'NN','চুন':'NN','চুনকাম':'NN','চুনচুনা':'NN',
'চুনট':'NN','চুনটদার':'JJ','চুনদানি':'NN','চুনা-পাথর':'NN','চুনা':'NN','চুনাপাথর':'NN','চুনাভাটি':'NN',
'চুনি':'NN','চুনুপুটিদের':'NN','চুনো':'NN','চুনোট':'VB','চুনোপুঁটি':'NN','চুনোপুটি':'NN','চুপ':'NN',
'চুপচাপ':'NN','চুপটি':'NN','চুপনো':'VB','চুপষে':'NN','চুপি-চুপি':'RB','চুপি':'RB','চুপিচুপি':'NN',
'চুপ্রি':'NN','চুবড়ি':'NN','চুবানো':'NN','চুবায়ে':'NN','চুবিয়া':'NN','চুমকি':'NN','চুমু':'VB',
'চুমুক':'NN','চুম্বকত্ব':'NN','চুম্বন':'VB','চুয়েট':'NN','চুর':'VBN','চুরচুর':'JJ','চুরমা':'NN',
'চুরাচাঁদপুর':'NN','চুরানব্বই':'NN','চুরানব্বইতম':'JJ','চুরামী':'NN','চুরাশি':'NN','চুরাশিতম':'JJ','চুরি':'NN',
'চুরিও':'NN','চুরিকেউ':'NN','চুরিচামারিতে':'NN','চুরিটা':'NN','চুরিতে':'NN','চুরিদুদক':'NN','চুরিনো':'VB',
'চুরির':'NN','চুরিয়ে':'VBG','চুরী':'NN','চুরুট':'NN','চুর্ণ':'NN','চুল':'NN','চুলওয়ালা':'JJ',
'চুলকানি':'VBG','চুলকানী':'NN','চুলকানো':'VB','চুলকালে':'NN','চুলকুনি':'NN','চুলকে':'NN','চুলকোনোর':'NNV',
'চুলাচুলিতে':'NN','চুলায়':'NN','চুলি':'NN','চুলে':'NN','চুলো-চুলি':'NN','চুলো':'NN','চুল্লি':'NN',
'চুষবে':'NN','চুষি':'NN','চুহান্দতি':'NN','চুড়ি':'NN','চুড়িদারে':'NN','চুড়ো':'NN','চুয়াত্তর':'NN',
'চুয়াত্তরতম':'JJ','চুয়ান্ন':'NN','চুয়ান্নতম':'JJ','চুয়াল্লিশ':'NN','চুয়াল্লিশতম':'JJ','চুয়েট':'NN','চূঊ':'NN',
'চূচক':'NN','চূড়':'NN','চূড়ান্ত':'JJ','চূড়ান্তভাবে':'RB','চূড়িয়া':'NN','চূণী':'NN','চূর্ণ':'VBN',
'চূর্ণন':'NN','চূর্ণিত':'JJ','চূষা':'NN','চূড়ান্ত':'NN','চূড়ামণির':'NNP','চূড়ায়':'NN','চে':'NN',
'চেঁচ':'NN','চেঁচানো':'VB','চেঁচামেচি':'NN','চেঁচিয়ে':'VB','চেঁচুলা':'NN','চেইতেন':'NN','চেক':'VB',
'চেকপয়েন্ট':'NN','চেকবাসী':'NN','চেকার':'NN','চেকিতান':'NN','চেকীয়':'NN','চেকে':'VB','চেখে':'VBN',
'চেঙ্গি':'NN','চেচকরু':'NN','চেচানো':'NNV','চেছি':'VB','চেঞ্জ':'NN','চেটালো':'NN','চেটেপুটে':'NN',
'চেতকী':'NN','চেতন':'NN','চেতনাধারী':'NN','চেতনাবিরোধী':'JJ','চেতনার':'NN','চেতনাশূন্যতা':'NN','চেতনাসম্পন্ন':'JJ',
'চেতনাহীন':'NN','চেতা':'NN','চেদিরাজ':'NN','চেন':'NN','চেনা-জানা':'JJ','চেনা-পরিচিত':'JJ','চেনা':'VBN',
'চেনাজানা':'NNV','চেনানো':'VB','চেনার':'NN','চেনিস':'NN','চেনে':'NN','চেন্জ':'NN','চেন্টিয়ারি':'NN',
'চেন্নাই':'NN','চেপে':'VBG','চেপেছ':'VB','চেবল':'JJ','চেবুলা':'NN','চেম্পিয়ন':'NN','চেম্বার':'NN',
'চেম্বার্স':'NN','চেয়ে':'NN','চেয়েছিলেন':'VBD','চেরনা':'NN','চেরাগ':'NN','চেরানো':'VB','চেরি':'NN',
'চেরুই':'NN','চেলা':'NN','চেলারা':'NN','চেলি':'NN','চেলেন্জ':'NN','চেষ্টা':'NN','চেষ্টাই':'VB',
'চেষ্টার':'VBG','চেষ্টারত':'JJ','চেষ্টায়':'VBG','চেষ্ঠা':'VB','চেসটা':'VB','চেস্টা':'NN','চেস্টায়':'NN',
'চেস্রামি':'NN','চেহারা':'NN','চেহারার':'NN','চেহারায়ও':'NN','চোখে':'NN','চোর':'NN','চোরদের':'NNS',
'চোরাই':'NN','চোরের':'NN','চে্যেছিল':'VBD','চেড়া':'NN','চেড়ে':'VB','চেয়াছেন':'VB','চেয়ার':'NN',
'চেয়ারপারসনের':'NN','চেয়ারম্যান':'NNP','চেয়ারম্যানগণ':'NNS','চেয়ারম্যানের':'NNP','চেয়ারে':'NN','চেয়েই':'NN','চেয়েও':'VB',
'চেয়েছি':'VBD','চেয়েছিল':'VB','চেয়েছিলেন':'VB','চেয়েছে':'NN','চেয়ো':'VB','চৈকিত':'NN','চৈতণ্যদোয়':'NN',
'চৈতন':'NN','চৈতন্য-জীবনীকার':'NN','চৈতন্য':'NN','চৈতন্যমহাপ্রভূ':'NNP','চৈতন্যরূপে':'NN','চৈতন্যের':'NNP','চৈতালি':'NN',
'চৈতী':'NN','চৈত্য':'NN','চৈত্র-শুক্ল':'NN','চৈত্র':'NNP','চৈত্রগৌড়ি':'NN','চৈত্ররথ':'NN','চৈত্রাবলী':'NN',
'চৈনিক':'JJ','চৈলাশক':'NN','চোঁখ':'NNS','চোঁচ':'NN','চোকানো':'VB','চোখ-সওয়া':'NN','চোখ':'NNS',
'চোখকেও':'NN','চোখগুলো':'NN','চোখটা':'NN','চোখদুটি':'NN','চোখমুখ':'NN','চোখা':'NN','চোখে':'NNS',
'চোখের':'NNS','চোগা':'NN','চোঙ':'NN','চোঙায়':'NNS','চোঙে':'NN','চোঙ্গা':'NN','চোট':'NN',
'চোটে':'VBN','চোটেও':'NN','চোট্টাদের':'VBN','চোট্টামিতে':'NN','চোতা':'NN','চোথ':'NN','চোদ্দ':'NN',
'চোপড়া':'NNP','চোর-পুষ্পী':'NN','চোর':'NN','চোরকে':'NN','চোরগলি':'NN','চোরচোট্টারা':'NN','চোরদের':'NNS',
'চোরদেরকে':'NN','চোরপাট্টা':'NN','চোরপেট':'NN','চোরবদন':'NN','চোরবাটপার':'NN','চোরবাটপারদের':'NNS','চোরমুগ':'NN',
'চোরর':'NN','চোরাই':'JJ','চোরাকারবার':'NN','চোরাকারবারী':'NN','চোরাগলি':'NN','চোরাগুপ্তা':'NN','চোরাচালান':'VBG',
'চোরাচালানকারী':'NN','চোরাবাজার':'NN','চোরাবালি':'NN','চোরালয়ের':'NN','চোরাস্ত্রোত':'NN','চোরায়':'VBG','চোরে':'NNS',
'চোরের':'NN','চোল':'NN','চোলবাসী':'NN','চোলরঙ':'NN','চোলরা':'NNP','চোলাই':'NN','চোষ':'NN',
'চোষণীয়':'JJ','চোষা':'VBG','চোসা':'NN','চোয়াল':'NN','চৌকা':'NN','চৌকাঠ-প্রদীপ':'NN','চৌকাঠ':'NN',
'চৌকি':'NN','চৌকির':'NN','চৌকী':'NN','চৌকোণা':'NN','চৌখস':'JJ','চৌখা':'NN','চৌখুপি':'NN',
'চৌগাশা':'NN','চৌঠা':'NN','চৌতনী':'NN','চৌতারা':'NN','চৌত্রিশ':'NN','চৌত্রিশতম':'JJ','চৌথ':'NN',
'চৌথিয়া':'NN','চৌদ্দ':'JJ','চৌদ্দগুষ্টি':'NN','চৌদ্দতম':'JJ','চৌদ্দপুরুষ':'NNS','চৌদ্দশ':'CD','চৌধুরি':'NN',
'চৌধুরী':'NN','চৌপট':'JJ','চৌপাই':'NN','চৌপাট':'VB','চৌবংসা':'NN','চৌবন্দী':'NN','চৌবাইন':'NN',
'চৌবাচ্চা':'NN','চৌবে':'NN','চৌমাথা':'NN','চৌম্বক':'JJ','চৌরাস্তা':'NN','চৌল':'NN','চৌষট্টি':'NN',
'চৌষট্টিতম':'JJ','চৌসার':'NN','চৌহদ্দির':'NN','চৌহান':'NN','চ্চা':'NN','চ্ছল':'JJ','চ্ছা':'NN',
'চ্ছি':'VB','চ্ছিন্ন':'JJ','চ্ছে':'VB','চ্যবন':'NN','চ্যবনপ্রাশ':'NN','চ্যম্পিয়ন':'NN','চ্যাঙারি':'NN',
'চ্যাটচ্যটে':'NN','চ্যাটাং':'WDT','চ্যাটার্জি':'NNP','চ্যানেল':'NN','চ্যানেলগুলো':'NNS','চ্যানেলে':'NN','চ্যান্সেলর':'NN',
'চ্যাপটা':'NN','চ্যাপলিনও':'NNP','চ্যাপ্টা':'NN','চ্যাপ্টানাকযুক্ত':'JJ','চ্যাম্প':'NN','চ্যাম্পিয়ন্স':'NNS','চ্যাম্পিয়ন':'NN',
'চ্যাম্পিয়নদের':'NNS','চ্যাম্পিয়নশিপ':'NN','চ্যাম্পিয়নস':'NNS','চ্যাম্পিয়ান':'NN','চ্যাম্প‌িয়ন':'NN','চ্যালা-চামুণ্ডারা':'NN','চ্যালা':'NN',
'চ্যালেঞ্জ':'NN','চ্যালেঞ্জপূর্ণ':'JJ','চ্যালেঞ্জের':'VBG','চ্যুত':'VBN','চ্যূত':'NN','চড়ক':'JJ','চড়ছে':'NN',
'চড়থাপ্পড়':'NN','চড়বে':'NN','চড়া':'NN','চড়ে':'NN','চয়কে':'NN','চয়তা':'NN','চয়ন':'VB',
'চয়নকর্তা':'NN','চয়নিত':'JJ','চয়নীয়':'JJ','চয়ের':'NN','চ‌োরেরই':'NN','চ‍্যানেল':'NNS','ছ':'NN',
'ছই':'VB','ছক':'NN','ছকই':'JJ','ছকে':'VB','ছক্কা':'NN','ছট':'NN','ছটপটানি':'NN',
'ছটফট':'NN','ছটা':'NN','ছটাকা':'NN','ছটি':'CD','ছড়াতে':'NN','ছড়ানো-ছিটানো':'JJ','ছড়ানো':'NN',
'ছড়ি':'NN','ছড়িয়ে':'NN','ছত্তরপুর':'NN','ছত্তিশগড়ী':'NN','ছত্তিশগড়ের':'NNP','ছত্বর':'NN','ছত্রক':'NN',
'ছত্রচ্ছায়ায়':'NN','ছত্রছায়ায়':'NN','ছত্রধর':'NN','ছত্রপতি':'NN','ছত্রভঙ্গ':'NN','ছত্রাক':'NN','ছত্রিশ':'NN',
'ছত্রিশগড়ি':'NN','ছত্রিশগড়ের':'JJ','ছত্রিশতম':'JJ','ছদ্ধ':'NN','ছদ্মনাম':'NN','ছদ্মবেশ':'NN','ছদ্মবেশী':'JJ',
'ছদ্মবেশে':'NN','ছনছন':'VB','ছনীয়':'JJ','ছনেও':'NN','ছন্দ':'NN','ছন্দভঙ্গ':'NN','ছন্দশাস্ত্র':'NN',
'ছন্দশাস্ত্রী':'NN','ছন্দালঙ্কার':'NN','ছন্দে':'NN','ছন্দোবদ্ধ':'JJ','ছন্ন':'JJ','ছন্নছাড়া':'NN','ছপকা':'NN',
'ছবর':'NNS','ছবার':'NN','ছবি':'NN','ছবিই':'NNS','ছবিগুলি':'NN','ছবিগুলো':'NNS','ছবিটা':'NN',
'ছবিতে':'NN','ছবিমেলার':'NN','ছবির':'NN','ছবী':'NNS','ছবেন':'VB','ছব্বু':'NNP','ছম':'NN',
'ছমছম':'NN','ছয়টার':'NN','ছরিলা':'NN','ছরের':'NN','ছল-কপট':'NN','ছল':'NN','ছলকানো':'JJ',
'ছলকে':'RB','ছলচাতুরি':'NN','ছলচাতুরী':'NN','ছলছল':'NN','ছলনা':'NN','ছলনাশূণ্য':'NN','ছলনাহীন':'NN',
'ছলনায়':'NN','ছলপূর্ণ':'JJ','ছলময়':'JJ','ছলরহিত':'NN','ছলহীনতা':'NN','ছলা':'NN','ছলাকলা':'NN',
'ছলে':'NN','ছলেবলে':'NN','ছাঁইচ':'NN','ছাঁকনি':'NN','ছাঁকা':'VBN','ছাঁকানো':'VB','ছাঁচ':'NN',
'ছাঁচা':'VB','ছাঁচে':'NN','ছাঁট':'NN','ছাঁটা':'VB','ছাঁটাই':'VBG','ছাঁটাইকারী':'JJ','ছাঁটার':'NN',
'ছাঁদন':'NN','ছাঁদনাতলায়':'NN','ছাঁদে':'NN','ছাঃলীগ':'NN','ছাই':'NN','ছাইচাপা':'NN','ছাইদান':'NN',
'ছাইপাশের':'NN','ছাইভস্ম':'NN','ছাইড়া':'NN','ছাউনি':'NN','ছাএলীগের':'NN','ছাওয়া':'VB','ছাওয়ার':'NN',
'ছাক্কী-পাঞ্জী':'NN','ছাগল':'NN','ছাগলছানা':'NN','ছাগলটার':'NNS','ছাগলী':'NN','ছাগলের':'NNS','ছাগী':'NN',
'ছাগুটাকে':'NN','ছাঙ্গুর':'NN','ছাছ':'NN','ছাটা':'VB','ছাটাই':'NN','ছাটাইয়ের':'NN','ছাড়':'NN',
'ছাড়ছেন':'VBG','ছাড়পোকাযুক্ত':'JJ','ছাড়বে':'VB','ছাড়া':'IN','ছাড়াও':'PSP','ছাড়ানো':'NN','ছাড়িয়ে':'VBG',
'ছাত':'NN','ছাতার':'NN','ছাতু':'NN','ছাত্র-ছাত্রীগণ':'NN','ছাত্র':'NN','ছাত্রগণ':'NN','ছাত্রছাত্রী':'NNS',
'ছাত্রছাত্রীদেরকে':'NNS','ছাত্রছেলে':'NN','ছাত্রজীবনের':'NN','ছাত্রটি':'NN','ছাত্রদলে':'NN','ছাত্রদের':'NNS','ছাত্রবৃত্তি':'NN',
'ছাত্রবৃন্দ':'NNS','ছাত্ররা':'NNS','ছাত্ররাজনীতির':'NNS','ছাত্রলিগের':'NN','ছাত্রলীগকে':'NN','ছাত্রলীগেতো':'NN','ছাত্রশিবির':'NN',
'ছাত্রসংগঠন':'NN','ছাত্রসংগঠনগুলির':'NNS','ছাত্রসংগঠনগুলোর':'NN','ছাত্রসংগঠনের':'NNS','ছাত্রসমাজ':'NN','ছাত্রসমাজকে':'NNS','ছাত্রাবস্থাতেই':'NN',
'ছাত্রাবাস':'NN','ছাত্রাবাসী':'JJ','ছাত্রালয়':'NN','ছাত্রীকে':'NN','ছাত্রীদের':'NNS','ছাত্রীর':'NN','ছাত্রের':'NNS',
'ছাত্র্ছাত্রীরা':'NN','ছাদ':'NN','ছানতা':'NN','ছানারও':'NN','ছানি':'NN','ছানো':'NNV','ছান্দোগ্য':'NN',
'ছাপ':'NNS','ছাপকা':'NN','ছাপরা':'NN','ছাপলে':'NN','ছাপা':'VBN','ছাপাই':'NN','ছাপাখানা':'NN',
'ছাপাতেন':'NN','ছাপানো':'VBN','ছাপানোর':'VBG','ছাপান্ন':'NN','ছাপার':'NN','ছাপালেন':'VBN','ছাপায়':'VBN',
'ছাপিয়ে':'VBG','ছাপিয়া':'VBN','ছাপিয়ে':'VBG','ছাপের':'NNS','ছাপোষা':'NN','ছাপ্পা':'NN','ছাপ্পান্নতম':'JJ',
'ছাফাই':'VBG','ছাবো':'VB','ছাব্বিশ':'NN','ছাব্বিশতম':'JJ','ছামত':'JJ','ছায়':'NN','ছার':'NN',
'ছারপোকা':'NN','ছাল':'NN','ছালৌরী':'NN','ছাড়':'NN','ছাড়ছেন':'VBG','ছাড়তে':'VB','ছাড়ব':'VB',
'ছাড়বার':'NNV','ছাড়বে':'VB','ছাড়বেতাকে':'NN','ছাড়বেন':'VB','ছাড়ল':'VB','ছাড়লে':'NN','ছাড়লেন':'VBN',
'ছাড়লো':'VB','ছাড়া':'NN','ছাড়াই':'IN','ছাড়াএই':'NN','ছাড়াছাড়ি':'NN','ছাড়াতে':'NN','ছাড়াতো':'IN',
'ছাড়ার':'VB','ছাড়ি':'NN','ছাড়িয়া':'VB','ছাড়িয়ে':'VBG','ছাড়িয়েছে':'VBD','ছাড়ীয়ে':'NN','ছাড়ুন':'VB',
'ছাড়ে':'VB','ছাড়েনা':'VB','ছাড়ের':'NN','ছায়া-গ্রাহিণী':'NN','ছায়া-চিত্র':'NN','ছায়া':'NN','ছায়াতলে':'NN',
'ছায়াদান':'NN','ছায়াদানকারীরা':'VBG','ছায়ানট':'NN','ছায়াপথ':'NN','ছায়াময়':'JJ','ছায়াযুক্ত':'JJ','ছায়ার':'NNS',
'ছায়ায়':'NN','ছি-ছি':'NN','ছি':'NN','ছিঁড়তে':'VB','ছিঃ':'NN','ছিকনী':'NN','ছিছড়া':'NN',
'ছিছি':'NN','ছিট':'NN','ছিটকানি':'NN','ছিটকে':'NN','ছিটফোটাও':'NN','ছিটমহল':'NN','ছিটমহলের':'VB',
'ছিটা':'NN','ছিটানো':'NN','ছিটাবে':'NN','ছিটিয়ে':'NN','ছিটেফোঁটাও':'NN','ছিটেফোটাও':'NN','ছিট্':'NN',
'ছিতা':'NN','ছিত্তি':'NN','ছিদ্দিক':'NN','ছিদ্র':'NN','ছিদ্রবিহীন':'JJ','ছিদ্রযুক্ত':'JJ','ছিদ্রহীন':'JJ',
'ছিদ্রান্বেষক':'JJ','ছিদ্রান্বেষণ':'NN','ছিনতাই':'VBG','ছিনতাইকারি':'NN','ছিনতাইকারীদের':'NNS','ছিনতাইকারীর':'NN','ছিনতাইকারীরাও':'NNS',
'ছিনতাইবাজ':'JJ','ছিনতাইয়ের':'NN','ছিনন্-ভিন্ন':'RB','ছিনাল':'NN','ছিনিমিনি':'NN','ছিনিয়ে':'NN','ছিনে':'VB',
'ছিন্দওয়াড়া':'NN','ছিন্ন':'NN','ছিন্নভিন্ন':'VB','ছিন্নমস্তক':'JJ','ছিন্নমস্তা':'VBN','ছিন্নাগ্রবৃক্ষ':'JJ','ছিপ':'NN',
'ছিবড়া':'NN','ছিবেন':'VB','ছিবড়ে':'NN','ছিরোটা':'NN','ছিল':'NN','ছিলইনা':'VB','ছিলকি':'NN',
'ছিলনা':'VB','ছিলা':'NN','ছিলামতাহলে':'NN','ছিলামভাই':'NN','ছিলি':'VB','ছিলিম-বরদার':'NN','ছিলিমপোশ':'NN',
'ছিলিমবরদার':'NN','ছিলে':'NN','ছিলেনছিলেন':'NN','ছিলো':'VB','ছিলো':'NN','ছিলোতারা':'NN','ছিলোপোলিং':'VBG',
'ছিলোরাজার':'NN','ছিাম':'VB','ছিড়ে':'NN','ছিড়েছিলো':'VB','ছিয়া':'VB','ছিয়াত্তর':'NN','ছিয়াত্তরতম':'JJ',
'ছিয়ানব্বই':'NN','ছিয়ানব্বইতম':'JJ','ছিয়াশি':'NN','ছিয়াশিতম':'JJ','ছিয়াশিতে':'NN','ছিয়ে':'VB','ছু':'NN',
'ছুঁচানো':'NN','ছুঁচো':'NN','ছুঁড়ে':'VB','ছুঁড়লে':'RP','ছুঁড়ে':'VB','ছুঁয়া':'NN','ছুঁয়ো':'VB',
'ছুকরী':'NN','ছুকে':'NN','ছুটকি':'NN','ছুটছিল':'VB','ছুটছে':'VBG','ছুটছেন':'VB','ছুটতাম':'VB',
'ছুটন্ত':'JJ','ছুটবে':'VB','ছুটলো':'VB','ছুটা':'NN','ছুটিতে':'NN','ছুটে':'VB','ছুড়ি':'NN',
'ছুড়ে':'VB','ছুতা':'NN','ছুতে':'VB','ছুতেও':'JJ','ছুতোর':'NN','ছুতোরনি':'NN','ছুতোয়':'NN',
'ছুনি':'VB','ছুমন্তর':'NN','ছুরই':'NN','ছুরিকা':'NN','ছুরিকাচি':'NNS','ছুরীধার':'NN','ছুড়তো':'VBG',
'ছুড়ে':'NN','ছুড়েছিল':'VB','ছুয়ার':'NN','ছুয়ে':'NN','ছেঁকে':'NN','ছেঁটে':'VBN','ছেঁড়া':'NN',
'ছেঁড়াফাটা':'NN','ছেকানুপ্রাস':'NN','ছেচল্লিশ':'NN','ছেচল্লিশতম':'JJ','ছেটানো':'NN','ছেড়া':'VB','ছেড়েছে':'VBN',
'ছেদ':'NN','ছেদন':'NN','ছেদনীয়':'JJ','ছেদিত':'JJ','ছেদে':'NN','ছেদ্য':'JJ','ছেনা':'VB',
'ছেনি':'NN','ছেন্টার':'NN','ছেপে':'VB','ছেরা':'NN','ছেরে':'VB','ছেলে-মেয়ে':'NN','ছেলে':'NNP',
'ছেলেকে':'NN','ছেলেগুলোকে':'NN','ছেলেটাকে':'NN','ছেলেটার':'NN','ছেলেটিকে':'NN','ছেলেদের':'NNS','ছেলেদেরকে':'NN',
'ছেলেপেলেরাই':'NNS','ছেলেবুড়া':'NN','ছেলেবেলায়':'NN','ছেলেমানুষি':'NN','ছেলেমেয়ে':'NN','ছেলেমেয়েদের':'NNS','ছেলেমেয়েরা':'NN',
'ছেলের':'NN','ছেলেরাই':'NN','ছেষট্টি':'NN','ছেষট্টিতম':'JJ','ছোট':'NN','ছোলা':'NN','ছেড়া':'VB',
'ছেড়ে':'NN','ছেড়েছি':'VB','ছেড়েছে':'VBN','ছেড়েছেন':'VB','ছেড়েদে':'NN','ছেয়ে':'NN','ছে‌লে':'NN',
'ছৈয়দ':'NN','ছোঁ':'NN','ছোঁও':'VB','ছোঁড়া':'VB','ছোঁড়েন':'NN','ছোঁয়া':'NN','ছোঁয়াচে':'NN',
'ছোঁয়াছুঁয়ি':'NN','ছোঁয়ানো':'VB','ছোঁয়ার':'NN','ছোঃ':'RP','ছোকরা':'NN','ছোকড়ারা':'NNS','ছোখেও':'NNS',
'ছোট-ছোট':'JJ','ছোট':'NN','ছোটখাট':'JJ','ছোটখাটো':'NN','ছোটগল্পের':'NN','ছোটদলগুলো':'NN','ছোটদের':'NN',
'ছোটবেলা':'NN','ছোটমাপের':'NN','ছোটরা':'NN','ছোটাছুটি':'NN','ছোটো-খাটো':'JJ','ছোটো-চাঁদ':'NN','ছোটো':'NN',
'ছোটোখাটো':'JJ','ছোটোদের':'NN','ছোট্ট':'NN','ছোট্টু':'NNP','ছোড়া':'VB','ছোড়াছুড়ি':'NN','ছোপ':'NNS',
'ছোপওয়ালা':'JJ','ছোবন':'NN','ছোরা':'NN','ছোল':'NN','ছোলা-মটর':'NN','ছোলা':'NN','ছোলাভাজা':'NN',
'ছোলার':'NN','ছোড়দা':'NN','ছোড়াতে':'NN','ছোয়া':'NN','ছোয়ারা':'NN','ছ্যাকরা':'NN','ছড়া':'NN',
'ছড়াচ্ছিল':'VBG','ছড়াচ্ছে':'VB','ছড়াতে':'VB','ছড়ানো':'VB','ছড়াবে':'VB','ছড়ায়':'NN','ছড়ি':'NN',
'ছড়িয়ে':'VB','ছয়':'NN','ছয়গুণ':'NNS','ছয়জন':'NN','ছয়টি':'NN','ছয়তলা':'NN','ছয়নয়':'NN',
'জ-এর':'NNP','জ':'NN','জঁট':'NN','জঁড':'NN','জং':'NN','জংগি':'NN','জংগিবাদে':'NN',
'জংগির':'NN','জংগী':'NN','জংগীরাসত্যি':'NN','জংগৈ':'NN','জংঙ্গীর':'NN','জংলি':'NN','জংশন':'NNP',
'জই':'NN','জউইক':'NN','জউলস':'NN','জওহরলাল':'NN','জওয়ান':'NN','জকাল':'NN','জকিটাকে':'NN',
'জকীয়':'JJ','জকেই':'NN','জকের':'NN','জকোষ':'NN','জখন':'NN','জখবর':'NN','জখম':'NN',
'জগ':'NN','জগজীবন':'NNP','জগজ্জননী':'NN','জগজ্জয়ী':'JJ','জগণ':'NN','জগত':'NN','জগতজয়ী':'JJ',
'জগতটা':'NN','জগতসিংহপুর':'NN','জগতে':'NN','জগত্':'NN','জগদগুরু':'NN','জগদম্বা':'NN','জগদম্বার':'NNP',
'জগদলপুর':'NN','জগদীশ':'NN','জগদীশচন্দ্র':'NN','জগদীশ্বরী':'NN','জগদ্দল':'NN','জগদ্ধাতা':'NN','জগদ্ধাত্রী':'NNP',
'জগদ্ধাত্রীরূপে':'NN','জগদ্বল':'NN','জগনের':'NN','জগন্নাথ-পুরী':'NN','জগন্নাথপুরী':'NN','জগন্মাতা':'NN','জগন্য':'NN',
'জগমোহন':'NN','জগা':'NN','জগাই-':'NNP','জগাইয়ের':'NNP','জগাখিচুড়ী':'NN','জগাখিচুড়ি':'NN','জগার':'NNP',
'জগী':'NN','জগোজ':'NN','জগৎ':'NN','জঘণ্য':'NN','জঘন্যতম':'NN','জঙ্গম':'JJ','জঙ্গল':'NN',
'জঙ্গলী':'NN','জঙ্গলের':'NN','জঙ্গি':'NN','জঙ্গিদলটি':'NN','জঙ্গিবাদ':'NN','জঙ্গিবাদে':'NN','জঙ্গিমুক্ত':'NN',
'জঙ্গির':'NN','জঙ্গি–সন্ত্রাসীদের':'NN','জঙ্গী-হরিতকী':'NN','জঙ্গী':'NN','জঙ্গীবাদী':'NN','জঙ্গীরা':'NN','জঙ্গীসন্ত্রাসীরা':'NN',
'জঙ্ঘা':'NN','জঙ্ঘারি':'NN','জছিল':'VB','জজ':'NN','জজবা':'NN','জজমিয়া':'NN','জঞ্জাল':'NN',
'জট':'NN','জটমুক্ত':'JJ','জটা':'NN','জটাজুট':'NN','জটাধারী':'JJ','জটামাসি':'NN','জটার':'NN',
'জটায়':'NN','জটিল':'JJ','জটিলক':'NN','জটিলতার':'NN','জটুল':'NN','জঠর':'NN','জঠরাগ্নি':'NN',
'জঠিল':'JJ','জড়':'NN','জড়ত্ব':'NN','জড়নো':'VB','জড়বুদ্ধি':'NN','জড়ানো':'NN','জড়ি-বুটি':'NN',
'জড়ি':'NN','জড়িবুটি':'NN','জড়িয়ে':'VB','জড়িয়া':'NN','জড়ো':'NN','জণগনের':'NN','জণ্ডিস-এর':'NN',
'জতীয়':'NN','জতুকা':'NN','জতুরস':'NN','জত্ব':'NN','জদি':'NN','জদের':'NN','জন-':'JJ',
'জন-জাতি':'NN','জন-হরণ':'NN','জন-হিত':'NN','জন':'NN','জনক':'NN','জনকপুর':'NN','জনকল্যাণ':'VB',
'জনকল্যাণমূলক':'NN','জনকল্যাণের':'VB','জনকল্যানকর':'NN','জনকৃতি':'NN','জনকে':'NN','জনগণ':'NN','জনগণও':'NN',
'জনগণতাদের':'NN','জনগণনা':'NN','জনগণরে':'NN','জনগণের':'NN','জনগন':'NN','জনগনকে':'NN','জনগনরা':'NN',
'জনগনের':'NN','জনগোষ্ঠির':'NN','জনগোষ্ঠী':'NN','জনগোষ্ঠীর':'NN','জনঘনত্ব':'NN','জনচিত্তাকৃষ্টকারী':'JJ','জনজাতি':'NN',
'জনজীবন':'NN','জনজোয়ার':'NN','জনডিস':'NN','জনতন্ত্র':'NN','জনতা':'NN','জনতান্ত্রিক':'NN','জনতার':'NN',
'জনদুর্ভোগ':'NN','জনদের':'NN','জনন':'NN','জননাঙ্গ':'NN','জননিকা':'NN','জননী':'NN','জননীর':'NN',
'জননে':'NN','জননেতা':'NN','জননেন্দ্রিয়':'NN','জনপথ':'NN','জনপোযোগী':'JJ','জনপ্রতি':'NN','জনপ্রশাসন':'NN',
'জনপ্রিও':'NN','জনপ্রিয়তা':'NN','জনপ্রিয়তা':'NN','জনপ্রিয়তার':'NN','জনপ্রিয়াতা':'NN','জনফাইনালের':'NN','জনবল':'NN',
'জনবসতির':'NN','জনবহুল':'JJ','জনবান্ধব':'NN','জনবিচিছন্ন':'NN','জনবিরোধী':'NN','জনবৃদ্ধির':'NN','জনভোগান্তি':'NN',
'জনম':'NN','জনমজুর':'NN','জনমত':'NN','জনমনে':'NN','জনমনোরঞ্জক':'JJ','জনমানবহীন':'JJ','জনমানস':'NN',
'জনমুখি':'NN','জনমে':'NN','জনযুদ্ধ':'NN','জনরব':'NN','জনরোষ':'NN','জনরোষের':'NN','জনশক্তি':'NN',
'জনশিক্ষা':'NN','জনশূন্য':'JJ','জনশ্রুত':'JJ','জনশ্রুতি':'NN','জনসংখ্যা':'NN','জনসংখ্যাকে':'NN','জনসংখ্যাসংক্রান্ত':'NN',
'জনসংখ্যায়':'NN','জনসংগ্রাম':'NN','জনসংহার':'NN','জনসচেতনতামূলক':'NN','জনসভা':'NN','জনসভার':'NN','জনসমক্ষে':'NN',
'জনসমর্থন':'NN','জনসমষ্টি':'NN','জনসমাজ':'NN','জনসম্পর্ক':'NN','জনসাধারণ':'NN','জনসাধারন':'NN','জনসেবক':'NN',
'জনসেবায়':'NN','জনস্বার্থের':'NN','জনস্রোতের':'NN','জনহিত':'NN','জনহিতকর':'JJ','জনা':'NN','জনাক্রোশ':'NN',
'জনাকয়েক':'CD','জনাদেশ':'NN','জনাধার':'NN','জনাব':'NN','জনাবএবার':'NN','জনাবওয়াদা':'NN','জনাবগণ':'NN',
'জনাবহিসাব':'NN','জনার':'NN','জনারির':'NN','জনার্দন':'NN','জনালেও':'NN','জনাশ্রয়':'NN','জনিত':'NN',
'জনিনা':'NN','জনীক':'JJ','জনীয়':'JJ','জনে':'NN','জনের':'NN','জনৈক':'JJ','জন্তর-মন্তর':'NN',
'জন্তু':'NN','জন্তুদিগের':'NN','জন্ত্রী':'NN','জন্নাত':'NN','জন্ন্য':'IN','জন্ন্যে':'NN','জন্ম-ঘুট্টী':'NN',
'জন্ম-তিথি':'NN','জন্ম':'NNP','জন্মই':'NN','জন্মকাল':'NN','জন্মকুণ্ডলী':'NN','জন্মগত':'NN','জন্মগ্রহণ':'NNP',
'জন্মগ্রহণনো':'VB','জন্মঘুট্টী':'NN','জন্মজন্মান্তর':'NN','জন্মজাত':'NN','জন্মতিথি':'NN','জন্মদাতা':'NN','জন্মদান':'VB',
'জন্মদিন':'NN','জন্মনিয়ন্ত্রণ':'NN','জন্মপত্র':'NN','জন্মভুমি':'NN','জন্মভূমিতে':'NN','জন্মমাত্রই':'RB','জন্মরহস্য':'NN',
'জন্মলগ্ন':'NN','জন্মসময়':'NN','জন্মসূত্রে':'NN','জন্মস্থান':'NN','জন্মহার':'NN','জন্মাতাম':'NN','জন্মান':'NN',
'জন্মান্তর':'NN','জন্মান্ধ':'JJ','জন্মাবধি':'RB','জন্মাবে':'JJ','জন্মায়':'VB','জন্মালে':'NN','জন্মালেও':'VB',
'জন্মাষ্টমী':'NN','জন্মায়':'NN','জন্মেছে':'NN','জন্মোত্সব':'NN','জন্য':'CC','জন্যআরো':'NN','জন্যই':'NN',
'জন্যইতো':'IN','জন্যও':'NN','জন্যকাশী':'NN','জন্যতো':'IN','জন্যদুর্নীতির':'NN','জন্যবরং':'NN','জন্যবিজ্ঞ':'NN',
'জন্যরাজনীতিতে':'NN','জন্যসংবিধানে':'NN','জন্যে':'NN','জন্যেই':'NN','জন্যেও':'NN','জন্যয়':'IN','জন্স':'NN',
'জন‌গন':'NN','জন‍্য':'NNS','জন‍্যও':'IN','জপ':'NN','জপকারী':'NN','জপতপের':'NN','জপথলে':'NN',
'জপনীয়':'JJ','জপবেন':'NN','জপমালা':'NN','জপ্য':'JJ','জব':'NN','জবংশ':'NN','জবটি':'NN',
'জবর':'JJ','জবরদস্তি':'RB','জবলেস':'JJ','জবস':'NN','জবা':'NN','জবাইকে':'NN','জবাদ':'NN',
'জবাবটা':'NN','জবাবদিহি':'NN','জবাবদিহিতার':'NN','জবাবদিহির':'NN','জবাবদীহিতা':'NN','জবাবী':'JJ','জবাবের':'NN',
'জবালা':'NN','জবাস':'NN','জবুত':'JJ','জব্দ':'VBN','জব্বর':'JJ','জব্বলপুর':'NN','জমকালো':'NN',
'জমজম':'NN','জমজোহরা':'NN','জমতেছে':'NNS','জমবেনা':'NN','জমশন্য':'NN','জমহল':'NN','জমা-পুঁজি':'NN',
'জমা':'NN','জমাকর্তা':'JJ','জমাখরচের':'NN','জমাট':'NN','জমাটবদ্ধ':'JJ','জমাদার':'NN','জমান':'JJ',
'জমানত':'NN','জমানবিশ':'NN','জমানা':'NN','জমানাতনামা':'NN','জমানো':'NN','জমাবন্দী':'NN','জমায়েত':'JJ',
'জমার':'NN','জমালগোটা':'NN','জমায়':'NNS','জমায়েত':'NN','জমি':'NN','জমিকন্দ':'NN','জমিজমা':'NN',
'জমিতে':'NN','জমিদার':'NN','জমিদারনী':'NN','জমিদারিআনা':'NN','জমিদারির':'NN','জমিনে':'NN','জমিয়ে':'VB',
'জমির':'NN','জমিয়ে':'NN','জমিয়েছে':'NNS','জমুই':'NN','জমে':'VB','জমের':'NN','জম্বির':'NN',
'জম্বুখন্ড':'NN','জম্বুদ্বীপ':'NN','জম্বুনজ':'NN','জম্বুমতি':'NN','জম্ভ':'NN','জম্মু-তাওয়াই':'NN','জম্মু':'NN',
'জয়':'NN','জয়ন্ত':'NN','জয়ী':'NN','জরকে':'NNP','জরত্কারু':'NN','জরদা':'NN','জরদোজ়ী':'NN',
'জরবপাত':'NN','জরা':'NN','জরাকুমার':'NN','জরাগ্রস্ত':'NN','জরাজীর্ণ':'JJ','জরাথ্রুষ্ট':'NN','জরানো':'NNV',
'জরারহিত':'JJ','জরাসন্ধ':'NN','জরায়ু':'NN','জরায়ুর':'NN','জরি':'NN','জরিদার':'JJ','জরিপ':'NN',
'জরিমানা':'NN','জরিযুক্ত':'JJ','জরির':'NN','জরী':'NN','জরীপকারী':'NN','জরুরি':'NN','জরুরী':'RB',
'জরুল':'NNP','জর্জ':'NN','জর্জটাউন':'NN','জর্জর':'JJ','জর্জরিত':'NN','জর্জস্':'NN','জর্জিয়া':'NN',
'জর্জিয়াবাসী':'NN','জর্জিয়ার':'JJ','জর্জেট':'NN','জর্ডন':'NN','জর্ডনিয়ান':'NN','জল-ক্রীড়া':'NN','জল-ধারা':'NN',
'জল-পরী':'NN','জল-বিহার':'NN','জল-বৃষ্টি':'NN','জল-মানুষ':'NN','জল-সেনা':'NN','জল-হাওয়া':'NN','জল':'NN',
'জলকণা':'NN','জলকন্যা':'NN','জলকপোত':'NN','জলকর':'NN','জলকাক':'NN','জলকুক্কুটি':'NN','জলকুল্তল':'NN',
'জলকেও':'NN','জলকেলি':'NN','জলক্রীড়া':'NN','জলখাবার':'NN','জলগাঁও':'NN','জলঘড়ি':'NN','জলঘাস':'NN',
'জলঘূর্ণি':'NN','জলচর':'NN','জলচালিত':'JJ','জলচ্ছাস':'NN','জলজ':'NN','জলজাত':'JJ','জলজাহাজ':'NN',
'জলজিরা':'NN','জলঢোরা':'NN','জলতরঙ্গ':'NN','জলদস্যু':'NN','জলদান':'NN','জলদানকারী':'JJ','জলদি':'JJ',
'জলদেবতা':'NN','জলধর-কেদারা':'NN','জলধর':'NN','জলধারা':'NN','জলধি':'NN','জলনিকাশীর':'NN','জলনীলিকা':'NN',
'জলন্ত':'NN','জলপট্টি':'NN','জলপতি':'NN','জলপরী':'NN','জলপাই':'NN','জলপাইগুড়ী':'NN','জলপাত্র':'NN',
'জলপান':'NN','জলপিপুল':'NN','জলপূর্ণ':'NN','জলপোত':'NN','জলপ্রবাহ':'NN','জলফড়িং':'NN','জলবদ্ধতার':'NN',
'জলবন্টন':'NN','জলবর্ষণকারী':'NN','জলবসন্ত':'NN','জলবাহিকা':'NN','জলবায়ু':'NN','জলবায়ুবিজ্ঞানী':'NN','জলবিন্দুজ':'NN',
'জলবিল্ব':'NN','জলবিহার':'NN','জলবৃষ্চিক':'NN','জলভরা':'NN','জলভাত':'NN','জলমগ্ন':'NN','জলমণ্ডল':'NN',
'জলমনুষ্য':'NN','জলমার্গ':'NN','জলময়':'JJ','জলযট':'NN','জলযন্ত্র':'NN','জলযান':'NN','জলযোগের':'NN',
'জলরঙ':'NN','জলরাশি':'NN','জললো':'NN','জলসন্ধ':'NN','জলসা':'NN','জলসেচ':'NN','জলসেচের':'NN',
'জলসেনা':'NN','জলসেনাধক্ষ্য':'NN','জলস্তম্ভ':'NN','জলস্রোত':'NN','জলহরণ':'NN','জলহস্তী':'NN','জলহীন':'JJ',
'জলাঞ্জলি':'NN','জলাতঙ্ক':'NN','জলাধার':'NN','জলাধিপ':'NN','জলাবদ্দতা':'VBG','জলাবদ্ধতাত':'VBG','জলাভিষেক':'NN',
'জলার':'NN','জলালুদ্দীন':'NNP','জলাশয়':'NN','জলির':'NN','জলীয়':'NN','জলুস':'NN','জলে':'NN',
'জলেছে':'VB','জলের':'NN','জলোটি':'NN','জলোদর':'NN','জলোদ্ধতিগতি':'NN','জল্পনা':'NN','জল্লাদ':'NN',
'জল৩জির':'NN','জশপুর':'NN','জশেন':'VB','জসভা':'NN','জস্ব':'NN','জস্র':'JJ','জহর':'NN',
'জহির':'NN','জহিরুদ্দিন':'NN','জহিরুল':'NN','জহুর':'NN','জহুরী':'NN','জহ্নু':'NN','জ়নগণ':'NNS',
'জ়ীবনমান':'NN','জ়ের':'NN','জা':'NN','জাঁকজমকপূর্ণ':'NN','জাঁতাকল':'NN','জাঁতাপেষা':'VB','জাঁতাশাল':'NN',
'জাঁতি':'NN','জাংশন':'NN','জাইকা':'NN','জাইট':'NNP','জাইর':'NN','জাইরাইট':'NNP','জাইরাম':'NN',
'জাউকগা':'NN','জাওয়া':'NN','জাওয়ার':'NNP','জাকজমকের':'NN','জাকানা':'NN','জাকারবার্গ':'NN','জাকার্তা':'NN',
'জাকে':'NN','জাখোম':'NN','জাগতে':'NN','জাগরণ':'NN','জাগরণই':'VBG','জাগরয়িতা':'JJ','জাগা':'NN',
'জাগাটা':'NNV','জাগানো':'NN','জাগানো':'VB','জাগাব':'NN','জাগির':'NN','জাগিয়েছেন':'VB','জাগুয়ার':'NN',
'জাগৃতি':'VBG','জাগে':'NN','জাগ্রত':'NN','জাগ্রতকে':'VB','জাগ্রেব':'NN','জাঘী':'NN','জাঙ্গিয়া':'NN',
'জাঙ্ঘিল':'NN','জাছেছ':'VBG','জাজ-মল্হার':'NN','জাজপুর':'NN','জাজলি':'NN','জাজী':'JJ','জাজে':'VB',
'জাজ্জ্বল্যমান':'JJ','জাঞ্জগীর-চাঁপা':'NN','জাঞ্জিবার':'NN','জাট':'NN','জাটলি':'NN','জাটা':'NN','জাঠ':'NN',
'জাণু':'NN','জাত-পাত':'NN','জাত':'NN','জাতকের':'NN','জাতভাই':'NN','জাতহীন':'JJ','জাতার':'NN',
'জাতি-সম্বন্ধীয়':'JJ','জাতি':'NN','জাতিক':'NNP','জাতিকে':'NN','জাতিগত':'JJ','জাতিগোষ্ঠী':'NN','জাতিচ্যূত':'JJ',
'জাতিটিকে':'NN','জাতিত্ব':'NN','জাতিদ্বন্দ্ব':'NN','জাতিপত্রী':'NN','জাতিপুষ্প':'NN','জাতিবাচক':'NN','জাতিভেদ':'NN',
'জাতির':'NN','জাতিরাই':'NN','জাতিসংক্রান্ত':'JJ','জাতিসংঘ':'NN','জাতিসংঘের':'NN','জাতিসমূহ':'NN','জাতিয়':'NNP',
'জাতিয়তাটা':'NN','জাতী':'NN','জাতীতে':'NN','জাতীয়':'NNP','জাতীয়তাবাদী':'NN','জাতীর':'NN','জাতীয়করণ':'NN',
'জাতীয়তা':'NN','জাতীয়তাবাদী':'NN','জাতুক':'NN','জাতূকর্ণ':'NN','জাতের':'NN','জাদবতো':'NNP','জাদা':'NNP',
'জাদু':'NN','জাদুগরনি':'NN','জাদুঘরে':'NN','জাদের':'NN','জান':'NN','জানত':'VB','জানতাম':'NN',
'জানতে':'VB','জানতো':'VB','জাননাতে':'NNP','জানবাজারের':'NNP','জানবে':'VB','জানবো':'VB','জানমাল':'NN',
'জানলা':'NN','জানলাম':'VB','জানলার':'NN','জানলে':'VB','জানলেও':'VB','জানা-শোনা':'NN','জানা':'NN',
'জানাই':'VB','জানাইতবে':'VBG','জানাইদুদক':'NN','জানাচ্ছি':'VB','জানাচ্ছে':'VBG','জানাজা':'NN','জানাতে':'NN',
'জানান':'VB','জানানআহারে':'VB','জানানো':'NN','জানানোরও':'NN','জানাবএমন':'VB','জানাবো':'VB','জানামতে':'NNP',
'জানামাজ':'NN','জানার':'VB','জানালা':'NN','জানালাম':'VB','জানালার':'NN','জানালে':'VBN','জানালেই':'VB',
'জানালেও':'NN','জানালেন':'VBN','জানালো':'VB','জানাশোনা':'NN','জানায়':'VB','জানি':'NNP','জানিতোমার':'NNS',
'জানিনা':'NNP','জানিপপ':'NN','জানিয়েছে':'VB','জানিস':'NN','জানিস্্':'VB','জানিয়ে':'VBN','জানিয়েছি':'VBN',
'জানিয়েছিলাম':'VB','জানিয়েছে':'VBN','জানিয়েছেন':'NN','জানি—এরা':'NN','জানু':'NN','জানুক':'VB','জানুকর্ণ':'NN',
'জানুন':'VB','জানুয়ারি':'NNP','জানুয়াঁ':'NN','জানুয়ারি':'NNP','জানুয়ারিতেই':'NNP','জানুয়ারী':'NN','জানুয়ারীতে':'NNP',
'জানে':'NNS','জানেই':'NN','জানেতনু':'NN','জানেন':'VB','জানেনা':'VB','জানের':'NN','জানো':'VB',
'জানো':'VB','জানোয়ার':'NN','জানোয়ারদের':'NNS','জান্তব':'JJ','জান্তে':'NN','জান্নাতবাসী':'NN','জান্নাতুল':'NN',
'জাপটা':'NN','জাপান':'NN','জাপানকে':'NNP','জাপানবাসী':'JJ','জাপানি':'JJ','জাপানী':'NN','জাপানীদের':'NN',
'জাপানীরা':'JJ','জাপানে':'NN','জাপার':'NN','জাফনা':'NNP','জাফরান':'NN','জাফরানি':'JJ','জাফরানী':'NN',
'জাফরাবাদ':'NN','জাফরাবাদের':'JJ','জাফরুল্লাহ':'NN','জাব':'NN','জাবপ্রেস':'NN','জাবর':'NN','জাবাই':'NN',
'জাবালি':'NN','জাবি':'NN','জাবিত্রী':'NN','জাবিয়া':'NN','জাবী':'JJ','জাবে':'VB','জাবেই':'NN',
'জাবেদায়':'NN','জাভা':'NN','জাভান':'JJ','জাভানিস':'NN','জাভাবাসী':'NN','জাম':'NN','জামতারা':'NN',
'জামদগ্নি':'NN','জামদানী':'NN','জামধর':'NN','জামবন':'NN','জামশেদপুর':'NN','জামা-কাপড়':'NN','জামা':'NN',
'জামাই':'NN','জামাইকান':'NN','জামাইকার':'JJ','জামাইবাবু':'NN','জামাকাপড়':'NN','জামাত':'NN','জামাতকে':'NN',
'জামাতজঙ্গী':'NN','জামাতবিএনপি':'NN','জামাতবিএনপির':'NN','জামাতমুক্ত':'JJ','জামাতশিবির':'NN','জামাতশিবিরের':'NN','জামাতা':'NN',
'জামাতিদের':'NN','জামাতিরা':'NNS','জামাতের':'NN','জামানতই':'NN','জামায়াতে':'NN','জামার':'NN','জামাল':'JJ',
'জামালগোটা':'NN','জামায়তি':'NN','জামায়াতমুক্ত':'JJ','জামায়াতশিবিরকে':'NN','জামায়াতের':'NN','জামিন-অযোগ্য':'JJ','জামিন':'NN',
'জামিনে':'NN','জামিলের':'NN','জামীন':'NN','জামেভর':'NN','জামেলা':'NN','জাম্বন্তী':'NN','জাম্বিয়া':'NN',
'জাম্বিয়াবাসী':'NN','জাম্বিয়ার':'JJ','জায়':'NN','জায়না':'NN','জার':'NN','জারতন্ত্র':'NN','জারা':'NN',
'জারিগান':'NN','জারিত':'JJ','জারিনা':'NN','জারির':'VBN','জারী':'VBN','জারে':'NN','জার্নাল':'NNP',
'জার্নালিজম':'NN','জার্মাণ':'NNP','জার্মান-বাসী':'NN','জার্মানদের':'NNP','জার্মানবাসী':'NN','জার্মানরা':'JJ','জার্মানি':'NN',
'জার্মানিই':'NNP','জার্মানিকেই':'NN','জার্মানিদের':'NN','জার্মানীর':'NN','জার্মানের':'JJ','জার্মিনি':'NNP','জার্সি':'NN',
'জাল':'NN','জালজীবি':'NN','জালনা':'VBG','জালবন্দ':'NN','জালভোট':'NN','জালযুক্ত':'JJ','জালা':'NN',
'জালান্ধর':'NN','জালাল':'NN','জালালুদ্দিন':'NNP','জালায়':'NN','জালি':'NN','জালিমদের':'NNS','জালিয়াত':'NN',
'জালিয়াতির':'NN','জালিয়ে':'VBG','জালে':'NN','জালোর':'NN','জালৌন':'NN','জাসদ':'NN','জাসদসর্বহারা':'NN',
'জাসদের':'NN','জাস্ট':'RB','জাস্টিস':'NNP','জাহা':'NN','জাহাঁপনা':'NN','জাহাংগীর':'NN','জাহাআলম':'NN',
'জাহাঙ্গীর':'NN','জাহাঙ্গীরি':'NN','জাহাঙ্গীরের':'NNP','জাহাজ':'NN','জাহাজগুলো':'NN','জাহাজটিতে':'NN','জাহাজডুবি':'NN',
'জাহাজী':'NN','জাহাজের':'NN','জাহান':'NN','জাহানার':'NN','জাহান্নম':'NN','জাহালমকে':'NN','জাহালমের':'NN',
'জাহালামরা':'NN','জাহির':'NN','জাহিরুদ্দীন':'NN','জাহেলি':'NN','জাহ্নবী':'NN','জায়':'NN','জায়গাই':'NN',
'জায়গাগুলা':'NNS','জায়গাটা':'NN','জায়গাতে':'NN','জায়গার':'NN','জায়গায়-জায়গায়':'RB','জায়গায়':'NN','জায়গির':'NN',
'জায়পত্রী':'NN','জায়ফল':'NN','জায়েজ':'JJ','জায়েদ':'NN','জি':'NN','জিংক':'NNP','জিই':'NN',
'জিউতিয়া':'NN','জিউস':'NN','জিএম':'NN','জিএসপি':'NN','জিও':'NN','জিওর':'NN','জিওলজিক্যাল':'NNP',
'জিকে':'NN','জিগিন':'NN','জিগুরণ':'NN','জিগ্যেস':'NN','জিগ্যেসাবাদ':'NNS','জিঙ্ক':'NN','জিঙ্গনী':'NN',
'জিজিয়া':'NN','জিজ্ঞাস':'NN','জিজ্ঞাসাবাদ':'NN','জিজ্ঞাসাহীন':'JJ','জিজ্ঞাসিত':'JJ','জিজ্ঞাসু':'NN','জিজ্ঞেস':'NNS',
'জিঞ্জিরায়':'NN','জিডি':'NN','জিডিপির':'NN','জিত':'NN','জিতছে':'VB','জিততেছে':'VB','জিততোই':'VB',
'জিতবই':'NN','জিতবা':'VB','জিতবেন':'VB','জিতলি':'VB','জিতলেই':'VB','জিতা':'VB','জিতাষ্টমী':'NN',
'জিতায়':'VB','জিতুক':'VB','জিতে':'NN','জিতেছি':'VB','জিতেছে':'VB','জিতেনি':'VB','জিতেন্দ্রিয়':'NN',
'জিত্তে':'NN','জিদ':'NN','জিদানের':'NN','জিন':'NN','জিনপোশ':'NN','জিনস':'NNS','জিনসংলগ্ন':'NN',
'জিনা':'NN','জিনিশ':'NNS','জিনিষ':'NN','জিনিষটা':'NN','জিনিষপত্র':'NN','জিনিস':'NN','জিনিসই':'NNS',
'জিনিসগুলা':'NNS','জিনিসটা':'NN','জিনিসপত্র':'NN','জিনিসপত্রের':'NNS','জিনিসের':'NN','জিন্দ':'JJ','জিন্স':'NN',
'জিপ':'NN','জিপি':'NN','জিপিতে':'NN','জিপির':'NN','জিপে':'NN','জিপ্সী':'NN','জিব':'NN',
'জিবনে':'NN','জিবাউটি':'NN','জিব্রালটর':'NN','জিভ':'NN','জিভফোঁড়া':'NN','জিভা':'NN','জিম':'NN',
'জিমনাশিয়াম':'NN','জিমমী':'NN','জিমেইল':'NN','জিম্বাবুয়ে':'NN','জিম্বাবুয়ে':'NN','জিম্বাবুয়েআয়ারল্যান্ড':'NN','জিম্বাবুয়েও':'NN',
'জিম্বাবুয়েবাংলাদেশ':'NN','জিম্বাবুয়ের':'NN','জিম্বাবোয়ে':'NN','জিম্মা':'NN','জিয়া':'NN','জির':'NN','জিরকোনিয়াম':'NN',
'জিরা':'NN','জিরো':'NN','জিল':'NN','জিলিপি':'NN','জিলেট':'NN','জিল্যান্ড':'NN','জিহাদ':'NN',
'জিহাদী':'JJ','জিহ্বা':'NN','জিহ্বাজপ':'NN','জিহ্বাতল':'NN','জিহ্বামূল':'NN','জিৎ':'VB','জিয়া':'NN',
'জিয়াউদ্দিন':'NN','জিয়াউর':'NN','জিয়াও':'NN','জিয়াকেই':'NN','জিয়ার':'NN','জিয়ে':'VB','জী':'NN',
'জীকে':'NN','জীজাবাই':'NN','জীতে':'NN','জীনাত':'NNP','জীপ':'NN','জীপীএস':'NN','জীব':'NN',
'জীবকুল':'NN','জীবজগত':'NN','জীবদ্দশায়':'NN','জীবন-যাপন':'NN','জীবন-লীলায়':'NN','জীবন':'NN','জীবনকাল':'NN',
'জীবনচক্র':'NN','জীবনটা':'NN','জীবনদায়ী':'NN','জীবনধন':'NN','জীবনধারণের':'NN','জীবননদী':'NN','জীবনপাত':'VB',
'জীবনবিমুখ':'NN','জীবনবীমা':'NN','জীবনবৃত্তান্ত':'NN','জীবনভর':'RB','জীবনমরণ':'NN','জীবনযাত্রা':'NN','জীবনযাত্রায়':'NN',
'জীবনযাপন':'NN','জীবনযাপনের':'NN','জীবনযুদ্ধ':'NN','জীবনশৈলী':'NN','জীবনসঙ্গিনী':'NN','জীবনসাথী':'NN','জীবনহরণকারী':'JJ',
'জীবনহীন':'JJ','জীবনাচার':'NN','জীবনাশক':'NN','জীবনি-শক্তি':'NN','জীবনী':'NN','জীবনীশক্তি':'NN','জীবনে':'NN',
'জীবনেও':'NN','জীবনেচ্ছু':'NN','জীবনের':'NN','জীবন্ত':'NN','জীববিজ্ঞান':'NNP','জীববিজ্ঞানী':'NN','জীববৈচিত্র্য':'NN',
'জীবমণ্ডল':'NN','জীবা':'NN','জীবাণুকে':'NN','জীবাণুঘটিত':'JJ','জীবাণুনাশ':'NN','জীবাণুবিজ্ঞান':'NN','জীবাণুশাস্ত্র':'NN',
'জীবাত্মার':'NN','জীবিকা':'NN','জীবিকানির্বাহের':'NN','জীবিকার':'NN','জীবিকাহীন':'JJ','জীবিকোপার্জন':'NN','জীবিত':'NN',
'জীবিতকুণ্ডে':'NN','জীবিতদের':'NN','জীবী':'JJ','জীবীত':'VB','জীবীদের':'NN','জীবের':'NN','জীমূত':'NN',
'জীমূতাষ্টমী':'NN','জীরা':'NN','জীরে':'NN','জীর্ণ-শীর্ণ':'JJ','জীর্ণ':'NN','জীর্ণোদ্ধার':'NN','জীল্যাণ্ড':'NN',
'জুঁই':'NN','জুঁড়িহা':'NN','জুআঠ':'NN','জুই':'NN','জুগজুগি':'NN','জুগনু':'NN','জুগস্পিটসে':'NN',
'জুগুপ্সা':'NN','জুগুপ্সু':'JJ','জুগে':'NN','জুজু':'NN','জুট':'NN','জুটতেছে':'NN','জুটবে':'NN',
'জুটমিলের':'NN','জুটি':'NN','জুড়ি':'NN','জুড়িহীন':'JJ','জুড়ে':'NN','জুডিয়া':'NNP','জুডিশিয়াল':'NN',
'জুডিশিয়ারি':'NN','জুতসই':'NN','জুতা':'NN','জুতাখোর':'JJ','জুতাগ্র':'NN','জুতানো':'VB','জুতার':'NN',
'জুতো':'NN','জুতোখোর':'JJ','জুতোর':'NN','জুদেব':'NN','জুন':'NN','জুনআগস্ট':'NN','জুনাইদ':'NN',
'জুনাগড়':'NN','জুনায়েদ':'NN','জুনিয়র':'NN','জুনিয়ার':'NN','জুনে':'NN','জুন্হেবোটো':'NN','জুপিটার':'NN',
'জুবলী':'NN','জুবা':'NN','জুবায়েরের':'NN','জুবিলি':'NN','জুভেনাইল':'NN','জুভেন্টাসে':'NN','জুভের':'NN',
'জুম':'NN','জুম্বলি':'NN','জুরি':'NN','জুরিয়ে':'NN','জুরী':'NNP','জুরে':'NN','জুলপি':'NN',
'জুলাই':'NN','জুলাইআগষ্ট':'NN','জুলি':'NN','জুলিয়ান':'NN','জুলিয়াস':'NNP','জুলিয়েটের':'NN','জুলুম':'NN',
'জুলুমনির্যাতন':'NN','জুলুমের':'NN','জুষা':'NNP','জুস':'NN','জুহার':'NN','জুহু':'NN','জুড়লেন':'VB',
'জুড়ি':'NN','জুড়ির':'NN','জুড়িয়া':'VB','জুড়ে':'NN','জুয়া':'NN','জুয়াখানা':'NN','জুয়াঘর':'NN',
'জুয়াড়ী':'JJ','জুয়াবাজ':'NN','জুয়ার':'NN','জুয়ায়':'NN','জুয়ীর':'NN','জুয়েলার্সের':'NN','জে.':'NNP',
'জেঁকে':'NN','জেঃ':'NN','জেএমবির':'NN','জেএসসি':'NN','জেকে':'NNP','জেখানে':'NN','জেগে':'NN',
'জেগেছিলো':'NN','জেছে':'VB','জেট':'NN','জেটিতে':'NN','জেঠী':'NN','জেড':'NN','জেডিসি':'NN',
'জেত':'NN','জেতব্য':'JJ','জেতা':'VB','জেতানো':'NN','জেতাবে':'NN','জেতেন':'NN','জেতেনি':'VB',
'জেত্রোফা':'NN','জেদ':'NN','জেদাজেদি':'NN','জেদী':'NN','জেদ্দার':'NN','জেন':'NN','জেনকার':'NN',
'জেনন':'NN','জেনার':'NN','জেনারেল':'NN','জেনারেশন':'NN','জেনারেশান':'NN','জেনিভা':'NN','জেনুইন':'NN',
'জেনে':'NN','জেনেও':'NN','জেনেটিক':'JJ','জেনেবুঝে':'RB','জেনেভা':'NN','জেনেশুনে':'NN','জেনো':'NN',
'জেন্টেলম্যান':'NN','জেন্দ-আবেস্তা':'NN','জেন্দ':'NNP','জেপি':'NN','জেফ':'NN','জেবত্ব':'NN','জেব্রা':'NN',
'জেমস':'NNP','জের':'NN','জেরও':'NN','জেরক্স':'NN','জেরা':'NN','জেরার্ডের':'NN','জেরি':'NN',
'জেরুজালেম':'NN','জেরে':'NN','জেরেমি':'NN','জেল':'NN','জেলকর্মী':'NN','জেলখানা':'NN','জেলখানার':'JJ',
'জেলখানায়':'NN','জেলজুলুম':'NN','জেলর':'NN','জেলাই':'NN','জেলাগুলো':'NN','জেলাটি':'NN','জেলাধিকারিক':'NN',
'জেলাধীশ':'NN','জেলাম':'NN','জেলাসির':'NN','জেলায়':'NN','জেলি':'NN','জেলেদেরকে':'NN','জেলেনীর':'NN',
'জেলেরা':'NN','জেল্লা':'NN','জেষ্ঠ্য':'NN','জেসমিন':'NN','জেহাদ':'NN','জেহাদী':'JJ','জোট':'NN',
'জোরে':'NN','জোহা':'NN','জোয়ারে':'NN','জেয়':'JJ','জৈগীষব্য':'NN','জৈতশ্রী':'NN','জৈন-দর্শন':'NN',
'জৈন':'NN','জৈনদর্শন':'NN','জৈনধর্মালম্বী':'NN','জৈন্য':'NN','জৈব':'NN','জৈবপ্রযুক্তি':'NN','জৈবরসায়ন':'NNP',
'জৈবিক':'NN','জৈমিনি':'NN','জৈষ্ঠ-কৃষ্ণ':'NN','জৈষ্ঠ্য':'NN','জৈষ্ঠ্যের':'NNP','জো':'NN','জোঁক':'NN',
'জোংখা':'NN','জোক':'NN','জোকস':'NN','জোকার':'NN','জোকারে':'NN','জোকোভিচও':'NN','জোক্স':'NN',
'জোগাই':'NN','জোগাড়':'NN','জোগানো':'VB','জোগানোর':'NN','জোগাবেশফিকুল':'NN','জোগারি':'NN','জোগাড়':'VB',
'জোগীড়া':'NN','জোগ্রীবা':'NN','জোঙ্কা':'NN','জোচ্চর':'NN','জোচ্চুরিপনা':'NN','জোচ্চোর':'JJ','জোচ্ছরি':'NN',
'জোট':'NN','জোটবদ্ধ':'NN','জোটে':'NN','জোড়':'NN','জোড়বিহীন':'JJ','জোড়া':'NN','জোড়ুয়া':'NN',
'জোড়ে':'NN','জোত':'NN','জোতগাড়ি':'NN','জোতজমি':'NN','জোতদণ্ড':'NN','জোতদার':'NN','জোতা':'NN',
'জোতানো':'VB','জোতার':'NN','জোত্স্না-মধুর':'NNP','জোন':'NN','জোনাকি':'NN','জোনে':'NN','জোবাই':'NN',
'জোয়ানে':'NN','জোর':'NN','জোরও':'NN','জোরকরে':'NN','জোরজনগনের':'NN','জোরদার':'RB','জোরপূর্বক':'NN',
'জোরহাট':'NN','জোরালো':'JJ','জোরালোভাবে':'NN','জোরে':'NN','জোর্তিষীমূলক':'NN','জোলো':'JJ','জোশ':'NN',
'জোসে':'NN','জোহর':'NN','জোহিলা':'NN','জোড়':'NN','জোড়াতালি':'NN','জোড়াসাঁকো':'NNP','জোড়ে':'NN',
'জোয়া':'NN','জোয়ার':'NN','জোয়ারী':'NN','জোয়ারের':'NN','জোয়াল':'NN','জোয়েলিকের':'NN','জৌঞ্চী':'NN',
'জৌনপুর':'NN','জৌলুসের':'NN','জ্জন':'NN','জ্ঞ':'NN','জ্ঞাত':'NN','জ্ঞাতব্য':'JJ','জ্ঞাতযৌবনা':'NN',
'জ্ঞাতা':'JJ','জ্ঞাতার্থে':'NN','জ্ঞাতি':'NN','জ্ঞান-তত্ব':'NN','জ্ঞান':'NN','জ্ঞানগম্য':'JJ','জ্ঞানগর্ভ':'NN',
'জ্ঞানচক্ষু':'NN','জ্ঞানচর্চার':'NN','জ্ঞানতত্ব':'NN','জ্ঞানদা':'NN','জ্ঞানপাপি':'NN','জ্ঞানপূর্ণ':'JJ','জ্ঞানবিজ্ঞান':'NN',
'জ্ঞানবৃক্ষ':'NN','জ্ঞানময়':'JJ','জ্ঞানরাশির':'NN','জ্ঞানলাভ':'NN','জ্ঞানশূণ্যতা':'NN','জ্ঞানহীন':'JJ','জ্ঞানহীনতা':'NN',
'জ্ঞানাতীত':'JJ','জ্ঞানার্জন':'NN','জ্ঞানি':'NN','জ্ঞানীগুনিদের':'NN','জ্ঞানে':'NN','জ্ঞানেন্দ্রিয়':'NN','জ্ঞানের':'NN',
'জ্ঞানেশ্বরী':'NN','জ্ঞাপক':'NN','জ্ঞাপন':'VB','জ্ঞাপিত':'JJ','জ্ঞেয়':'NN','জ্ঞ্যনিদের':'NN','জ্ঞ্যানী':'NN',
'জ্ন্য':'NN','জ্বর':'NN','জ্বরে':'NN','জ্বল':'JJ','জ্বলছিল':'VB','জ্বলতে':'VB','জ্বলন্ত':'NN',
'জ্বলবেন':'VB','জ্বলা':'NN','জ্বলুক':'VB','জ্বলুনি':'NN','জ্বলে':'NN','জ্বালা':'NN','জ্বালাইতাছে':'VB',
'জ্বালাও':'NN','জ্বালাতে':'VB','জ্বালানি':'NN','জ্বালানী':'NN','জ্বালানো':'NN','জ্বালামুখী':'NN','জ্বালামূখীয়':'JJ',
'জ্বালায়':'NN','জ্বালিনি':'NN','জ্বালিয়েছে':'VB','জ্বি':'UH','জ্বিনা':'NN','জ্বী':'NN','জ্যা':'NN',
'জ্যাক':'NNP','জ্যাকপট':'NN','জ্যাকরেণ্ডা':'NN','জ্যাকলিন':'NN','জ্যাকেট':'NN','জ্যাজ':'NN','জ্যাঠতুতো':'JJ',
'জ্যাঠা':'NN','জ্যান্ত':'JJ','জ্যাপানিস্':'NN','জ্যাম':'NN','জ্যামিতিক':'JJ','জ্যামিতির':'NN','জ্যামে':'NN',
'জ্যেঠু':'NN','জ্যেষ্ঠতা':'NN','জ্যেষ্ঠা':'NN','জ্যৈষ্ঠ':'NNP','জ্যোতি':'NN','জ্যোতিদাদা':'NNP','জ্যোতিবা':'NN',
'জ্যোতির্বিজ্ঞান':'NN','জ্যোতির্বিদ':'NN','জ্যোতির্ময়':'JJ','জ্যোতির্লিঙ্গ':'NN','জ্যোতিলালের':'NNP','জ্যোতিষ-চক্র':'NN','জ্যোতিষ-বিদ্যা':'NN',
'জ্যোতিষ':'NN','জ্যোতিষবিদ্যা':'NN','জ্যোতিষশাস্ত্র':'NN','জ্যোতিষী':'NN','জ্যোতিসম্পন্ন':'JJ','জ্যোত্স্না':'NN','জড়':'NN',
'জড়তা':'NN','জড়বুদ্ধির':'NN','জড়াই':'VBG','জড়ান':'NNV','জড়ানো':'NN','জড়ি':'VB','জড়িত':'NN',
'জড়িতগুলারে':'NN','জড়িতদের':'NN','জড়িতদেড়':'VBN','জড়িতের':'NN','জড়ো':'NN','জয়-জয়বন্তী':'NN','জয়':'NN',
'জয়আর':'NN','জয়কার':'NN','জয়টা':'NN','জয়তু':'NN','জয়ত্সেন':'NN','জয়দ্রথ':'NN','জয়নব':'NN',
'জয়ন্ত':'NN','জয়ন্তী':'NN','জয়পিএসজিতে':'NN','জয়পুর':'NN','জয়পুরহাটেও':'NN','জয়প্রকাশ':'NN','জয়বাংলা':'NN',
'জয়মল্লার':'NN','জয়মাল্য':'NN','জয়রাতটা':'NN','জয়রামবাটি':'NNP','জয়রামবাটিতেও':'NNP','জয়রামবাটীতে':'NNP','জয়লাভ':'VBG',
'জয়শ্রী':'NN','জয়সল':'NN','জয়সিংহ':'NN','জয়সুরিয়া':'NN','জয়স্তম্ভ':'NN','জয়া':'NN','জয়ানকী':'NN',
'জয়ানন্দ':'NN','জয়াবতী':'NN','জয়াবহা':'NN','জয়ী':'NN','জয়ীলাভ':'VBG','জয়ে':'NN','জয়েণ্ট':'NN',
'জয়েতী':'NN','জয়েত্-গৌরী':'NN','জয়েত্':'NN','জয়েত্কল্যাণ':'NN','জয়েত্শ্রী':'NN','জয়েন্ট':'NN','জয়ের':'NN',
'জয়েসের':'NNP','ঝ':'NN','ঝঁপানী':'NN','ঝকঝক':'VB','ঝকঝকে':'NN','ঝকমক':'NN','ঝক্কর':'NNP',
'ঝক্কির':'NN','ঝখান':'NN','ঝগড়া-ঝাটি':'NN','ঝগড়া':'NN','ঝগড়াটি':'JJ','ঝগড়ুটে':'NN','ঝগড়া':'NN',
'ঝঙ্কার':'NN','ঝছেন':'VB','ঝজনতা':'NNS','ঝজ্জর':'NN','ঝঝুঝুবী':'NN','ঝঞ্ঝা':'NN','ঝঞ্ঝাটে':'NN',
'ঝঞ্ঝার':'NN','ঝটকা':'NN','ঝটকানো':'VB','ঝটপট':'RB','ঝটিকা':'NN','ঝটিতে':'NN','ঝড়':'NN',
'ঝড়বেরি':'NN','ঝড়া':'NN','ঝড়ানো':'VB','ঝড়ে':'VB','ঝতাম':'VB','ঝতেই':'NN','ঝনকবাত':'NN',
'ঝনঝন':'NN','ঝনস':'NN','ঝপটানী':'NN','ঝপতাল':'NN','ঝপাব':'NN','ঝপিয়া':'NN','ঝপ্পানী':'NN',
'ঝবঝবী':'NN','ঝবধরী':'NN','ঝম-ঝম':'NN','ঝমেলাবাজ':'JJ','ঝর':'NN','ঝরঝরে':'JJ','ঝরতে':'VB',
'ঝরনা':'NN','ঝরা':'VB','ঝরাবে':'VB','ঝরিয়ে':'VB','ঝরে':'NNS','ঝরোকা':'NN','ঝর্ণা':'NN',
'ঝর্ণাধারা':'NNS','ঝর্সুগুডা':'NN','ঝলক':'NN','ঝলকানো':'VB','ঝলমল':'NN','ঝলমলে':'JJ','ঝলসানো':'NN',
'ঝলসে':'NN','ঝলাম':'VB','ঝলেও':'RP','ঝলেন':'VB','ঝষি':'NN','ঝাঁক':'NN','ঝাঁকড়া':'JJ',
'ঝাঁকা':'NN','ঝাঁকানো':'VB','ঝাঁকিয়ে':'VB','ঝাঁকুনি':'NN','ঝাঁখ':'NN','ঝাঁজি':'NN','ঝাঁঝ':'NN',
'ঝাঁঝরা':'NN','ঝাঁট':'NN','ঝাঁড়া':'NN','ঝাঁপ':'NN','ঝাঁপাঝাঁপি':'NN','ঝাঁপান':'NN','ঝাঁপিয়ে':'VB',
'ঝাঁসি':'NN','ঝাউ':'NN','ঝাউলাকিছুই':'NN','ঝাজরা':'NN','ঝাড়-ফুঁক':'NN','ঝাড়':'NN','ঝাড়খণ্ড':'NN',
'ঝাড়ন':'NN','ঝাড়ফুঁক':'NN','ঝাড়া':'NN','ঝাড়াই':'NN','ঝাড়াইনো':'VB','ঝাড়াইবাছাই':'NN','ঝাড়াইযের':'NN',
'ঝাড়ানো':'VB','ঝাড়ার':'NN','ঝাড়িদার':'JJ','ঝাড়ু':'NN','ঝাণ্ডা':'NN','ঝাতে':'VB','ঝানো':'NNV',
'ঝান্ডা':'NN','ঝাপ':'NN','ঝাপটায়':'NN','ঝাপসিয়ে':'VB','ঝাপিয়ে':'VBG','ঝাবুয়া':'NN','ঝামটা':'NN',
'ঝামুমো':'NN','ঝামেলা':'NN','ঝামেলাও':'JJ','ঝামেলায়':'JJ','ঝায়':'VB','ঝারখণ্ড':'NN','ঝারসুগুডা':'NN',
'ঝারি':'NN','ঝারের':'NN','ঝার্সগুড':'NN','ঝাল':'NN','ঝালকাঠীতে':'NN','ঝালমুড়ির':'NN','ঝালর':'NN',
'ঝালা':'VB','ঝালাই':'NN','ঝালাইকারী':'NN','ঝালাপালা':'NN','ঝালাবাড়':'NN','ঝালোর':'NN','ঝাড়খণ্ডে':'NNP',
'ঝাড়ি':'NN','ঝি':'NN','ঝিঁঝিঁ':'NN','ঝিকঝিক':'VB','ঝিঙুর':'NN','ঝিঙ্গিনী':'NN','ঝিঞ্ঝী':'NN',
'ঝিনঝিন':'NN','ঝিনি':'VB','ঝিনুক':'NN','ঝিম':'NN','ঝিমন্ত':'NN','ঝিমানো':'NN','ঝিমিয়ে':'NN',
'ঝিল':'NN','ঝিলমিল':'NN','ঝিলিক':'JJ','ঝিলে':'NN','ঝিল্লি':'NN','ঝিল্লীযুক্ত':'JJ','ঝিল্লীসমন্বিত':'JJ',
'ঝিয়া':'VB','ঝীঙ্গা':'NN','ঝুঁকছে':'VBG','ঝুঁকি':'NN','ঝুঁকিতে':'NN','ঝুঁকিপূর্ণ':'NN','ঝুঁকিময়রাতের':'NN',
'ঝুঁকির':'NN','ঝুঁটি':'NN','ঝুকছে':'NN','ঝুকি':'NN','ঝুকিপূর্ন':'NN','ঝুটি':'NN','ঝুড়ি':'NN',
'ঝুনঝুন':'NN','ঝুপড়ি':'NN','ঝুপড়িতে':'NN','ঝুবঝুবি':'NN','ঝুম':'VB','ঝুমক':'NN','ঝুমঝুমি':'NN',
'ঝুমর':'NN','ঝুমুর':'NN','ঝুরি':'NN','ঝুরু':'RB','ঝুলছে':'VBG','ঝুলটা':'NN','ঝুলতে':'NN',
'ঝুলন':'NN','ঝুলনী-বাগলী':'NN','ঝুলনী':'NN','ঝুলন্ত-পুল':'NN','ঝুলন্ত-সাঁকো':'NN','ঝুলন্ত':'JJ','ঝুলপি':'NN',
'ঝুলা':'NN','ঝুলাইয়েন':'NN','ঝুলানো':'VBG','ঝুলি':'NN','ঝুলিয়েছে':'VBN','ঝুলে':'NN','ঝুড়ি':'NN',
'ঝুড়ির':'NNS','ঝেঁপে':'VB','ঝেতে':'VB','ঝেড়ে':'VB','ঝোঁক':'NN','ঝোঁকানো':'NN','ঝোড়া':'NN',
'ঝোড়ো':'JJ','ঝোতা':'NN','ঝোপ':'NN','ঝোপঝাড়':'NN','ঝোপঝাড়ে':'VB','ঝোপড়ি':'NN','ঝোরা':'NN',
'ঝোল':'NN','ঝোলদার':'JJ','ঝোলা':'VB','ঝোলানো':'NN','ঝোলে':'VB','ঝ্যুল':'NNP','ঝড়':'NN',
'ঝড়ের':'NN','ঞ':'NN','ঞতাই':'NN','ঞতার':'NN','ঞদের':'NN','ঞাতি':'NN','ঞানী':'JJ',
'ঞানে':'NN','ঞাপণ':'NN','ঞাসা':'NN','ঞ্চন':'NNP','ঞ্চম':'CD','ঞ্চল':'JJ','ঞ্চি':'NN',
'ঞ্চয়':'NN','ঞ্ছা':'NN','ঞ্জক':'JJ','ঞ্জন':'NNP','ঞ্জল':'JJ','ঞ্জী':'NNP','ঞ্জয়':'NNP',
'ট-এর':'NNP','ট-বর্গ':'NN','ট-বর্গীয়':'JJ','ট':'NN','টং':'VB','টইটুম্বুর':'NN','টক-মিষ্টি':'NN',
'টক':'NN','টকত্ব':'NN','টকভাব':'NN','টকমিষ্টি':'JJ','টকশো':'NN','টকশোগুলো':'NNS','টকশোতে':'NN',
'টকা-তোপ':'NN','টকিজ':'NN','টকীয়':'JJ','টকে':'VB','টকের':'NN','টক্কর':'NN','টক্র':'NN',
'টখাট':'NNP','টগণ':'NN','টগবগ':'NN','টগর':'NN','টগরগোড়া':'NN','টগলগ':'NN','টঙ্ক':'NN',
'টঙ্কন':'NN','টঙ্কার':'NN','টঙ্সরী':'NN','টছিল':'VB','টছেন':'VB','টজনক':'JJ','টটার':'NN',
'টড়িয়া':'NN','টতাম':'VB','টথা':'NN','টদান':'NN','টদের':'NN','টন':'NN','টনটন':'VB',
'টনটনানি':'NN','টনসিল':'NN','টনার':'NN','টনি':'NN','টনির':'NNP','টনের':'NNS','টন্সিল':'NN',
'টপ':'NN','টপকানো':'VBG','টপকে':'NN','টপটপ':'NN','টপমাল':'NN','টপার':'NN','টপিক':'NN',
'টপিকস':'NNS','টপ্পা':'NN','টব':'NN','টবেই':'VB','টব্য':'NN','টম':'NNP','টমকী':'NN',
'টমটম':'NN','টমসনকে':'NNP','টমাস':'NNP','টমি':'NN','টমেটোর':'NN','টরকনী':'NN','টরগী':'NN',
'টরন্টো':'NN','টরাবা':'NN','টর্চ':'NN','টলটে':'VB','টলমল':'NN','টলমলানি':'NN','টলস্টয়':'NNP',
'টলারেন্স':'NN','টলিউড':'NN','টলে':'VB','টলেট':'NN','টলেমি':'NNP','টলেমিদের':'NNP','টস':'NN',
'টস্থ':'NN','টহরকটঠা':'NN','টহল':'NN','টহীন':'JJ','টা':'IN','টাঁক':'NN','টাঁকা':'VB',
'টাঁকি':'NN','টাঁড়':'NN','টাংগাইল':'NN','টাংগি':'NN','টাং্গাইল':'NN','টাঅসাধারণ':'NN','টাই':'NN',
'টাইগার':'NN','টাইগারদের':'NNS','টাইগারেরা':'NNS','টাইগার্স':'NN','টাইগ্রিনা':'NN','টাইট':'NNP','টাইটান':'NN',
'টাইটেনিয়াম':'NN','টাইটেলটা':'NN','টাইপ':'NN','টাইপকৃত':'JJ','টাইপরাইটার':'NN','টাইপিং':'NN','টাইপের':'NN',
'টাইফ-রাইটার':'NN','টাইফয়েড':'NN','টাইম':'NN','টাইমটেবল':'NN','টাইমস':'NNS','টাইমার':'NN','টাইমিং':'NN',
'টাইল':'NNS','টাউট':'NN','টাউনশিপ':'NN','টাও':'NN','টাওয়ার':'NN','টাওয়ারের':'NN','টাক':'NN',
'টাকওলা':'NN','টাকওয়ালা':'JJ','টাকলা':'NN','টাকা-খোর':'JJ','টাকা-পয়সা':'NN','টাকা-পয়সার':'JJ','টাকা':'NN',
'টাকাইতো':'NN','টাকাইনা':'NNP','টাকাএবার':'NN','টাকাও':'NN','টাকাওয়ালদের':'NNS','টাকাকে':'NN','টাকাকড়ি-সৃজনের':'NN',
'টাকাখুচরা':'NN','টাকাগুলো':'NN','টাকাটা':'NN','টাকাতে':'NN','টাকাতেও':'NN','টাকাপয়সা':'NN','টাকাব্যবসা':'NN',
'টাকামেগা':'NN','টাকায়':'NN','টাকারই':'NN','টাকারতো':'NN','টাকাশ্রমিকের':'NN','টাকাহা':'NN','টাকিলা':'NN',
'টাকু':'NN','টাকুয়া':'NN','টাকে':'NN','টাক্স':'NN','টাঙাচ্ছে':'VB','টাঙানো':'NN','টাঙিয়ে':'VB',
'টাঙ্গস্টেন':'NN','টাঙ্গাইল':'NN','টাঙ্গানো':'VB','টাঙ্গি':'NN','টাচফোন':'NN','টাচস্ক্রিন':'NN','টাটকা':'NN',
'টাটানগর':'NN','টাটায়':'NN','টাট্টু':'NN','টাতাই':'NN','টাতে':'IN','টাদশ':'CD','টান-টান':'RB',
'টান':'NN','টানছে':'VBG','টানটান':'NN','টানতে':'VB','টানা':'NN','টানাটানি':'NN','টানানো':'VB',
'টানাপাখা':'NN','টানার':'NN','টানায়ে':'VB','টানি':'VB','টানিয়া':'VB','টানিয়েছিলেন':'VBD','টানী':'JJ',
'টানে':'NNS','টানেল':'NN','টানেহয়তো':'NN','টানো':'NNV','টাফ':'IN','টাফি':'NN','টাবা':'NN',
'টাবালেবু':'NN','টামি':'NN','টায়':'NN','টার':'NN','টারজেনের':'NNP','টারত':'NN','টারবাইন':'NN',
'টারবিয়াম':'NN','টারি':'NN','টারে':'NN','টার্নিং':'VBG','টার্ম':'NN','টার্মে':'NN','টাল':'NN',
'টালবাহানা':'VB','টালমাটাল':'JJ','টালাক':'JJ','টালি':'NN','টালে':'NN','টাস্ক':'NN','টাস্কিত':'VBN',
'টাস্ট':'NN','টায়রা':'NN','টি.বি.':'NN','টি':'NN','টিঁয়া':'NN','টিংকু':'NNP','টিআই':'NN',
'টিআইবির':'NN','টিউটর':'NN','টিউনিস':'NN','টিউনিসিয়ান':'JJ','টিউনীশিয়া':'NN','টিউনীশিয়ান':'NN','টিউব':'NN',
'টিউবওয়েল':'NN','টিউবওয়েলের':'NNS','টিউবে':'NN','টিউমার':'NN','টিউলিপ':'NN','টিউশনি':'NN','টিএইচ':'NN',
'টিএনও':'NN','টিএমসি':'NN','টিক':'NN','টিকটিক':'NN','টিকঠি':'NN','টিকড়া':'NN','টিকতে':'NN',
'টিকবন':'JJS','টিকবে':'VB','টিকভাবেই':'RB','টিকমগড়':'NN','টিকর':'JJ','টিকল':'NN','টিকলী':'NN',
'টিকসই':'JJ','টিকা':'NN','টিকি':'NN','টিকিটি':'NNS','টিকিটে':'NN','টিকিয়া':'NN','টিকে':'NN',
'টিকেট':'NNS','টিকেনাকাজেই':'NN','টিক্কা':'NN','টিগত':'JJ','টিগুসিগাল্পা':'NN','টিঙ্কচার-ওপিয়াই':'NN','টিঙ্কচার-কার্ডিমাম':'NN',
'টিঙ্কচার-স্টিল':'NN','টিচারকে':'NN','টিচারদের':'NNS','টিচিংস':'NNP','টিচিঙ':'NN','টিজম':'NN','টিজিং':'VBG',
'টিটকারি':'VBG','টিটি':'NN','টিটুয়েন্টি':'NN','টিটুয়েন্টিতুষার':'NN','টিটেনাস':'NN','টিটোয়েন্টি':'NN','টিতে':'NN',
'টিদ্যা':'NN','টিন':'NN','টিনের':'NN','টিন্ডা':'NN','টিপ':'NN','টিপটিপ':'NN','টিপস':'NN',
'টিপু':'NN','টিপ্পণী':'NN','টিপ্পনী':'NN','টিপ্সহহি':'NNS','টিফিন':'NN','টিফিনের':'NN','টিবি':'NN',
'টিভি':'NN','টিভির':'NN','টিভে':'NN','টিম':'NN','টিমএক':'NN','টিমকেই':'NN','টিমটা':'NN',
'টিমটিম':'VB','টিমথির':'NNP','টিমে':'NN','টিমের':'NN','টিরিনস':'NN','টিরে':'NN','টিলা':'NN',
'টিলাযুক্ত':'NN','টিলেহু':'NN','টিসি':'NN','টিসিবি':'NN','টিস্':'NN','টিয়া':'NN','টিয়াপাখি':'NN',
'টিয়ার':'NN','টিয়ে':'VB','টি২০':'NN','টীকা-টিপ্পনি':'NN','টীকা':'NN','টীকাযুক্ত':'NN','টীকার':'NN',
'টীটী':'NN','টীতে':'NNP','টীম':'NN','টীমের':'NN','টু-পাইস':'NN','টু':'NN','টুইট':'NNS',
'টুইটার':'NN','টুইস্ট':'NN','টুক':'NN','টুকটাক':'NN','টুকরি':'NN','টুকরু':'NNS','টুকরো':'NN',
'টুকলিবাজ':'NN','টুকি':'NN','টুকুই':'NN','টুজি':'NN','টুটুকা':'NN','টুটেনখামেন':'NNP','টুতে':'NN',
'টুথ':'NN','টুথপাউডার':'NN','টুথপেস্ট':'NN','টুথব্রাশ':'NN','টুন':'NN','টুনকি':'NN','টুনটুন':'NN',
'টুনীশিয়ান':'NN','টুপি':'NN','টুপির':'NN','টুবেলিয়ান':'NN','টুবেলু':'NN','টুমকী':'NN','টুর':'NN',
'টুরকির':'NN','টুরিস্ট':'NN','টুর্ণামেন্ট':'NN','টুর্নামেণ্টে':'NN','টুর্নামেন্টে':'NN','টুল':'NN','টুসু':'NN',
'টুয়েন্টি':'NN','টেইন':'NNP','টেক':'NN','টেকনলজিতে':'NN','টেকনাফ':'NN','টেকনিক':'NN','টেকনিকাল':'JJ',
'টেকনিক্যালবিদ্যালয়':'NN','টেকনিশিয়ান':'NN','টেকনোলজি':'NN','টেকর':'NNP','টেকসই':'NN','টেকা':'NN','টেকে':'NN',
'টেক্কা':'NN','টেক্নেটিয়াম':'NN','টেক্স':'NN','টেক্সাস':'NN','টেক্সাসী':'NNP','টেক্সের':'NN','টেঙ্গে':'NN',
'টেছে':'VB','টেট':'NNP','টেটকা':'NN','টেণ্ডার':'NN','টেন':'NN','টেনশনে':'NN','টেনস':'NN',
'টেনিস':'NN','টেনে':'NN','টেনেভারত':'NN','টেনেহিঁচড়ে':'VBG','টেন্টলুম':'NN','টেন্ডার':'NN','টেন্ডারবাজি':'VBG',
'টেন্ডারে':'NN','টেন্ডুলকারকে':'NN','টেন্ডুলকারের':'NN','টেন্ডুল্কার':'NN','টেপ-রেকর্ডার':'NN','টেপ':'NN','টেপরেকর্ডার':'NN',
'টেপা':'NN','টেপাটেপি':'NN','টেপি':'NN','টেবলেট':'NN','টেবিল':'NN','টেবিলে':'JJ','টেবিলের':'NN',
'টেবেলভুক্ত':'JJ','টেমস্-এর':'NNP','টেম্পারিং':'NN','টেম্পারেচার':'NN','টেম্পো':'NN','টের':'NN','টেররিস্ট':'NN',
'টেরিডোফাইটার':'NNP','টেরিফ':'NN','টেরোরিজম':'NN','টেরোস্টিদের':'NNS','টেলড':'NN','টেলার':'NN','টেলিকম':'NN',
'টেলিকমিউনিকেশন':'NNS','টেলিকমে':'NN','টেলিগ্রাফ':'NN','টেলিটক':'NN','টেলিটকে':'NN','টেলিটকেরফোর':'NN','টেলিনর':'NN',
'টেলিফোন':'NN','টেলিভিজন':'NN','টেলিভিশনে':'NN','টেলিযোগাযোগ':'NNS','টেলিস্কোপ':'NN','টেলুরিয়াম':'NN','টেলে':'NN',
'টেষ্টেও':'NN','টেসলা':'NN','টেস্ট':'NN','টেস্টটিউব':'NN','টেস্টনো':'VB','টেস্টার':'NN','টেস্টে':'JJS',
'টেস্টের':'NN','টোল':'NN','টোয়েন্টি':'NN','টৈয়াঁ':'NN','টোংক':'NN','টোকনা':'NN','টোকরি':'NN',
'টোকা':'VB','টোকাম্যাক':'NN','টোকাস':'NNP','টোকিয়ো':'NN','টোকোফেরাল':'NN','টোগো':'NN','টোগোলিজ':'JJ',
'টোগোলিস':'NN','টোটল':'NNP','টোটা':'NN','টোটি':'NN','টোড':'NN','টোড়ী':'NN','টোনদা':'NNP',
'টোন্স':'NN','টোপ':'NN','টোপে':'NN','টোপোলজি':'NN','টোবর':'NNP','টোবাকোতে':'NNP','টোবাগো':'NN',
'টোম':'NN','টোমোগ্রাফ':'NN','টোরী':'NN','টোল':'NN','টোলে':'NN','টোস্ট':'NN','টোয়েনের':'NN',
'টোয়েন্টি':'NN','টোয়ের':'NN','ট্টা':'NN','ট্টী':'NNP','ট্টো':'NNP','ট্বেনসাঙ্গ':'NN','ট্যক্সি':'NN',
'ট্যম':'NN','ট্যাঁক':'NN','ট্যাঁড়া-ব্যাঁকা':'JJ','ট্যাংক':'NN','ট্যাংরা':'NN','ট্যাকটিক্স':'NNS','ট্যাকলিং':'NN',
'ট্যাক্স':'NN','ট্যাক্সধিকার':'NNS','ট্যাক্সপেয়ার':'NN','ট্যাক্সভ্যাট':'NN','ট্যাক্সি':'NN','ট্যাক্সে':'NN','ট্যাক্সোন':'NN',
'ট্যাগ':'NNS','ট্যাগে':'NN','ট্যাঙ্ক':'NN','ট্যাঙ্কারের':'NN','ট্যান':'NN','ট্যাব':'NN','ট্যাবলো':'NN',
'ট্যারা':'NN','ট্যালেন্ট':'NN','ট্যাস্ক':'NN','ট্যুর':'NN','ট্যেক্সের':'NN','ট্রন':'NN','ট্রপি':'NN',
'ট্রপিটা্রও':'NN','ট্রপোস্ফিয়ার':'NN','ট্রফি':'NN','ট্রফিতে':'NN','ট্রমকার্ড':'NN','ট্রমাকে':'NN','ট্ররচার':'NN',
'ট্রস':'NN','ট্রাই':'NN','ট্রাইডেন্ত':'NN','ট্রাইবুনাল':'NN','ট্রাউট':'NN','ট্রাঙ্ক':'NN','ট্রাজেডি':'NN',
'ট্রাজেডীর':'NN','ট্রানজিট':'NN','ট্রানজিস্টার':'NN','ট্রানসেকশানে':'NN','ট্রান্সফর্মার':'NN','ট্রান্সলেট':'NN','ট্রাফিক':'NN',
'ট্রাবানকোর':'NN','ট্রাভেল':'NN','ট্রাম-বাসের':'NN','ট্রাম':'NN','ট্রাম্প':'NN','ট্রাম্পকে':'NN','ট্রাম্পেরই':'NN',
'ট্রায়াড':'NNP','ট্রাস্ট-এর':'NNP','ট্রাস্ট':'NN','ট্রাস্টের':'NN','ট্রায়ালটুকুই':'NN','ট্রি':'NN','ট্রিটমেন্ট':'NN',
'ট্রিটি':'NN','ট্রিনিডাডের':'NNP','ট্রিপ':'NNP','ট্রিপল':'NN','ট্রিপ্টোফেন':'NN','ট্রিমারের':'NN','ট্রী':'NN',
'ট্রে-কারনাইয়া':'NNP','ট্রে':'NN','ট্রেইনিকেও':'NN','ট্রেইলার':'NN','ট্রেক':'NN','ট্রেগ':'NN','ট্রেড-ইউনিয়ন':'NN',
'ট্রেড':'NNP','ট্রেডইউনিয়ন':'NNS','ট্রেডমার্ক':'NN','ট্রেডিশন':'NN','ট্রেণ্টএর':'NNP','ট্রেন':'NN','ট্রেনটা':'NN',
'ট্রেনিং':'NN','ট্রেনে':'NN','ট্রেসিং':'NN','ট্রো':'NN','ট্র্যাক':'NN','ট্র্যাকিওফাইট':'NN','ট্র্যাক্টার':'NN',
'ট্র্যাজিক':'NN','ট্রয়':'NN','ট্্ল':'NN','টয়ট্রেন':'NN','টয়লেট':'NN','ট‍্যাক্স':'NN','ঠ':'NN',
'ঠক-ঠক':'NN','ঠক':'JJ','ঠকছে':'VB','ঠকঠক':'NN','ঠকঠকিয়ে':'VB','ঠকবাজি':'VB','ঠকাইয়ের':'NNP',
'ঠকাচ্ছেন':'VB','ঠকাতে':'NN','ঠকানো':'VB','ঠকি':'NN','ঠকুর':'NN','ঠকে':'VB','ঠকের':'NN',
'ঠগ':'NN','ঠগবিদ্যা':'NN','ঠগমুরি':'NN','ঠগলাড্ডু':'NN','ঠগীনি':'NN','ঠঠবা':'NN','ঠতলই':'VB',
'ঠন':'NN','ঠনঠনে':'NN','ঠনেই':'VB','ঠনের':'NN','ঠপটে':'VB','ঠবার':'NNV','ঠবেন':'VB',
'ঠাঁই':'NN','ঠাকই':'JJ','ঠাকুমা':'NN','ঠাকুরকে':'NN','ঠাকুরত্ত':'NN','ঠাকুরদের':'NN','ঠাকুরপো':'NN',
'ঠাকুরমার':'NN','ঠাকুরের':'NNP','ঠাকুর্দা':'NN','ঠাট-বাট':'NN','ঠাট':'NN','ঠাটদার':'JJ','ঠাট্টা':'NN',
'ঠাট্টাকিন্তু':'NN','ঠাণা':'NN','ঠাণ্ডা':'NN','ঠাতা':'NN','ঠাত্':'RB','ঠানে':'NN','ঠানো':'NNV',
'ঠান্ডা':'NN','ঠাপানো':'VB','ঠামো':'VB','ঠাসা':'NN','ঠিক-ঠাক':'RB','ঠিক':'NN','ঠিকইতো':'NN',
'ঠিকও':'JJ','ঠিকঠাক':'NN','ঠিকঠাকই':'RB','ঠিকতবে':'NN','ঠিকতমত':'NN','ঠিকভাবে':'RB','ঠিকমত':'NN',
'ঠিকরে':'VB','ঠিকসময়ে':'NN','ঠিকা':'NN','ঠিকাদার':'JJ','ঠিকাদারি':'NN','ঠিকানা':'NN','ঠিকিই':'NN',
'ঠিকে':'NN','ঠিকেদারি':'NN','ঠিক্বই':'NN','ঠিটা':'NN','ঠিতে':'VB','ঠিয়া':'VB','ঠীকে':'NN',
'ঠুঁটো':'NN','ঠুকতে':'NN','ঠুকতেই':'VB','ঠুকে':'NN','ঠুকেই':'VB','ঠুটু':'NN','ঠুনকো':'JJ',
'ঠুমরী':'NN','ঠুরে':'VB','ঠুর্রী':'NN','ঠুলি':'NN','ঠুস্সী':'NN','ঠেক':'NN','ঠেকছে':'VB',
'ঠেকনা':'NN','ঠেকাও':'VB','ঠেকাদার':'NN','ঠেকানো':'VB','ঠেকাব':'VB','ঠেকায়':'VB','ঠেকুয়া':'NN',
'ঠেকে':'VB','ঠেছে':'VB','ঠেনি':'VB','ঠেলা':'NN','ঠেলাগাড়ি':'NN','ঠেলাঠলি':'VB','ঠেলাঠেলি':'NN',
'ঠেলার':'NN','ঠেলায়':'VB','ঠেলায়ই':'NN','ঠেলি':'VB','ঠেলে':'NN','ঠেস':'NN','ঠেহে':'NN',
'ঠোঁট':'NN','ঠোঁটকাটা':'JJ','ঠোঁটের':'NN','ঠোঁঠা':'NN','ঠোকর':'NN','ঠোক্কর':'NN','ঠোঙা':'NN',
'ঠোট':'NN','ঠোটস্থ':'NN','ঠ্যাকা':'VB','ঠ্যাঙওয়ালা':'JJ','ঠ্যালা':'NN','ঠ্যালায়':'NN','ড-এর':'NNP',
'ড':'NN','ডংগ':'NN','ডঃ':'NN','ডঃভীমরাও':'NN','ডক':'NN','ডকটরেটের':'NN','ডকিউমেন্ট':'NN',
'ডকুমেণ্টশন':'NN','ডকুমেণ্টারী':'NN','ডকুমেন্টরী':'NN','ডকের':'NN','ডক্টর':'NN','ডক্স':'NNP','ডগ':'NN',
'ডগা':'NN','ডগি':'NN','ডঙ্কা':'NN','ডজন':'NN','ডট':'NN','ডটির':'NN','ডন':'NN',
'ডনীয়':'JJ','ডনের':'NNP','ডপোরিজো':'NN','ডবরু':'NN','ডবল':'JJ','ডবলস্':'NN','ডবের':'NNP',
'ডব্লিউ':'NN','ডম-ডম':'NN','ডমডম':'VB','ডমরু':'NN','ডমিঙ্গো':'NN','ডমিনিক':'NN','ডমিনেট':'NN',
'ডমেস্টিক':'NN','ডর':'NN','ডরহীন':'NN','ডরোথি':'NNP','ডলকে':'NN','ডলফিন':'NN','ডলার':'NN',
'ডলারশপ':'NN','ডলারের':'NN','ডলীর':'NN','ডহোম':'NN','ড়':'NN','ড়ছে':'VB','ড়বি':'NNP',
'ড়বে':'VB','ড়াও':'VB','ড়ার':'NN','ড়িত':'JJ','ড়ির':'NN','ড়ীর':'NN','ড়েন':'VB',
'ডা.':'NN','ডাঁট':'VB','ডাঁটা':'NN','ডাঁবু':'NN','ডাঁরহরা':'NN','ডাঁশ':'NN','ডাঁয়া':'NN',
'ডাঁয়ে-বাঁয়ে':'RB','ডাংগুলি':'NN','ডাঃ':'NN','ডাই-অক্সাইড':'NN','ডাই':'NN','ডাইএনসেফালোন':'NN','ডাইক':'NN',
'ডাইগনোষটিক':'NN','ডাইথেন':'NN','ডাইনামাইট':'NN','ডাইনামিক্স':'NN','ডাইনি':'NN','ডাইনেমো':'NN','ডাইভ':'NN',
'ডাইভে':'NN','ডাইরিতে':'NN','ডাইরেক্ট':'NN','ডাইলক':'NN','ডাইস':'NNP','ডাইহাইড্রোঅর্গোস্ট্রোল':'NN','ডাইয়ের':'NN',
'ডাউন':'NN','ডাউনটাউন':'NN','ডাউনপেমেন্ট':'NN','ডাউনলোড':'NN','ডাউনলোডিং':'NN','ডাউনে':'NN','ডাউরাউকাউলী':'NN',
'ডাক-চৌকি':'NN','ডাক-ব্যয়':'NN','ডাক':'NN','ডাকগাড়ী':'NN','ডাকঘর':'NN','ডাকঘরে':'NN','ডাকটিকিট':'NN',
'ডাকত':'VB','ডাকতি':'NN','ডাকতে':'VB','ডাকতেন':'NN','ডাকনাম':'NN','ডাকবাংলো':'NN','ডাকযোগে':'NN',
'ডাকল':'NN','ডাকসু':'NN','ডাকা':'NN','ডাকাডাকি':'NN','ডাকাত':'NN','ডাকাতকালীর':'NNP','ডাকাতদের':'NN',
'ডাকাতরা':'NN','ডাকাতিতে':'NN','ডাকাতিব্যাংক':'NN','ডাকাতির':'NN','ডাকাতের':'NN','ডাকাবেন':'VB','ডাকার':'NN',
'ডাকি':'NN','ডাকে':'NN','ডাকেএটাই':'NN','ডাকেন':'NN','ডাকেনফিল্ড':'NN','ডাকের':'NN','ডাক্কারী':'NN',
'ডাক্তারই':'NN','ডাক্তারখানায়':'NN','ডাক্তারদের':'NN','ডাক্তারবৌ':'NN','ডাক্তারের':'NN','ডাগ্গর':'NN','ডাঙ্কী':'NN',
'ডাঙ্গ':'NN','ডাঙ্গরী':'NN','ডাঙ্গোরী':'NN','ডাচ':'NN','ডাচবাংলা':'NN','ডাচ্':'NN','ডাটা':'NN',
'ডাটাফাইল':'NN','ডাটাবেস':'NN','ডাডলি':'NNP','ডাণ্ডা':'NN','ডাতে':'NN','ডান':'NN','ডানকুনির':'NNP',
'ডানদিক-বাঁদিক':'RB','ডানদিক':'NN','ডানপন্থীআজকেই':'NN','ডানবাম':'NN','ডানলপ':'NNP','ডানহাত':'NN','ডানা':'NN',
'ডানাওলা':'JJ','ডানাকাটা':'NN','ডানাবিহীন':'JJ','ডানাযুক্ত':'JJ','ডান্ডা':'NN','ডান্স':'NN','ডাফ':'NN',
'ডাফলী':'NN','ডাব':'NN','ডাবরা':'NN','ডাবল':'NN','ডাবা':'NN','ডাব্লুডাব্লুডাব্লু':'NN','ডামাডোল':'NN',
'ডামি':'NN','ডারা':'NN','ডার্ক':'NN','ডাল-পিঠা':'NN','ডাল':'NN','ডালকাঁটা':'NN','ডালগুলি':'NN',
'ডালবে':'NN','ডালভাত':'NN','ডালমুট':'NN','ডালসী':'NN','ডালহাউসি':'NN','ডালা':'NN','ডালিম':'NN',
'ডালে':'NN','ডাষ্টবিনের':'NN','ডাস':'NN','ডাস্টবিন':'NN','ডাস্টার':'NN','ডাহা':'NN','ডাহুক':'NN',
'ডায়টিং':'NN','ডায়নসার':'NN','ডায়বেটোলজিস্ট':'NN','ডায়রেক্টর':'NN','ডায়লিসিস':'NN','ডায়াগ্রাম':'NN','ডায়াবেটিক':'NN',
'ডায়াবেটিসে':'NN','ডায়ামিটার':'NN','ডায়াল':'NN','ডায়ালের':'NN','ডায়েট':'NN','ডায়েটিশিয়ান':'NN','ডায়েরি':'NN',
'ডায়েরী':'NNP','ডায়েরীতে':'NN','ডি-ব্যাঙ্ক':'NN','ডি.':'NNP','ডি.এন.এ':'NNP','ডি.লিট.':'NNP','ডি':'NN',
'ডিংসা':'NN','ডিঃ':'FW','ডিঅক্সিএডিনোসিন':'NN','ডিঅক্সিরাইবোনিউক্লিক':'NN','ডিঅর':'NN','ডিআডিও':'NN','ডিউই':'NNP',
'ডিউটি':'NN','ডিএফবি':'NN','ডিএমপির':'NN','ডিএসসিসি':'NN','ডিকটেটরশিপের':'NN','ডিকশনারি':'NN','ডিকসন':'NN',
'ডিকেন্স':'NN','ডিকের':'NNP','ডিক্রি':'NN','ডিক্লাইনিং':'NN','ডিগ্রি':'NN','ডিগ্রিধারীদের':'NN','ডিগ্রী':'NN',
'ডিগ্রেডেবল':'NN','ডিগ্ৰি':'NN','ডিঙানো':'VB','ডিঙি':'NN','ডিঙিয়ে':'VB','ডিঙ্গল':'NN','ডিঙ্গিয়ে':'VB',
'ডিঙ্গী':'NN','ডিজলাইক':'VB','ডিজাইন':'NN','ডিজারভ':'NN','ডিজিক্যাম':'NN','ডিজিজ':'NN','ডিজিটাল':'NN',
'ডিজিটালাইজেশনের':'NN','ডিজিটে':'NN','ডিজিট্যাল':'NN','ডিজেটে':'NN','ডিজেলের':'NN','ডিটেকশন':'NN','ডিটেক্টর':'NN',
'ডিট্যাচেবল':'JJ','ডিঠোহরি':'NN','ডিডাক্সন':'NNP','ডিতে':'NNP','ডিন':'NN','ডিনারটা':'NN','ডিনি':'NNP',
'ডিপ':'NN','ডিপার্টমেণ্ট':'NN','ডিপার্টমেন্টে':'NN','ডিপিডিসি':'NN','ডিপো':'NN','ডিপোতে':'NN','ডিপ্রেশন':'NNP',
'ডিপ্রেশনে':'NN','ডিপ্রেসডলীগের':'NNP','ডিপ্লোমা':'NN','ডিফুসান':'NN','ডিফেন্ডার':'NN','ডিফেন্সিভ':'NN','ডিবক্সে':'NN',
'ডিবরী':'NN','ডিবা':'NN','ডিবি':'NN','ডিবিবিএল':'NN','ডিবে':'NN','ডিব্বা':'NN','ডিব্রুগড়':'NN',
'ডিভাইস':'NN','ডিভাইসে':'NN','ডিভিডেন্টের':'NN','ডিভিশন':'NN','ডিভিসনের':'NNP','ডিভোর্স':'NN','ডিভোর্সী':'JJ',
'ডিম':'NN','ডিমওয়ালা':'JJ','ডিমভরা':'JJ','ডিমভাজা':'NN','ডিমাই':'NN','ডিমান্ড':'NN','ডিমারিয়ার':'NN',
'ডিমিডফিল্ডার':'NN','ডিমেও':'NN','ডিমেনশিয়া':'NN','ডিমের':'NN','ডিম্ব':'NN','ডিম্বজ':'JJ','ডিম্বাকার':'NN',
'ডিম্বাকৃতি':'JJ','ডিম্বাণু':'NN','ডিয়ার':'NN','ডিরেক্টর':'NN','ডিরেম':'NN','ডিলার':'NN','ডিলারশিপের':'NN',
'ডিলিউসন':'NN','ডিলেমা':'NN','ডিল্লা':'NN','ডিশিসন':'NN','ডিস':'NN','ডিসঅর্ডার':'NN','ডিসকোর্স':'NN',
'ডিসক্রিমিনেশন':'NNP','ডিসপিউট্':'NNP','ডিসপ্লে':'NN','ডিসমিস':'NN','ডিসলাইকের':'NN','ডিসি':'NN','ডিসিসিআই':'NN',
'ডিসেবলইনেবল':'NN','ডিসেম্বর':'NN','ডিসেম্বরেও':'NN','ডিস্':'NN','ডিস্কটা':'NN','ডিস্টার্ব':'NN','ডিস্টেম্পার':'NN',
'ডিস্ট্রিক':'NN','ডিয়া':'NNP','ডিয়ার':'NN','ডিয়েগো':'NN','ডীকে':'NN','ডীগড়':'NNP','ডীলা':'NN',
'ডীহ':'NN','ডু':'NN','ডুংগরপুর':'NN','ডুইন':'NNP','ডুকে':'NN','ডুগডুগি':'NN','ডুগি':'NN',
'ডুন্ডা':'JJ','ডুপ্লিকেট':'JJ','ডুপ্লিকেটর':'NN','ডুব':'NN','ডুবজাহাজ':'NN','ডুবতে':'JJ','ডুবন্ত':'NN',
'ডুববে':'NN','ডুবল':'NN','ডুবাইতে':'NN','ডুবানো':'VB','ডুবানোর':'VBG','ডুবাবে':'NN','ডুবি':'NN',
'ডুবিয়েছে':'NN','ডুবুরি':'NN','ডুবুরী':'JJ','ডুবে':'NN','ডুবেছে':'VBN','ডুমনী':'NNP','ডুমুর':'NN',
'ডুমুরের':'NNS','ডুয়েট':'NN','ডুরে':'NN','ডুলি':'NN','ডুশ':'NN','ডুসুম':'NN','ডে':'NN',
'ডেঁরখাম্মা':'NN','ডেইলি':'NN','ডেইলিতে':'NNP','ডেউয়া':'NN','ডেক-চেয়ারে':'NN','ডেক':'NN','ডেকুরে':'NN',
'ডেকে':'VB','ডেকেছে':'NN','ডেকেছেন':'VBN','ডেকেরশান':'NN','ডেক্সটপ':'NN','ডেগ':'NN','ডেঙ্গু':'NN',
'ডেচকি':'NN','ডেট':'NN','ডেটা':'NNS','ডেটাফাইল':'NN','ডেড':'NN','ডেঢ়খাম্মান':'NN','ডেনমার্ক':'NN',
'ডেনমার্কীয়':'NN','ডেনিম':'NN','ডেনে':'VB','ডেন্টালের':'NNP','ডেপুটি':'NN','ডেবরি':'NN','ডেভিডসনের':'NNP',
'ডেভিল':'NN','ডেভিস-হেডন':'NN','ডেভিস':'NNP','ডেভেলপ':'NN','ডেভেলপমেন্ট':'NNP','ডেভেলপার':'NN','ডেভেলপাররা':'NNS',
'ডেমনস্ট্রশনের':'NN','ডেমোক্রাসীর':'NN','ডেমোক্রেসী':'JJ','ডেমোক্র্যাট':'JJ','ডেমোগ্রাফিক':'JJ','ডেম্বেলে':'NN','ডেরা':'NN',
'ডেরেক':'NN','ডেলটা':'NN','ডেলাওয়ার':'NN','ডেলি':'RB','ডেলিভার':'NN','ডেলিভারী':'NN','ডেল্টা':'NN',
'ডেশন':'NNP','ডেসটিনি':'NN','ডেসটিনিরও':'NN','ডেসপ্যাচ':'NN','ডেস্ক':'NN','ডেস্কের':'NN','ডোবানোর':'VBG',
'ডোবে':'NN','ডেয়ারি':'NN','ডোঙায়':'NN','ডোজ':'NN','ডোড়ী':'NN','ডোডা':'NN','ডোডো':'NN',
'ডোনাল্ড':'NNP','ডোনেশান':'NN','ডোপামাইন':'NN','ডোবর':'NN','ডোবানো':'NN','ডোবে':'NN','ডোম':'NN',
'ডোমিনিকা':'NN','ডোমিনিকার':'JJ','ডোমিনিয়ন':'NNP','ডোরা':'NN','ডোরাকাটা':'NN','ডোল':'NN','ডোসা':'NN',
'ডোহোরা':'NN','ডোয়া':'NN','ডৌঁরা':'NN','ড্ডা':'NN','ড্যানিয়েল':'NNP','ড্যান্স':'NN','ড্যারেন':'NNS',
'ড্র':'NN','ড্রপ':'NN','ড্রাইআপ':'NN','ড্রাইভার':'NN','ড্রাইভারের':'NN','ড্রাইভিং':'NN','ড্রাগ':'NN',
'ড্রাগন':'NN','ড্রাফট':'NN','ড্রাম':'NN','ড্রামাবাজি':'NN','ড্রায়ার':'NN','ড্রিংকস':'NNS','ড্রিব্লিং':'VBG',
'ড্রিম':'NN','ড্রিলিঙ্গ':'NN','ড্রেন':'NN','ড্রেস':'NN','ড্রৈক্মা':'NN','ড্রোন':'NN','ড্রয়ার':'NN',
'ড্রয়িং':'VBG','ডয়ার':'NN','ঢ':'NN','ঢং':'NN','ঢংঢং':'NN','ঢগণ':'NN','ঢঙ':'NN',
'ঢমঢম':'VB','ঢলকা':'NN','ঢ়':'NN','ঢা':'NN','ঢাউস':'NN','ঢাক':'NN','ঢাকঢোল':'NN',
'ঢাকতে':'VB','ঢাকনা':'NN','ঢাকা':'NN','ঢাকাই':'NN','ঢাকাকেও':'NN','ঢাকাচত্তগ্রাম':'NN','ঢাকাতে':'NN',
'ঢাকাপাটন':'NN','ঢাকাবাসিরা':'NNS','ঢাকাযুক্ত':'NN','ঢাকার':'NN','ঢাকাসিলেট':'NN','ঢাকায়':'NN','ঢাবি':'NN',
'ঢাবিতে':'NN','ঢামনা':'NN','ঢারকা':'NN','ঢাল':'NN','ঢালছেন':'VBG','ঢালতে':'NN','ঢালা':'NN',
'ঢালাইনো':'VB','ঢালাও':'NN','ঢালাওভাবে':'RB','ঢালানো':'VB','ঢালার':'NN','ঢালি':'NN','ঢালুক':'NN',
'ঢালে':'NN','ঢিপঢিপ':'NN','ঢিবি':'NN','ঢিমে':'JJ','ঢিল':'NN','ঢিলা':'JJ','ঢিলি':'NN',
'ঢিলে-ঢালা':'JJ','ঢিলে':'NN','ঢিলেঢালা':'JJ','ঢু':'NN','ঢুঁঢলা':'NN','ঢুকছে':'VBG','ঢুকতে':'NN',
'ঢুকতেছেনা':'VBG','ঢুকবে':'NN','ঢুকল':'VBD','ঢুকলেন':'VBD','ঢুকাও':'NN','ঢুকাবেন':'NN','ঢুকিয়ে':'VBN',
'ঢুকে':'NN','ঢুকেই':'VB','ঢুকেছিলাম':'VB','ঢুকেছে':'NN','ঢুলি':'NN','ঢেঁকা':'NN','ঢেঁকুলি':'NN',
'ঢেউ':'NN','ঢেউয়ের':'NN','ঢেকি':'NN','ঢের':'NN','ঢেলবাঁশি':'NN','ঢেলা':'NN','ঢোলটা':'NN',
'ঢোক':'NN','ঢোকানো':'NN','ঢোকার':'NNV','ঢোকে':'NN','ঢোল':'NN','ঢোলএকজন':'NN','ঢোলকাঠি':'NN',
'ঢোলবাদক':'NN','ঢ্যাঁটা':'JJ','ঢ্যাঁড়োস':'NN','ণ':'NN','ণও':'NNP','ণকারান্ত':'JJ','ণকৃত':'JJ',
'ণগণ':'NN','ণগান':'NN','ণণোকার-মন্ত্র':'NN','ণতার':'NN','ণদের':'NN','ণনাম':'NN','ণনাশ':'NN',
'ণনের':'NN','ণপতি':'NN','ণবরা':'NN','ণবেশ':'NNP','ণভুক':'NNP','ণভেদ':'NN','ণাকে':'NN',
'ণাগত':'JJ','ণাটি':'NN','ণাতে':'VB','ণাত্':'RB','ণামই':'NN','ণায়':'NN','ণালী':'JJ',
'ণালয়':'NN','ণিকা':'NN','ণিতে':'NN','ণিনি':'VB','ণিমন':'NN','ণীকে':'NN','ণীগণ':'NN',
'ণীতে':'NN','ণীয়':'JJ','ণীরা':'NN','ণুকে':'NNP','ণুতা':'NN','ণুতে':'VB','ণেরই':'PR',
'ণেরা':'NN','ণ্টও':'NNP','ণ্টা':'NN','ণ্টু':'NNP','ণ্টে':'VB','ণ্ঠে':'NN','ণ্ডন':'NNP',
'ণ্ডপ':'NN','ণ্ডল':'NNP','ণ্ডা':'NN','ণ্ডী':'JJ','ণ্ডে':'NN','ণ্য':'NN','ণয়ের':'NN',
'ত-পা':'NN','ত-বর্গ':'NN','ত-বর্গীয়':'JJ','ত':'NN','তঃপর':'RP','তইরি':'NN','তও':'NN',
'তকড়ি':'NN','তকমা':'NN','তকরারি':'NN','তকলি':'NN','তকার':'NN','তকারান্ত':'JJ','তকাল':'RB',
'তকের':'NN','তক্তপোষ':'NN','তক্তা':'NN','তক্তি':'NN','তক্রপ্রমেহে':'NN','তক্রারিষ্ট':'NN','তক্ষ':'NN',
'তখন':'NN','তখনও':'NN','তখনকার':'NN','তখনতো':'RB','তখনি':'RB','তখিহা':'NN','তখুনি':'NN',
'তগণ':'NN','তগর':'NN','তঙ্ক':'NN','তঙ্গা':'NN','তছ-নছ':'VB','তছ':'JJ','তছনছ':'NN',
'তছরুপ':'NN','তছরূপ':'NN','তছাড়া':'RB','তজ':'NN','তজনে':'NN','তজ্জনিত':'JJ','তঞ্চন':'NN',
'তঞ্জল':'NN','তট-রেখা':'NN','তট':'NN','তটদেশ':'JJ','তটবর্তী':'JJ','তটবাসী':'JJ','তটরক্ষক':'NN',
'তটরেখা':'NN','তটস্থ':'NN','তটাই':'PR','তটায়':'NN','তটিনী':'NN','তটীয়':'JJ','তড়পানো':'VB',
'তড়িতময়':'JJ','তড়িত্':'NN','তড়িত্প্রভা':'NN','তড়িত্বান':'NN','তড়িৎ':'NN','তণ্ডুল':'NN','তত':'NN',
'ততকালিক':'JJ','ততকালীন':'RB','ততক্ষণ':'NN','ততক্ষণে':'RB','ততক্ষন':'NN','ততখানি':'NN','ততটা':'NN',
'ততটুকু':'CD','ততদিন':'NN','ততদিনই':'RB','ততপর':'JJ','ততপশ্চাত্':'RB','ততবার':'NNS','ততসম':'NN',
'ততহড়':'NN','ততার':'NN','ততুম':'VB','ততোক্ষণ':'RB','ততোধিক':'JJ','তত্কালীন':'RB','তত্ক্ষণাত্':'RB',
'তত্তবধায়ক':'NN','তত্তাবধানে':'VBN','তত্তাবধায়্ক':'NN','তত্ত্ব':'NN','তত্ত্বগত':'JJ','তত্ত্বজ্ঞ':'NN','তত্ত্বটি':'NN',
'তত্ত্বদর্শী':'NN','তত্ত্বাবতায়ক':'NN','তত্ত্বাবধানে':'VBN','তত্ত্বাবধানের':'NN','তত্ত্বাবধায়ক':'NN','তত্ত্বের':'NN','তত্পর':'NN',
'তত্পুরুষ':'NN','তত্ব-জ্ঞান':'NN','তত্ব':'NN','তত্বজ্ঞান':'NN','তত্ববধ্যায়ক':'NN','তত্বাবধানে':'NN','তত্বাবধায়ক':'NN',
'তত্বের':'NN','তত্সত্ত্বেও':'RP','তথা':'NN','তথাকতিত':'JJ','তথাকথিত':'NN','তথাকার':'NN','তথাগত':'NN',
'তথাপি':'RB','তথৈবচ':'NN','তথ্য':'NN','তথ্যউপাত্তের':'NN','তথ্যও':'NN','তথ্যগুলো':'NN','তথ্যচিত্র':'NN',
'তথ্যটা':'NN','তথ্যনির্ভর':'VBN','তথ্যপত্রটি':'NN','তথ্যপূর্ণ':'JJ','তথ্যপ্রযুক্তি':'NN','তথ্যবহুল':'JJ','তথ্যমতে':'NN',
'তথ্যরাশি':'NN','তথ্যসহ':'NN','তথ্যাদি':'NN','তথ্যানুসন্ধান':'NN','তথ্যান্বেষণ':'VB','তথ্যাবলীর':'NNP','তথ্যে':'NN',
'তথ্যের':'NN','তদনত':'NN','তদনুকূল':'RB','তদনুযায়ী':'RB','তদনুরূপ':'RB','তদনুসার':'JJ','তদনুসারে':'RB',
'তদন্':'RB','তদন্ত':'NN','তদন্তও':'NN','তদন্তকারী':'NN','তদন্তাধীন':'NN','তদন্তে':'NN','তদন্তের':'NN',
'তদন্দ':'NN','তদবির':'NN','তদর্থক':'JJ','তদানুসারে':'RB','তদার':'NN','তদারকি':'NN','তদারকির':'NN',
'তদিন':'NN','তদূর':'NN','তদের':'PR','তদেহ':'NN','তদোপরান্ত':'RB','তদ্গুন':'NN','তদ্ধিত':'NN',
'তদ্বির':'NN','তদ্বিরকারককে':'NN','তদ্ভব':'NN','তদ্রুপ':'JJ','তনক':'NN','তনজেব':'NN','তনতা':'NN',
'তনসুখ':'NN','তনাদ':'NN','তনায়':'NN','তনু':'NN','তনুজা':'NN','তনুদের':'NN','তনুধারী':'JJ',
'তনুপট':'NN','তনুমধ্যা':'NN','তনুশ্রীর':'NNP','তনের':'NN','তনৈলা':'NN','তন্ডি':'NN','তন্ডুরণ':'NN',
'তন্ডুল-জল':'NN','তন্ডুলা':'NN','তন্ডুলীয়ক':'NN','তন্ডুলোঘ':'NN','তন্তু':'NN','তন্তুকাষ্ঠ':'NN','তন্তুবাদক':'NN',
'তন্ত্র':'NN','তন্ত্রবিদ্যা':'NN','তন্ত্রশাস্ত্র':'NN','তন্ত্রসাদনায়':'NN','তন্ত্রহোম':'NN','তন্ত্রিকা':'NN','তন্ত্রের':'NN',
'তন্দান':'NN','তন্দুর':'NN','তন্দুয়া':'NN','তন্দ্রালস':'NN','তন্দ্রালু':'JJ','তন্দ্রিলসন্নিপাত':'NN','তন্ব':'NN',
'তন্বী':'JJ','তন্ময়':'NN','তন্য':'JJ','তন্রিকা':'NN','তনয়':'NN','তপ':'NN','তপন':'NNP',
'তপনা':'NN','তপশীলী':'JJ','তপস্বিনী':'NN','তপস্বীনি':'NN','তপস্যা':'NN','তপের':'NN','তপোজ':'JJ',
'তপোড়ী':'NN','তপোবন':'NN','তপোভূমি':'NN','তপ্ত-ক্যাথোড':'NN','তপ্ত':'NN','তপ্তসূমি':'NN','তপ্তায়নী':'NN',
'তফন':'NN','তফসিল':'NN','তফসিলী':'NN','তফাত':'NN','তফাত্':'NN','তফাৎ':'NN','তব':'FW',
'তবক':'NN','তবকযুক্ত':'JJ','তবক্ষীর':'NN','তবতা':'NN','তবর':'NN','তবলচী':'NN','তবলা-বাদক':'NN',
'তবলা':'NN','তবলাবাদক':'NN','তবলী':'NN','তবা':'NN','তবাঙ্গ':'NNS','তবাদ':'NN','তবার':'NNV',
'তবিক':'JJ','তবিদ':'NN','তবিয়তে':'NN','তবু':'RB','তবে':'CC','তব্ধ':'JJ','তব্য':'NN',
'তভাগ':'NN','তম':'NN','তমরাজ':'NN','তমসা':'NN','তমান':'JJ','তমামী':'NN','তমার':'NNS',
'তমাল':'NN','তমালপাতা':'NN','তমায়':'NN','তমিস্র':'NN','তমুক':'NN','তমেঙ্গলাঙ্গ':'NN','তমের':'NN',
'তমোগুণ':'NN','তমোগুণযুক্ত':'JJ','তমোময়':'JJ','তম্ব':'NN','তম্বুর':'NN','তম্বুরা':'NN','তম্বুরাবাদক':'NN',
'তম্ভ':'NN','তম্ভাবতী':'NN','তর':'NN','তরকম':'NN','তরকারি':'NN','তরকারীর':'NN','তরকাড়ি':'NN',
'তরঙ্গ':'NN','তরঙ্গায়িত':'JJ','তরঙ্গিনী':'NN','তরটা':'NN','তরণি':'NN','তরতাজা':'RB','তরপত':'NN',
'তরপের':'NN','তরফ':'NN','তরফদারি':'NN','তরফে':'RB','তরফের':'NN','তরবর':'NN','তরবারীর':'NN',
'তরমীরা':'NN','তরমুজ':'NN','তরল-গতিবিজ্ঞান':'NN','তরল-গতিশক্তি':'NN','তরল':'NN','তরশু':'NN','তরা':'NN',
'তরাং':'RP','তরাই':'NN','তরাজু':'NN','তরাপি':'NN','তরাবা':'NN','তরাম':'NN','তরিক':'JJ',
'তরিকায়':'NN','তরিকুল':'NN','তরিত':'JJ','তরিৎ':'NN','তরী':'NN','তরীন':'JJ','তরু':'NN',
'তরুক্ষীর':'NN','তরুণ':'NN','তরুণজ্বর':'NN','তরুণদের':'NN','তরুণযুবারা':'NN','তরুণী':'NN','তরুণীর':'NN',
'তরুন':'NN','তরুবর':'NN','তরুলতা':'NN','তরে':'NN','তরেও':'NN','তরো':'RP','তরোতা':'NN',
'তর্ক-শাস্ত্রী':'NN','তর্ক':'NN','তর্ককারক':'JJ','তর্কগম্য':'JJ','তর্কচঞ্চু':'NN','তর্কটা':'NN','তর্কবিদ':'JJ',
'তর্কশক্তি':'NN','তর্কশাস্ত্র':'NN','তর্কশাস্ত্রী':'NN','তর্কসংগত':'JJ','তর্কহীন':'JJ','তর্কাতর্কি':'NN','তর্কাতীত':'JJ',
'তর্কী':'NN','তর্কে':'NN','তর্জনগর্জনএ':'VBG','তর্জনী':'NN','তর্জ্জমা':'NN','তর্পণ':'NN','তর্পণকারী':'JJ',
'তর্পন':'NN','তল':'NN','তলওয়াড়ী':'NN','তলদেশ':'NN','তলব':'VB','তলবএর':'NNS','তলসী':'NN',
'তলা':'NN','তলাতে':'NN','তলান':'NN','তলানিতে':'NN','তলাবিহীন':'NN','তলার':'NN','তলিয়ে':'NN',
'তলীয়':'JJ','তলে':'NN','তলোয়ার':'NN','তলোয়াড়ধারী':'NN','তলোয়ারধারী':'NN','তলোয়ারবাজি':'NN','তলোয়ারের':'NN',
'তল্প':'NN','তল্লাশ':'NN','তল্লাশিকারী':'NN','তসবী':'NN','তসবেও':'NN','তসর':'NN','তসরূফ':'NN',
'তসরের':'NN','তসু':'NN','তস্কর':'NN','তস্ত':'JJ','তস্যগলির':'NN','তহবিল':'NN','তহবিলের':'NNS',
'তহলে':'RB','তহশীল':'NN','তহসিল':'NN','তহারত':'NN','তা':'DT','তাঁকে':'PR','তাঁড়া':'NN',
'তাঁত':'NN','তাঁতিনী':'NN','তাঁতের':'PR','তাঁদের':'NN','তাঁদেরও':'NN','তাঁবু':'NN','তাঁবেদার':'JJ',
'তাঁবেদারি':'NN','তাঁবোলিয়া':'NN','তাঁর':'PR','তাঁরও':'NN','তাঁরা':'PR','তাঁরাই':'PRP','তাঁরাতো':'PR',
'তাঁহাকে':'PR','তাঁহারা':'PR','তাং':'NN','তাংশ':'PR','তাই':'CC','তাইওয়ানি':'NN','তাইওয়ানী':'JJ',
'তাইজুল':'NN','তাইজুলও':'NN','তাইতো':'NN','তাইন':'PR','তাইনা':'NN','তাইপেয়ি':'NN','তাইবা':'NN',
'তাইবানবাসী':'NN','তাইলে':'RB','তাইলেই':'NN','তাইলেও':'RB','তাঈর':'NN','তাউস':'NN','তাও':'NN',
'তাওয়া':'NN','তাক':'NN','তাকা':'PR','তাকান':'VB','তাকানো':'VB','তাকানোর':'NN','তাকালাম':'VB',
'তাকি':'NN','তাকিয়ে':'VB','তাকী':'NN','তাকে':'PR','তাক্ষ্রপ্রসব':'NN','তাগড়া':'JJ','তাগতুম্বী':'NN',
'তাগপহনি':'NN','তাগসা':'NN','তাগাদা':'NN','তাগালগ':'NN','তাগিদ':'NN','তাগিদে':'VBG','তাগী':'NN',
'তাচ্ছিল্য':'VB','তাছাড়া':'NN','তাছাড়':'RP','তাছাড়াও':'RP','তাছে':'NN','তাজ':'NN','তাজউদ্দিন':'NN',
'তাজগরি':'NN','তাজপুরের':'NNP','তাজমহল':'NN','তাজরিনের':'NN','তাজা':'NN','তাজিক':'NN','তাজিকিস্তান':'NN',
'তাজিয়া':'NN','তাজী':'NN','তাজুল':'NN','তাজের':'NN','তাজ্জব':'JJ','তাঞ্জানিয়া':'NN','তাঞ্জানিয়ার':'JJ',
'তাঞ্জাবুর':'NN','তাঞ্জোরের':'NNP','তাটা':'PR','তাড':'NNP','তাড়কা':'NN','তাড়াতাড়ি':'RB','তাড়ানো':'NN',
'তাড়াবার':'NN','তাড়াহুড়ো':'NN','তাড়ি':'NN','তাড়িয়ে':'VBN','তাড়ী':'NN','তাণ্ডব':'NN','তাণ্ডবলীলা':'NN',
'তাত':'NN','তাতারবাসী':'NN','তাতারের':'JJ','তাতি':'NN','তাতুনকে':'PR','তাতেই':'NN','তাতেও':'IN',
'তাতেতো':'NN','তাত্':'PR','তাত্ক্ষণিক':'NN','তাত্পর্য':'NN','তাদের':'PR','তাদেরই':'NN','তাদেরকে':'NN',
'তাদেরকেইবেশি':'NN','তাদেরকেউ':'NN','তাদেরি':'NN','তান':'NN','তানও':'PR','তানজিয়া':'NN','তানপুরা':'NN',
'তানভীর':'NN','তানসেন':'NN','তানা':'NN','তানাহলে':'RB','তানি':'PR','তানিয়া':'NN','তানে':'PR',
'তান্ডব':'NN','তান্ত্রিক':'NN','তাপ-প্লীহা':'NN','তাপ':'NN','তাপগতিবিজ্ঞান':'NN','তাপজনিত':'JJ','তাপন':'NN',
'তাপনাশক':'JJ','তাপমাত্রা':'NN','তাপমান':'NN','তাপমাপার':'NN','তাপস':'NN','তাপহারী':'JJ','তাপিজ':'NN',
'তাপী':'NN','তাপ্তী':'NN','তাপ্পি':'NN','তাবান':'NN','তাবিজ':'NN','তাবু':'NN','তাবেদার':'NN',
'তাবোল':'NN','তাবৎ':'NN','তামজান':'NN','তামড়া':'NN','তামত':'RB','তামরস':'NN','তামসিক':'JJ',
'তামহাড়ী':'NN','তামা':'NN','তামাকখোর':'NN','তামাঘটিত':'JJ','তামাটে':'NN','তামানশিষ্যের':'NN','তামান্না':'NN',
'তামার':'NN','তামাশাব্যালট':'NN','তামাশায়':'JJS','তামিম':'NN','তামিমকে':'NN','তামিমদের':'NN','তামিমমুশফিক':'NN',
'তামিমময়':'NN','তামিল':'NN','তামিলকে':'NNP','তামিলগণের':'NN','তামিলদের':'NNP','তামিলনাড়ু':'NN','তামিলনাড়ুর':'NNP',
'তামিলরা':'PR','তামিস্ত্র':'NN','তামী':'NN','তামুক':'NN','তাম্বাকু':'NN','তাম্বুল':'NN','তাম্বুলীনি':'NN',
'তাম্র':'NN','তাম্রচূড়':'NN','তাম্রজাক্ষ':'NN','তাম্রধাতু':'NN','তাম্রধ্বজ':'NN','তাম্রপক্ষা':'NN','তাম্রপাত্র':'NN',
'তাম্রপুষ্পী':'NN','তাম্রবর্ণ':'JJ','তাম্রমূলা':'NN','তাম্রযুগ':'NN','তাম্রিকা':'NN','তাযবীহ':'NN','তায়':'PR',
'তার':'PR','তারই':'PRP','তারউপর':'IN','তারও':'PR','তারক':'NN','তারকটোড়ী':'NN','তারকব্রহ্ম':'NN',
'তারকমাণী':'NN','তারকশ':'NN','তারকষা':'NN','তারকাঁটা':'NN','তারকাক্ষ':'NN','তারকাটার':'NN','তারকাদের':'NNS',
'তারকার':'PR','তারকারা':'NNS','তারকাসুর':'NN','তারকায়ণ':'NN','তারকুট':'NN','তারকুণ্ডলী':'JJ','তারকুলা':'NN',
'তারকেশ':'NN','তারকেশ্বর':'PR','তারগুলিয়া':'NN','তারঘর':'NN','তারচে':'NN','তারচেয়েও':'DT','তারচেয়েও':'DT',
'তারজন্য':'NN','তারজালি':'NN','তারণ':'VB','তারণকর্তা':'NN','তারণী':'NN','তারনা':'NN','তারপর':'CC',
'তারপিন':'NN','তারব':'NN','তারবার্তা':'NN','তারবিহীন':'JJ','তারবৃত্ত':'NN','তারমানে':'NN','তারল্য':'NN',
'তারস্বরে':'VB','তারহা':'NN','তারা':'PR','তারাঙ্কিত':'JJ','তারাচিহ্ন':'NN','তারাটি':'NN','তারাতারি':'JJ',
'তারাধিপ':'NN','তারাধীশ':'NN','তারানা':'NN','তারাপতি':'NN','তারাপীড়':'NN','তারাবতী':'NN','তারাবিহীন':'JJ',
'তারাভ':'NN','তারাভরা':'JJ','তারামণ্ডল':'NN','তারামতী':'NN','তারাযুক্ত':'JJ','তারার':'NN','তারারন্ধ্র':'NN',
'তারাহীন':'JJ','তারি':'NN','তারিখ':'NN','তারিখে':'IN','তারিখেও':'NN','তারিফ':'NN','তারু':'PR',
'তারুণ্য':'NN','তারে':'NN','তারেককে':'NN','তারেকখাম্বা':'NN','তারেকের':'NN','তারেশ':'NN','তার্কিক':'NN',
'তার্কিশ':'VB','তার্ক্ষ্য':'NN','তার্প্য':'NN','তার্মানে':'NN','তার্রী':'NN','তাল-বন':'NN','তাল':'NN',
'তালকন্দ':'NN','তালকেতু':'NN','তালগাছ':'NNS','তালগাছটা':'NN','তালগোণ্ডা':'NN','তালগোল':'NN','তালনবমী':'NN',
'তালপত্রিকা':'NN','তালপাতা':'NNS','তালবন':'NN','তালবাদ্য':'NN','তালবিহীন':'JJ','তালবৃক্ষ':'NN','তালবেণু':'NN',
'তালব্য':'NN','তালমিল':'VB','তালমূলিকা':'NN','তালরঙ্গ':'NN','তালরস':'NN','তালশাঁস':'NN','তালস্কন্ধ':'NN',
'তালা':'NN','তালাক-তালাক-তালাক':'NN','তালাক':'NN','তালাটা':'NN','তালাবন্ধ':'NN','তালার':'NN','তালি':'NN',
'তালিকা-পুস্তক':'NN','তালিকা':'NN','তালিকাটি':'NN','তালিকাবদ্ধ':'JJ','তালিকাভুক্ত':'VBN','তালিকায়':'NN','তালিকায়':'NN',
'তালিন':'NN','তালিবানী':'JJ','তালিম':'NN','তালীশপত্র':'NN','তালু':'NN','তালুকদার':'NN','তালুকদারকেও':'NN',
'তালুকন্টক':'NN','তালুপাকা':'NN','তালুফাড়':'NN','তালে':'NN','তালেবানের':'NN','তাল্বর্বুদ':'NN','তাশকন্দ':'NN',
'তাশন':'PR','তাশা':'NN','তাস':'NN','তাসকিন':'NN','তাসলিমা':'NN','তাসা':'PR','তাসের':'NN',
'তাহত':'PR','তাহপেঁচ':'NN','তাহমিনা':'NN','তাহলে':'CC','তাহলেআর':'NN','তাহলেই':'RB','তাহলেও':'NN',
'তাহলেতো':'RB','তাহা':'DT','তাহাই':'NN','তাহাকে':'PR','তাহাদের':'NN','তাহার':'PR','তাহারাই':'PR',
'তাহে':'PR','তাহের':'NN','তাহেরদের':'NN','তা্ই':'RB','তাৎপর্য':'NN','তাড়াতাড়ি':'NN','তাড়ানো':'NN',
'তাড়ি':'RB','তাড়িয়ে':'VB','তায়ালা':'JJ','তা‌তে':'NN','তা‌দেরও':'NN','তা‌বেদা‌রি':'NN','তা–ও':'NN',
'তিউনিশিয়ার':'JJ','তিকড়ী':'NN','তিকতিক':'NN','তিকর':'JJ','তিকা':'NN','তিক্ত':'NN','তিক্তভাব':'NN',
'তিখি':'NN','তিগণ':'NN','তিগত':'JJ','তিজিয়া':'NN','তিটা':'NN','তিটি':'CD','তিতরোখী':'NN',
'তিতা':'NN','তিতিক্ষ':'NN','তিতির':'NN','তিতে':'NN','তিত্তিরি':'NN','তিথি':'NN','তিথিপত্রস':'NN',
'তিদারী':'NN','তিধর':'PR','তিধারা':'NN','তিন-চারতলা':'NN','তিন':'CD','তিনগুণ':'NN','তিনঘাত':'JJ',
'তিনচাকা':'NN','তিনচাকাবিশিষ্ট':'JJ','তিনচাকার':'JJ','তিনছড়া':'NN','তিনজন':'JJ','তিনজনে':'PR','তিনজনের':'PR',
'তিনটা':'NN','তিনটায়':'NN','তিনটির':'NN','তিনতারওয়ালা':'JJ','তিনদিক':'NN','তিনদিকের':'JJ','তিনদিন':'NN',
'তিনদুয়ারী':'NN','তিনধরনের':'NN','তিনপায়া':'JJ','তিনপ্রকার':'PR','তিনফসলী':'JJ','তিনবার':'NN','তিনমূর্তি':'NN',
'তিনরঙা':'NN','তিনশ':'JJ','তিনশোটি':'NN','তিনসুকিয়া':'NN','তিনহাজার':'NN','তিনি':'PR','তিনিই':'NN',
'তিনিও':'PRP','তিনিটি':'NN','তিনেক':'JJ','তিপড়া':'NN','তিপতিয়া':'NN','তিপান্ন':'JJ','তিপান্নে':'CD',
'তিপ্পান্নতম':'JJ','তিফলিস':'NN','তিব্বত':'NN','তিব্র':'NN','তিভা':'NN','তিমত':'JJ','তিমা':'NN',
'তিমিঙ্গিল':'NN','তিমিটার':'NN','তিমিধ্বজ':'NN','তিমির':'NN','তিমিরাবগুণ্ঠনে':'NN','তিমুরের':'NN','তিরই':'PR',
'তিরওয়াট':'NN','তিরঙ্গা':'NN','তিরন্দাজি':'NN','তিরপ':'NN','তিরষ্কার':'NN','তিরস্কার':'VB','তিরস্কারে':'NN',
'তিরস্কিরিণী':'NN','তিরস্কৃত':'NN','তিরা':'NN','তিরানব্বই':'NN','তিরানব্বইতম':'JJ','তিরানা':'NN','তিরাশি':'NN',
'তিরাশিতম':'JJ','তিরাহী':'NN','তিরি':'NN','তিরিশ-চল্লিশ':'CD','তিরিশ':'JJ','তিরুনেল্লবেলি':'NN','তিরুপতি':'NN',
'তিরুবনন্তপুরম':'NN','তিরুবন্নামালাই':'NN','তিরুবরুর':'NN','তিরূবিথান্কূর':'NN','তিরে':'NN','তিরোধান':'NN','তির্যক':'JJ',
'তিল':'NN','তিলওয়াসিনী':'NN','তিলক':'NN','তিলককামোদ':'NN','তিলকহার':'NN','তিলকুট':'NN','তিলকের':'NN',
'তিলতেল':'NN','তিলদানী':'NN','তিলপট্টী':'NN','তিলপাপড়ি':'NN','তিলপিঞ্জ':'NN','তিলফুল':'NN','তিলবন':'NN',
'তিলমাপট্টী':'NN','তিলময়ূর':'NN','তিলাঞ্জলী':'NN','তিলাবা':'NN','তিলারী':'NN','তিলার্ধমাত্র':'NN','তিলি':'NN',
'তিলিত্সা':'NN','তিলেচালে':'NN','তিলের':'NN','তিলোত্তমা':'NN','তিলোত্তমায়':'NNP','তিলোরা':'NN','তিল্ব':'NN',
'তিল্লী':'NN','তিশয়':'CD','তিষ্ঠা':'NN','তিসখুদ':'NN','তিসমার':'NN','তিসস':'NNP','তিসি':'NN',
'তিস্তা':'NN','তিহত':'JJ','তিহদ্দি':'NN','তিহরি':'NN','তিহস':'NN','তিয়াত্তর':'NN','তিয়াত্তরতম':'JJ',
'তীক্ষ্ণ':'JJ','তীক্ষ্ণক':'NN','তীক্ষ্ণকন্টক':'NN','তীক্ষ্ণগন্ধা':'NN','তীক্ষ্ণবুদ্ধি':'JJ','তীজ':'NN','তীতি':'NN',
'তীব্র':'NN','তীব্রগন্ধা':'NN','তীব্রবুদ্ধি':'JJ','তীয়':'JJ','তীর':'NN','তীরচিহ্ন':'NN','তীরন্দাজ':'NN',
'তীরবত্':'JJ','তীরা':'NN','তীরেই':'NN','তীর্ণা':'NN','তীর্থ-যাত্রী':'NN','তীর্থ':'NN','তীর্থক্ষেত্র':'NN',
'তীর্থঙ্কর':'NN','তীর্থপাদীয়':'NN','তীর্থযাত্রা':'NN','তীর্থসেবক':'NN','তীর্থস্থান':'NN','তীর্থাটক':'NN','তীর্থেরকাক':'NN',
'তীসা':'NN','তুঁত':'NN','তুঁবড়ী':'NN','তুং':'NN','তুংজাল':'NN','তুই':'PRP','তুইবাই':'NN',
'তুকবন্দি':'NN','তুকান্ত':'NN','তুকারাম':'NN','তুকি':'NN','তুকে':'PR','তুকোবা':'NN','তুক্কল':'NN',
'তুগ্র':'NN','তুঙ্গ':'NN','তুঙ্গভদ্রা':'NN','তুঙ্গীনাস':'NN','তুচ্ছ':'NN','তুচ্ছতাচ্ছিল্য':'NN','তুচ্ছাতিতুচ্ছ':'JJ',
'তুঝাক':'NNP','তুঞ্জ':'NN','তুটি':'PR','তুণ্ডকেশরী':'NN','তুণ্ডীগুদপাক':'NN','তুতঃ':'RB','তুতি':'NN',
'তুতিকোরিন':'NN','তুতী':'NN','তুতুকুরি':'NN','তুতে':'PR','তুন':'NN','তুন্দি':'NN','তুপয়':'NN',
'তুফান':'NN','তুবড়ানো':'JJ','তুবড়ি':'NN','তুবরা':'NN','তুবা':'RP','তুমকুর':'NN','তুমারিয়া':'NN',
'তুমি':'PRP','তুমিই':'NN','তুমুল':'NN','তুম্ব':'NN','তুম্বরু':'NN','তুম্বি':'NN','তুম্বুরু':'NN',
'তুরগ':'NN','তুরগদানব':'NN','তুরগী':'NN','তুরঙ্গগৌড়':'NN','তুরঙ্গমশালা':'NN','তুরঙ্গী':'NN','তুরপুন':'NN',
'তুরমতি':'NN','তুরষ্ক':'NN','তুরষ্কের':'NN','তুরস্ককে':'NN','তুরস্কের':'NN','তুরা':'NN','তুরী-বাদক':'NN',
'তুরী':'NN','তুরীবাদক':'NN','তুরীয়াতীত':'NN','তুরুপ':'NN','তুর্কমেনিস্তানবাসী':'NN','তুর্কি':'VB','তুর্কিমেনিস্তান':'NN',
'তুর্কিমেনিস্তানি':'JJ','তুর্কিস্তান':'NN','তুর্কিস্তানবাসী':'JJ','তুর্কী':'JJ','তুর্বশ':'NN','তুর্য্য':'NN','তুর্রাবাজ':'NN',
'তুলছে':'VB','তুলত':'NN','তুলতুলে':'JJ','তুলতে':'NN','তুলন':'NN','তুলনাই':'NN','তুলনামূলক':'RB',
'তুলনায়':'NN','তুলনীয়':'JJ','তুলবে':'VB','তুললে':'RP','তুললেও':'VB','তুললো':'VB','তুলশি':'NN',
'তুলসিপাতা':'NN','তুলসী-পত্র':'NN','তুলসী':'NN','তুলসীতলায়':'NN','তুলসীপত্র':'NN','তুলসীমণ্ডপ':'NN','তুলা':'NN',
'তুলাদণ্ড':'NN','তুলাধুনা':'NN','তুলাবীজ':'NN','তুলাযন্ত্র':'NN','তুলার':'NN','তুলি':'NN','তুলিস':'NNP',
'তুলু':'NN','তুলুনা':'NN','তুলে':'NN','তুলেছিপ্রথমে':'NN','তুলেছিল':'NN','তুলেছে':'NN','তুলেতখন':'NN',
'তুলো':'NN','তুলোধোনকার':'NN','তুলোধোনা':'VB','তুলোযুক্ত':'JJ','তুলোর':'NN','তুল্য':'NN','তুশিয়ার':'NN',
'তুষ':'NN','তুষানল':'NN','তুষাম্বু':'NN','তুষার':'NN','তুষারপাত':'NN','তুষারময়':'JJ','তুষাররাষ্ট্র':'NN',
'তুষারাবৃত':'NN','তুষারের':'NN','তুষিত':'NN','তুষোত্থ':'NN','তুষ্ট':'NN','তুষ্টিকরণ':'NN','তুষ্ঠতার':'NN',
'তুহল':'NN','তুহিন':'NN','তুহুন্ড':'NN','তূণ':'NN','তূণীর':'NN','তূরী':'NN','তূর্য':'NN',
'তূহল':'NN','তৃণ':'NN','তৃণকর্ণ':'NN','তৃণকুটির':'NN','তৃণকেতকী':'NN','তৃণকেশর':'NN','তৃণগন্ধা':'NN',
'তৃণগৌর':'NN','তৃণগ্রন্থী':'NN','তৃণজীবী':'JJ','তৃণপত্রী':'NN','তৃণপ্রত্রিকা':'NN','তৃণভূমি':'NN','তৃণভোজী':'NN',
'তৃণমণি':'NN','তৃণমূল':'NN','তৃণশস্য':'NN','তৃণাবর্ত':'NN','তৃতা':'NN','তৃতীয়':'CD','তৃতীয়া':'NN',
'তৃতীয়':'JJ','তৃতীয়ক':'NN','তৃতীয়টিতে':'NN','তৃতীয়বার':'NN','তৃতীয়াংশ':'JJ','তৃপণ':'NN','তৃপপ্রিয়া':'NN',
'তৃপা':'NN','তৃপ্ত':'JJ','তৃপ্তি':'NN','তৃপ্তির':'NN','তৃষা':'NN','তৃষ্ণার্ত':'NN','তে':'NN',
'তেঁতুল':'NN','তেঁতো':'NN','তেই':'NN','তেইশতম':'JJ','তেও':'NN','তেওহারী':'NN','তেওয়ারী':'NN',
'তেগ':'NN','তেঙ্গা':'NN','তেছি':'VB','তেজ':'NN','তেজক':'JJ','তেজগাঁও':'NN','তেজপত্র':'NN',
'তেজশক্রিতার':'NN','তেজস':'FW','তেজস্ক্রিয়':'NN','তেজস্বিতা':'NN','তেজহীন':'JJ','তেজারত':'NN','তেজী':'NN',
'তেজে':'NN','তেজো-বিন্দু':'NN','তেজোদীপ্ত':'JJ','তেজোমণ্ডিত':'JJ','তেতারা':'NN','তেতাল্লিশ':'NN','তেতাল্লিশতম':'JJ',
'তেতুলিয়া':'NN','তেতো':'NN','তেত্রিশ':'NN','তেত্রিশতম':'JJ','তেন':'VB','তেনা':'NN','তেনি':'NN',
'তেপায়া':'NN','তেমন':'NN','তেমনটা':'NN','তেমনটি':'PR','তেমনি':'NN','তের':'NN','তেরঙ্গা':'JJ',
'তেরছা':'NN','তেরপল':'NN','তেরা':'NN','তেরেসা':'NN','তেরো':'NN','তেল-শোধন':'NN','তেল':'NN',
'তেলআভিভ':'NN','তেলও':'NN','তেলকালিবাবু':'NNP','তেলতেলে':'JJ','তেলতেলেভাব':'NN','তেলবাজ':'NN','তেলবাজী':'NN',
'তেলমণি':'NN','তেলরঙ':'NN','তেলরঙেই':'NN','তেলসমতি':'NN','তেলসুর':'NN','তেলা':'NN','তেলাপকার':'NN',
'তেলাপোকাও':'NN','তেলার':'NN','তেলিন':'NN','তেলিয়া':'NNP','তেলিয়াকাজু':'NN','তেলিয়াপখান':'NN','তেলিয়াসোহাগা':'NN',
'তেলী':'RB','তেলুগু':'NN','তেলে':'NN','তেলেঙ্গানা':'NN','তেলের':'NN','তেলো-ভেলোর':'NNP','তেল্লুর':'NN',
'তেষট্টি':'NN','তেষট্টিতম':'JJ','তেষ্টা':'NN','তেহদ্দি':'NN','তেহরান':'NN','তেহ্':'NNP','তো':'NN',
'তোমরা':'NN','তেড়ে':'NN','তৈত্তিরীয়':'NN','তৈরি':'VBN','তৈরিই':'NN','তৈরিনো':'VB','তৈরির':'NN',
'তৈরী':'JJ','তৈরীতে':'NN','তৈরীনো':'VB','তৈরীর':'NN','তৈল':'NN','তৈলপিঞ্জ':'NN','তৈলবীজ':'NN',
'তৈলমর্দন':'NN','তৈলস্ফটিক':'NN','তৈলস্যন্দা':'NN','তৈলাক্ত':'NN','তৈলাঞ্চী':'NN','তৈলাধার':'NN','তৈলিক':'NN',
'তৈল্যশস্য':'NN','তৈসস্যন্দা':'NN','তৈয়ার':'NN','তো':'CC','তোঅর্থমন্ত্রী':'NN','তোইবা':'NN','তোক':'NN',
'তোকে':'PR','তোগত':'NN','তোঙ্গ':'NN','তোটক':'NN','তোড়জোড়':'NN','তোড়া':'NN','তোতপুরী':'NN',
'তোতলা':'NN','তোতলানো':'VBG','তোতা':'NN','তোতাপাখি':'NN','তোত্র':'NN','তোদের':'NN','তোপ':'NN',
'তোপখানা':'NN','তোপচি':'NN','তোপান্ন':'NN','তোপের':'NN','তোফা':'NN','তোবরুক':'NN','তোমর':'NNS',
'তোমরা':'NN','তোমাকে':'NN','তোমাদের':'NN','তোমায়':'NN','তোমার':'NNS','তোমারা':'NN','তোমারেই':'NN',
'তোমায়':'PR','তোর':'NN','তোরণসুলভ':'JJ','তোরা':'NN','তোলপাড়':'NNV','তোলা':'NN','তোলাতে':'VB',
'তোলাবাজ':'NN','তোলার':'NN','তোলে':'NN','তোলেন':'VB','তোল্লাই':'VB','তোশাখানা':'NN','তোষ':'NN',
'তোষণ':'NN','তোষল':'NN','তোষামদ':'NN','তোষামদকারী':'JJ','তোষামুদিপূর্ণ':'JJ','তোষামোদ':'NN','তোষামোদি':'NN',
'তোষার':'NN','তোড়জোড়':'NN','তোড়া':'NNP','তোয়সর্পিকা':'NN','তোয়া':'PR','তোয়াক্কা':'NN','তোয়াক্কাই':'PR',
'তোয়ালে':'NN','তৌফিক':'NN','তৌফিলিদের':'NN','তৌড়ি':'NN','ত্কর':'JJ','ত্টা':'NN','ত্তই':'RB',
'ত্তন':'NN','ত্তম':'JJ','ত্তল':'JJ','ত্তা':'NN','ত্তী':'JJ','ত্তে':'NN','ত্নী':'NN',
'ত্বও':'NN','ত্বকও':'NN','ত্বকপাক':'NN','ত্বকি':'NN','ত্বকের':'NN','ত্বনু':'NN','ত্বরণ':'NN',
'ত্বরান্বিত':'NN','ত্বরিত':'JJ','ত্বরিতগতি':'NN','ত্বষ্টা':'NN','ত্বাষ্ট্রী':'NN','ত্বিলিসী':'NN','ত্বে':'NN',
'ত্মক':'JJ','ত্য-':'NN','ত্যক্ত':'JJ','ত্যজ':'NN','ত্যজনীয়':'JJ','ত্যা':'NN','ত্যাগই':'NN',
'ত্যাগস্বীকার':'NN','ত্যাগী':'JJ','ত্যাগের':'NN','ত্যাজ্য':'JJ','ত্যাদর':'NN','ত্যাড়ামি':'NN','ত্যি':'NN',
'ত্যে':'NN','ত্র':'NN','ত্রই':'PR','ত্রও':'NN','ত্রটিপূর্ণ':'NN','ত্রণ':'NN','ত্রপা':'NN',
'ত্রম্বকেশ্বর':'NN','ত্রসদস্যু':'NN','ত্রসরেণু':'NN','ত্রা':'NN','ত্রাণ-কার্য':'NN','ত্রাণ':'NN','ত্রাণকর্তা':'NN',
'ত্রাণমূলক':'JJ','ত্রাণসামগ্রী':'NN','ত্রাতা':'NN','ত্রাস':'NN','ত্রাসের':'NN','ত্রি-ষিখি':'NN','ত্রি':'NN',
'ত্রিকালজ্ঞ':'NN','ত্রিকালদর্শিতা':'NN','ত্রিকুট':'NN','ত্রিকোণা':'JJ','ত্রিকোণাকৃতির':'JJ','ত্রিকোণীয়':'JJ','ত্রিগুণ':'NN',
'ত্রিগুণাতীত':'JJ','ত্রিঘাত':'JJ','ত্রিচিরাপল্লি':'NN','ত্রিজটা':'NN','ত্রিত':'NN','ত্রিদশগুরু':'NN','ত্রিদশপুষ্প':'NN',
'ত্রিদশাচার্য':'NN','ত্রিদশাদীর্ঘিকা':'NN','ত্রিদিব':'NN','ত্রিদোষ':'NN','ত্রিদোষজ':'JJ','ত্রিধনী':'NN','ত্রিনিদাদ':'NN',
'ত্রিনিদাদিয়ান':'JJ','ত্রিনেত্রচূড়ামণি':'NN','ত্রিনেত্ররস':'NN','ত্রিনয়না':'NN','ত্রিপত্র':'NN','ত্রিপর্ণিকা':'NN','ত্রিপল':'NN',
'ত্রিপাঠীকে':'NN','ত্রিপাদিকা':'NN','ত্রিপুণ্ড':'NN','ত্রিপুরমল্লিকা':'NN','ত্রিপুরাতপনি':'NN','ত্রিপুরাসুর':'NN','ত্রিপুরেশ্বরী':'NN',
'ত্রিপুরোপনিষদ':'NN','ত্রিপোলী':'NN','ত্রিফলা':'NN','ত্রিবর্গ':'NN','ত্রিবর্ণরঞ্জিত':'JJ','ত্রিবলি':'NN','ত্রিবান্দম':'NN',
'ত্রিবার':'NN','ত্রিবাহু':'NN','ত্রিবিক্রম':'NN','ত্রিবেণী':'NN','ত্রিবেনী':'NN','ত্রিভুজ':'NN','ত্রিভুবনসুন্দরী':'NN',
'ত্রিভুবনে':'NN','ত্রিভূজ':'NN','ত্রিভূজাকার':'JJ','ত্রিভূজীয়':'JJ','ত্রিমাত্রিক':'NN','ত্রিমার্গগা':'NN','ত্রিমাসিক':'NN',
'ত্রিমাসীয়':'JJ','ত্রিমুকুট':'NN','ত্রিমুণ্ড':'NN','ত্রিমূর্তি':'NN','ত্রিযামা':'NN','ত্রিলোক':'NN','ত্রিলোকনাথ':'NN',
'ত্রিলোকেশ্বর':'NN','ত্রিলোচন':'NNP','ত্রিলোহী':'NN','ত্রিশ':'NN','ত্রিশঙ্কু':'NN','ত্রিশতম':'JJ','ত্রিশিখ':'NN',
'ত্রিশিরা':'NN','ত্রিশীর্ষক':'NN','ত্রিশুলধারী':'JJ','ত্রিশূল':'NN','ত্রিশেক':'JJ','ত্রিশের':'NN','ত্রিশোর্ধ':'NN',
'ত্রিষ্টুভ':'NN','ত্রিস':'NNP','ত্রিসন্ধি':'NN','ত্রিসন্ধ্যকুসুম':'NN','ত্রিসরী':'NN','ত্রিসামা':'NN','ত্রিসুর':'NN',
'ত্রিস্তনী':'NN','ত্রিস্তবা':'NN','ত্রিহণ':'NN','ত্রিহায়নী':'NN','ত্রী':'NN','ত্রীমার্গী':'NN','ত্রীষুক':'NN',
'ত্রুটি':'NN','ত্রুটিপূর্ণ':'NN','ত্রূটি':'NN','ত্রে':'NN','ত্রেতাযুগ':'NN','ত্রেমাতুর':'NN','ত্রৈবলি':'NN',
'ত্রৈমাসিক':'JJ','ত্রৈলোক্য':'NN','ত্রৈলোক্যনাথ':'NNP','ত্রোটক':'NN','ত্র্যক্ষ':'NN','ত্র্যারুণ':'NN','ত্রয়':'JJ',
'ত্রয়ী':'NN','ত্রয়োদশ':'CD','ত্রয়োদশতম':'JJ','ত্রয়োদশী':'NN','ত্রয়োবিংশ':'CD','ত্সক':'NN','ত্সর':'NN',
'ত্সি':'NN','ত্্ও':'NN','তৎকালীন':'NN','তৎপর':'NN','তৎপরতার':'NN','তড়িঘড়ি':'NN','তড়িতের':'NN',
'তড়িত্গ্রস্ত':'JJ','তড়িত্দ্বার':'NN','তয়':'NN','তয়োধর':'NN','থ':'NN','থআন':'NN','থক':'NN',
'থকতা':'NN','থকথকে':'NN','থকরা':'NN','থকরী':'JJ','থকার':'NN','থকারান্ত':'JJ','থকিবে':'VB',
'থকেও':'NNP','থক্য':'NN','থটির':'NN','থড়থড়':'RB','থতমত':'NN','থতার':'NN','থবন':'NN',
'থবার':'NNV','থবিদ':'NN','থমকে':'VB','থমত':'RB','থমথমে':'NN','থমাস':'NNP','থমিক':'JJ',
'থমে':'NN','থমেই':'RB','থর':'NN','থরথর-কম্পনী':'NN','থরথর':'VB','থরনা':'NN','থরের':'NN',
'থর্ন':'NN','থলথলে':'JJ','থলি':'NN','থলিক':'JJ','থলে':'NN','থহীন':'JJ','থা':'NN',
'থাইকা':'VB','থাইমস':'NN','থাইমসগ্রন্থি':'NN','থাইমিন':'NN','থাইরয়েড':'NN','থাইল্যাণ্ড':'NN','থাইল্যান্ড':'NN',
'থাইল্যান্ডি':'NN','থাইল্যান্ডীয়':'JJ','থাক':'VB','থাকত':'VB','থাকতাম':'VB','থাকতে':'NN','থাকতেই':'VB',
'থাকতেন':'VB','থাকতো':'VB','থাকব':'VB','থাকবে':'VB','থাকবেও':'VB','থাকবেনা':'VB','থাকবো':'VB',
'থাকল':'VB','থাকলাম':'VB','থাকলেই':'VB','থাকলেন':'VB','থাকলো':'VB','থাকা':'VB','থাকাও':'VB',
'থাকাকালীন':'RB','থাকাকালে':'VB','থাকাটাই':'VB','থাকাতে':'VB','থাকাবস্থায়':'VB','থাকার':'VB','থাকারও':'VB',
'থাকি':'VB','থাকিকরতে':'VB','থাকিলে':'RP','থাকিয়া':'VB','থাকুক':'VB','থাকে':'VB','থাকেই':'RB',
'থাকেকিন্তু':'VB','থাকেন':'VB','থাকো':'VB','থাক্তে':'VB','থাক‌বে':'VB','থাগত':'JJ','থাটা':'NNV',
'থাটি':'NN','থাতামি':'NN','থাত্':'RP','থাদ্যনালী':'NN','থান':'NN','থানাদারি':'NN','থানার':'NN',
'থানায়৪':'NN','থানি':'VB','থানে':'NN','থানেশ্বর':'NN','থাপক':'NNP','থাপন':'NN','থাপি':'NN',
'থাপ্পড়':'NN','থাপ্পড়':'NN','থাবরা':'NN','থাবায়':'NN','থাম':'VB','থামওয়ালা':'NN','থামগুলো':'NN',
'থামছেই':'NN','থামবেন':'NN','থামা':'VB','থামাতে':'NN','থামানো':'VB','থামার':'NNV','থামায়':'NN',
'থামিয়ে':'NN','থামিয়ে':'VB','থামুন':'VB','থাযথ':'NNP','থায়':'VB','থারমাস':'NN','থার্টি':'NN',
'থার্মিডোরের':'NN','থার্মোমিটার':'NN','থালা':'NN','থায়ী':'JJ','থা‌কে':'NN','থিংক':'NN','থিউরিতে':'NN',
'থিও':'NNP','থিটা':'NNP','থিতানো':'VB','থিতি':'NN','থিবী':'NNP','থিম্পু':'NN','থিরথিরকম্পনী':'NN',
'থিসিসটী':'NN','থিহান':'NN','থিয়সফিস্ট':'NNP','থিয়েটার':'NN','থিয়েটারে':'NNP','থিয়েটারের':'NN','থিয়োডোলাইট':'NN',
'থীকে':'NN','থীরা':'NN','থীসহ':'NN','থু':'VB','থুজনের':'NN','থুতনি':'NN','থুতু':'NN',
'থুত্কার':'NN','থুথনী':'NN','থুথু':'NN','থুনের':'NN','থুবরে':'NN','থুলমা':'NN','থুলিয়াম':'NN',
'থেঁতলানো':'JJ','থেঁতো':'NN','থেঁতোনো':'VB','থেক':'IN','থেকই':'PSP','থেকিয়ে':'VB','থেকে':'IN',
'থেকেআল্লাহ্':'NN','থেকেই':'IN','থেকেও':'NN','থেকেদেশে':'NN','থেকেহরিন':'NN','থেকো':'NN','থেক্কাডি':'NNP',
'থেছি':'VB','থেতলানো':'VB','থেতলে':'VB','থেবসে':'NNP','থেবাইদ':'NNP','থেমে':'VB','থেরাপি':'NN',
'থেলিয়াম':'NN','থেয়াল':'NN','থে‌কে':'NN','থৈবচ':'NNP','থোক':'NN','থোবড়া':'NN','থোরাই':'NN',
'থোরিয়াম':'NN','থৌবল':'NN','থ্যা':'NNP','থ্যাংকউ':'NN','থ্যাকারে':'NNP','থ্যালিয়াম':'NNP','থ্যে':'NNP',
'থ্রম্বসাস':'NNP','থ্রম্বোসিস':'NNP','থ্রাক্স':'NNP','থ্রি':'NN','থ্রিজির':'NN','থ্রী':'CD','দ-ঘন':'NN',
'দ':'NNP','দংশন':'VBG','দংশনকারী':'JJ','দংশনের':'NN','দংশেনি':'NN','দঃ':'NNP','দই-এর':'NN',
'দই':'NN','দইন্যতা':'NN','দইবড়া':'NN','দইয়ের':'NN','দওয়া':'VB','দকার':'NN','দকারান্ত':'JJ',
'দকিয়ানুস':'NN','দকের':'NN','দক্ষ':'NN','দক্ষজনগোষ্টী':'NN','দক্ষজা':'NN','দক্ষতার':'NN','দক্ষযজ্ঞ':'NNP',
'দক্ষসাবর্ণি':'NN','দক্ষিণ-পশ্চিম':'NN','দক্ষিণ-পশ্চিমি':'JJ','দক্ষিণ-পূর্ব':'NN','দক্ষিণ':'NN','দক্ষিণপন্থা':'NN','দক্ষিণপন্থীরাও':'NN',
'দক্ষিণপূর্ব':'NN','দক্ষিণরায়':'NN','দক্ষিণাবর্ত':'NN','দক্ষিণায়ণরত':'JJ','দক্ষিণায়ন':'NN','দক্ষিণে':'NN','দক্ষিণের':'NNP',
'দক্ষিণেশ্বরে':'NNP','দক্ষিন':'NN','দক্ষিনআফ্রিকা':'NN','দক্ষিনপন্থী':'JJ','দক্ষিনাঞ্চলে':'NN','দক্ষের':'NNP','দখমা':'NN',
'দখল':'NN','দখলকারী':'JJ','দখলদারকে':'NN','দখলদারবাহিনী':'NNS','দখলদারি':'NN','দখলদারীত্বের':'NN','দখলমুক্ত':'NN',
'দখলে':'NN','দগদগে':'NN','দগ্ধ':'VBN','দগ্ধরথ':'NN','দগ্ধাক্ষর':'NN','দজনক':'JJ','দজ্জাল':'NN',
'দটির':'NN','দড়াম্':'NN','দড়ি':'NN','দণ্ড':'NN','দণ্ডকবৃত্ত':'NN','দণ্ডকলা':'NN','দণ্ডগৌরী':'NN',
'দণ্ডতাম্রী':'NN','দণ্ডধারী':'NN','দণ্ডনীতি':'NN','দণ্ডনীয়':'JJ','দণ্ডবত':'NN','দণ্ডবিধির':'NN','দণ্ডাজ্ঞা':'NN',
'দণ্ডাদেশ':'NN','দণ্ডায়মান':'VBG','দণ্ডি':'NN','দণ্ডিত':'JJ','দণ্ডী':'NN','দতিয়া':'NN','দত্ত':'NN',
'দত্তকগ্রহণ':'NN','দত্তাত্রেয়':'NN','দত্তাত্রয়োপনিষদ':'NN','দত্তোলি':'NN','দদা':'NN','দদের':'NN','দধি':'NN',
'দধিমন্থনের':'NN','দধিমুখ':'NN','দধীচি':'NNP','দনষ্ট্রাল':'NN','দনার':'NN','দনায়ু':'NN','দনিক':'JJ',
'দনু':'NN','দনের':'NN','দন্ড':'NN','দন্ডবাসী':'NN','দন্ডবিধি':'NN','দন্ডাধিকারী':'NN','দন্ডায়মান':'VBG',
'দন্ডিত':'JJ','দন্ত-চিকিত্সক':'NN','দন্ত-মূলিকা':'NN','দন্ত':'NN','দন্তচিকিত্সা':'NN','দন্তপংক্তি':'NN','দন্তপুপ্পুট':'NN',
'দন্তবিহীন':'JJ','দন্তমাজন':'NN','দন্তযুক্ত':'JJ','দন্তলেখন':'NN','দন্তী':'NN','দন্তীয়':'JJ','দন্তুর':'JJ',
'দন্তেওয়াড়া':'NN','দন্তের':'NN','দন্তোলুখলিক':'NN','দন্তোষ্ঠ্য':'NN','দন্ত্যোষ্ঠ':'JJ','দপ':'VB','দপুর':'NNP',
'দপ্তর':'NN','দফতর':'NN','দফা':'NN','দফারফা':'NN','দফায়':'RB','দফ্তর':'NN','দবের':'NN',
'দভৌম':'JJ','দম-উনুন':'NN','দম':'NN','দমকল':'NN','দমকলকর্মী':'NN','দমকলা':'NN','দমঘোষ':'NN',
'দমদমের':'NNP','দমন-দিউ':'NN','দমন':'NN','দমনে':'NN','দমনের':'NN','দমসাজ':'NN','দমানো':'VB',
'দমায়ে':'NN','দমিত':'JJ','দমিয়ে':'VB','দমের':'NN','দম্পতি':'NN','দম্পতিদের':'NN','দম্পতিরই':'NN',
'দম্বল':'NN','দম্ভ':'NN','দম্ভভরে':'RB','দম্ভহীন':'JJ','দম্ভহীনতা':'NN','দম্ভে':'NN','দম্ভোক্তিভরা':'VBG',
'দময়ন্তী':'NN','দময়ী':'JJ','দয়া':'VB','দর-দাম':'NN','দর':'NN','দরকরা':'NN','দরকষাকষি':'NN',
'দরকার':'NN','দরকারআর':'VBN','দরকারও':'VBN','দরকারকারন':'VBN','দরকারটা':'NN','দরকারমত':'JJ','দরকারী':'NN',
'দরকারের':'VBN','দরকা‌রি':'JJ','দরখাস্ত':'NN','দরগা':'NN','দরজাটা':'NN','দরজাযুক্ত':'JJ','দরজার':'NN',
'দরদ':'NN','দরদি':'NN','দরপত্র':'NN','দরবার':'NN','দরবারিরা':'NN','দরবারীকান্হড়া':'NN','দরবারে':'NN',
'দরবেশরা':'NNS','দরাঙ্গ':'NN','দরাদরি':'NN','দরিদ্র':'NN','দরিদ্রতা':'NN','দরিদ্ররা':'NN','দরিমুখ':'NN',
'দরিয়া':'NN','দরিয়ামে':'NN','দরীযায়':'NN','দরীর':'NN','দরুণ':'JJ','দরূণ':'IN','দরূপ':'NN',
'দরে':'NN','দরেতারা':'NN','দরেস':'NN','দরোগাগিরী':'NN','দর্জি':'NN','দর্জিনী':'NN','দর্দ্':'NN',
'দর্প':'NN','দর্পণের':'NN','দর্পরোহিত':'JJ','দর্পশূণ্য':'JJ','দর্পহীন':'JJ','দর্পহীনতা':'NN','দর্পী':'JJ',
'দর্বি':'NN','দর্ভক':'NN','দর্রাজ':'NN','দর্শ':'NN','দর্শককে':'NNS','দর্শকগণ':'NN','দর্শকদের':'NNS',
'দর্শকবৃন্দ':'NN','দর্শকরা':'NN','দর্শণের':'NN','দর্শন':'NN','দর্শনকে':'NN','দর্শনশাস্ত্র':'NN','দর্শনাভিলাষী':'NN',
'দর্শনার্থি':'NN','দর্শনার্থে':'NNS','দর্শনীয়':'JJ','দর্শনে':'NN','দর্শনের':'NN','দর্শনোপনিষদ':'NN','দল-বল':'NN',
'দল':'NN','দলআজ':'NN','দলই':'NN','দলএর':'NN','দলও':'NN','দলকানা':'NN','দলকানাদের':'NNS',
'দলকানার':'NN','দলকানারা':'NNS','দলকে':'NN','দলগুলি':'NNS','দলগুলিকে':'NN','দলগুলির':'NNS','দলগুলো':'NNS',
'দলগুলোকে':'NN','দলগুলোর':'NNS','দলছুট':'NN','দলটা':'NN','দলটার':'NN','দলটি':'NN','দলটির':'NN',
'দলতো':'NN','দলত্যাগী':'NN','দলথভন':'NN','দলদাস':'NN','দলদাসরা':'VB','দলন':'NN','দলনামটা':'NN',
'দলনির্বাচনে':'NN','দলনেত্রী':'NN','দলপতি':'NN','দলবদল':'NN','দলবল':'NN','দলবাজ':'NN','দলবাজী':'NN',
'দলবেঁধে':'RB','দলভাঙার':'NN','দলভুক্ত':'VBN','দলমত':'NN','দলসর্বস্ব':'NN','দলা':'NN','দলাদলি':'NN',
'দলাধিপতী':'NN','দলান্ধ':'NN','দলায়':'NN','দলিত':'NN','দলিল':'NN','দলিয়ো':'NN','দলীপ':'NN',
'দলীয়':'NN','দলে':'NN','দলেন':'VB','দলেন্তী':'NN','দলের':'NN','দলেরা':'NN','দশ':'NN',
'দশকন্ধ':'NN','দশকীয়':'JJ','দশকে':'NN','দশকের':'NNS','দশগুণ':'NNS','দশগ্রীব':'NN','দশজন':'CD',
'দশজনের':'NN','দশটা':'NN','দশটি':'CD','দশদিন':'NNS','দশদিনে':'NN','দশনছেদ্য':'JJ','দশনামী':'NN',
'দশবারো':'CD','দশম':'NN','দশমভাব':'NN','দশমাংশ':'NN','দশমিক':'NN','দশমী':'NN','দশমুণ্ড':'NN',
'দশরথ':'NN','দশলক্ষের':'NN','দশলাখ':'NN','দশহরা':'NN','দশহাজার':'NN','দশা':'NN','দশাই':'NN',
'দশানন':'NN','দশাবতার':'NN','দশাভাল':'NN','দশার্ণ':'NNP','দশাস্য':'NN','দশাহ':'NN','দশায়':'NNS',
'দশে':'NN','দশেক':'JJ','দশের':'NN','দশোয়ী':'NN','দস্তমল':'NN','দস্তাঘটিত':'JJ','দস্তাচূর্ণ':'NN',
'দস্তানা':'NN','দস্তাবেজ':'NN','দস্তুর':'NN','দস্য':'NN','দস্যু-হৃদয়':'NN','দস্যু':'NN','দস্যুবৃত্তিতে':'NN',
'দহন':'NN','দহবহরা':'NN','দা':'NNS','দাঁড়':'NN','দাঁড়নো':'VB','দাঁড়ানো':'NN','দাঁড়িপাল্লা':'NN',
'দাঁড়িয়ে':'VB','দাঁড়িয়ে':'VBG','দাঁড়ী':'NN','দাঁত.':'NN','দাঁত':'NNS','দাঁতওয়ালা':'NN','দাঁতখোঁচানি':'NN',
'দাঁতন':'NN','দাঁতযুক্ত':'NN','দাঁতহীন':'NN','দাঁতাল':'JJ','দাঁতী':'NN','দাঁড়':'VB','দাঁড়াইয়াছে':'VB',
'দাঁড়াচ্ছে':'VBG','দাঁড়াতে':'VB','দাঁড়াতেও':'VBG','দাঁড়াতেন':'VB','দাঁড়ান':'VB','দাঁড়ানোর':'VB','দাঁড়াবার':'NNV',
'দাঁড়াবে':'VB','দাঁড়াল':'VB','দাঁড়ালেই':'RP','দাঁড়ালো':'VB','দাঁড়ি':'NNP','দাঁড়িপাল্লা':'NNS','দাঁড়িয়ে':'VBG',
'দাঁড়িয়েছিলেন':'VB','দাংগা':'NN','দাই':'NN','দাইবা':'NNP','দাইমা':'NN','দাউ':'VB','দাউদাউ':'VB',
'দাও':'NN','দাওয়ার':'NN','দাকে':'NN','দাক্ষায়ণী':'NN','দাক্ষিণশাল':'NN','দাক্ষিণাত্যের':'NNP','দাখিল':'NN',
'দাখিলের':'NN','দাগ':'NNS','দাগওয়ালা':'JJ','দাগর':'NN','দাগহীন':'JJ','দাগা':'NNS','দাগানো':'NN',
'দাগি':'NN','দাগী':'JJ','দাঙ্গা':'NN','দাচন':'NN','দাড়চিনি':'NN','দাড়াওয়ালা':'JJ','দাড়ি':'NN',
'দাড়িওয়ালা':'NN','দাডাবো':'NN','দাতব্য':'NN','দাতা':'NN','দাতিয়া':'NN','দাতে':'VB','দাদ':'NN',
'দাদবিহীন':'JJ','দাদরা':'NN','দাদশ্বশুর':'NN','দাদা':'NN','দাদাগিরি':'NN','দাদাদের':'NNS','দাদাবাবু':'NN',
'দাদার':'NN','দাদাশ্বশুড়':'NN','দাদাশ্বশুর':'JJ','দাদু':'NN','দাদুদয়াল':'NN','দাদুপন্থী':'NN','দাদুর':'NN',
'দাধর':'NN','দান-ধ্যান':'NN','দান-পত্র':'NN','দান':'NN','দানকর্তা':'NN','দানকারী':'NN','দানকেই':'NN',
'দানন্দই':'NN','দানপাত্র':'NN','দানপেটি':'NN','দানব':'NN','দানবারি':'NN','দানবিক':'JJ','দানবী':'NN',
'দানবীয়':'JJ','দানবের':'NNS','দানম্':'NN','দানযোগ্য':'JJ','দানশীল':'NN','দানশীলা':'NN','দানশৌণ্ড':'JJ',
'দানা':'NN','দানাদার':'JJ','দানাধিকারী':'NN','দানাযুক্ত':'JJ','দানার':'NN','দানাশস্য':'NN','দানি':'NN',
'দানী':'NN','দানীয়':'JJ','দানে':'NN','দানেচ্ছু':'JJ','দানের':'NN','দান্ডিয়া':'NN','দান্তেওয়াড়া':'NN',
'দাপট':'NN','দাপটেই':'NN','দাপুটে':'NN','দাপ্তরিক':'NN','দাবকী':'NN','দাবটি':'NN','দাবন':'NN',
'দাবনগেরে':'NN','দাবমো':'NN','দাবা':'NN','দাবানল':'NN','দাবাবা':'NN','দাবায়ে':'NN','দাবি':'NN',
'দাবিগুলো':'NNS','দাবিটি':'NN','দাবিতে':'NN','দাবিদার':'NN','দাবিল':'NN','দাবিয়ে':'VBN','দাবী':'NN',
'দাবীতে':'NN','দাবীদার':'NN','দাবীর':'NNS','দাবৌনি':'NN','দাবড়ানী':'NN','দাম':'NN','দামও':'NN',
'দামচন্দ্র':'NN','দামচা':'NN','দামতো':'JJ','দামনীতি':'NN','দামামা':'NN','দামাস্কাস':'NN','দামাহ':'NN',
'দামি':'NN','দামী':'JJ','দামে':'NN','দামের':'NN','দামোহ':'NN','দাম্পত্য':'JJ','দাম্ভিক':'NN',
'দাম্ভিকতাকে':'NN','দায়ভার':'NN','দায়িত্ব':'NN','দায়ী':'JJ','দারও':'NN','দারগা':'NN','দারচিনি':'NN',
'দারপ্রান্তে':'NN','দারভাঙা':'NN','দারস্ত':'NN','দারা':'NN','দারাজ':'NN','দারান':'NN','দারি':'NNP',
'দারিদ্র':'NN','দারিদ্রতার':'NN','দারিদ্রপীড়িত':'NN','দারিদ্রমুক্ত':'NN','দারিদ্রসহ':'NN','দারিদ্রসীমার':'NN','দারিদ্র্য':'NN',
'দারিদ্র্যসীমার':'NN','দারিয়েছে':'VB','দারী':'NN','দারুক':'NN','দারুগন্ধা':'NN','দারুণ':'NN','দারুন':'NN',
'দারুনভাবে':'RB','দারুফল':'NN','দারুহরিদ্রা':'NN','দারে':'NN','দারোগা':'NN','দারোয়ান':'NN','দার্জিলিং':'VBG',
'দার্জিলিঙ':'NN','দার্শনিক':'NN','দার্শনিকেরা':'NN','দালত':'NN','দালান':'NN','দালালদের':'NNS','দালালরা':'NN',
'দালালির':'NN','দালালের':'NN','দালেলা':'NN','দালয়':'NN','দাশগুপ্ত':'NNP','দাশু':'NNP','দাশুরি':'NN',
'দাস-সমাজব্যহস্থায়':'NN','দাস':'NN','দাসকরণ':'NN','দাসকে':'NNP','দাসত্ব':'NN','দাসদাসী':'NN','দাসদের':'NN',
'দাসানুদাস':'NN','দাসী':'NN','দাসের':'NNS','দাসেয়ী':'NN','দাস্য':'NN','দাহ':'NN','দাহক':'JJ',
'দাহকারি':'NN','দাহোদ':'NN','দাহ্য':'JJ','দাড়':'NN','দাড়াক':'VB','দাড়াতে':'NN','দাড়ান':'VB',
'দাড়ানো':'VB','দাড়াবার':'VB','দাড়াল':'VB','দাড়ালো':'VB','দাড়ি':'NN','দাড়িঁয়ে':'VB','দাড়িগোঁপের':'NN',
'দাড়িয়ে':'VB','দায়-দ্বায়িত্বের':'NN','দায়':'NN','দায়ক':'VBG','দায়দায়িত্ব':'NN','দায়বদ্ধতা':'NN','দায়বার':'JJ',
'দায়ভার':'NN','দায়রাজজ':'NN','দায়ি':'NN','দায়িত্ব':'NN','দায়িত্বজ্ঞান':'NN','দায়িত্বজ্ঞানহীন':'JJ','দায়িত্বজ্ঞানহীনতা':'NN',
'দায়িত্বটাই':'NN','দায়িত্বতবে':'NN','দায়িত্বপূর্ণ':'JJ','দায়িত্ববোধ':'NN','দায়িত্বভার':'NN','দায়িত্বরত':'JJ','দায়িত্বশীল':'NN',
'দায়িত্বহীন':'JJ','দায়িত্বে':'NN','দায়িত্ব্যে':'NN','দায়ী':'JJ','দায়ীত্ব':'NN','দায়ীদের':'NN','দায়ের':'VBN',
'দি':'NNP','দিই':'JJ','দিইনি':'NN','দিউ':'NN','দিও':'VB','দিওয়ান':'NN','দিক':'NN',
'দিকগুলিকে':'NN','দিকচক্রবাল':'NN','দিকট':'NN','দিকটায়':'NN','দিকদর্শন':'NN','দিকনির্ণায়ক':'JJ','দিকনির্ণয়কারী':'NN',
'দিকনির্দেশক':'NN','দিকপতি':'NN','দিকপাল':'NN','দিকভ্রষ্ট':'JJ','দিকশুল':'NN','দিকসূচক':'NN','দিকস্বামী':'NN',
'দিকা':'NN','দিকে':'NNS','দিকের':'NN','দিক্ষা':'NN','দিক্ষাপাল':'NN','দিখু':'NN','দিগদর্শক':'NN',
'দিগন্ত':'NN','দিগন্তবিস্তৃত':'JJ','দিগন্তে':'NN','দিগভ্রম':'NN','দিগভ্রষ্ট':'VB','দিগম্বর':'NN','দিগেশ':'NN',
'দিগ্গজ':'NN','দিগ্দর্শক':'NN','দিগ্বিজয়ী':'JJ','দিগ্বিজয়ে':'NN','দিগ্ভ্রম':'NN','দিগ্ভ্রষ্ট':'JJ','দিগ্ভ্রষ্টতা':'NN',
'দিগ্রাজ':'NN','দিঘি':'NN','দিঙ্ঘোচ':'NN','দিচ্ছ':'VBG','দিচ্ছিলেন':'VB','দিচ্ছেই':'VB','দিচ্ছেন':'VBG',
'দিছ':'VB','দিছিলেন':'VB','দিছেন':'VB','দিজ্ঞজেরা':'NN','দিজ্লা':'NN','দিণ্ডকল':'NN','দিত':'VB',
'দিতি':'NN','দিতুম':'VB','দিতে':'VB','দিতেও':'VB','দিতেছেন':'VB','দিতো':'JJ','দিতোনা':'NN',
'দিত্সু':'JJ','দিদা':'NN','দিদিমা':'NN','দিদির':'NN','দিদিশাশুড়ি':'NN','দিধিষু':'JJ','দিন-দিন':'RB',
'দিন-রাত':'NN','দিন':'NNP','দিনই':'NN','দিনকানা':'NN','দিনকে':'NN','দিনক্ষণ':'NN','দিনগুলো':'NNS',
'দিনচর্চা':'NN','দিনটা':'NN','দিনটি':'NN','দিনদিন':'NN','দিনদুপুরেই':'NN','দিননা':'NN','দিনপঞ্জিকা':'NN',
'দিনবদল':'NN','দিনব্যাপী':'NN','দিনভর':'RB','দিনমজুর':'NN','দিনমজুরী':'NN','দিনযে':'NNP','দিনরাত':'NN',
'দিনশেষে':'NN','দিনা':'NN','দিনাঙ্কিত':'JJ','দিনাজপুর':'NN','দিনান্তের':'NN','দিনান্ধ':'JJ','দিনাবসান':'NN',
'দিনার':'NN','দিনী':'NN','দিনেই':'NN','দিনের':'NN','দিনেশ':'NN','দিনোন্ধ':'NN','দিফু':'NN',
'দিব':'NN','দিবমিঢ':'NN','দিবস-অন্ধ':'NN','দিবস':'NN','দিবসটা':'NN','দিবসাভিসারিকা':'NN','দিবসীয়':'JJ',
'দিবসের':'NN','দিবা':'NN','দিবাকরের':'NN','দিবাঙ্গ':'NN','দিবারাত্রি':'NN','দিবালা':'NN','দিবালার':'NN',
'দিবাস্বপ্ন':'NN','দিবে':'VB','দিবেআমরা':'NN','দিবেদেশের':'NN','দিবেন':'VB','দিবেনা':'NN','দিবেসুস্থ্য':'NN',
'দিবো':'NN','দিবোদাস':'NN','দিবোল্কা':'NN','দিব্বি':'NN','দিব্যচক্ষু':'NN','দিব্যদৃষ্টি':'NN','দিব্যপুরুষ':'NN',
'দিব্যবাক্য':'NN','দিব্যভাবরূপের':'NN','দিব্যসরিতা':'NN','দিব্যাস্ত্র':'NN','দিব্যি':'NN','দিব্যেন্দুর':'NNP','দিমা':'NN',
'দিমুখি':'NN','দিয়ে':'IN','দিয়েছিল':'VB','দিয়েছেন':'VB','দিয়োনিসিয়ুস':'NNP','দিরও':'NN','দিরাত্র':'NN',
'দিরে':'NN','দিল':'VB','দিলখুশ':'JJ','দিলখোলা':'NN','দিলপসন্দ':'NN','দিলাম':'VB','দিলামগণতন্ত্র':'NN',
'দিলামজানি':'NN','দিলামসময়':'NN','দিলীপ':'NN','দিলুম':'VB','দিলে':'NN','দিলেই':'JJ','দিলেও':'NN',
'দিলেখালি':'NN','দিলেতো':'NN','দিলেনতাতে':'NN','দিলেপাবলিক':'NN','দিলের':'NN','দিলো':'VB','দিলো':'NN',
'দিলোপেট্রোল':'NN','দিল্ল':'NN','দিল্লি':'NNP','দিল্লিওয়ালা':'JJ','দিল্লিকেও':'NN','দিল্লিতে':'NNP','দিল্লী':'NN',
'দিল্লীতে':'NNP','দিশা-নির্দেশ':'NN','দিশা':'NN','দিশাওয়াকাশ':'NN','দিশাচক্ষু':'NN','দিশানির্দেশ':'NN','দিশাপতি':'NN',
'দিশাহীন':'JJ','দিশি':'JJ','দিস':'NN','দিসপুর':'NN','দিসে':'NN','দিস্তা':'NN','দিহিতা':'NN',
'দিহিতার':'NN','দিয়লী':'NN','দিয়া':'NN','দিয়াছিলেন':'VB','দিয়াছেন':'VB','দিয়ে':'IN','দিয়েই':'VB',
'দিয়েচে':'VB','দিয়েছি':'VB','দিয়েছিলাম':'VB','দিয়েছিলো':'VB','দিয়েছে':'NN','দিয়েছেএমন':'VB','দিয়েছেনতো':'VB',
'দিয়েন':'VB','দি‌তে':'VB','দি‌য়ে‌ছেন':'VB','দী':'NN','দীওয়ানী':'NN','দীক':'NN','দীক্ষা':'NN',
'দীক্ষায়ূপ':'NN','দীক্ষিত':'JJ','দীঘি':'NNP','দীতে':'NN','দীন':'NN','দীননাথ':'JJ','দীনবত্সল':'JJ',
'দীনবন্ধু':'NN','দীনশরণ':'JJ','দীনু':'NNP','দীনের':'NNP','দীনেশ':'JJ','দীনেশচন্দ্র':'NNP','দীপ':'NN',
'দীপকমালা':'NN','দীপকাবৃত্তি':'NN','দীপকে':'NN','দীপজালা':'NN','দীপদান':'NN','দীপমালা':'NN','দীপযোষ্ঠী':'NN',
'দীপশিখা':'NN','দীপাবতী':'NN','দীপিকা':'NN','দীপু':'NN','দীপ্ত':'NN','দীপ্ততা':'NN','দীপ্তিপূর্ণ':'JJ',
'দীপ্তিমান':'NN','দীপ্তিময়':'VB','দীপ্যমান':'JJ','দীরও':'NN','দীর্ঘ':'NN','দীর্ঘকায়':'JJ','দীর্ঘক্ষণ':'NN',
'দীর্ঘগামী':'JJ','দীর্ঘজিহ্বা':'NN','দীর্ঘজীবন':'NN','দীর্ঘতপা':'NN','দীর্ঘতা':'NN','দীর্ঘদণ্ডী':'NN','দীর্ঘদন্তবিশিষ্ট':'JJ',
'দীর্ঘদর্শিতা':'NN','দীর্ঘদর্শী':'JJ','দীর্ঘদিন':'NN','দীর্ঘদেহী':'NN','দীর্ঘনাস':'JJ','দীর্ঘপ্রজ্ঞ':'NN','দীর্ঘবাহু':'NN',
'দীর্ঘমূলা':'NN','দীর্ঘমেয়াদি':'NN','দীর্ঘমেয়াদী':'JJ','দীর্ঘমেয়াদে':'NN','দীর্ঘরত':'JJ','দীর্ঘরদ':'NN','দীর্ঘলোচন':'NN',
'দীর্ঘশ্বাস':'NN','দীর্ঘশ্বাসী':'JJ','দীর্ঘশ্রবা':'NN','দীর্ঘশ্রোত্রবিশিষ্ট':'JJ','দীর্ঘসময়':'NN','দীর্ঘসূএিতা':'NN','দীর্ঘসূত্রী':'JJ',
'দীর্ঘস্থায়ী':'NN','দীর্ঘাকার':'JJ','দীর্ঘাবয়ব':'JJ','দীর্ঘায়ু':'NN','দীর্ঘায়ত':'JJ','দীর্ঘায়ু':'NN','দীর্ঘিদন':'NN',
'দীর্ণ':'JJ','দীয়া':'NNP','দু-আড়াই':'CD','দু-এক':'CD','দু-একজন':'JJ','দু-চাকা':'NN','দু-তিন':'CD',
'দু-ধারা':'NN','দু':'CD','দুঃখ':'NN','দুঃখগাথা':'NN','দুঃখগ্রস্ত':'JJ','দুঃখজনক':'JJ','দুঃখজনকআর':'NN',
'দুঃখজনকশুধু':'NN','দুঃখদায়ী':'JJ','দুঃখপূর্ণ':'NN','দুঃখপ্রকাশ':'NN','দুঃখপ্রদ':'JJ','দুঃখভারাক্রান্ত':'JJ','দুঃখময়':'NN',
'দুঃখানুভূতি':'NN','দুঃখান্তক':'JJ','দুঃখান্তিক':'NN','দুঃখিত':'NN','দুঃখীদের':'NN','দুঃখীমুখ':'NN','দুঃখে':'NN',
'দুঃখেষ্বনুদ্বিগ্নমনা':'JJ','দুঃশল':'NN','দুঃশাষণের':'NN','দুঃশাসন':'NN','দুঃসংবাদ':'NN','দুঃসময়':'NN','দুঃসহ':'NN',
'দুঃসাধ্য':'JJ','দুঃসাহস':'NN','দুঃসাহসী':'JJ','দুঃসেবা':'NN','দুঃস্বপ্ন':'NN','দুঃস্বপ্নে':'NN','দুআনি':'NN',
'দুই-একবার':'RB','দুই-চারি':'CD','দুই-ধারী':'NN','দুই':'CD','দুইআড়াইজন':'NN','দুইই':'CD','দুইখানা':'NN',
'দুইগুণ':'JJ','দুইচাকার':'JJ','দুইজন':'NN','দুইটা':'NN','দুইটাকা':'NN','দুইটি':'NN','দুইটির':'NN',
'দুইদলকেই':'NN','দুইদিন':'NN','দুইধারা':'NN','দুইবার':'NN','দুইয়ের':'NN','দুএকজন':'CD','দুএকটা':'NN',
'দুএকদিন':'NN','দুএকবার':'RB','দুকর':'JJ','দুকে':'NN','দুক্কড়':'NN','দুক্কুলী':'NN','দুখঃ':'NN',
'দুখজনক':'NN','দুখণ্ড':'JJ','দুখানাকে':'NN','দুখিত':'NN','দুখে':'NN','দুগর':'NN','দুগর্ন্ধ':'NN',
'দুগাছা':'NN','দুগাসরা':'NN','দুগু':'NN','দুগুণ':'JJ','দুগ্ধ-পরিমাপক-ষন্ত্র':'NN','দুগ্ধ':'NN','দুগ্ধপায়ী':'JJ',
'দুগ্ধপোষ্য':'NN','দুগ্ধবতী':'JJ','দুগ্ধশালা':'NN','দুগ্ধহীন':'JJ','দুগ্ধাক্ষ':'NN','দুঘটনার':'NN','দুঙ্গরী':'NN',
'দুচাকা':'NN','দুচাকাবিশিষ্ট':'JJ','দুচারটে':'CD','দুজ':'NN','দুজনই':'NN','দুজনকেই':'NN','দুজনায়':'NN',
'দুজনেই':'NN','দুজনেরই':'NN','দুটি':'CD','দুটিআত্মবিক্রয়ের':'NN','দুটিই':'NN','দুটুকরো':'JJ','দুটো':'NN',
'দুটো':'NN','দুটোরই':'NN','দুতরফা':'JJ','দুতাবাস':'NN','দুতাবাসের':'NN','দুতিকা':'NN','দুতিনজন':'NN',
'দুতী':'NN','দুদক':'NN','দুদককে':'NN','দুদকের':'NN','দুদদকেও':'NN','দুদশ':'NN','দুদামী':'NN',
'দুদিকে':'NN','দুদিন':'CD','দুদিনই':'NN','দুদুক':'NN','দুদুবার':'NN','দুদে':'NN','দুদেভ্যান্ত':'NN',
'দুদ্ধী':'NN','দুধ':'NN','দুধধারা':'NN','দুধপিঠে':'NN','দুধফেনী':'NN','দুধভাত':'NN','দুধযুক্ত':'JJ',
'দুধরাজ':'NN','দুধারে':'NN','দুধিয়া':'NN','দুধে':'NN','দুধেল':'NN','দুধ্ওয়া':'NNP','দুন':'NN',
'দুনম্বরি':'NN','দুনর্ীতি':'NN','দুনলী':'NN','দুনসরিস':'NN','দুনিতি':'NN','দুনিয়া':'NN','দুনিয়ায়':'NN',
'দুনিয়াকে':'NN','দুনিয়াজোড়া':'NN','দুনিয়াতে':'NN','দুনিয়ার':'NN','দুনীতি':'NN','দুন্দুভি':'NN','দুপক্ষের':'NN',
'দুপথেই':'NN','দুপাশ':'NN','দুপায়ের':'NN','দুপুর':'NN','দুপুরে':'NN','দুপেয়ে':'VB','দুবছর':'NN',
'দুবজ্যোয়া':'NN','দুবস্যু':'NN','দুবাই':'NN','দুবার':'CD','দুবারের':'NN','দুবাহু':'NN','দুবৃত্তদের':'NN',
'দুবে':'NN','দুব্যঘাস':'NN','দুভাগ':'NN','দুম':'NN','দুমড়ে':'NN','দুমদাম':'RB','দুমদুম':'NN',
'দুমাস':'NN','দুমুখো':'NN','দুম্বা':'NN','দুযনের':'NN','দুর':'RB','দুরখা':'NN','দুরগতি':'NN',
'দুরঙা':'JJ','দুরত্ব':'NN','দুরদুর':'VB','দুরনিতি':'NN','দুরন্ত':'JJ','দুরন্তপনা':'NN','দুরপনেয়':'JJ',
'দুরবল':'NN','দুরবস্থা':'NN','দুরবীন':'NN','দুরব্যাবহার':'NN','দুরভিপ্রায়ী':'JJ','দুরভিসন্ধি':'NN','দুরম':'NN',
'দুরাকাঙ্খ':'NN','দুরাচার':'NN','দুরাচারিতা':'NN','দুরাচারী':'JJ','দুরাত্মা':'NN','দুরাধন':'NN','দুরান্ত':'JJ',
'দুরাবস্থা':'NN','দুরারাধ্য':'JJ','দুরারোগ্য':'NN','দুরালাপ':'NN','দুরাশাই':'NN','দুরুক্তি':'NN','দুরুত্ব':'NN',
'দুরূহ':'JJ','দুরে':'NN','দুর্কল':'NN','দুর্গত':'JJ','দুর্গতি':'NN','দুর্গন্ধ':'NN','দুর্গন্ধপূর্ণ':'JJ',
'দুর্গন্ধযুক্ত':'NN','দুর্গন্ধিত':'VB','দুর্গম':'NN','দুর্গাপদের':'NN','দুর্গাপুর':'NNP','দুর্গোত্সব':'NN','দুর্গ্রাহ্য':'JJ',
'দুর্ঘটনা':'NN','দুর্ঘটনার':'NN','দুর্ঘটার':'NN','দুর্জন':'NN','দুর্দম':'NN','দুর্দমনীয়':'JJ','দুর্দর্শন':'NN',
'দুর্দশাগ্রস্ত':'NN','দুর্দিন':'NN','দুর্দৈব':'NN','দুর্ধর':'NN','দুর্নাম':'NN','দুর্নিতি':'NN','দুর্নিতী':'NN',
'দুর্নিবার্য':'JJ','দুর্নীতি':'NN','দুর্নীতিকে':'NN','দুর্নীতিগুস্ত':'NN','দুর্নীতিগ্রস্থ':'NN','দুর্নীতিটা':'NN','দুর্নীতিতে':'NN',
'দুর্নীতিবাজদের':'NN','দুর্নীতিমুক্ত':'NN','দুর্নীতিলুটপাট':'NN','দুর্নীতে':'NN','দুর্বল':'NN','দুর্বলতাই':'NN','দুর্বলের':'NN',
'দুর্বার':'NN','দুর্বিনীত':'JJ','দুর্বিমোচন':'NN','দুর্বিষহ':'NN','দুর্বুদ্ধি':'NN','দুর্বৃত্তদের':'NN','দুর্বৃত্তি':'NN',
'দুর্বেষ্টিকা':'NN','দুর্বোধ্য':'JJ','দুর্ব্যবহার':'NN','দুর্ব্যবহারকারী':'JJ','দুর্ভাগা':'NN','দুর্ভাগ্যক্রমে':'NN','দুর্ভাগ্যজনক':'JJ',
'দুর্ভাগ্যের':'NN','দুর্ভিক্ষ':'NN','দুর্ভিক্ষপীড়িত':'JJ','দুর্ভিক্ষের':'NN','দুর্ভেদ্য':'JJ','দুর্ভোগে':'NN','দুর্মদ':'NN',
'দুর্মর্ষণ':'NN','দুর্মিল':'NN','দুর্মুখ':'NN','দুর্যোগ':'NN','দুর্যোগপূর্ণ':'JJ','দুর্যোগে':'NN','দুর্লভ':'NN',
'দুল.':'NN','দুলকি':'NN','দুলদুল':'NN','দুলন':'NN','দুলাখ':'NN','দুলালচন্দ্র':'NNP','দুলি':'NN',
'দুশমত':'NN','দুশমনদের':'NN','দুশলা':'NN','দুশো':'JJ','দুশ্চর':'NN','দুশ্চরিত্রা':'NN','দুশ্চিন্তন':'NN',
'দুশ্চিন্তার':'NN','দুষনে':'NN','দুষিত':'VBN','দুষ্কর':'NN','দুষ্কর্ম':'NN','দুষ্কর্মকারী':'JJ','দুষ্কৃতি':'NN',
'দুষ্কৃতিকারীদের':'NN','দুষ্কৃত্য':'NN','দুষ্খদির':'NN','দুষ্ট':'NN','দুষ্টচেতা':'NN','দুষ্টবুদ্ধিসম্পন্ন':'JJ','দুষ্টমতি':'JJ',
'দুষ্টা':'NN','দুষ্টামি':'NN','দুষ্টু':'JJ','দুষ্টুমি':'NN','দুষ্পাচ্য':'JJ','দুষ্প্রধর্ষ':'NN','দুষ্প্রবৃত্তি':'NN',
'দুষ্প্রহর্ষ':'NN','দুষ্প্রাপ্য':'JJ','দুষ্মন্ত':'NN','দুষ্যোদর':'NN','দুসরা':'NNP','দুসান্বে':'NN','দুসুতো':'NN',
'দুস্কর':'NN','দুস্তর':'JJ','দুহাত':'NN','দুহিয়া':'NN','দু্র্ভোগে':'NN','দুয়া':'NN','দুয়ারে':'NN',
'দুয়ালি':'NN','দুয়ে':'CD','দুয়েকটা':'NN','দুয়ো':'NN','দূঃখে':'NN','দূত':'NN','দূতাবাস':'NN',
'দূতাবাসে':'NN','দূতি':'NN','দূতীর':'NN','দূদককে':'NN','দূনীতির':'NN','দূভিক্ষ':'NN','দূর':'RB',
'দূরকরুন':'NN','দূরকারী':'JJ','দূরতম':'NN','দূরত্বকে':'NN','দূরত্বের':'NN','দূরদর্শন-তন্ত্র':'NN','দূরদর্শন':'NN',
'দূরদর্শিতা':'NN','দূরদৃষ্টি':'NN','দূরদ্রষ্টা':'JJ','দূরন্ত':'NN','দূরবর্তী':'JJ','দূরবীণ':'NN','দূরভাষ':'NN',
'দূরলিখ':'NN','দূরসঞ্চার':'NN','দূরস্থ':'JJ','দূরাগত':'JJ','দূরাভাস':'NN','দূরীকরণ':'NN','দূরীকৃত':'JJ',
'দূরুহ':'JJ','দূরে':'RB','দূরের':'NN','দূর্গ':'NN','দূর্গন্ধময়':'NN','দূর্গপতি':'NN','দূর্গা-নবমী':'NN',
'দূর্গাপূজা':'NN','দূর্গার':'NNP','দূর্গাষ্টমী':'NN','দূর্গোত্সব':'NN','দূর্ঘটনার':'NN','দূর্ণীতি':'NN','দূর্ণীতিবাজরা':'NNS',
'দূর্ণীতিমুক্ত':'NN','দূর্দশা':'NN','দূর্নাম':'NN','দূর্নিতি':'NN','দূর্নীতি':'NN','দূর্নীতিদেশের':'NN','দূর্নীতিবাজ':'NNP',
'দূর্নীতিবাজদের':'NN','দূর্নীতিমুক্ত':'NN','দূর্নীতিসৎ':'NN','দূর্নীতেতে':'NN','দূর্বল':'NN','দূর্বলের':'NN','দূর্বা-ফুল':'NN',
'দূর্বার':'NN','দূর্বিত্তায়ন':'NN','দূর্ব্যবহার':'NN','দূর্ভাগ্য':'NN','দূর্ভোগ':'VBG','দূর্লভ':'NN','দূষণ':'NN',
'দূষণকারী':'NN','দূষণে':'NN','দূষন':'NN','দূষিত':'NN','দৃগ্বিষ':'NN','দৃঢ়-নেমি':'NN','দৃঢ়':'NN',
'দৃঢ়ক্ষত্র':'NN','দৃঢ়চ্যুত':'NN','দৃঢ়তা':'NN','দৃঢ়তাপূর্ণ':'JJ','দৃঢ়তাপূর্বক':'RB','দৃঢ়তার':'NN','দৃঢ়তাহীন':'JJ',
'দৃঢ়দস্যু':'NN','দৃঢ়নেত্র':'NN','দৃঢ়পদ':'NN','দৃঢ়প্রতিজ্ঞ':'NN','দৃঢ়বর্মা':'NN','দৃঢ়ভাবে':'RB','দৃঢ়রথ':'NN',
'দৃঢ়সন্ধ':'NN','দৃঢ়হস্ত':'NN','দৃঢ়াযুদ্ধ':'NN','দৃঢ়াশ্ব':'NN','দৃঢ়ায়ু':'NN','দৃপ্ত':'JJ','দৃশ্য-বর্ণণ':'NN',
'দৃশ্য':'NN','দৃশ্যকাব্য':'NN','দৃশ্যগুলি':'NN','দৃশ্যগ্রহণ':'NN','দৃশ্যটা':'NN','দৃশ্যত':'RB','দৃশ্যপট':'NN',
'দৃশ্যবর্ণণ':'NN','দৃশ্যমান':'JJ','দৃশ্যান্ত':'NN','দৃশ্যাবলী':'NN','দৃশ্যে':'NN','দৃষদবতী':'NN','দৃষ্ট':'NN',
'দৃষ্টান্তমুলক':'JJ','দৃষ্টান্তমূল্ক':'JJ','দৃষ্টি':'NN','দৃষ্টিকোণ':'NN','দৃষ্টিগোচর':'JJ','দৃষ্টিতে':'NN','দৃষ্টিধৃক':'NN',
'দৃষ্টিনন্দন':'VBG','দৃষ্টিপটল':'NN','দৃষ্টিবান':'JJ','দৃষ্টিবিভ্রম':'NN','দৃষ্টিভঙ্গি':'NN','দৃষ্টিভঙ্গির':'NN','দৃষ্টিভঙ্গীতেই':'NN',
'দৃষ্টিভ্রম':'NN','দৃষ্টিশক্তি':'NN','দৃষ্টিশক্তিসম্পন্ন':'JJ','দৃষ্টিসীমা':'NN','দৃষ্টিহীন':'JJ','দৃষ্টিহীনতচা':'NN','দৃস্টি':'NN',
'দৃস্টিভংগির':'NN','দৃড়':'NN','দৃঢ়':'NN','দৃঢ়তা':'NN','দৃঢ়ত্বের':'NN','দৃঢ়ভিত্তির':'NN','দে-না':'VB',
'দে':'VB','দেঁতো':'JJ','দেই':'JJ','দেইও':'NN','দেইখা':'VB','দেইনা':'NN','দেইনি':'VB',
'দেইলিয়া':'NN','দেউরি':'NN','দেউলিয়া':'NN','দেউলিয়ত্ব':'NN','দেউলিয়াআর':'NN','দেউলে':'NN','দেউস':'NNP',
'দেওগঙ্গ':'NN','দেওঘর':'NN','দেওয়া':'VBN','দেওয়ার':'NN','দেওর':'NN','দেওলিয়া':'NN','দেওয়া':'VBN',
'দেওয়াই':'NN','দেওয়াকিন্তু':'NN','দেওয়াটা':'NN','দেওয়ানগঞ্জ':'NNP','দেওয়ানি':'NN','দেওয়ানো':'VB','দেওয়ার':'NN',
'দেওয়াললদন্ড':'NN','দেওয়ালা':'NN','দেওয়ালেন':'VB','দেওয়ালের':'NN','দেওয়ায়':'VBN','দেখ':'VB','দেখগুলো':'VB',
'দেখচ্ছে':'VB','দেখছি':'VB','দেখছিনা':'VBG','দেখছিনে':'VB','দেখছিসব':'VB','দেখছে':'VBG','দেখতাছি':'VBG',
'দেখতাম':'VB','দেখতে':'NN','দেখতেই':'VB','দেখতেছি':'VBG','দেখতেতো':'VB','দেখদে':'VB','দেখন':'VB',
'দেখনদারি':'NN','দেখনি':'VB','দেখনোর':'VB','দেখব':'VB','দেখবাল':'VB','দেখবেন':'VB','দেখবো':'NN',
'দেখবোরে':'VB','দেখভাল':'VB','দেখলাম':'VB','দেখলেই':'VB','দেখলেন':'VB','দেখা-শোনা':'JJ','দেখা-সাক্ষাত্':'VB',
'দেখা':'VB','দেখাইছ':'VB','দেখাইছে':'VBG','দেখাইনি':'VB','দেখাইলেও':'VB','দেখাক':'VB','দেখাচেছ':'VB',
'দেখাচ্ছেআর':'VB','দেখাটা':'VB','দেখাতে':'VB','দেখাদেখি':'NN','দেখান':'VB','দেখানু':'VBG','দেখানো':'NN',
'দেখানোর':'VB','দেখাবে':'VB','দেখায়':'VB','দেখার':'NN','দেখারও':'VB','দেখালে':'VB','দেখালেন':'VB',
'দেখাশুনা':'VB','দেখাশুনো':'NN','দেখাশোনার':'NN','দেখায়':'VB','দেখায়নি':'VB','দেখা‌বে':'VB','দেখি':'VB',
'দেখিতে':'VB','দেখিনা':'VB','দেখিনাদাম':'NN','দেখিনি':'NN','দেখিয়ে':'VBG','দেখিয়া':'VB','দেখিয়ে':'VBG',
'দেখিয়েছিলেন':'VB','দেখিয়েছে':'VBD','দেখিয়েছো':'NN','দেখুক':'NN','দেখুন':'VB','দেখে':'NN','দেখেও':'VB',
'দেখেছি':'NN','দেখেছিলাম':'NN','দেখেছিসুতরাং':'NN','দেখেছে':'VBN','দেখেন':'VB','দেখেননি':'NN','দেখেনি':'NN',
'দেখেশুনে':'RB','দেখো':'VB','দেখ‌ছে':'VBG','দেগুইতো':'NN','দেগে':'NN','দেজ':'NN','দেড়':'JJ',
'দেড়শো':'NN','দেতীবৃক্ষ':'NN','দেদারচে':'NN','দেদীপ্যমান':'JJ','দেন':'VB','দেনখালি':'NN','দেনতাহলেই':'NN',
'দেননা':'NN','দেননিতাই':'NN','দেনা':'NN','দেনার':'NN','দেব-ঋণ':'NN','দেব-নাগরী':'NN','দেব-মন্দির':'NN',
'দেব':'NN','দেবইচ্ছা':'NN','দেবক':'NN','দেবকন্যা':'NN','দেবকাষ্ঠ':'NN','দেবকিরি':'NN','দেবকী':'NN',
'দেবকুল্যা':'NN','দেবকূল':'NN','দেবগড়':'NN','দেবগান্ধার':'NN','দেবগায়ন':'NN','দেবগিরী':'NN','দেবগৃহ':'NN',
'দেবঘন':'NN','দেবচিকিতসক':'NN','দেবতা':'NN','দেবতাকৃত':'JJ','দেবতাতুল্য':'JJ','দেবতাদের':'NNS','দেবতার':'NN',
'দেবতুল্য':'JJ','দেবত্র':'NN','দেবদত্ত':'NN','দেবদারু':'NN','দেবদাস':'NN','দেবদাসকে':'NNP','দেবদাসী':'NN',
'দেবদূত':'NN','দেবদেবীর':'NNP','দেবনাগরী':'NN','দেবনাথ':'NNP','দেবনিন্দুক':'JJ','দেবন্দ্রনাথ':'NNP','দেবপুরী':'NN',
'দেবপূজ্য':'NN','দেবপ্রয়াগ':'NN','দেববতী':'NN','দেববন্দ':'NN','দেববর্ণিনী':'NN','দেববাণী':'NN','দেববেহাগ':'NN',
'দেবব্রত':'NN','দেবভাষা':'NN','দেবমন্দির':'NN','দেবমানক':'NN','দেবযাত্রী':'NN','দেবযানি':'NN','দেবযোনি':'NN',
'দেবর':'NN','দেবরক্ষিত':'NN','দেবরাজ':'NN','দেবরানি':'NN','দেবর্ষি':'NN','দেবল':'NN','দেবশাখ':'NN',
'দেবসময়':'NN','দেবসুলভ':'JJ','দেবসেনা':'NN','দেবস্থান':'NN','দেবাংশধারী':'JJ','দেবাঙ্গনা':'NN','দেবাচার্য':'NN',
'দেবাতঙ্ক':'NN','দেবাতিথি':'NN','দেবাদাবদি':'NN','দেবানন্দের':'NNP','দেবানিক':'NN','দেবার':'NN','দেবাশিস':'NN',
'দেবাস':'NN','দেবাহুতি':'NN','দেবি':'NN','দেবী-প্রতিমা':'NN','দেবী-মন্দির':'NN','দেবী':'NN','দেবীকে':'NNP',
'দেবীপূজার':'NN','দেবীমন্দির':'NN','দেবীর':'NN','দেবীস্থান':'NN','দেবে':'JJ','দেবেগৌড়া':'NN','দেবেজ্য':'NN',
'দেবেন':'VB','দেবেন্দ্র':'NN','দেবেন্দ্রনাথ':'NNP','দেবেশী':'NN','দেবেহাহাহাহা':'NN','দেবো':'NN','দেবোত্থান':'NN',
'দেমী':'JJ','দেয়':'NN','দেয়া':'VBN','দেয়ার':'NN','দের':'NN','দেরও':'NN','দেরটা':'RB',
'দেরা':'NN','দেরাদুন':'NN','দেরি':'NN','দেরিতে':'RB','দেরী':'RB','দেল':'NN','দেলদুয়ারে':'NN',
'দেলা':'NN','দেশ-এ':'NN','দেশ-প্রেম':'NN','দেশ':'NN','দেশউন্নয়ন':'NN','দেশএ':'NN','দেশক':'NN',
'দেশকার':'NN','দেশকে':'NN','দেশগান্ধার':'NN','দেশগুলাতে':'NNS','দেশগুলিকে':'NN','দেশগুলিতে':'NNS','দেশগুলো':'NNS',
'দেশগুলোতে':'NN','দেশগুলোর':'NNS','দেশজ':'JJ','দেশজুড়ে':'NN','দেশটা':'NN','দেশটাও':'NN','দেশটাকে':'NN',
'দেশটি':'NN','দেশটিতে':'NN','দেশতাই':'NN','দেশত্যাগী':'JJ','দেশদ্রোহী':'NN','দেশদ্রোহীতার':'NN','দেশদ্রোহীদের':'NNS',
'দেশনেতা':'NN','দেশপিছিয়ে':'NN','দেশপ্রেম':'NN','দেশপ্রেমিকরা':'NNS','দেশপ্রেমী':'NN','দেশপ্রেমীর':'NN','দেশপ্রেমের':'NN',
'দেশবাংলাদেশের':'NN','দেশবাসী':'NN','দেশবাসীকে':'NNS','দেশবাসীরা':'NN','দেশব্যপী':'JJ','দেশভক্ত':'NN','দেশভাগের':'NN',
'দেশভারতীয়':'JJ','দেশমল্লার':'NN','দেশময়':'JJ','দেশরক্ষা':'NN','দেশরত্ন':'NN','দেশলাই':'NN','দেশসমূহকে':'NNS',
'দেশসমূহের':'NN','দেশসুদ্ধ':'JJ','দেশহিত':'NN','দেশাই':'NN','দেশাখ্য':'NN','দেশাঙ্কী':'NN','দেশাচার':'NN',
'দেশাটন':'NN','দেশান্তরী':'NN','দেশি':'NN','দেশী':'NN','দেশীরাও':'NN','দেশীয়':'JJ','দেশীয়দের':'NN',
'দেশে':'NN','দেশেও':'NN','দেশেরই':'NN','দেশো':'NNP','দেশোদ্রোহিদের':'NNS','দেসবালী':'NN','দেসাই':'NN',
'দেহ-মন':'NN','দেহ':'NN','দেহটা':'NN','দেহদৈর্ঘ্য':'NN','দেহধারী':'JJ','দেহবান':'JJ','দেহবুদ্ধির':'NN',
'দেহমন':'NN','দেহরক্ষী':'NN','দেহরহিত':'JJ','দেহলি-দীপক':'NN','দেহাতি':'NN','দেহাত্মবাদ':'NN','দেহান':'NN',
'দেহিকা':'NN','দেহে':'NN','দোষ':'NN','দোস্ত':'NN','দোয়া':'NN','দেড়':'NN','দেড়ঘণ্টা':'NN',
'দেড়দুবছরই':'NNS','দেড়শ':'NN','দেড়শত':'VBN','দেয়':'NNS','দেয়আমার':'NN','দেয়আশা':'JJ','দেয়ই':'NN',
'দেয়এরা':'NN','দেয়তাহলে':'RB','দেয়না':'JJ','দেয়নি':'NN','দেয়ভারতীয়রা':'NN','দেয়সেখানে':'RB','দেয়া':'VBN',
'দেয়াই':'VB','দেয়াটা':'VB','দেয়ানেয়ার':'VB','দেয়ার':'NN','দেয়াল':'NNS','দেয়ালগুলি':'NN','দেয়ালগুলিতে':'NNS',
'দেয়ালে':'NN','দেয়ালের':'NNS','দেয়াশলাইর':'NN','দেয়ায়':'NN','দেয়ে':'VBG','দে‌শের':'NN','দৈত্য':'NN',
'দৈত্যাকার':'JJ','দৈত্যারি':'NN','দৈনন্দিন':'JJ','দৈনন্দিনী':'NN','দৈনিক':'JJ','দৈনিকী':'NN','দৈন্য':'NN',
'দৈন্যদশা':'NN','দৈব':'NN','দৈবজাত':'JJ','দৈববাণী':'NN','দৈববাদী':'NN','দৈবমণি':'NN','দৈবিক':'JJ',
'দৈবী':'NN','দৈবে':'RB','দৈব্য':'NN','দৈরথ':'NN','দৈর্ঘ্য':'NN','দৈহিক':'JJ','দৈহিকধর্ম':'NN',
'দোঁহা':'NN','দোআ':'NNS','দোক':'NN','দোকান-চুরি':'NN','দোকান':'NN','দোকানদারী':'NN','দোকানদারেরা':'NNS',
'দোকানদের':'NN','দোকানেই':'NN','দোকান্দার':'NN','দোকাহা':'NN','দোঙ্গা':'NN','দোজখ':'NN','দোজবরপু':'NN',
'দোজবরপুং':'JJ','দোজাই':'NN','দোতলা':'NN','দোতালায়':'NN','দোদিন':'NN','দোদুল্যমান':'JJ','দোদুল্যমানতা':'NN',
'দোধক':'NN','দোধারা':'NN','দোনলা':'JJ','দোনা':'NNP','দোনালা':'JJ','দোপেঁয়াজা':'NN','দোভাষী':'NN',
'দোমহলা':'NN','দোয়া':'NNS','দোরঙা':'JJ','দোল':'NN','দোলগতিযুক্ত':'JJ','দোলন':'NN','দোলনকালে':'NN',
'দোলনায়':'NN','দোলাচাল':'NN','দোলানো':'VB','দোলায়মান':'JJ','দোশ':'NN','দোষ-ত্রুটি':'NN','দোষ':'NN',
'দোষক্ষালন':'NN','দোষগুলা':'NN','দোষটা':'NN','দোষত্রুটি':'NN','দোষনির্ণয়':'NN','দোষপূর্ণতা':'NN','দোষযুক্ত':'NN',
'দোষসরকার':'NN','দোষহীন':'JJ','দোষাপনয়':'NN','দোষারোপ':'NN','দোষারোপের':'NN','দোষি':'NN','দোষীকে':'NN',
'দোষীব্যক্তির':'NN','দোষে':'NN','দোষের':'NN','দোস':'NN','দোসরদের':'NN','দোসা':'NN','দোহন':'VBG',
'দোহননো':'VB','দোহর':'NN','দোহাই':'VB','দোহারা':'JJ','দোহায়':'NN','দোড়ে':'NN','দোয়রী':'NN',
'দোয়া':'VB','দোয়াঁশ':'NN','দোয়াঙ্গ':'NN','দোয়াত':'NN','দোয়াব':'NN','দোয়ায়':'NN','দোয়েল':'NN',
'দৌঁড়নো':'VB','দৌঁড়ায়':'NN','দৌড়-ঝাঁপ':'VBG','দৌড়':'NN','দৌড়নো':'VB','দৌড়বীর':'NN','দৌড়াদৌড়ি':'VBG',
'দৌড়ানো':'VBG','দৌত্য':'NN','দৌরাত্ম':'NN','দৌরাত্য':'NN','দৌর্বল্য':'NN','দৌলত':'NN','দৌলতে':'RB',
'দৌহিত্র':'NN','দৌড়':'VB','দৌড়াতে':'VB','দৌড়াদৌড়ি':'VB','দৌড়ানো':'VB','দৌড়াবে':'VB','দৌড়ে':'NN',
'দ্দশ':'CD','দ্দি':'NNP','দ্ধা':'NN','দ্ধু':'NN','দ্বন্দ':'NN','দ্বন্দ্ব':'NN','দ্বন্দ্বমূলক':'JJ',
'দ্বন্দ্বযুদ্ধে':'VB','দ্বন্দ্বহীন':'JJ','দ্বাদশ':'NN','দ্বাদশতম':'JJ','দ্বাদশরাত্র':'NN','দ্বাদশাংশু':'NN','দ্বাপর':'NN',
'দ্বাবিংশ':'CD','দ্বাবিংশতি':'NN','দ্বার':'NN','দ্বারকানথের':'NNP','দ্বারকে':'NNP','দ্বারকেশ্বরের':'NNP','দ্বারপতি':'NN',
'দ্বারপালক':'NN','দ্বারবন্ধে':'PSP','দ্বারসন্ধি':'NN','দ্বারা NP':'NN','দ্বারা':'RB','দ্বারাই':'NN','দ্বারাধ্যক্ষ':'NN',
'দ্বারিকা':'FW','দ্বারিকাপুরি':'NN','দ্বারে-দ্বারে':'RB','দ্বারে':'NN','দ্বাড়ালো':'NN','দ্বায়িত্ব':'NN','দ্বায়িত্বশীল':'JJ',
'দ্বায়িত্বে':'NN','দ্বি':'NN','দ্বিকর্মক':'NN','দ্বিখণ্ডক':'JJ','দ্বিখন্ডিত':'VBN','দ্বিগু':'NN','দ্বিগুণ':'JJ',
'দ্বিগুণের':'NN','দ্বিগুন':'JJ','দ্বিঘাত':'NN','দ্বিচক':'NN','দ্বিচারী':'JJ','দ্বিজ':'NN','দ্বিজন্মা':'JJ',
'দ্বিজপতি':'NN','দ্বিতল':'NN','দ্বিতলসেতুর':'NN','দ্বিতীয়':'NN','দ্বিতীয়ত':'RB','দ্বিতীয়':'NN','দ্বিতীয়টি':'NN',
'দ্বিতীয়তঃ':'RB','দ্বিতীয়বার':'NN','দ্বিতীয়ার্ধ':'NN','দ্বিধা-দ্বন্দ্ব-সংশয়':'NN','দ্বিধা':'NN','দ্বিধাগ্রস্ত':'NN','দ্বিধাগ্রস্থ':'JJ',
'দ্বিধাদ্বন্দে':'NN','দ্বিধাবোদ':'NN','দ্বিধাহীন':'JJ','দ্বিধায়':'NN','দ্বিপ':'NN','দ্বিপক্ষীয়':'NN','দ্বিপদ':'JJ',
'দ্বিপাক্ষিক':'NN','দ্বিপ্রহরে':'NN','দ্বিবর্ষজীবী':'JJ','দ্বিবর্ষীয়':'NN','দ্বিবাহু':'JJ','দ্বিবিদ':'NN','দ্বিবীজপত্র':'NN',
'দ্বিবীজপত্রী':'JJ','দ্বিবেদি':'NN','দ্বিভাষিক':'NN','দ্বিভুজ':'JJ','দ্বিমত':'NN','দ্বিমতপোষণকারী':'JJ','দ্বিযুগ্মজ':'NN',
'দ্বিরদ':'NN','দ্বিরাগত':'JJ','দ্বিরাগমন':'NN','দ্বীতিয়':'VB','দ্বীপ':'NN','দ্বীপপুঞ্জ':'NN','দ্বীপবাসী':'NN',
'দ্বীপসমূহ':'NN','দ্বীপিয়':'JJ','দ্বীপীয়':'NN','দ্বেষ':'NN','দ্বেষপূর্ণ':'JJ','দ্বেষপূর্ণতা':'NN','দ্বেষপূর্বক':'RB',
'দ্বেষহীন':'NN','দ্বেষহীনভাবে':'RB','দ্বৈত':'NN','দ্বৈতবাদী':'NN','দ্বৈপায়ন':'NN','দ্বৈমাতুর':'NN','দ্ব্যর্থতা':'NN',
'দ্ব্যাক্ষায়ণ':'NN','দ্য':'NN','দ্যত':'JJ','দ্যা':'NN','দ্যাখো':'VB','দ্যাশকে':'NN','দ্যু-মণি':'NN',
'দ্যুতমত্':'NN','দ্যুতশালা':'NN','দ্যুতি':'NN','দ্যুতিমান':'NN','দ্যুম্নিক':'NN','দ্যূতক্রীড়া':'NN','দ্যূতগৃহ':'NN',
'দ্র':'FW','দ্রই':'NN','দ্রক':'NNP','দ্রণ':'NN','দ্রব':'NN','দ্রবচালিত':'JJ','দ্রবণ':'NN',
'দ্রবণের':'NN','দ্রবীকরণ':'NN','দ্রবীভবন':'NN','দ্রব্য':'NN','দ্রব্যগুলিকে':'NN','দ্রব্যটির':'NN','দ্রব্যমূলের':'NN',
'দ্রব্যমূল্যের':'NN','দ্রব্যসামগ্রী':'NN','দ্রব্যাটির':'NN','দ্রব্যাদির':'NN','দ্ররিদ্র':'NN','দ্রষ্টব্য':'JJ','দ্রষ্টা':'NN',
'দ্রাক্ষ':'NN','দ্রাক্ষারস':'NN','দ্রাঘিমাংশ':'NN','দ্রাবক':'NN','দ্রাবিড়':'JJ','দ্রাবিড়গোড়':'NN','দ্রাবিড়':'JJ',
'দ্রাবিড়কে':'NN','দ্রাব্য':'NN','দ্রী':'NN','দ্রুত':'RB','দ্রুতই':'NN','দ্রুতকর্মক্ষম':'NN','দ্রুতগামী':'NN',
'দ্রুতট্রাম্প':'NN','দ্রুততম':'NN','দ্রুততার':'NN','দ্রুতপদ':'NN','দ্রুতবিলম্বিত':'NN','দ্রুতবেগের':'JJ','দ্রুপদ':'NN',
'দ্রুপদাদিত্য':'NN','দ্রুব':'NN','দ্রুমারু':'NN','দ্রুমিল':'NN','দ্রুমেশ্বর':'NN','দ্রুহ্যু':'NN','দ্রূততার':'NN',
'দ্রোণ':'NN','দ্রোণকলস':'NN','দ্রোণক্ষীরা':'NN','দ্রোণগিরি':'NN','দ্রোণদুগ্ধা':'NN','দ্রোণপুত্র':'NN','দ্রোণস':'NN',
'দ্রোণাচার্য্য':'NN','দ্রোণি':'NN','দ্রোহী':'NN','দ্রৌপদী':'NN','দ্রৌপদীর':'NNP','দ্রৌপদেয়':'NN','দ্র্যবাত্মক':'NN',
'দড়ি':'NN','দড়িযায়':'NN','দড়ির':'NN','দয়রা':'NN','দয়া-মৃত্যু':'NN','দয়া':'VB','দয়াকরে':'NN',
'দয়ানন্দ':'NN','দয়ানিধি':'NN','দয়াপাত্র':'JJ','দয়াপূর্বক':'RB','দয়াবান':'JJ','দয়াময়':'JJ','দয়ারসাগর':'JJ',
'দয়ারহিত':'JJ','দয়ার্দ্র':'JJ','দয়ালু':'NN','দয়াশীল':'JJ','দয়াসাগর':'NN','দয়াসিক্ত':'JJ','দয়াহীন':'JJ',
'দয়াহীনতা':'NN','দয়ায়':'RB','দয়িতা':'NN','দয়ে':'NN','দ‌ক্ষিন':'NN','ধ':'NN','ধংকেনাল':'NN',
'ধংশ':'NN','ধংস':'NN','ধংসপ্রাপ্ত':'JJ','ধংসাত্বক':'NN','ধংসের':'NN','ধআর':'RP','ধই':'NN',
'ধইঞ্চা':'NN','ধইরা':'NN','ধইরেন':'NN','ধক':'VB','ধকলইতো':'NN','ধকার':'NN','ধজয়ী':'JJ',
'ধটক':'NN','ধটির':'NN','ধড়':'NN','ধড়িবাজ':'NN','ধণ':'NN','ধণ্যবাদ':'NN','ধতার':'NN',
'ধতুরিয়া':'NN','ধত্তা':'NN','ধদেব':'NNP','ধদের':'NN','ধন-দৌলত':'NN','ধন':'NN','ধনকুবের':'NN',
'ধনকুবেরএকশো':'JJ','ধনকুবেররা':'NN','ধনকে':'NN','ধনকোষ':'NN','ধনঞ্জয়':'NN','ধনতবর্ত':'NN','ধনতরস':'NN',
'ধনত্রয়োদশী':'NN','ধনদায়ী':'JJ','ধনধান্য':'NN','ধননাথ':'NN','ধনপতি':'NN','ধনপ্রদ':'NN','ধনবান':'NN',
'ধনমার':'NN','ধনযাচী':'NN','ধনরাশি':'NN','ধনলোভী':'JJ','ধনলোলুপ':'JJ','ধনশালী':'JJ','ধনসম্পত্তি':'NN',
'ধনসার':'NN','ধনহীন':'JJ','ধনা':'NN','ধনাগম':'NN','ধনাঢ্য':'JJ','ধনাত্মক':'NN','ধনাদেশ':'NN',
'ধনান্বেষী':'JJ','ধনার':'NN','ধনি':'NN','ধনিষ্টা':'NN','ধনিয়া':'NN','ধনী':'NN','ধনীগরীবের':'NN',
'ধনীদের':'NN','ধনীর':'JJ','ধনীরা':'NN','ধনু':'NN','ধনুকাকার':'JJ','ধনুকাকৃতি':'NN','ধনুর':'NN',
'ধনুর্গহ':'NN','ধনুর্ধর':'NN','ধনুর্ধারী':'JJ','ধনুর্বিদ্যা':'NN','ধনুর্যজ্ঞ':'NN','ধনুষাক্ষ':'NN','ধনুষ্টংকার':'NN',
'ধনে':'NN','ধনেশ':'NN','ধনোপার্জন':'NN','ধন্দে':'NN','ধন্নবাদ':'NN','ধন্নাসিকা':'NN','ধন্বন্তরী':'NN',
'ধন্য':'NN','ধন্যকুমারজীর':'NNP','ধন্যবাদ':'NN','ধন্যবাদমুশফিক':'NN','ধন্যবাদযে':'NN','ধন্যবাদী':'JJ','ধন্যা':'NN',
'ধন‍্যবাদ':'NN','ধবংস':'NN','ধবধবে':'VB','ধবনি':'NN','ধবল':'NN','ধবলধোলাই':'NN','ধবলশ্রী':'NN',
'ধবলা':'NN','ধবাক':'JJ','ধবার':'NN','ধভাব':'NN','ধমক':'VB','ধমকানো':'VB','ধমকি':'NN',
'ধমকের':'NN','ধমধম':'NN','ধমনী':'NN','ধমরতী':'NN','ধমান':'JJ','ধমার':'NN','ধমাল':'NN',
'ধমিয়ে':'NN','ধমূল':'JJ','ধমোকা':'NN','ধম্':'NN','ধর-পাকড়':'NN','ধর':'NN','ধরকে':'NNP',
'ধরগণ':'NN','ধরছে':'NN','ধরণ':'NN','ধরণীজা':'NN','ধরণীধর':'NN','ধরণে':'NN','ধরণের':'NNP',
'ধরতে':'NN','ধরন':'NN','ধরনে':'NN','ধরপাকড়':'NN','ধরফরানি':'NN','ধরব':'NN','ধরবার':'NNV',
'ধরবে':'NN','ধরবেন':'NN','ধরবো':'NN','ধরম':'NN','ধররা':'NN','ধরল':'VB','ধরলাম':'NN',
'ধরলে':'NN','ধরলেতো':'NN','ধরা':'NN','ধরাছোঁয়ার':'NN','ধরাতল':'NN','ধরাধরি':'NN','ধরাধামে':'NN',
'ধরানো':'NN','ধরাবাহিক':'NN','ধরার':'NN','ধরাশায়ী':'VBG','ধরিতে':'VB','ধরিত্রী':'NN','ধরিয়ে':'NN',
'ধরিয়া':'VB','ধরিয়ে':'NN','ধরুন':'NN','ধরে':'NN','ধরেও':'NN','ধরেছিল':'VB','ধরেছিলাম':'NN',
'ধরেছে':'NN','ধরেছেমনে':'NN','ধরেতবে':'NN','ধরেন':'NN','ধরেনা':'NN','ধরের':'NN','ধরো':'VB',
'ধরৌলি':'NN','ধর্ণা':'NN','ধর্নায়':'NN','ধর্ব':'JJ','ধর্ম-আচার্যা':'NN','ধর্ম-উপদেশিকা':'NN','ধর্ম-কর্ম':'NN',
'ধর্ম-নিষ্ঠতা':'NN','ধর্ম-পরায়ণতা':'NN','ধর্ম-বিধি':'NN','ধর্ম-যুদ্ধ':'NN','ধর্ম-শালা':'NN','ধর্ম':'NN','ধর্মকেতু':'NN',
'ধর্মগণতন্ত্র':'NN','ধর্মগুরু':'NN','ধর্মগ্রন্থ':'NN','ধর্মঘট':'NN','ধর্মচক্র':'NN','ধর্মচার্যা':'NN','ধর্মচ্যূত':'JJ',
'ধর্মজ্ঞ':'NN','ধর্মজ্ঞান':'NN','ধর্মজ্ঞানী':'JJ','ধর্মদ্রবী':'NN','ধর্মধ্বোজী':'NN','ধর্মনাথ':'NN','ধর্মনিরপেক্ষ':'JJ',
'ধর্মনিরপেক্ষই':'NN','ধর্মনিষ্ঠ':'NN','ধর্মপত্নি':'NN','ধর্মপত্নীর':'NN','ধর্মপথভ্রষ্ট':'JJ','ধর্মপরায়ণ':'JJ','ধর্মপাল':'NN',
'ধর্মপুত্র':'NN','ধর্মপ্রচারক':'NN','ধর্মবতী':'NN','ধর্মবর্জিত':'JJ','ধর্মবিজ্ঞানীরা':'NN','ধর্মবিশ্বাস':'NN','ধর্মবিশ্বাসী':'JJ',
'ধর্মবিশ্বাসের':'NN','ধর্মবীর':'JJ','ধর্মবৃক্ষ':'NN','ধর্মবোধ':'NN','ধর্মভীরু':'JJ','ধর্মভ্রষ্ট':'NN','ধর্মমঙ্গল':'NNP',
'ধর্মমণ্ডলীর':'NN','ধর্মমাতা':'NN','ধর্মযুগ':'NN','ধর্মরাজের':'NN','ধর্মলিপি':'NN','ধর্মশালা':'NN','ধর্মশাস্ত্র':'NN',
'ধর্মশাস্ত্রজ্ঞ':'JJ','ধর্মশিক্ষিকা':'NN','ধর্মশীলতা':'NN','ধর্মসংস্কারক':'NN','ধর্মসঙ্কট':'NN','ধর্মসূত্র':'NN','ধর্মাচার্য':'NN',
'ধর্মাত্মা':'NN','ধর্মানুসারী':'JJ','ধর্মান্তরিত':'JJ','ধর্মান্তরিতকরণ':'NN','ধর্মান্ধ':'JJ','ধর্মান্ধতা':'NN','ধর্মাবলম্বী':'NN',
'ধর্মার্থ':'NN','ধর্মার্থে':'RB','ধর্মালম্বী':'NN','ধর্মী':'NN','ধর্মীয়':'NN','ধর্মীয়সামাজিক':'NN','ধর্মীয়':'NN',
'ধর্মেই':'NN','ধর্মেয়ু':'NN','ধর্মোপদেশ':'NN','ধর্য':'NN','ধর্ষক':'NN','ধর্ষণকারী':'NN','ধর্ষিত':'JJ',
'ধলা':'JJ','ধলাই':'NN','ধস':'NN','ধসকা':'NN','ধসন':'NN','ধসে':'VB','ধহীন':'JJ',
'ধা':'NN','ধাঁক':'NN','ধাঁধা':'NN','ধাঁধিয়ে':'VB','ধাই':'NN','ধাওয়া':'VB','ধাকে':'NN',
'ধাক্কা':'NN','ধাক্কাধাক্কি':'NN','ধাতব':'NN','ধাতবীয়':'JJ','ধাতস্ত':'JJ','ধাতা':'NN','ধাতু-ঘট':'NN',
'ধাতুকর্ম':'NN','ধাতুঘট':'NN','ধাতুপাত্র':'NN','ধাতুবিজ্ঞানী':'NN','ধাতুমুদ্রা':'NN','ধাতুর':'NN','ধাতুশেখর':'NN',
'ধাতে':'NN','ধাত্রী':'NN','ধান':'NN','ধানও':'NN','ধানক্ষেতে':'NN','ধানখর':'NN','ধানচালের':'NN',
'ধানচাষি':'NN','ধানত':'JJ','ধানথিয়া':'NN','ধানবাদ':'NN','ধানমন্ডি':'NN','ধানসিড়ি':'NN','ধানাই':'NN',
'ধানিয়ামাল':'NN','ধানী':'JJ','ধানে':'NN','ধানেরশীষকে':'NN','ধান্দা':'NN','ধান্দাবাজী':'NN','ধান্দাবাজের':'NN',
'ধান্ধা':'NN','ধান্ধায়':'NN','ধান্য':'NN','ধান্যাক':'NN','ধাপ':'NN','ধাপের':'NN','ধাপ্পবাজি':'NN',
'ধাপ্পাবাজ':'JJ','ধাপ্পাবাজি':'NN','ধাবন':'VB','ধাবরা':'NN','ধাবিকা':'NN','ধাবী':'NN','ধাম':'NN',
'ধামত':'RB','ধামন':'NN','ধামশ্রী':'NN','ধামা':'NN','ধামাচাপা':'NN','ধামিন':'NN','ধামে':'NN',
'ধায়':'NN','ধার':'VB','ধারও':'NN','ধারওলা':'JJ','ধারওয়ালা':'NN','ধারক-বাহক':'NN','ধারক':'NN',
'ধারণা':'NN','ধারণাটি':'NN','ধারণামতে':'NN','ধারণাসমূহ':'NN','ধারণের':'NN','ধারন':'NN','ধারনাগুলি':'NN',
'ধারনার':'NN','ধারবাড়':'NN','ধারবাহিকভাবে':'RB','ধারা':'NN','ধারাকদম':'NN','ধারাটি':'NN','ধারাণাও':'NN',
'ধারাত':'NN','ধারাপুপ':'NN','ধারাবাহিক':'NN','ধারাবাহিকতার':'NN','ধারাবাহিকভাবে':'RB','ধারাভাষ্য':'NN','ধারাভাষ্যকারের':'NN',
'ধারাভিকতা':'NN','ধারায়':'NN','ধারারই':'NN','ধারাল':'JJ','ধারায়':'NN','ধারি':'NN','ধারে':'VB',
'ধারের':'NN','ধার্মিক-অনুষ্ঠান':'NN','ধার্মিক-বিধি':'NN','ধার্মিকতা':'NN','ধার্মিকবিধি':'NN','ধার্য':'NN','ধার্য্য':'JJ',
'ধায়ক':'NN','ধা‌রে':'NN','ধিক':'NN','ধিক্':'NN','ধিক্কারবাণীতে':'NN','ধিক্কৃত':'JJ','ধিতা':'NN',
'ধিল':'NN','ধিয়ে':'VB','ধীকে':'NN','ধীজি':'NNP','ধীতে':'NN','ধীবর':'NN','ধীমা-তীতালা':'NN',
'ধীমান':'NN','ধীমে':'JJ','ধীর':'RB','ধীরা':'NN','ধীরে':'RB','ধীরেন্দ্রচন্দ্র':'NNP','ধুঁকছিল':'NN',
'ধুঁকতে':'VB','ধুইয়া':'NN','ধুক-পুক':'VB','ধুকড়ি':'NN','ধুকপুক':'VB','ধুকপুকানি':'NN','ধুকে':'NN',
'ধুচুনি':'NN','ধুতরা':'NN','ধুতি':'NN','ধুতিটি':'NN','ধুতী':'NN','ধুতুরা':'NN','ধুতে':'VB',
'ধুত্তোরি':'NN','ধুনটে':'NN','ধুনারি':'NN','ধুনুচি':'NN','ধুনো':'NN','ধুন্ধু':'NN','ধুপিত':'JJ',
'ধুবরি':'NN','ধুম-পান':'NN','ধুম':'NN','ধুমকেতু':'NN','ধুমত্যসেন':'NN','ধুমধাম':'NN','ধুমধামের':'RB',
'ধুমধুম':'VB','ধুমপান':'NN','ধুমসি':'NN','ধুমিনী':'NN','ধুম্রকেতু':'NN','ধুম্রপর্ণা':'NN','ধুম্রপান':'NN',
'ধুম্রাক্ষ':'NN','ধুরকট':'NN','ধুরন্ধর':'NN','ধুরা':'NN','ধুরিয়ামল্লার':'NN','ধুরী':'JJ','ধুর্ত':'NN',
'ধুলা':'NN','ধুলাবালি':'NN','ধুলার':'NN','ধুলি':'NN','ধুলিসাত্':'NN','ধুলে':'NN','ধুলো':'NN',
'ধুসর':'JJ','ধুস্সা':'NN','ধুয়া':'NN','ধুয়ে':'NN','ধুয়েমুছে':'VB','ধূপ':'NN','ধূপকাঠি':'NN',
'ধূপদান':'NN','ধূপন':'NN','ধূপারতি':'NN','ধূবিত্র':'NN','ধূমকেতু':'NN','ধূমপান':'VBG','ধূমশিখা':'NN',
'ধূমায়িত':'JJ','ধূম্রপান':'VBG','ধূম্রপ্পাঁ':'NN','ধূর্ত':'NN','ধূর্ততাপূর্ণ':'JJ','ধূর্ম-পান':'NN','ধূলা':'NN',
'ধূলি':'NN','ধূলিচিত্র':'NN','ধূলিধূসরিত':'JJ','ধূলিধ্বজ':'NN','ধূলিবন্দন':'NN','ধূলিময়':'JJ','ধূলো':'NN',
'ধূলোবন্দন':'NN','ধূসর':'NN','ধৃতরাষ্ট্র':'NN','ধৃতরাষ্ট্রকে':'NNP','ধৃতরাষ্ট্রী':'NN','ধৃতরাষ্ট্রীয়':'JJ','ধৃতি':'NN',
'ধৃষ্ট':'JJ','ধৃষ্টকেতু':'NN','ধৃষ্টদ্যুম্ন':'NN','ধৃষ্ণি':'NN','ধেড়ে':'NN','ধেনু':'NN','ধেনুকাসুর':'NN',
'ধেনুমতি':'NN','ধেনো':'NNP','ধেমাজী':'NN','ধৈবত':'NN','ধৈর্য':'NN','ধৈর্যহীন':'JJ','ধৈর্যহীনতা':'NN',
'ধৈর্যের':'NN','ধৈর্য্যবান':'JJ','ধৈর্য্যশীল':'JJ','ধোঁকা':'NN','ধোঁটি':'NN','ধোঁডা':'NN','ধোঁয়াচ্ছন্ন':'JJ',
'ধোঁয়াটে':'NN','ধোওয়া':'NN','ধোকা':'NN','ধোকাবাজির':'NN','ধোড়':'NN','ধোতর':'NN','ধোনা':'VB',
'ধোনি':'NN','ধোপ':'NN','ধোপাখানা':'NN','ধোপাঘাট':'NN','ধোপানি':'NN','ধোবি':'NN','ধোবিপাট':'NN',
'ধোয়া':'NNV','ধোলপুর':'NN','ধোলাই':'NN','ধোয়া':'NN','ধোয়ানো':'VB','ধৌ':'NN','ধৌত':'JJ',
'ধৌতকরণ':'NN','ধৌম্য':'NN','ধৌল':'NN','ধৌলাখৈর':'NN','ধৌলী':'NN','ধ্বংশযজ্ঞ':'NN','ধ্বংশের':'NN',
'ধ্বংস':'NN','ধ্বংসকারী':'NN','ধ্বংসনো':'VB','ধ্বংসপ্রাপ্ত':'NN','ধ্বংসযজ্ঞ':'NN','ধ্বংসস্তূপ':'NN','ধ্বংসাত্বক':'JJ',
'ধ্বংসাত্মক':'RB','ধ্বংসাবশেষ':'NN','ধ্বংসের':'NN','ধ্বংসোন্মুখ':'NN','ধ্বজ':'NNP','ধ্বজগ্রীব':'NN','ধ্বজদণ্ড':'NN',
'ধ্বজা':'NN','ধ্বজাধারী':'JJ','ধ্বণিত':'NN','ধ্বনিগ্রাহী':'NN','ধ্বনিত':'JJ','ধ্বনিতত্ত্ব':'NNP','ধ্বনিতাত্ত্বিক':'JJ',
'ধ্বনিতে':'NN','ধ্বনিবিদ্যা':'NNP','ধ্বনির':'NN','ধ্বনিসংক্রান্ত':'JJ','ধ্বনী-বিস্তারক':'NN','ধ্বন্যাত্মক':'JJ','ধ্বস':'NN',
'ধ্বস্ত':'NN','ধ্বস্তাধ্বস্তি':'NN','ধ্বান্ত':'NN','ধ্যম':'NN','ধ্যাণনিষ্ট':'JJ','ধ্যাণমগ্ন':'JJ','ধ্যাণী':'JJ',
'ধ্যাতানি':'NN','ধ্যান-জ্ঞান':'NN','ধ্যান-ধারণার':'NN','ধ্যান':'NN','ধ্যানবিন্দু':'NN','ধ্যানহীন':'JJ','ধ্যানহীনতা':'NN',
'ধ্যানাবস্থা':'NN','ধ্যানী':'JJ','ধ্যে':'NN','ধ্রবা':'NN','ধ্রুপদ':'NN','ধ্রুপদী':'NN','ধ্রুব':'JJ',
'ধ্রুবতারা':'NN','ধ্রুবনন্দ':'NN','ধ্রুবরত্না':'NN','ধ্রুবসন্ধি':'NN','ধ্রুবা':'NN','ধ্রুবীকরণ':'NN','ধড়পাকড়':'NN',
'ন-এড':'NN','ন-পুকুর':'NNP','ন':'NN','নং':'NN','নংড়ামি':'NN','নই':'NN','নইলে':'RP',
'নএর':'NNP','নওয়াজ':'NN','নওয়াবেকির':'NN','নক':'JJ','নকটা':'NN','নকল':'NN','নকলকারী':'NN',
'নকলবাজ':'JJ','নকলের':'NN','নকশা-খচিত':'NN','নকশা':'NN','নকশাকাটা':'JJ','নকশাকার':'NN','নকশাদার':'JJ',
'নকশাবাজ':'NN','নকশাল':'NN','নকশালপন্থা':'NN','নকশালবাদ':'NN','নকশালরাও':'NN','নকসা':'NN','নকারান্ত':'JJ',
'নকাল':'NN','নকুলদানা':'NN','নকুলান্ধরোগ':'NN','নকুলী':'NN','নকুলের':'JJ','নকুড়':'NNP','নকেই':'NN',
'নকেটসর':'NN','নক্তা':'NN','নক্ষত':'NN','নক্ষত্রজাত':'JJ','নক্ষত্রনাথ':'NN','নক্ষত্রপুঞ্জ':'NNP','নক্ষত্রপুঞ্জের':'NN',
'নক্ষত্রমণ্ডল':'NN','নক্ষত্রে':'NN','নক্ষত্রের':'NNS','নক্ষত্রেশ':'NN','নক্সা':'NN','নখ':'NNS','নখখাদী':'NN',
'নখখেকো':'JJ','নখদন্তহীন':'NN','নখবিষ্কির':'NN','নখবিহীন':'JJ','নখরাঘাতে':'NN','নখরাবাজ':'JJ','নখশূল':'NN',
'নখাস':'NN','নখী':'NN','নখের':'NN','নগণ':'NN','নগণ্য':'NN','নগদ-কারবারের':'NN','নগদ':'NN',
'নগদন্তী':'NN','নগদে':'NN','নগনিকা':'NN','নগন্নিকা':'NN','নগন্য':'NN','নগর-নিবাসী':'JJ','নগর':'NN',
'নগরগুলিতেও':'NN','নগরঘড়ি':'NN','নগরনিবাসী':'JJ','নগরপাল':'NN','নগরবধূ':'NN','নগরবাসী':'NN','নগররাষ্ট্রগুলিকে':'NN',
'নগরশুল্ক-ঘর':'NN','নগরহার':'NN','নগরাধিপতি':'NN','নগরালী':'JJ','নগরায়ন':'NN','নগরী':'NN','নগরীকৃত':'JJ',
'নগরীতে':'NN','নগরে':'NN','নগানিকা':'NN','নগাস':'NN','নগুচিকে':'NNP','নগুণ':'NN','নগেনচন্দ্র':'NNP',
'নগ্ন':'VBN','নগ্নজিত্':'NN','নগ্ননো':'VB','নগ্নপদ':'JJ','নগ্নভাবে':'VBN','নঘোর':'NN','নঙ্গর':'NN',
'নচাপ':'NN','নচিকেতা':'NN','নচুল':'NN','নচেত':'RB','নছ':'JJ','নছিল':'VB','নজনে':'NN',
'নজম':'NN','নজর-ঘাঁটি':'NN','নজর':'NN','নজরই':'VB','নজরদারই':'NN','নজরদারিতে':'NN','নজরদারিরির':'NN',
'নজরবন্দি':'JJ','নজরবন্দী':'NN','নজরুল':'NN','নজরে':'NN','নজিরও':'NN','নজিরবিহীন':'NN','নজীর':'NN',
'নঞর্থক':'NN','নট':'NN','নটনারায়ণ':'NN','নটপর্ণ':'NN','নটবর':'NN','নটবসন্ত':'NN','নটমল':'NN',
'নটমল্লার':'NN','নটসাল':'NN','নটাও':'NN','নটি':'NN','নটির':'NN','নট্যা':'NN','নডজামেন':'NN',
'নডনে':'NN','নড়বড়ে':'NN','নড়বি':'VB','নড়া-চড়া':'NN','নড়ানো':'VB','নড়িনী':'NN','নড়িয়ে':'VB',
'নডিং':'NN','নডের':'NN','নঢ':'NN','নত':'NN','নতজানু':'VB','নতদ্রুম':'NN','নতমস্তক':'JJ',
'নতমী':'NN','নতশির':'JJ','নতার':'NN','নতি':'NN','নতুন':'NNP','নতুনতর':'JJ','নতুনত্ব':'NN',
'নতুনদের':'NNS','নতুনপক্ব':'JJ','নতুনভাবে':'NN','নতুবা':'RB','নতেন':'VB','নত্ব':'NN','নথ':'NN',
'নথিকরণ':'NN','নথিপত্র':'NN','নথিপত্রেরও':'NN','নথীবদ্ধ':'NN','নথীভুক্ত':'NN','নথীভূক্ত':'NN','নথের':'NNP',
'নদ':'NN','নদভীর':'NN','নদিন':'NN','নদিয়া':'NN','নদী':'NN','নদীগর্ভের':'NN','নদীগুলো':'NNS',
'নদীতে':'NN','নদীর':'NN','নদীহীন':'NN','নদীয়ার':'NN','নদুলসাই':'NN','নদেন':'VB','নদেব':'NNP',
'নদের':'NN','নধিক':'JJ','নন-গেজেটেড্':'JJ','নন':'NN','ননগত':'JJ','ননগর':'NNP','ননগেজেটেড':'JJ',
'ননদ':'NN','ননদিনী':'NN','ননদী':'JJ','ননদেশে':'NN','ননাথ':'NNP','ননী':'NN','ননীও':'NNP',
'ননীর':'NN','নন্ত':'JJ','নন্দ':'NN','নন্দঘোষ':'NNP','নন্দন':'NN','নন্দনতত্ত্ব':'NN','নন্দনমালা':'NN',
'নন্দরাণী':'NN','নন্দরানী':'NNP','নন্দরুখ':'NN','নন্দা':'NN','নন্দিত':'VBN','নন্দিনী':'NN','নন্দীকেশর':'NN',
'নন্দীগ্রাম':'NN','নন্দীগ্রামেই':'NNP','নন্দীগ্রামের':'NN','নন্দীতরু':'NN','নন্দুবার':'NN','নন্য':'JJ','নন্হে':'NNP',
'নপুংসক':'NN','নপুংসত্ব':'NN','নব-খন্ড':'NN','নব':'NN','নবকার্ষিগুগল':'NN','নবখন্ড':'NN','নবগঠিত':'JJ',
'নবগড়':'NN','নবগ্রহ':'NN','নবজাগরণ':'NN','নবজাত':'NN','নবজাতকের':'NN','নবতারা':'NN','নবদম্পতি':'NN',
'নবদম্পতিকে':'NNS','নবদিগন্ত':'NNP','নবদূর্গা':'NN','নবদ্বীপ':'NNP','নবদ্বীপচন্দ্র':'NNP','নবদ্বীপে':'NNP','নবনারায়ণ':'NNP',
'নবনিযুক্ত':'JJ','নবনিযুক্তী':'NN','নবনির্বাচিত':'VBN','নবনির্মিত':'NN','নবনীত':'NN','নবপরিণীত':'JJ','নববধূ':'NN',
'নববর্ষ':'NN','নববাবুর':'NNP','নববিধা':'NN','নববিধান':'JJ','নববিবাহিত':'JJ','নববিবাহিতা':'NN','নবম':'NN',
'নবমল্লিকা':'NN','নবমী':'NN','নবযুবতী':'NN','নবযৌবনা':'NN','নবরঙ্গপুর':'NN','নবরচিত':'JJ','নবরত':'NNP',
'নবরত্ন':'NN','নবরাজত্বের':'NN','নবরাত্রী':'NN','নবসারি':'NN','নবাঁ':'NN','নবাগত':'JJ','নবাগতদের':'NN',
'নবাদ':'NN','নবান্ন':'NN','নবাব':'NN','নবাবজাদা':'NN','নবাবপুত্র':'NN','নবার':'NNV','নবারা':'NN',
'নবায়ণ':'VB','নবায়ন':'NN','নবিক':'JJ','নবিনদের':'NNS','নবীকরণ':'NN','নবীকরণযোগ্য':'JJ','নবীকৃত':'JJ',
'নবীন':'RB','নবীনচাঁদ':'NNP','নবীনতম':'NN','নবীনের':'NNP','নবীশ':'JJ','নবু':'NNP','নবের':'NNP',
'নব্বই':'NN','নব্য':'JJ','নব্যযুগে':'NN','নভঃ':'NN','নভঃযান':'NN','নভগ':'NN','নভয়':'NN',
'নভশ্চর':'JJ','নভস্থল':'NN','নভাক':'NN','নভেম্বর':'NN','নভো':'NN','নভোএয়ারের':'NN','নমদা':'NN',
'নমনশীলতা':'NN','নমনিয়':'JJ','নমনীয়':'NN','নমনীয়তার':'NN','নমনে':'NN','নমস্কার':'NN','নমস্য':'JJ',
'নমান':'NN','নমিত':'JJ','নমিনাথ':'NN','নমিনেশন':'NN','নমুচি':'NN','নমুনা':'NN','নমুনাসুতরাং':'NN',
'নমূনা':'NN','নমেরু':'NN','নমোস':'NN','নম্বর':'NN','নম্বরগুলো':'NNS','নম্বরটা':'NNP','নম্বরটি':'NNP',
'নম্বরপ্লেট':'NN','নম্বরী':'NNP','নম্বরে':'NNS','নম্বরের':'NN','নম্র':'JJ','নম্রতা':'NN','নম্রতাপূর্বক':'RB',
'নম্রভাব':'NN','নয়':'NN','নয়আশা':'NN','নযোগ':'NN','নর-নারায়':'NN','নর':'NN','নরওয়ে':'NN',
'নরওয়েজিয়ান':'NN','নরওয়েবাসী':'NN','নরক':'NN','নরকগতি':'NN','নরকম':'NN','নরকস্থা':'NN','নরকাসুর':'NN',
'নরকে':'NN','নরখাদক':'NN','নরডিস্ক':'NN','নরদমা':'NN','নরদেহ':'NN','নরনারায়ণ':'NN','নরনারীর':'NN',
'নরনৌল':'NN','নরপতি':'NN','নরপাল':'NN','নরপিশাচ':'NN','নরবলি':'NN','নরম':'NN','নরমপন্থী':'JJ',
'নরমাল':'NN','নরমে':'JJ','নরমেধ':'NN','নরসংহার':'NN','নরসিংদী':'NN','নরসিংহ':'NN','নরসিংহপুর':'NN',
'নরসিংহা':'NNP','নরসিঙ্গা':'NN','নরহত্যা':'NN','নরহরি':'NN','নরাজ':'NNP','নরাত':'NN','নরাধিপতি':'NN',
'নরান্তক':'NN','নরাশ্ব':'NN','নরায়':'NN','নরী':'NN','নরুন':'NN','নরেন':'NNP','নরেন্দ্র':'NN',
'নরেন্দ্রনাথের':'NNP','নরেশ':'NN','নর্তক':'NN','নর্থ':'NN','নর্দটক':'NN','নর্দমা':'NN','নর্মদা':'NN',
'নর্রী':'NN','নল':'NN','নলকুবের':'NN','নলকূপ':'NN','নলকে':'NNP','নলখাগড়া':'NN','নলটির':'NN',
'নলতা':'NN','নলপক্ষ':'NN','নলমীন':'NN','নলাখী':'JJ','নলাভ':'NN','নলাম':'VB','নলার':'NN',
'নলি':'NN','নলিকাবিহীন':'NN','নলিকাযন্ত্র':'NN','নলিতা':'NN','নলিনী':'NN','নলী':'NN','নলে':'NN',
'নলেন':'VB','নলেনগুড়':'NN','নলের':'NN','নশাহ':'NN','নশীল':'JJ','নশ্বর':'JJ','নষট':'NN',
'নষ্ক':'JJ','নষ্ট':'NN','নষ্টদের':'NNS','নষ্টবিষ':'JJ','নষ্টামি':'NN','নষ্টেন্দুকলা':'NN','নষ্টের':'NN',
'নসতরঙ্গ':'NN','নসফাড়':'NN','নসবন্দী':'NN','নসাউ':'NN','নসিক':'JJ','নসিব':'NN','নসেট':'NN',
'নসেন':'NNP','নস্ক':'JJ','নস্য':'NN','নস্যি':'NN','নহবত':'NN','নহবতেই':'NN','নহরের':'NN',
'নহলা':'NN','নহুষ':'NN','নহে':'NN','না-9':'NNP','না-ই':'RP','না-করা':'JJ','না-চল':'JJ',
'না':'RP','নাই':'DT','নাইআজকে':'NN','নাইআপনাদের':'NNS','নাইআশাকরি':'NN','নাইইমাম':'NN','নাইউন্নয়নের':'NN',
'নাইএকদল':'NN','নাইএখন':'NN','নাইএগুগা':'NN','নাইএটা':'NNP','নাইওরা':'NN','নাইক':'NN','নাইক্ষমতায়':'NN',
'নাইজার':'NN','নাইজিরিয়া':'NN','নাইজিরিয়ান':'JJ','নাইজিরিয়াবাসী':'NN','নাইজীবনের':'NN','নাইজেরিয়ান':'NN','নাইজেরীয়':'JJ',
'নাইজেল':'NN','নাইট':'NNP','নাইট্রিক':'NN','নাইট্রোজেন':'NN','নাইড':'NN','নাইত':'NNP','নাইতাছাড়া':'MD',
'নাইন':'NNP','নাইনলের':'NN','নাইপরিবেশ':'NN','নাইপাড়াপড়শির':'NN','নাইবা':'NN','নাইবিজ্ঞাপন':'NN','নাইম':'NN',
'নাইরা':'NN','নাইরোনালদো':'NN','নাইরোবী':'NN','নাইল':'NN','নাইশুধু':'NN','নাইশেষমেষ':'NN','নাইস':'NNP',
'নাইসাধারন':'NN','নাইয়া':'NN','নাঈম':'NN','নাউল্টো':'NN','নাএই':'NN','নাএকজন':'NN','নাএগুলো':'JJ',
'নাএটা':'NN','নাএবার':'NN','নাএরা':'NN','নাও':'VB','নাওও':'NN','নাওয়ার':'NN','নাক':'NN',
'নাককাটা':'JJ','নাকচ':'NN','নাকছাবি':'NN','নাকছিকনী':'NN','নাকড়া':'NN','নাকত':'NN','নাকফোড়া':'NN',
'নাকবংশি':'NN','নাকবিহীন':'JJ','নাকর':'JJ','নাকশির':'NN','নাকাইন্দা':'NN','নাকানিচোবানি':'NN','নাকারণ':'NN',
'নাকাল':'VBG','নাকি':'CC','নাকিএকজন':'NN','নাকিধনীরা':'NN','নাকিন্তু':'NN','নাকিলীগ':'NN','নাকিসুরে':'NN',
'নাকী':'CC','নাকুল':'NN','নাকুলৌষ্ঠী':'NN','নাকে':'NN','নাকেননা':'NN','নাকের':'NN','নাকো':'NN',
'নাখুদা':'NN','নাখেয়ে':'VBG','নাগ':'NN','নাগকন্যা':'NN','নাগকেশর':'NN','নাগকেসর':'NN','নাগতুম্বী':'NN',
'নাগদন্ত':'NN','নাগদন্তী':'NN','নাগদলা':'NN','নাগদৌন':'NN','নাগদ্রুমা':'JJ','নাগধ্বনি':'NN','নাগনায়ক':'NN',
'নাগপঞ্চমী':'NN','নাগপতি':'NN','নাগপাশ':'NN','নাগপুর':'NN','নাগপুরের':'NN','নাগপুষ্প':'NN','নাগফনী':'NN',
'নাগবন্ধু':'NN','নাগবল':'NN','নাগবালা':'NN','নাগভগিনী':'NN','নাগমণি':'NN','নাগমাতা':'NN','নাগমোচর':'NN',
'নাগযজ্ঞ':'NN','নাগর':'NN','নাগরকোইল':'NN','নাগরথ':'NN','নাগরদোলায়':'NN','নাগরা':'NN','নাগরিক':'NN',
'নাগরিকতা':'NN','নাগরিকত্ববিহীন':'NN','নাগরিকদের':'NNS','নাগরিকশাস্ত্র':'NN','নাগরিকের':'NNS','নাগরীক':'NN','নাগলোক':'NN',
'নাগসম্ভব':'NN','নাগা':'NN','নাগাড়াবাদক':'NN','নাগাত':'NN','নাগাদ':'RP','নাগাপট্টিনম':'NN','নাগারা':'NN',
'নাগার্জুনী':'NN','নাগালরে':'NN','নাগালের':'JJ','নাগাল্যাণ্ড':'NN','নাগাসাকি':'NN','নাগিন':'NN','নাগিবুল':'NN',
'নাগী-গায়ত্রী':'NN','নাগীন':'NN','নাগেশ':'NN','নাগেশ্বরনাথ':'NN','নাগোদ':'NN','নাগৌর':'NN','নাগ‌রিক':'NN',
'নাঙ্গাও':'NN','নাচ-গান':'NN','নাচ':'NN','নাচটা':'NN','নাচত':'VBG','নাচতাম':'NN','নাচতেছেন':'VBG',
'নাচতেন':'VB','নাচনী':'NN','নাচবে':'NN','নাচলুক':'NN','নাচা':'VB','নাচানাচি':'VBG','নাচানো':'VB',
'নাচারিকা':'NN','নাচিনি':'VB','নাচিয়ে':'JJ','নাচুনী':'NN','নাচে':'VB','নাচের':'NN','নাছোড়বান্দা':'JJ',
'নাজনীনের':'NN','নাজমুল':'NN','নাজলাবন্দ':'NN','নাজানা':'NNP','নাজি':'NNP','নাজিউর':'NN','নাজিয়া':'NN',
'নাজীবনটাই':'NN','নাজুক':'NN','নাট':'NN','নাটক-বিভাগে':'NN','নাটক-শালা':'NN','নাটক':'NN','নাটকটি':'NN',
'নাটকশালা':'NN','নাটকীয়':'NN','নাটকে':'NN','নাটরের':'NN','নাটা':'NN','নাটি':'NN','নাট্য-শালা':'NN',
'নাট্য':'NN','নাট্যকর্মী':'NN','নাট্যকলা':'NN','নাট্যনিকেতন':'NN','নাট্যবিদ্যা':'NN','নাট্যমঞ্চের':'NN','নাট্যশালা':'NN',
'নাট্যশাস্ত্র':'NN','নাট্যশিল্পী':'NN','নাট্যাক্সের':'NN','নাট্যোক্তি':'NN','নাড়া':'VB','নাড়াচাড়া':'NN','নাড়ানো':'NN',
'নাড়ি':'NN','নাড়ীজঙ্ঘ':'NN','নাড়ীনক্ষত্র':'NN','নাড়ু':'NN','নাডা':'NN','নাতক':'NN','নাতনি':'NN',
'নাতবউ':'NN','নাতাই':'NN','নাতাদের':'NNS','নাতার':'NN','নাতালি':'NN','নাতিশীতোষ্ণ':'NN','নাতীনাতনীরা':'NNS',
'নাতীর':'NN','নাতে':'VB','নাতো':'NN','নাত্':'RP','নাত্সি':'NN','নাত্সী':'NN','নাথ':'NN',
'নাথপন্থি':'NN','নাদ-বিন্দু':'NN','নাদ':'NN','নাদবিন্দু':'NN','নাদি':'NN','নাদিরশাহ':'NN','নাদিরশাহী':'JJ',
'নাদিরী':'NN','নাদিয়েই':'NN','নাদী':'JJ','নাদেশের':'NN','নাদেহি':'NN','নান-প্লাস-আল্ট্রা':'NN','নান':'NN',
'নানখাতাই':'NN','নানা':'NN','নানাকন্দ':'NN','নানাখাতে':'NNS','নানাদিক':'JJ','নানান':'NN','নানানভাবে':'NNS',
'নানাবিধ':'JJ','নানাভাবে':'NNS','নানামতাবলম্বী':'JJ','নানামুখী':'NN','নানারকম':'JJ','নানারকমের':'NN','নানাস্থানে':'NN',
'নানিয়ে':'NN','নানো':'NNV','নান্দক':'NN','নান্দনিক':'JJ','নান্দিমুখী':'NN','নান্দেড':'NN','নান্নু':'NN',
'নান্নুরা':'NN','নাপতা':'NN','নাপিত':'NN','নাপিতালয়':'NN','নাপিতিনী':'NN','নাপিতের':'NN','নাপুলিশ':'NN',
'নাপেয়ে':'VBG','নাপ্রতি':'NN','নাফিস':'NN','নাবছর':'NNS','নাবাচক':'JJ','নাবালিক':'NN','নাবালিকাস্ত্রী':'JJ',
'নাবাস্তবে':'RB','নাবাহ':'NN','নাবি':'NN','নাবিকের':'JJ','নাবিকেরা':'NN','নাবিশেষ':'NN','নাব্য':'JJ',
'নাভাগ':'NN','নাভাদাস':'NN','নাভারত':'NN','নাভি':'NN','নাভিচ্ছেদন':'NN','নাভিপাক':'NN','নাভিযুক্ত':'JJ',
'নাভিশোথ':'NN','নাভিশ্বাস':'VBG','নাম-ঠিকানা':'NN','নাম-ডাক':'NN','নাম':'NN','নামইতো':'NN','নামও':'NN',
'নামকরণ':'NN','নামকরা':'JJ','নামকির্তন':'NN','নামক্কল':'NN','নামগুলো':'NN','নামচি':'NN','নামছে':'NN',
'নামঞ্জুর':'JJ','নামঞ্জুরী':'NN','নামটা':'NN','নামটাও':'NN','নামটিই':'NN','নামঠিকানা':'NN','নামতা':'NN',
'নামতো':'NN','নামদা':'NN','নামদ্বাদশী':'NN','নামধন':'NN','নামধারী':'JJ','নামপট্টী':'NN','নামবহুল':'JJ',
'নামবে':'NN','নামমাত্র':'RB','নামল':'VB','নামলে':'NN','নামলেন':'NNP','নামলো':'NN','নামসংকীর্তন':'NN',
'নামহীন':'JJ','নামা':'NNP','নামাইছে':'VBN','নামাঙ্কণ':'NN','নামাঙ্কন':'VBG','নামাঙ্কিত':'NN','নামাচ্ছে':'NN',
'নামাজ':'NN','নামাজী':'NN','নামাতে':'NN','নামানো':'NN','নামান্তরকরণ':'NN','নামাবলী':'JJ','নামাবে':'NN',
'নামার':'NNP','নামায়':'IN','নামি':'NN','নামিবিয়া':'NN','নামিবিয়াবাসী':'NN','নামিবিয়ার':'JJ','নামিরপুর':'NN',
'নামিয়ে':'NN','নামী-দামি':'JJ','নামী':'NN','নামীদামী':'NN','নামুদ্রার':'NN','নামুন':'NN','নামে':'NN',
'নামেও':'NN','নামেমাত্র':'RB','নামের':'NN','নামো':'NNP','নাম্':'NN','নাম্নী':'JJ','নাম্বাবরে':'NNP',
'নাম্বার':'NNS','নাম্বারটা':'NNP','নাম্বারে':'NN','নাম্বুদরিপাদ':'NN','নাম্মারটা':'NNP','নাময়':'NN','নাযদি':'NN',
'নায়':'NN','নাযারা':'NN','নাযেমন':'NN','নায্য':'NN','নার':'NN','নারকীয়':'JJ','নারকেল':'NN',
'নারকেলের':'NN','নারকোলের':'NN','নারগিস':'NN','নারঝিনক':'NN','নারদ':'NN','নারদপরিব্রাজক':'NN','নারদপুরাণ':'NN',
'নারদীয়':'JJ','নারফিক':'NN','নারস':'NN','নারাচ':'NN','নারাচী':'NN','নারায়ণ':'NN','নারাষ্ট্রপক্ষ':'NN',
'নারায়ণ':'NN','নারায়ণগঞ্জের':'NN','নারায়ণী':'NN','নারায়ণোপনিষদ':'NN','নারায়ন':'NN','নারি':'NN','নারী':'NN',
'নারীকেই':'NN','নারীত্বের':'NN','নারীদের':'NNS','নারীদেহের':'NN','নারীপুরুষের':'NN','নারীবেশে':'NN','নারীর':'NN',
'নারীরাও':'NN','নারীশ্বর':'NN','নারীষ্ঠ':'NN','নারুসে':'NNP','নার্কোটিকস্':'NN','নার্ভাস':'NN','নার্ভাসনেসই':'NN',
'নার্ভের':'NN','নার্স':'NN','নার্সারিতে':'NN','নার্সিংহোম':'NN','নারয়ণগঞ্জ':'NN','নারয়ণী':'NN','নাল':'NN',
'নালতে':'NN','নালন্দা':'NN','নালবাঁশ':'NN','নালার':'NN','নালি':'NN','নালিকা':'NN','নালিশের':'NN',
'নালী':'NN','নালে':'NN','নালো':'JJ','নাশ':'NN','নাশক':'NN','নাশকতার':'NN','নাশপাতি':'NN',
'নাশুধুমাত্র':'NN','নাস':'NN','নাসত্যিটাকে':'NN','নাসরীন':'NN','নাসা-বিবর':'NN','নাসা':'NN','নাসাজ্বর':'NN',
'নাসাদন্ড':'NN','নাসাপরিশোষ':'NN','নাসার':'NN','নাসারন্ধ্র':'NN','নাসারা':'NN','নাসাস্থি':'NN','নাসিং':'NN',
'নাসিকা-গুহা':'NN','নাসিকামল':'NN','নাসিক্য':'JJ','নাসিম':'NN','নাসিমমাহবুব':'NN','নাসির':'NN','নাসিরুদ্দিন':'NN',
'নাসিরুলকে':'NN','নাসীরউদ্দীন':'NNP','নাসের':'NN','নাস্তানাবুদ':'NN','নাস্তালিক':'NN','নাস্তিকতা':'NN','নাস্তিকতাবাদী':'JJ',
'নাস্তিকত্ব':'NN','নাহ':'NN','নাহলে':'NN','নাহিদ':'NN','নাহয়':'NN','নাহয়মনোভাব':'NN','না্':'NN',
'নাড়ছে':'NN','নাড়তে':'VB','নাড়া':'NN','নাড়াচাড়া':'NN','নাড়ার':'NNV','নাড়ীতার':'NN','নায়':'NN',
'নায়কও':'NN','নায়কত্ব':'NN','নায়কী':'NN','নায়কীকানাড়া':'NN','নায়কীমল্লার':'NN','নায়কের':'NN','নায়শাস্ত্রী':'NN',
'নায়িকা':'NN','নায়িকার':'NN','নায়েক':'NN','না‌':'NN','নি':'NN','নিংড়ানো':'VB','নিংড়ে':'VB',
'নিঃশঙ্ক':'JJ','নিঃশঙ্কা':'NN','নিঃশব্দ':'NN','নিঃশব্দে':'RB','নিঃশর্ত':'NN','নিঃশুল্ক':'NN','নিঃশেষ':'NN',
'নিঃশ্চিত':'NN','নিঃশ্বাস-এর':'NN','নিঃসংশয়ে':'RB','নিঃসঙ্কোচ':'NN','নিঃসঙ্কোচী':'JJ','নিঃসঙ্কোচে':'RB','নিঃসঙ্গ':'NN',
'নিঃসন্তান':'NN','নিঃসন্দেহে':'RB','নিঃসরণ':'NN','নিঃসহায়':'NN','নিঃসৃত':'NN','নিঃস্থাথ':'NN','নিঃস্ব':'VB',
'নিঃস্বার্থ':'JJ','নিঃস্বার্থতা':'NN','নিঃস্রাব':'NN','নিই':'NN','নিউ':'NN','নিউইয়র্ক':'NN','নিউইয়ারের':'NN',
'নিউক্লীয়াস':'NNP','নিউক্লয়ার':'NN','নিউজ':'NN','নিউজটাই':'NN','নিউজিলান্ড':'NN','নিউজিল্যাণ্ড':'NN','নিউজিল্যান্ডকেই':'NN',
'নিউজিল্যান্ডী':'NN','নিউজিল্যান্ডীয়':'JJ','নিউজিল্যান্ডে':'NN','নিউজে':'NN','নিউজের':'NN','নিউটন':'NN','নিউরন':'NN',
'নিউরোপ্যাথি':'NN','নিঋতি':'NN','নিএবং':'NN','নিও':'VB','নিওডাইমিয়াম':'NN','নিক':'NN','নিকটতম':'RB',
'নিকটতা':'NN','নিকটবর্তী':'JJ','নিকটস্থ':'JJ','নিকটাগত':'JJ','নিকটাত্মীয়':'NN','নিকটে':'NN','নিকন্দ-রোগে':'NN',
'নিকষা':'NN','নিকানো':'JJ','নিকারসনকে':'NNP','নিকারাগুয়া-বাসী':'NN','নিকারাগুয়ান':'NN','নিকারাগুয়ার':'JJ','নিকাশ':'NN',
'নিকাষি':'NN','নিকুঞ্জ':'NN','নিকুঞ্জদেবীকে':'NNP','নিকুম্ভ':'NN','নিকৃষ্ট':'NN','নিকৃষ্টতম':'JJ','নিকৃষ্টতা':'NN',
'নিকেতন':'NN','নিকেলকে':'NN','নিকেশ':'NN','নিকোটিনিক':'NN','নিকোবর':'NN','নিকোলা':'NN','নিক্কেপ':'NN',
'নিক্তি':'NN','নিক্ষিপ্ত':'JJ','নিক্ষুভা':'NN','নিক্ষেপ':'NN','নিক্ষেপক':'JJ','নিক্ষেপকারী':'NN','নিখর্বট':'NN',
'নিখুঁত':'NN','নিখোঁজ':'NN','নিখোঁজের':'NN','নিগম':'NN','নিগর্ত':'JJ','নিগুর্ডী':'NN','নিগ্রহ':'NN',
'নিগ্রহী':'JJ','নিগ্রো':'NN','নিগ্রোদের':'NNP','নিগ্রোয়েড':'NN','নিঘন্টু':'NN','নিঘিন্যে':'NN','নিঙড়ানো':'VB',
'নিঙরানো':'JJ','নিচ':'JJ','নিচছে':'NN','নিচন্দ্র':'NN','নিচিতা':'NN','নিচু':'NN','নিচুভূমি':'NN',
'নিচুল':'NN','নিচে':'NN','নিচেকার':'NN','নিচ্চে':'NN','নিচ্ছি':'NN','নিচ্ছে':'VB','নিচ্ছেন':'NN',
'নিছক':'NN','নিছেন':'NN','নিজ':'NN','নিজত্ব':'NN','নিজদের':'NN','নিজসম্মান':'NN','নিজস্ব':'JJ',
'নিজস্বতা':'NN','নিজাম':'NN','নিজামশাহী':'NN','নিজামাবাদ':'NN','নিজামী':'NN','নিজামের':'JJ','নিজে':'NN',
'নিজেইতো':'NN','নিজেও':'NN','নিজেকেই':'NN','নিজেদের':'PR','নিজেদেরই':'NN','নিজেদেরকেই':'NN','নিজের':'NN',
'নিজেরই':'PR','নিজেরও':'NN','নিজেরা':'NN','নিজেরাও':'NN','নিটল':'NN','নিটে':'NN','নিটোল':'JJ',
'নিঠুর':'NN','নিড়াই':'NN','নিড়ানো':'NN','নিত':'NN','নিতকনে':'NN','নিতবর':'NN','নিতান্ত':'NN',
'নিতাম':'VB','নিতি':'NN','নিতিমালা':'NN','নিতে':'VB','নিতেছে':'VB','নিতেপুজিবাদী':'NN','নিতো':'NN',
'নিত্তপ্রয়োজনিয়':'NN','নিত্য':'NN','নিত্যক্রিয়া':'NN','নিত্যতা':'NN','নিত্যদিনের':'NN','নিত্যপ্রয়োজনীয়':'NN','নিত্যহোম':'NN',
'নিদর্শন':'NN','নিদাঘ':'NN','নিদারুণ':'JJ','নিদাহাস':'NN','নিদি':'NNP','নিদিধ্যাস':'NN','নিদেনপক্ষে':'NN',
'নিদ্রা':'NN','নিদ্রাগত':'JJ','নিদ্রাচ্ছন্ন':'JJ','নিদ্রার':'NN','নিদ্রালু':'JJ','নিদ্রাহীনতা':'NN','নিদ্রিত':'NN',
'নিধন':'NN','নিধাস':'NN','নিধি':'NN','নিধিনাথ':'NN','নিধিপ':'NN','নিধিরাম':'NN','নিন':'NN',
'নিনমাননীয়':'NN','নিনাদ':'NN','নিনাদিত':'JJ','নিনি':'VB','নিন্দনীয়':'JJ','নিন্দা':'NN','নিন্দাজনক':'JJ',
'নিন্দার':'JJ','নিন্দাসূচক':'JJ','নিন্দায়':'NN','নিন্দুক':'NN','নিন্দুকের':'NN','নিন্দেও':'NN','নিন্ম':'NN',
'নিন্মমানের':'NN','নিপতিথি':'NN','নিপাট':'JJ','নিপাত':'NN','নিপাতযোগ্য':'JJ','নিপাতের':'NN','নিপীড়ন':'VB',
'নিপীড়িত':'JJ','নিপীড়ন':'NN','নিপুণ':'NN','নিপুত্র':'NN','নিফটি':'NN','নিব':'NN','নিবন্ধ':'NN',
'নিবন্ধগ্রন্থ':'NN','নিবন্ধিত':'JJ','নিবন্ধের':'NN','নিবর্াচনের':'NN','নিবহুরা':'JJ','নিবাচন':'NN','নিবাড়া':'NN',
'নিবারক':'NN','নিবারণের':'NN','নিবার্চন':'NN','নিবার্য':'JJ','নিবাস-স্থল':'NN','নিবাস':'NN','নিবাসী':'NN',
'নিবি':'NN','নিবিড়':'JJ','নিবিড়তা':'NN','নিবিড়':'JJ','নিবৃত্ত':'NN','নিবৃত্তির':'NN','নিবে':'NN',
'নিবেদনীয়':'NN','নিবেদিত':'JJ','নিবেদিতভাবে':'NN','নিবেদিতার':'NNP','নিবেন':'NN','নিবেরিয়াল':'NN','নিবেশ':'NN',
'নিবো':'VB','নিভতে':'NN','নিভন্ত':'JJ','নিভানো':'VB','নিভিয়ে':'NN','নিভৃত':'JJ','নিভে':'VB',
'নিম':'NN','নিমকহারাম':'NN','নিমকি':'NN','নিমগাছে':'NN','নিমগির্দ':'NN','নিমচ':'NN','নিমজ্জনযোগ্য':'NN',
'নিমজ্জিত':'NN','নিমণ্ত্রণ':'NN','নিমণ্ত্রণহীন':'JJ','নিমতলীর':'NN','নিমন্ত্রণ':'NN','নিমন্ত্রণে':'NN','নিমন্ত্রনা':'VB',
'নিমন্ত্রাতা':'NN','নিমপাতা':'NN','নিমফল':'NN','নিমবীজ':'NN','নিমাই':'NNP','নিমাইয়ের':'NNP','নিমার':'NN',
'নিমি':'NN','নিমিত্তই':'RB','নিমিত্তে':'NN','নিমিরাজ':'NN','নিমিষেই':'NN','নিমূল':'NN','নিমের':'NN',
'নিমেষ-মাত্র':'RB','নিমেষ':'NN','নিমোচী':'NN','নিমোনা':'NN','নিম্ন':'NN','নিম্নকক্ষ':'NN','নিম্নগামী':'JJ',
'নিম্নচাপ':'NN','নিম্ননামের':'NN','নিম্নবংশ':'NN','নিম্নবিত্ত':'NN','নিম্নভাগ':'NN','নিম্নমধ্যবিত্তের':'NN','নিম্নমান':'JJ',
'নিম্নমানের':'NN','নিম্নমুখী':'NN','নিম্নমুল্যের':'NN','নিম্নরেখাঙ্কন':'NN','নিম্নলিখিত':'NN','নিম্নলোচা':'NN','নিম্নশ্রেণির':'NN',
'নিম্নস্থ':'JJ','নিম্নাঙ্কিত':'JJ','নিম্নে':'NN','নিম্ব':'NN','নিম্ম':'JJ','নিময়':'NN','নিযন্ত্রণকারী':'NN',
'নিয়ন্ত্রণ':'VB','নিয়ন্ত্রন':'NN','নিয়ম':'NN','নিয়মিত':'JJ','নিয়মের':'NN','নিয়া':'NN','নিয়ে':'VB',
'নিয়েছে':'VB','নিয়োগকর্তা':'NN','নিয়োগকর্তার':'NN','নিযুক্ত':'NN','নিযোক্তা':'JJ','নিযোজ্য':'JJ','নিরক্ষর':'NN',
'নিরক্ষীয়':'JJ','নিরঙ্কুশ':'NN','নিরঞ্জন':'JJ','নিরত':'JJ','নিরন্তর':'RB','নিরন্তরতা':'NN','নিরন্ধ্র':'JJ',
'নিরপক্ষতার':'NN','নিরপবাদ':'JJ','নিরপরাধ':'NN','নিরপেক্ষ':'NN','নিরপেক্ষতা':'NN','নিরপেক্ষতার':'NN','নিরব':'NN',
'নিরবধি':'JJ','নিরবলম্ব':'JJ','নিরবশেষতাং':'JJ','নিরবাচন':'NN','নিরবাচনের':'NN','নিরবিচ্ছিন্ন':'NN','নিরবে':'NN',
'নিরবয়ব':'JJ','নিরভর':'NN','নিরভ্র':'JJ','নিরর্থক':'NN','নিরর্থকও':'JJ','নিরলস':'JJ','নিরসনের':'NN',
'নিরসভাব':'NN','নিরস্ত':'NN','নিরস্ত্রীকরন':'NN','নিরহংকার':'NN','নিরহংকারী':'JJ','নিরাই':'NN','নিরাইনো':'VB',
'নিরাকার':'NN','নিরাকারী':'JJ','নিরানব্বই':'NN','নিরানব্বইতম':'JJ','নিরানো':'VB','নিরাপত্তা':'NN','নিরাপত্তাবাহিনী':'NN',
'নিরাপত্তাহীন':'NN','নিরাপত্তাহীনতার':'NN','নিরাপদ':'NN','নিরামিশাষী':'NN','নিরামিশাসী':'JJ','নিরামিষ':'NN','নিরাময়':'VBG',
'নিরালম্ব':'NN','নিরাশ':'NN','নিরাশাজনক':'NN','নিরাশাবাদ':'NN','নিরাশ্রিত':'JJ','নিরাশ্রয়':'NN','নিরাসক্ত':'JJ',
'নিরাসক্তনো':'VB','নিরাহার':'NN','নিরিবিলিতে':'NN','নিরীক্ষক':'NN','নিরীক্ষণকারী':'NN','নিরীক্ষার':'NN','নিরীক্ষিত':'JJ',
'নিরীশ্বর':'JJ','নিরীশ্বরতা':'NN','নিরীশ্বরবাদী':'NN','নিরীহ':'JJ','নিরীহ‌দেরও':'NN','নিরুতসাহিত':'NN','নিরুত্তর':'NN',
'নিরুত্সুক':'JJ','নিরুদিষ্ট':'JJ','নিরুদ্দেশ':'NN','নিরুদ্ধগুহ্য':'NN','নিরুদ্ধপ্রকাশ':'NN','নিরুদ্বিগ্নতা':'NN','নিরুপদ্রূত':'JJ',
'নিরুপায়':'NN','নিরুপিত':'JJ','নিরুব্ধ':'JJ','নিরুৎসাহিত':'NN','নিরূড়':'NN','নিরূড়লক্ষণা':'NN','নিরূদ্দেশ':'NN',
'নিরূদ্দেশ্য':'JJ','নিরূপণ':'NN','নিরেট':'NN','নিরেপক্ষ':'NN','নিরোগ':'NN','নিরোধী':'JJ','নির্গত':'NN',
'নির্গন্ধ':'JJ','নির্গম':'NN','নির্গুণ':'NN','নির্গুণ্ডীকল্প':'NN','নির্ঘন্ট':'NN','নির্ঘাত':'NN','নির্চা':'NN',
'নির্জন':'NN','নির্জলা':'JJ','নির্জলাএকাদশী':'NN','নির্জলীকরণ':'NN','নির্ণয়':'NN','নির্ণায়ক':'NN','নির্ণীত':'JJ',
'নির্ণয়':'NN','নির্দল':'JJ','নির্দষ্টা':'NN','নির্দিস্ট':'NN','নির্দেশ':'NN','নির্দেশকারী':'JJ','নির্দেশনা':'NNS',
'নির্দেশনামূলক':'NN','নির্দেশপত্র':'NN','নির্দেশালয়':'NN','নির্দেশিত':'NN','নির্দেশেই':'NN','নির্দেশে্যে':'NN','নির্দোষ':'NN',
'নির্দ্দিষ্ট':'JJ','নির্দ্বিধায়':'NN','নির্দয়তা':'NN','নির্দয়তাপূর্বক':'RB','নির্দয়ী':'NN','নির্ধন':'NN','নির্ধারকদের':'NNS',
'নির্ধারকরাই':'NN','নির্ধারণগুলো':'NNS','নির্ধারণপূর্বক':'NN','নির্ধারণেই':'NN','নির্ধারনি':'NN','নির্ধারনে':'NN','নির্ধারিত':'VBN',
'নির্ধার‌নের':'NN','নির্ধেশক':'NN','নির্নিমিখ':'RB','নির্পযোপমা':'NN','নির্বংশ':'NN','নির্বস্তুক':'NN','নির্বহণ':'NN',
'নির্বাচক':'NN','নির্বাচকরা':'NN','নির্বাচন':'NN','নির্বাচনকালীন':'NN','নির্বাচনকেও':'NN','নির্বাচনক্ষেত্র':'NN','নির্বাচনগুলোতে':'NN',
'নির্বাচনটা':'NN','নির্বাচনভিত্তিক':'NN','নির্বাচনযা':'NN','নির্বাচনে':'NN','নির্বাচনেও':'NN','নির্বাচনেরও':'NN','নির্বাচিত':'NN',
'নির্বাণপ্রাপ্ত':'JJ','নির্বাণোপনিষদ':'NN','নির্বাত':'NN','নির্বানের':'NN','নির্বাসন':'NN','নির্বাহ':'NN','নির্বাহী':'NN',
'নির্বিকল্প':'JJ','নির্বিকার':'NN','নির্বিঘ্ন':'JJ','নির্বিঘ্নে':'NN','নির্বিচারে':'VB','নির্বিবাদ':'NN','নির্বিভাগ':'JJ',
'নির্বিরোধ':'JJ','নির্বিশেষে':'RB','নির্বীজ':'NN','নির্বীজকরণ':'VB','নির্বীর':'JJ','নির্বীষীতৃণ':'NN','নির্বুদ্ধি':'NN',
'নির্বেতন':'JJ','নির্বোধ':'NN','নির্ব্যাজ':'NN','নির্ভর':'JJ','নির্ভরতা':'NN','নির্ভরযোগ্য':'JJ','নির্ভরশীল':'NN',
'নির্ভরশীলফসল':'NN','নির্ভার':'NN','নির্ভীক':'JJ','নির্ভুল':'NN','নির্ভেজাল':'JJ','নির্ভেজালভাবে':'NN','নির্ভয়':'NN',
'নির্মম':'NN','নির্মমভাবে':'RB','নির্মল':'NN','নির্মলা':'NN','নির্মাণ-পর্যবেক্ষক':'NN','নির্মাণ':'NN','নির্মাণনো':'VB',
'নির্মাণাধীন':'JJ','নির্মাণে':'NN','নির্মাতা':'NN','নির্মান':'NN','নির্মাল্য':'NN','নির্মিত':'NN','নির্মুক্ত':'NN',
'নির্মূল':'NN','নির্মেঘ':'JJ','নির্মেষ':'NN','নির্মোহ':'NN','নির্ময়ের':'NN','নির্যাতন':'NN','নির্যাতনের':'NN',
'নির্যাতিত':'JJ','নির্যাতিতবিচারক':'NN','নির্যাস':'NN','নির্লজ্জ':'NN','নির্লজ্জভাবে':'RB','নির্লজ্জের':'NN','নির্লিপ্ত':'JJ',
'নির্লিপ্ততা':'NN','নির্লোভ':'JJ','নিরৎসাহিত':'VBN','নিল':'NN','নিলাজ':'JJ','নিলাম':'NN','নিলামের':'NN',
'নিলু':'NN','নিলে':'VB','নিলেই':'NN','নিলেতো':'NN','নিলো':'NN','নিলয়ের':'NN','নিশচিত':'JJ',
'নিশঠ':'NN','নিশস্ত্র':'JJ','নিশা':'NN','নিশাকালই':'NN','নিশাচর':'NN','নিশাজল':'NN','নিশাতৈল':'NN',
'নিশাদ':'JJ','নিশান':'NN','নিশানবরদার':'NN','নিশানাবাজ':'NN','নিশান্ধী':'NN','নিশাবেদ':'NN','নিশাভোজী':'JJ',
'নিশি':'NN','নিশিচারণ':'NN','নিশিদিন':'RB','নিশিপাল':'NN','নিশিপালনের':'NN','নিশিপালিকা':'NN','নিশুম্ভ':'NN',
'নিশে':'NN','নিশ্চই':'NN','নিশ্চত':'JJ','নিশ্চয়ই':'NN','নিশ্চয়তার':'NN','নিশ্চল':'JJ','নিশ্চলতা':'NN',
'নিশ্চিত':'NN','নিশ্চিতএখানে':'NN','নিশ্চিতভাবে':'RB','নিশ্চিতে':'NN','নিশ্চিন্তে':'NN','নিশ্চিরা':'NN','নিশ্চিহ্ন':'VB',
'নিশ্চিয়তা':'NN','নিশ্চুপ':'NN','নিশ্চেষ্ট':'NN','নিশ্চেষ্টাকরণ':'NN','নিশ্চয়':'NN','নিশ্চয়তা':'NN','নিশ্চয়ী':'NN',
'নিশ্ছিদ্র':'JJ','নিশ্বাস':'NN','নিশ্রেণিকা-তৃণ':'NN','নিষঙ্গী':'NN','নিষধ':'NN','নিষধাবতী':'NN','নিষাদ':'NN',
'নিষিদ্ধ.মানা':'JJ','নিষিদ্ধ':'NN','নিষেধ':'NN','নিষেধহীন':'JJ','নিষেধাজ্ঞা':'NN','নিষ্কণ্টক':'JJ','নিষ্কপটতা':'NN',
'নিষ্কম্প':'JJ','নিষ্কর্ম':'JJ','নিষ্কর্মা':'NN','নিষ্কলঙ্ক':'NN','নিষ্কলুষ':'NN','নিষ্কাম':'NN','নিষ্কাশ':'NN',
'নিষ্কাশনের':'NN','নিষ্কাশী':'JJ','নিষ্কাসন':'NN','নিষ্কুম্ভ':'NN','নিষ্কৃতি':'NN','নিষ্ক্রিয়তা':'NN','নিষ্টিগ্রী':'NN',
'নিষ্ঠা':'NN','নিষ্ঠাবান':'JJ','নিষ্ঠার':'NN','নিষ্ঠাহীন':'JJ','নিষ্ঠীবন':'NN','নিষ্ঠুর':'NN','নিষ্ঠুরতার':'NN',
'নিষ্পক্ষতা':'NN','নিষ্পদ':'JJ','নিষ্পাদিত':'JJ','নিষ্পাপতা':'NN','নিষ্পেক্ষ':'JJ','নিষ্পেষিত':'NN','নিষ্প্রভ':'JJ',
'নিষ্প্রাণ':'NN','নিষ্প্রয়োজনীয়':'JJ','নিষ্ফল':'JJ','নিসন্দেহে':'RB','নিসপিস':'NN','নিসর্গ':'NN','নিসি':'NN',
'নিসুন্দ':'NN','নিসে':'NN','নিস্কৃত-ধন':'NN','নিস্ক্রিয়':'JJ','নিস্চিত':'JJ','নিস্তব্ধ':'JJ','নিস্তব্ধতা':'NN',
'নিস্তেজ':'NN','নিস্পত্তি':'NN','নিস্পন্দ':'JJ','নিস্পৃহ':'JJ','নিস্প্রভ':'JJ','নিস্ফলা':'NN','নিস্ফলাই':'JJ',
'নিস্বার্থ':'RB','নিহঙ্গ':'NN','নিহত':'JJ','নিহতদের':'NN','নিহাই':'NN','নিহাললোচন':'NN','নিহিত':'NN',
'নি্বাচন':'NN','নিয়':'NN','নিয়ণ্ত্রণ':'NN','নিয়ত':'NN','নিয়তির':'JJ','নিয়ন':'NN','নিয়ন্ত্রক':'NN',
'নিয়ন্ত্রণ':'NN','নিয়ন্ত্রণহীন':'JJ','নিয়ন্ত্রণহীনতা':'NN','নিয়ন্ত্রণাধীন':'JJ','নিয়ন্ত্রণে':'NN','নিয়ন্ত্রন':'NN','নিয়ন্ত্রনহীন':'VBN',
'নিয়ন্ত্রনে':'NN','নিয়ন্ত্রিত':'NN','নিয়ন্রনে':'NN','নিয়ম-কানুন':'NN','নিয়ম-নিষ্ঠা':'NN','নিয়ম-নীতিহীন':'JJ','নিয়ম-পালন':'NN',
'নিয়ম':'NN','নিয়মকানুন':'NN','নিয়মগুলো':'NNS','নিয়মতান্ত্রিক':'JJ','নিয়মপালন':'NN','নিয়মবিধি':'NN','নিয়মবিহীন':'JJ',
'নিয়মভঙ্গ':'NN','নিয়মভঙ্গের':'NNS','নিয়মসম্মত':'RB','নিয়মসেবী':'JJ','নিয়মানুবর্তী':'JJ','নিয়মানুযায়ী':'NN','নিয়মানুসারে':'RB',
'নিয়মাবলী':'NN','নিয়মিত':'RB','নিয়মিতই':'JJ','নিয়মিতভাবে':'RB','নিয়মেই':'NN','নিয়র':'NN','নিয়লা':'NN',
'নিয়াই':'NN','নিয়াছিলেন':'VB','নিয়াজুল':'NN','নিয়াজুলরা':'NN','নিয়ামক':'NN','নিয়ার':'NN','নিয়ুন':'NN',
'নিয়ে':'NN','নিয়েই':'IN','নিয়েও':'VB','নিয়েগণতন্ত্র':'VB','নিয়েগের':'VB','নিয়েছ':'VB','নিয়েছিল':'VB',
'নিয়েছিলেন':'VB','নিয়েছে':'VBN','নিয়েছেএই':'VB','নিয়েছেন':'VBN','নিয়েতো':'VB','নিয়োগ':'NN','নিয়ে্ই':'IN',
'নিয়োগ':'NN','নিয়োগকর্তা':'NN','নিয়োগগুলো':'NNS','নিয়োগদাতা':'NN','নিয়োগদানে':'VBG','নিয়োগপত্র':'NN','নিয়োগপ্রাপ্ত':'VBN',
'নিয়োগী':'JJ','নিয়োগের':'NN','নিয়োজন':'NN','নিয়োবিয়াম':'NN','নিয়োমাবর্তিতা':'NN','নি‌য়ে':'NN','নীকে':'NN',
'নীচ':'NN','নীচকুল':'NN','নীচকুলজাত':'JJ','নীচতা':'NN','নীচবংশ':'NN','নীচবংশজাত':'JJ','নীচু':'NN',
'নীচুনো':'VB','নীচে':'NN','নীট':'VB','নীটা':'NN','নীতি':'NN','নীতিকথা':'NNS','নীতিগত':'NN',
'নীতিজ্ঞ':'JJ','নীতিটি':'NN','নীতিতে':'NN','নীতিনির্ধারক':'NNS','নীতিনৈতিকতা':'NNS','নীতিপূর্ণ':'JJ','নীতিবহির্ভূত':'JJ',
'নীতিবাদ':'NN','নীতিবান':'VBD','নীতিবানদের':'NNS','নীতিবিদ':'NN','নীতিবিরুদ্ধ':'JJ','নীতিবিহীনতা':'NN','নীতিবোধ':'NN',
'নীতিভ্রষ্ট':'JJ','নীতিমালা':'NNS','নীতিমালাকে':'NN','নীতিমালায়':'NN','নীতির':'NN','নীতিশাস্ত্র':'NN','নীতিশিক্ষায়':'NN',
'নীতিহীন':'NN','নীতে':'NN','নীদরল্যাঁণ্ড':'NN','নীবিবন্ধ':'NN','নীবিস':'NN','নীমচ':'NN','নীমরোড':'NN',
'নীমহাকিম':'NN','নীমা':'NN','নীমাস্তীন':'NN','নীমুচ':'NN','নীয়':'JJ','নীর':'NN','নীরগোঙ্গ':'NN',
'নীরজ':'NN','নীরবঅপনারা':'NN','নীরবতা':'NN','নীরবদর্শক':'JJ','নীরবে':'NN','নীরস':'JJ','নীরসতা':'NN',
'নীরিক্ষার':'NN','নীরু':'NN','নীল':'NN','নীলকণ্ঠ':'NN','নীলকণ্ঠের':'NNP','নীলকন্ঠ':'NN','নীলকমল':'NN',
'নীলকান্তমণি':'NNP','নীলকান্তমণির':'JJ','নীলকুন্তলা':'NN','নীলক্ষেতেও':'NN','নীলগাই':'NN','নীলগিরি':'NN','নীলচক্র':'NN',
'নীলনক্সা':'NN','নীলনদ':'NNP','নীলনদের':'NN','নীলনির্যাসক':'NN','নীলনী':'NN','নীলপক্ষ':'NN','নীলপদ্ম':'NN',
'নীলপুষ্প':'NN','নীলপুষ্পিকা':'NN','নীলফল':'NN','নীলবতী':'NNP','নীলবীজ':'NN','নীলম':'NN','নীলমল্লিকা':'NN',
'নীলমাধব':'NNP','নীলমেহ':'NN','নীলরং':'NN','নীলশিগ্রু':'NN','নীলসর':'NN','নীলা':'NN','নীলাক্ষ':'JJ',
'নীলাঙ্গ':'NN','নীলাঞ্জনা':'NN','নীলাব্জ':'NNP','নীলাম্বর':'NN','নীলার':'NNP','নীলাসন':'NN','নীলিমা':'NN',
'নীলু':'NNP','নীলেন্দু':'NN','নীষী':'JJ','নীহারিকা':'NN','নীহারিকায়':'NN','নীড়':'NNP','নীয়া':'NNP',
'নুইন':'NNP','নুইয়ে':'NN','নুকতি':'NN','নুকরী':'NN','নুক্তা':'NN','নুডল':'NN','নুড়ি':'NN',
'নুতন':'NNP','নুতনত্ব':'NN','নুন':'NN','নুনজুণ্ডাকে':'NNP','নুনদানি':'NN','নুনিয়া':'NN','নুনু':'NN',
'নুনের':'NN','নুন্নতম':'NN','নুনয়':'NN','নুবীয়':'JJ','নুভব':'NN','নুর':'NN','নুরজাহান':'NN',
'নুরুদের':'NN','নুরুদ্দীন':'NN','নুরুল':'NN','নুলো':'NN','নুষই':'NN','নুষী':'JJ','নুড়ি':'NN',
'নুয়াপাড়া':'NN','নূতন':'JJ','নূন্যতম':'NN','নূপুর':'NN','নূর':'NN','নূঢ়া':'NN','নৃকুলসংক্রান্ত':'JJ',
'নৃগ':'NN','নৃগোষ্ঠীগুলোকে':'NNS','নৃজাতি':'NN','নৃতত্ত্ব':'NN','নৃত্য-গীত':'NN','নৃত্য-নাট্য':'NN','নৃত্য':'NN',
'নৃত্যকার':'NN','নৃত্যগীতে':'NN','নৃত্যনাট্য':'NN','নৃত্যনো':'VB','নৃত্যপ্রিয়':'NN','নৃত্যরত':'JJ','নৃত্যশালা':'NN',
'নৃত্যাঙ্গনা':'NN','নৃত্যে':'NN','নৃপ':'NN','নৃপকুমকুম':'NN','নৃপতি':'NN','নৃপপ্রিয়া':'NN','নৃপরহিত':'JJ',
'নৃপোচিত':'NN','নৃমেধ':'NN','নৃশংস':'JJ','নৃশংসতা':'NN','নৃসিংহ-চতুর্দশী':'NN','নৃসিংহ':'NN','নৃহতি':'NN',
'নেংটি':'NN','নেই':'NN','নেইঅনেক':'JJ','নেইআবার':'NN','নেইআরেকটা':'RB','নেইই':'DT','নেইএক':'NN',
'নেইকারন':'NN','নেইগত':'NN','নেইগরুও':'NN','নেইতাই':'NN','নেইদশ':'NN','নেইদ্বিতীয়':'NN','নেইনাকি':'NN',
'নেইবরং':'RB','নেইবোর্ড':'NN','নেইব্যাংক':'NN','নেইভাগ্য':'NN','নেইমান্নার':'NN','নেইমারই':'NN','নেইমারের':'NN',
'নেইমিকে':'NN','নেইযার':'NN','নেইলড়াই':'NN','নেইহত্যাকারীদের':'NN','নেউল':'NN','নেউলের':'JJ','নেও':'NN',
'নেওয়া':'VB','নেওয়ার':'NNV','নেওয়া':'NN','নেওয়াকারণ':'VBG','নেওয়াজ':'NN','নেওয়াটা':'VBN','নেওয়াটাই':'NN',
'নেওয়াবিবেক':'NN','নেওয়ার':'NN','নেক':'NN','নেকড়ে':'NN','নেকলেস':'NN','নেকি':'NN','নেকে':'VB',
'নেকড়ের':'NN','নেগ':'NN','নেগাচার':'NN','নেগেটিভ':'JJ','নেচে':'NN','নেচেছিলে':'VB','নেছি':'VB',
'নেট':'NN','নেটওয়ার্ক':'NN','নেটওর্য়াকই':'NN','নেটওয়র্কিং':'NN','নেটওয়ার্কটা':'NN','নেটস্পিড':'NN','নেটে':'NN',
'নেটো':'NN','নেড়া':'JJ','নেড়ার':'NN','নেতা':'NN','নেতাও':'NN','নেতাকর্মিদের':'NNS','নেতাকর্মীকে':'NNS',
'নেতাকর্মীর':'NN','নেতাকর্মীরা':'NNS','নেতাকে':'NN','নেতাগুলী':'NN','নেতাতিনি':'NN','নেতাদের':'NN','নেতাবিহীন':'JJ',
'নেতার':'NN','নেতারাই':'NN','নেতারাও':'NNS','নেতায়':'NN','নেতি':'NN','নেতিক্রিয়া':'NN','নেতিবাচক':'JJ',
'নেতৃত্ত':'NN','নেতৃত্বও':'NN','নেতৃত্বাধীন':'NN','নেতৃত্বে':'VB','নেতৃত্বেযদিএই':'NN','নেতৃবর্গের':'NN','নেতৃবৃন্দ':'NNS',
'নেতে':'VB','নেত্তি':'NN','নেত্রগোলক':'NN','নেত্রবালা':'NN','নেত্ররোগ':'NN','নেত্রসীমা':'NN','নেত্রাঞ্জন':'NN',
'নেত্রাময়':'NN','নেত্রির':'NN','নেত্রীকে':'NN','নেত্রীত্বই':'NN','নেত্রীয়':'JJ','নেদারল্যান্ড':'NN','নেদারল্যান্ডসকে':'NNS',
'নেন':'VB','নেননি':'NN','নেনুয়া':'NN','নেপচুন':'NN','নেপচুনের':'NNP','নেপটিজম':'NN','নেপথ্য':'NN',
'নেপথ্যের':'NNS','নেপন':'NN','নেপাল-বাসী':'NN','নেপাল':'NN','নেপালবাসী':'NN','নেপালি':'NN','নেপোলিয়ান':'NN',
'নেপোয়':'NNP','নেপ্টুনিয়াম':'NN','নেব':'VB','নেবকারণ':'NN','নেবার':'VB','নেবুচাঁদনেজার':'NNP','নেবে':'VB',
'নেবেঞ্চুস':'RB','নেবেন':'NN','নেবেনা':'VB','নেবো':'VB','নেভানো':'VB','নেভানোর':'VBG','নেভি':'NN',
'নেমপ্লেট':'NN','নেমর':'NN','নেমি':'NN','নেমী':'NN','নেমীচক্র':'NN','নেমীনাথ':'NN','নেমে':'NN',
'নেমেই':'IN','নেমেছিল':'NN','নেমেছিলেন':'IN','নেমেছেন':'VBN','নেয়':'NNS','নেয়ার':'NNV','নেরই':'NNP',
'নেরও':'NN','নেরাওয়াতি':'NN','নেরেছে':'NN','নেলে':'VB','নেশন':'NN','নেশা':'NN','নেশাগ্রস্ত':'NN',
'নেশাগ্রস্থ':'VBN','নেশাড়ু':'NN','নেশাতুর':'JJ','নেশাতেই':'VBN','নেশাদ্রব্য':'JJ','নেশান্স':'NN','নেশামুক্ত':'NN',
'নেশার':'NN','নেশায়':'VBN','নেসলেই':'NNP','নেহরু':'NNP','নেহা':'NN','নেহাত':'RB','নেহাতই':'NN',
'নেহাত্':'RP','নেহে':'VB','নেহেরু':'NN','নোংরা':'NN','নোট':'NN','নেড়ে':'VB','নেয়':'NNS',
'নেয়ই':'NN','নেয়ইনি':'VB','নেয়নি':'VB','নেয়সেখানে':'NN','নেয়া':'VBN','নেয়াঃ':'NNP','নেয়াই':'VBN',
'নেয়াটা':'NN','নেয়ার':'NN','নেয়ে':'NN','নৈঋত':'NN','নৈকট্য':'NN','নৈতিক':'NN','নৈতিকতাপূর্ণ':'JJ',
'নৈতিকতাবোধ':'NN','নৈতিকতার':'NN','নৈতিকতাহীন':'JJ','নৈতিকভাবে':'NN','নৈনিতাল':'NN','নৈপণ্য':'NN','নৈপুণ্যতা':'NN',
'নৈপূন্যে':'NN','নৈবেদ্য':'NN','নৈমত্তিক':'NN','নৈরাঙ্যের':'NN','নৈরাশ্য':'NN','নৈর্ব্যক্তিক':'JJ','নৈশ':'NN',
'নৈশউত্সব':'NN','নৈশভোজ':'NN','নৈসর্গিক':'NN','নো':'NN','নোংরা':'NN','নোংরাচিটে':'JJ','নোংরামি':'NN',
'নোকার':'NN','নোঙর':'NN','নোঙ্গপো':'NN','নোট':'NN','নোটবন্দী':'NN','নোটবুক':'NN','নোটস্':'NN',
'নোটিফিকেশন':'NNS','নোটিশ':'NN','নোটে':'NN','নোটের':'NN','নোড়া':'NN','নোতি':'NNP','নোধা':'NN',
'নোনতা':'NN','নোনি':'NN','নোবল্':'JJ','নোবা':'NNP','নোবেল':'NN','নোবেলিয়াম':'NN','নোবো':'NN',
'নোভা':'NN','নোম':'NNP','নোমত':'JJ','নোরথ':'NNP','নোরম':'JJ','নোলক':'NN','নোয়া':'NN',
'নোয়াখালী':'NN','নোয়াম':'NNP','নোয়াহ':'NN','নৌ':'NN','নৌকা':'NN','নৌকাঘাট':'NN','নৌকাচালক':'NN',
'নৌকাটি':'NN','নৌকাবাহক':'NN','নৌকার':'NN','নৌকায়':'NN','নৌকো':'NN','নৌচকচোট':'NN','নৌচর':'JJ',
'নৌচা':'NN','নৌটঙ্কী':'NN','নৌদস্যু':'NN','নৌপথ':'NN','নৌপরিবহন':'NN','নৌবাহ':'NN','নৌবাহিনী':'NNP',
'নৌবিস্তার':'NN','নৌযাত্রা':'NN','নৌযোগে':'NN','নৌসাদর':'NN','নৌসেনা':'NN','নৌসেনাধক্ষ্য':'NN','নৌসৈনিক':'JJ',
'ন্যক্কারজনক':'NN','ন্যগ্রোধ':'NN','ন্যচ্ছ':'NN','ন্যস্ত':'NN','ন্যাকা':'NN','ন্যাক্কারজনক':'NN','ন্যাচারাল':'NN',
'ন্যাড়':'NN','ন্যাতা':'NN','ন্যানো':'NN','ন্যাপথা':'NN','ন্যাফেলিয়াম':'NNP','ন্যাবা':'NN','ন্যাবার্ড':'NNP',
'ন্যায্য':'NN','ন্যার':'NN','ন্যাশনাল':'NN','ন্যাশানাল':'NN','ন্যাশান্যাল':'NNP','ন্যাস':'NN','ন্যাসরক্ষক':'NN',
'ন্যায়-দর্শন':'NN','ন্যায়-শাস্ত্র':'NN','ন্যায়':'NN','ন্যায়কারী':'JJ','ন্যায়দর্শন':'NN','ন্যায়নীতি':'NN','ন্যায়পরায়ণ':'JJ',
'ন্যায়পালিকা':'NN','ন্যায়পূর্ণ':'JJ','ন্যায়বিচার':'NN','ন্যায়ভিত্তিক':'RB','ন্যায়মত':'RB','ন্যায়মূর্তি':'NN','ন্যায়শাস্ত্র':'NN',
'ন্যায়শাস্ত্রবিদ':'NN','ন্যায়সংগত':'JJ','ন্যায়সভা':'NN','ন্যায়হীন':'JJ','ন্যায়হীনতা':'NN','ন্যায়াদেশ':'NN','ন্যায়াধিকরণ':'NN',
'ন্যায়াধীশ':'NN','ন্যায়ের':'NN','ন্যায়োচিত':'JJ','ন্যু':'NN','ন্যুনতম':'NN','ন্যুমারোলজি':'NN','ন্যূন':'NN',
'ন্যূনতমবাদী':'JJ','ন্যূনতা':'NN','ন্যূনাধিক':'RB','নড়বড়ে':'NN','নড়াইল':'NN','নড়াইলে':'NN','নড়াইলের':'NN',
'নড়ে':'NN','নড়েচড়ে':'VBG','নয়-খন্ড':'NN','নয়':'NN','নয়আপনি':'NN','নয়আর':'NN','নয়ই':'NN',
'নয়উনি':'NN','নয়এটা':'NN','নয়ওনারা':'NNS','নয়কড়ি':'NN','নয়কলকাতার':'NN','নয়কি':'NN','নয়খন্ড':'NN',
'নয়খেলা':'NN','নয়গুণ':'NN','নয়ঘুমিয়ে':'VBG','নয়চিনি':'NN','নয়ছয়':'NN','নয়জনগন':'NN','নয়টার':'NN',
'নয়ডা':'NN','নয়ত':'RB','নয়তবুও':'NN','নয়তো':'NN','নয়তোবা':'RB','নয়ন':'NN','নয়নগোচর':'JJ',
'নয়নপট':'NN','নয়নপ্রান্ত':'NN','নয়নবারি':'NN','নয়নসুখ':'NN','নয়নাভিরাম':'JJ','নয়নু':'NN','নয়নে':'RB',
'নয়নোপান্ত':'NN','নয়নৌষধ':'NN','নয়মাস':'NNS','নয়া':'NN','নয়াগড়':'NN','নয়াপঞ্জ':'NN','নয়েক':'JJ',
'ন‌িরব‌ে':'NN','ন‍্যায‍্যতার':'NN','প-বর্গ':'NN','প-বর্গীয়':'JJ','প':'NN','পঁচনশীল':'JJ','পঁচাতে':'NN',
'পঁচাত্তরতম':'JJ','পঁচানব্বই':'NN','পঁচানব্ব্ইতম':'JJ','পঁচানো':'VB','পঁচাশি':'NN','পঁচাশিতম':'JJ','পঁচিশ':'NN',
'পঁচিশতম':'JJ','পঁচিশী':'NN','পঁচিশেক':'JJ','পঁচিয়েছে':'NN','পঁচে':'NN','পঁড়রী':'NN','পঁয়তাল্লিশ':'NN',
'পঁয়তাল্লিশতম':'JJ','পঁয়ত্রিশ':'NN','পঁয়ত্রিশতম':'JJ','পঁয়ষট্টি':'NN','পংক্তি':'NN','পই':'NN','পইরা':'NN',
'পইড়া':'NN','পউলা':'NN','পএ':'NN','পএের':'NN','পওয়ারি':'NN','পকতর':'JJ','পকথন':'NN',
'পকপক':'NN','পকরণ':'NN','পকারান্ত':'JJ','পকাশে':'NN','পকিন':'NN','পকিস্তানও':'NN','পকীয়':'JJ',
'পকূল':'JJ','পকৃত':'JJ','পকেট':'NN','পকেটএ':'NN','পকেটমার':'NN','পকেটে':'NN','পকোরা':'NN',
'পক্ক':'JJ','পক্ব':'NN','পক্রিয়া':'NN','পক্ষ':'NN','পক্ষকার':'NN','পক্ষকেই':'NN','পক্ষপতন':'NN',
'পক্ষপাতদুষ্ট':'JJ','পক্ষপাতদুস্ট':'NN','পক্ষপাতপূর্ণ':'JJ','পক্ষপাতরহিত':'JJ','পক্ষপাতশূণ্য':'NN','পক্ষপাতহীন':'NN','পক্ষাঘাত':'NN',
'পক্ষাঘাতগ্রস্ত':'JJ','পক্ষাঘাতপীড়িত':'JJ','পক্ষান্তরে':'NN','পক্ষালম্বন':'NN','পক্ষি':'NN','পক্ষী':'NN','পক্ষীন্দ্র':'NN',
'পক্ষীমাংস':'NN','পক্ষীশালা':'NN','পক্ষীশিকারী':'NN','পক্ষে':'NN','পক্ষেও':'PSP','পক্ষের':'NN','পখানভেদ':'NN',
'পগপান':'NN','পগরনা':'NN','পগার':'NN','পগড়ে':'VB','পঘাল':'NN','পঙক্তি':'NN','পঙ্কগড়ক':'NN',
'পঙ্কজ':'NN','পঙ্কজবাটিক':'NN','পঙ্কজাসন':'NN','পঙ্কজিত্':'NN','পঙ্কতিবদ্ধ':'VB','পঙ্কদিগ্ধশরীর':'NN','পঙ্কদিগ্ধাঙ্গ':'NN',
'পঙ্কিল':'JJ','পঙ্কিলতায়':'NN','পঙ্খিরাজ':'NN','পঙ্গপাল':'NN','পঙ্গী':'NN','পঙ্গুতা':'NN','পঙ্গুল':'NN',
'পচড়া':'NN','পচন':'NN','পচনশীল':'JJ','পচা':'NN','পচাত্তর':'NN','পচানক':'NN','পচানো':'VB',
'পচানোর':'NN','পচাপ':'NN','পচিশী':'NN','পচুই':'NN','পচে':'NN','পচ্চ-ব্রহ্ম':'NN','পচ্চি':'NN',
'পচ্চী':'NN','পছন্দ':'NN','পছন্দমত':'NN','পছন্দমাফিক':'JJ','পছন্দসই':'NN','পছন্দের':'NN','পজাত':'JJ',
'পজিটিভ':'NN','পজিশন':'NN','পজেটিভ':'NN','পজ্ঝটিকা':'NN','পঞ্চ-কোণ':'NN','পঞ্চ':'NN','পঞ্চকন্যা':'NN',
'পঞ্চকুলা':'NN','পঞ্চকেদার':'NNP','পঞ্চকোণ':'NN','পঞ্চগনী':'NN','পঞ্চগব্য':'NN','পঞ্চগৌড়':'NN','পঞ্চজন':'NN',
'পঞ্চতত্ত্ব':'NN','পঞ্চতন্ত্রের':'NNP','পঞ্চতপ':'NN','পঞ্চতারের':'JJ','পঞ্চতাল':'NN','পঞ্চতোলিয়া':'NN','পঞ্চদশ':'CD',
'পঞ্চদশতম':'JJ','পঞ্চদেব':'NN','পঞ্চধাতু':'NN','পঞ্চনদ':'NN','পঞ্চপদ':'NN','পঞ্চপল্লব':'NN','পঞ্চপাত':'NN',
'পঞ্চপ্রদীপ':'NN','পঞ্চবটী':'NN','পঞ্চবার্ষিকী':'JJ','পঞ্চবাহী':'JJ','পঞ্চবায়ু':'NN','পঞ্চভুজ':'JJ','পঞ্চভূজ':'NN',
'পঞ্চভৌতিক':'JJ','পঞ্চম':'NN','পঞ্চমতঃ':'RB','পঞ্চমপাণ্ডব':'NN','পঞ্চমহল':'NN','পঞ্চমাসা':'JJ','পঞ্চমী':'NN',
'পঞ্চমুখী':'NN','পঞ্চমুদ্রা':'NN','পঞ্চমুষ্টিক':'NN','পঞ্চমূল':'NN','পঞ্চরক্ষক':'NN','পঞ্চরস':'NN','পঞ্চলড়ী':'NN',
'পঞ্চশিখ':'NN','পঞ্চসেরি':'NN','পঞ্চহাজারি':'NN','পঞ্চাক্ষরী':'NN','পঞ্চাগ্নি':'NN','পঞ্চাঙ্গী':'NN','পঞ্চানন':'NNP',
'পঞ্চান্ন':'NN','পঞ্চামর':'NN','পঞ্চাশ':'NN','পঞ্চাশটি':'CD','পঞ্চাশেক':'JJ','পঞ্চাস':'NN','পঞ্চায়েত':'NN',
'পঞ্চায়েতের':'NN','পঞ্চেন্দ্রীয়':'NN','পঞ্চোলী':'NN','পঞ্জাবীদের':'NN','পঞ্জাবে':'NNP','পঞ্জি-পুস্তক':'NN','পঞ্জিকা':'NN',
'পঞ্জীকরণ':'NN','পট':'NN','পটওয়া':'NN','পটকা':'NN','পটচিত্র':'NN','পটনী':'NN','পটপট':'NN',
'পটবাদ্য':'NN','পটভূমি':'NN','পটভূমিকায়':'NN','পটমঞ্জরী':'NN','পটল':'NN','পটলাকৃতি':'JJ','পটলের':'NN',
'পটহ':'NN','পটহংসিকা':'NN','পটা':'NN','পটাতে':'NN','পটানো':'VB','পটানোর':'NN','পটাপট':'NN',
'পটার':'NN','পটাশ':'NN','পটাশিয়াম':'NN','পটায়':'NN','পটি':'NN','পটিক':'JJ','পটু':'NN',
'পটুতা':'NN','পটুয়া':'JJ','পটে':'VB','পটোঁহা':'NN','পটোরী':'NN','পটোল':'NN','পটোলিকা':'NN',
'পটোলী':'NN','পটোয়ারীর':'NN','পট্ট':'NN','পট্টবর্ধন':'NNP','পট্টি':'NN','পঠছন্দমত':'RB','পঠন-পাঠন':'NN',
'পঠন':'NN','পঠনাংশ':'NN','পঠনের':'NN','পঠিত':'JJ','পডবে':'VB','পড়ছে':'VB','পড়বে':'VB',
'পড়ল':'NN','পড়লে':'VB','পড়া':'NN','পড়াতে':'VB','পড়ানো':'NN','পড়ার':'VB','পড়াশোনা':'NN',
'পড়ি':'VB','পড়িনাতি':'NN','পড়ুন':'VB','পড়ে':'NN','পড়েছি':'VB','পড়েন':'VB','পঢিপ':'NN',
'পণ':'NN','পণজী':'NN','পণব':'NN','পণবন্দী':'NN','পণি':'NN','পণে':'JJ','পণের':'NN',
'পণ্ড':'NN','পণ্ডশ্রম':'NN','পণ্ডিচেরি':'NN','পণ্ডিত':'NN','পণ্ডিতকে':'NN','পণ্ডিতগিরী':'NN','পণ্ডিতদের':'JJ',
'পণ্ডিতের':'NNP','পণ্ডিতেরা':'NN','পণ্ডিন':'NN','পণ্য':'NN','পণ্যকে':'NN','পণ্যগুলো':'NN','পণ্যটি':'NN',
'পণ্যশালা':'NN','পণ্যে':'NN','পণ‌্যের':'NN','পতওয়া':'NN','পতগ':'NN','পতঙ্গভূক':'JJ','পতঞ্জলভাষ্য':'NN',
'পতঞ্জলি':'NN','পতঞ্জলিকৃত':'JJ','পতত্রীরাজ':'NN','পতদ্যাগ':'NN','পতন':'NN','পতনমতিট্টা':'NN','পতনশীল':'JJ',
'পতনে':'NN','পতনোন্মুখ':'JJ','পতরিঙ্গা':'NN','পতাকা':'NN','পতাকাচিহ্নিত':'JJ','পতাকাদন্ড':'NN','পতাকাধারক':'NN',
'পতাকাযুক্ত':'JJ','পতাকার':'NN','পতি':'NN','পতিকামা':'NN','পতিত':'NN','পতিতপাবন':'JJ','পতিতা':'NN',
'পতিতালয়ে':'NN','পতিত্বে':'NN','পতিনিন্দা':'NN','পতিব্রততা':'NN','পতির':'NN','পতেই':'NN','পতেঙ্গা':'NNP',
'পতোখা':'NN','পত্তই':'NN','পত্তিকার':'NN','পত্থরচটা':'NN','পত্নী':'NN','পত্নীনিষ্ঠ':'NN','পত্নীব্রত':'NN',
'পত্নীব্রতা':'JJ','পত্য':'NN','পত্র-ব্যবহার':'NN','পত্র-মিত্র':'NN','পত্র':'NN','পত্রকারিতা':'NN','পত্রকেও':'NN',
'পত্রটির':'NN','পত্রপত্রিকা':'NN','পত্রপালী':'NN','পত্রপাশ্যা':'NN','পত্রপুষ্পক':'NN','পত্রপ্রেরণা':'NN','পত্রবাহক':'NN',
'পত্রব্যবহার':'NN','পত্রযুক্ত':'JJ','পত্রর':'NN','পত্রশুক':'NN','পত্রহরিত্':'NN','পত্রহীন':'JJ','পত্রাচার':'NN',
'পত্রিকা':'NN','পত্রিকাগুলোতে':'NN','পত্রিকাটি':'NN','পত্রিকান্তরে':'NN','পত্রিকায়':'NN','পত্রের':'NN','পথ-প্রদর্শক':'NN',
'পথ':'NN','পথচারীদের':'NN','পথটি':'NN','পথপ্রদর্শক':'NN','পথভোলা':'JJ','পথভ্রষ্ট':'NN','পথযাত্রায়':'NN',
'পথযুক্ত':'JJ','পথরচটা':'NN','পথি':'NN','পথিকালয়':'NN','পথিকাশ্রয়':'NN','পথিকের':'NN','পথে':'NN',
'পথের':'NN','পথ্য':'NN','পথ্যাদিক্বাথ':'NN','পদ':'NN','পদক-তালিকা':'NN','পদক':'NN','পদক্ষেপ':'NN',
'পদক্ষেপকে':'NN','পদক্ষেপে':'NN','পদচারণ-সহায়ক':'NN','পদচারী':'NN','পদচিহ্ন':'NN','পদচ্যুত':'JJ','পদটা':'NN',
'পদটির':'NN','পদতল':'NN','পদতাগ':'NN','পদত্যাগ':'NN','পদত্যাগপত্র':'NN','পদদলন':'NN','পদদলিত':'JJ',
'পদধূলি':'NN','পদধ্বনি':'NN','পদনাম':'NN','পদপংক্তি':'NN','পদপদবীতে':'NN','পদবি':'NN','পদবীধারী':'NN',
'পদব্রজী':'NN','পদমর্যাদা':'NN','পদযাত্রা':'NN','পদরজ':'NN','পদস্থ':'JJ','পদহীন':'JJ','পদাংক':'NN',
'পদাঘাত':'NN','পদাতিক':'NN','পদাতিকবাহিনী':'NN','পদাধিকারি':'NN','পদাবনতি':'NN','পদাবরণ':'NN','পদাবলি':'NN',
'পদার':'NN','পদার্থ':'NN','পদার্থবিজ্ঞান':'NN','পদার্থবিদ':'NN','পদার্থবিদ্যাবিদরা':'NN','পদার্থে':'NN','পদার্পণ':'NN',
'পদালঙ্কার':'NN','পদাসন':'NN','পদিক':'NN','পদীর':'NN','পদে':'NN','পদেশ':'NN','পদোন্নিত':'NN',
'পদোক':'NN','পদোন্নতি':'NN','পদোন্নতিনো':'VB','পদ্ধতি':'NN','পদ্ধতিতে':'NN','পদ্বতি':'NN','পদ্ম-সমূহ':'NN',
'পদ্ম':'NN','পদ্মকান্ড':'NN','পদ্মগুণা':'NN','পদ্মনাভ':'NN','পদ্মনাল':'NN','পদ্মপত্র':'NN','পদ্মপলাশ':'NN',
'পদ্মপ্রভ':'NN','পদ্মবিভূষণ':'NN','পদ্মবীজ':'NN','পদ্মমালী':'NN','পদ্মরাজ':'NN','পদ্মসুত্র':'NN','পদ্মহস্তা':'NN',
'পদ্মাআহারে':'NN','পদ্মাক্ষ':'NN','পদ্মাদেবী':'NN','পদ্মাপারের':'NNP','পদ্মাবতীর':'NNP','পদ্মাব্রিজ':'NN','পদ্মায':'NNP',
'পদ্মার':'NN','পদ্মাসন':'NN','পদ্মাসেতু':'NN','পদ্মাসেতুর':'NN','পদ্মিনী':'NN','পদ্মের':'NN','পদ্য':'NN',
'পদ্যলেখক':'NN','পনস':'NN','পনসিকা':'NN','পনাথ':'NNP','পনার':'NN','পনি':'NN','পনিও':'NN',
'পনির':'NN','পনিরি':'JJ','পনীত':'JJ','পনীর':'NN','পনীয়':'JJ','পনের':'NN','পনেরোশো':'CD',
'পনৈলা':'NN','পন্ট':'NN','পন্টরপুর':'NN','পন্টিং':'NN','পন্টিংয়ের':'NN','পন্ডিত':'NN','পন্থ':'NN',
'পন্থাগুলি':'NN','পন্থাটাই':'NN','পন্থি':'NN','পন্থীআবার':'NN','পন্থের':'NN','পন্দ':'NN','পন্ন':'JJ',
'পন্নগাশন':'NN','পন্য':'NN','পন্যসামগ্রী':'NN','পন্যে':'NN','পন্হী':'NN','পপ':'NN','পপতী':'JJ',
'পপলিন':'NN','পপি':'NNP','পপুমপারে':'NN','পপুয়া':'NN','পপোটন':'NN','পফের':'NN','পবই':'NN',
'পবণ-বাণ':'NN','পবণ':'NN','পবণবাণ':'NN','পবন-পরীক্ষা':'NN','পবন':'NN','পবনদেব':'NN','পবনপরীক্ষা':'NN',
'পবিএ':'NN','পবিত্র':'NN','পবিত্রতার':'NN','পবিত্রী':'NN','পবীনব':'NN','পভার্টির':'NN','পভোগ':'NN',
'পমান':'NN','পম্পা':'NN','পম্পেও':'NN','পম্বা':'NN','পম্মন':'NN','পযন্ত':'NN','পয়সা':'NN',
'পয়েন্ট':'NN','পযার্প্ত':'NN','পর':'NN','পরও':'NN','পরওযদি':'NN','পরকটা-পাখি':'NN','পরকল্পিত':'NN',
'পরকাল':'NN','পরকালে':'NN','পরকিয়া':'NN','পরকীয়':'JJ','পরকীয়া':'NN','পরকে':'NN','পরখ':'NN',
'পরখকারি':'NN','পরখিত্র':'NN','পরগণা':'NN','পরগনী':'NN','পরগাছা':'NN','পরচর্চা':'NN','পরচুলা':'NN',
'পরছি':'NN','পরজ':'NN','পরজন্ত':'NN','পরজীবি':'NN','পরটি':'NN','পরত':'NN','পরতযুক্ত':'JJ',
'পরতলা':'NN','পরতে':'NN','পরতো':'NN','পরথন':'NN','পরদা':'NN','পরদানশিন':'JJ','পরদাবিশিষ্ট':'JJ',
'পরদাযুক্ত':'JJ','পরদারগামী':'JJ','পরদাহীন':'JJ','পরদিন':'NN','পরদুঃখে':'NN','পরদেশ':'NN','পরদেশে':'NN',
'পরনারী':'NN','পরনির্ভরতা':'NN','পরনির্ভরশীল':'JJ','পরনে':'NN','পরন্তু':'RP','পরপত্নী':'NN','পরপর':'NN',
'পরপারে':'NN','পরপুরঞ্জয়':'NN','পরপুরুষ':'NN','পরব':'NN','পরবরতন':'NN','পরবর্তিকালে':'NN','পরবর্তী':'RB',
'পরবর্তীতে':'NN','পরবশতঃ':'RB','পরবে':'NN','পরব্রহ্ম':'NN','পরভণী':'NN','পরম':'NN','পরমগুরু':'NN',
'পরমপরাগত':'NN','পরমপ্রিয়':'NN','পরমবীর':'NN','পরমব্রহ্ম':'NN','পরমহংস-পরিব্রাজক':'NN','পরমহংস':'NN','পরমহংসোপনিষদ':'NN',
'পরমা':'NN','পরমাণবিক':'NN','পরমাণুগুলোর':'NN','পরমাণুতে':'NN','পরমাণুবোমা':'NN','পরমাণুসমূহ':'NN','পরমানন্দ':'NN',
'পরমানবিক':'JJ','পরমান্ন':'NN','পরমায়ু':'NN','পরমুখাপেক্ষি':'NN','পরমুখাপেক্ষী':'JJ','পরমেশ্বরী':'NN','পরমেশ্বরীয়':'JJ',
'পরম্পরা':'NN','পরম্পরানুসারে':'RB','পরম্পরাবাদ':'NN','পরম্পরায়':'NN','পরযন্ত':'NN','পররাষ্ট্র':'NN','পররাষ্ট্রনীতিতে':'NN',
'পররাষ্ট্রমন্ত্রী':'NN','পরলে':'JJ','পরলেই':'VBG','পরলোক':'NN','পরলোকগত':'JJ','পরলোকগমন':'NN','পরশ':'NN',
'পরশুরাম':'NN','পরশে':'NN','পরশ্রীকাতর':'NN','পরসর্গ':'NN','পরসাধার':'NN','পরসাল':'NN','পরসী':'NN',
'পরস্ত্রী':'NN','পরস্ত্রীগামী':'JJ','পরস্পর':'NN','পরস্পরবিরোধী':'NN','পরস্পরের':'NN','পরস্পোপমা':'NN','পরস্মৈপদ':'NN',
'পরহিত':'NN','পরা-বিদ্যা':'NN','পরা':'NN','পরাক্রম':'NN','পরাক্রমী':'JJ','পরাক্ষী':'NN','পরাগকণা':'NN',
'পরাগকেশর':'NN','পরাগরেণু':'NN','পরাঙ্মুখ':'JJ','পরাজয়ের':'NN','পরাজিকা':'NN','পরাজয়':'NN','পরাজয়ের':'NN',
'পরাণ':'NN','পরাণুবীক্ষণ':'NN','পরাত':'NN','পরাতে':'VB','পরাধ':'NN','পরাধীন':'NN','পরাধীনতার':'NN',
'পরাধীনভাবে':'RB','পরানো':'NN','পরাবর্তন':'NN','পরাবর্তিত':'JJ','পরাবলম্বন':'NN','পরাবলম্বী':'JJ','পরাবাদী':'JJ',
'পরাভব':'NN','পরামর্শ':'NN','পরামর্শটা':'NN','পরামিতি':'NN','পরাশর':'NN','পরাশ্রিত':'JJ','পরাশ্রয়ী':'JJ',
'পরাসী':'NN','পরাহ':'NN','পরায়ণ':'NN','পরি':'NN','পরিক':'JJ','পরিকনার':'NN','পরিকরাঙ্কুর':'NN',
'পরিকলক':'NN','পরিকল্পনা':'NN','পরিকল্পনাকার':'NN','পরিকল্পনাবিদদের':'NN','পরিকল্পনামন্ত্রী':'NN','পরিকল্পনার':'VBG','পরিকল্পনারই':'NN',
'পরিকল্পিত':'NN','পরিক্রমণ':'NN','পরিক্ষক':'NN','পরিক্ষা':'NN','পরিক্ষার্থীদের':'NN','পরিক্ষিত':'NN','পরিখা':'NN',
'পরিখাবেষ্টীত':'NN','পরিগণিত':'JJ','পরিগ্রহ':'NN','পরিচয়':'NN','পরিচর্চা':'NN','পরিচর্যা':'NN','পরিচর্য্যা':'NN',
'পরিচারিকা':'NN','পরিচালক':'NN','পরিচালকের':'NN','পরিচালকেরা':'NNS','পরিচালকেরাই':'NN','পরিচালন':'NN','পরিচালনাকারী':'NN',
'পরিচালনাধীন':'JJ','পরিচালনায়':'NN','পরিচালনায়':'NN','পরিচায়ক':'NN','পরিচিত':'NN','পরিচ্ছদ':'NN','পরিচ্ছন্ন':'NN',
'পরিচ্ছেদ':'NN','পরিচ্ছেদক':'JJ','পরিচয়-পত্র':'NN','পরিচয়':'NN','পরিচয়নো':'VB','পরিচয়হীনতার':'NN','পরিচয়ে':'NN',
'পরিজন':'NN','পরিণত':'VBD','পরিণতর':'NN','পরিণতিও':'NNS','পরিণাম':'NN','পরিণামী':'JJ','পরিণামে':'NN',
'পরিণীত':'JJ','পরিণীতা':'NN','পরিণয়':'NN','পরিতাপের':'NN','পরিতৃপ্তি':'NN','পরিতোষ':'NN','পরিত্যক্ত':'NN',
'পরিত্যাজ্য':'JJ','পরিত্রাতা':'NN','পরিদর্শক':'NN','পরিদর্শন':'NN','পরিদ্বীপ':'NN','পরিধান':'NN','পরিধাননো':'VB',
'পরিধি':'NN','পরিধেয়':'JJ','পরিনত':'VBD','পরিনতির':'NNS','পরিনাম':'NN','পরিনিত':'VBD','পরিপক্ক':'NN',
'পরিপন্থি':'JJ','পরিপন্থী':'NN','পরিপুষ্ট':'JJ','পরিপূরক':'NN','পরিপূর্ণতা':'NN','পরিপোষক':'JJ','পরিপ্রেক্ষিত':'NN',
'পরিপ্লব':'NN','পরিবতন':'NN','পরিবরতন':'NN','পরিবর্ত':'JJ','পরিবর্তণ':'NN','পরিবর্তনই':'NN','পরিবর্তনকামী':'JJ',
'পরিবর্তনবাদী':'NN','পরিবর্তনশীল':'JJ','পরিবর্তনশেয়ার':'NN','পরিবর্তনীয়':'JJ','পরিবর্তনে':'NN','পরিবর্তনেরও':'NN','পরিবর্তিকা':'NN',
'পরিবর্তে':'RB','পরিবর্ধন':'NN','পরিবর্ধিত':'JJ','পরিবহণ':'NN','পরিবহন':'NN','পরিবাদ':'NN','পরিবার':'NN',
'পরিবারটা':'RB','পরিবারতন্ত্র':'NN','পরিবারতান্ত্রিক':'JJ','পরিবারপরিজন':'NN','পরিবারভুক্ত':'JJ','পরিবারসহ':'RB','পরিবারহীন':'JJ',
'পরিবারা':'RB','পরিবারের':'NN','পরিবাহক':'NN','পরিবাহী':'NN','পরিবৃত্ত':'NN','পরিবেশ':'NN','পরিবেশগত':'JJ',
'পরিবেশটাই':'NN','পরিবেশনকারি':'NN','পরিবেশননো':'VB','পরিবেশনে':'NN','পরিবেশবাদী':'NN','পরিবেশিত':'JJ','পরিবেশে':'NN',
'পরিবেশের':'NN','পরিবেষ্টিত':'JJ','পরিব্যক্ত':'NN','পরিব্যাপক':'JJ','পরিব্রতা':'JJ','পরিব্রাজ':'NN','পরিব্রাত':'NN',
'পরিভাষা':'NN','পরিভাষিত':'NN','পরিভ্রমণ':'NN','পরিমণ্ডলকে':'NN','পরিমল':'NN','পরিমাণও':'NN','পরিমাণগত':'JJ',
'পরিমাণস্বরূপ':'RB','পরিমাণে':'NN','পরিমান':'NN','পরিমাপ':'NN','পরিমাপকারী':'NN','পরিমার্জন':'NN','পরিমার্জিত':'JJ',
'পরিমিতি':'NN','পরিযায়ী':'NN','পরিযোজনা':'NN','পরির':'NN','পরিরিস্থিতি':'NN','পরিলক্ষিত':'NN','পরিলেহী':'NN',
'পরিলোক':'NN','পরিশিষ্ট':'JJ','পরিশিষ্ঠ':'NN','পরিশুদ্ধ':'NN','পরিশেষে':'RB','পরিশোধ':'NN','পরিশোধন':'NN',
'পরিশোধযোগ্য':'JJ','পরিশোধিত':'NN','পরিশোধের':'NN','পরিশ্রম':'NN','পরিশ্রমনারী':'NNS','পরিশ্রমসাধ্য':'JJ','পরিশ্রমহীনতা':'NN',
'পরিশ্রমে':'NN','পরিশ্রমেরও':'NN','পরিশ্রান্ত':'JJ','পরিশ্রান্তনো':'VB','পরিশ্রান্তি':'NN','পরিষদ':'NN','পরিষদের':'NN',
'পরিষেবার':'NN','পরিষ্করণ':'NN','পরিষ্কারক':'NN','পরিষ্কারনো':'VB','পরিষ্কারপরিচ্ছন্নদেশের':'NN','পরিষ্কারভাবে':'RB','পরিষ্কারর':'NN',
'পরিষ্কীর':'RB','পরিষ্কৃত':'JJ','পরিসংখান':'NNS','পরিসংখ্যানে':'NNS','পরিসংখ্যানের':'NN','পরিসকার':'JJ','পরিসঞ্চারণতন্ত্র':'NN',
'পরিসমাপন':'NN','পরিসমাপ্তিতে':'NN','পরিসর':'NN','পরিসরেই':'NN','পরিসীমা':'NN','পরিসীমিত.':'JJ','পরিস্কার':'NN',
'পরিস্তিতি':'NN','পরিস্থতি':'NN','পরিস্থিতিই':'NN','পরিস্থিতিতে':'NNS','পরিস্থিতিতেই':'NN','পরিস্থিতী':'NN','পরিস্থিতীতে':'NNS',
'পরিস্ফুট':'JJ','পরিস্হিতি':'NN','পরিহার':'NN','পরিহিত':'NN','পরিাস্থতি':'NN','পরিয়ে':'NN','পরী':'NN',
'পরীক্ষক':'NN','পরীক্ষণ':'VBG','পরীক্ষণকার্য্য':'NN','পরীক্ষণযোগ্য':'JJ','পরীক্ষা-নিরীক্ষার':'NN','পরীক্ষা-পত্র':'NN','পরীক্ষাই':'NN',
'পরীক্ষাগুলো':'NNS','পরীক্ষাগুলোতে':'NN','পরীক্ষাটা':'NN','পরীক্ষানিরীক্ষা':'NN','পরীক্ষানো':'VB','পরীক্ষামূলক':'NN','পরীক্ষায়ও':'JJS',
'পরীক্ষার':'NN','পরীক্ষার্থীদের':'NNS','পরীক্ষালব্ধ':'JJ','পরীক্ষায়':'JJS','পরীক্ষিত':'NN','পরীছম':'NN','পরীত':'JJ',
'পরীবন্দ':'NN','পরীলোক':'NN','পরুক':'NN','পরুচ্ছেয়':'NN','পরুষ':'NN','পরূপ':'NN','পরে':'RB',
'পরেই':'NN','পরেছ':'NN','পরেছিল':'IN','পরেছিলেন':'VB','পরেছে':'NN','পরেনি':'NN','পরের':'NN',
'পরেরগুলো':'NN','পরেরদিন':'NN','পরোক্ক':'NN','পরোক্ষভাবে':'RB','পরোটা':'NN','পরোপকার':'NN','পরোপকারী':'NN',
'পরোয়া':'NN','পরোষ্ণী':'NN','পরোয়া':'NN','পরোয়ানার':'NN','পর্ক':'NN','পর্চা':'NN','পর্জবেক্ষণ':'NN',
'পর্ণ-শালা':'NN','পর্ণ':'NN','পর্ণকুটিকা':'NN','পর্ণকূর্চ':'NN','পর্ণচোরক':'NN','পর্ণমোচী':'NN','পর্ণশালা':'NN',
'পর্ণশুক':'NN','পর্ণসমূহ':'NN','পর্ণসি':'NN','পর্ণাটক':'NN','পর্ণিকা':'NN','পর্ণী':'NN','পর্তুগাল':'NN',
'পর্তুগালবাসী':'NN','পর্তুগিজ':'NN','পর্তুগীজরা':'NNP','পর্দা':'NN','পর্দাপ্রথা':'NN','পর্দাফাঁস':'VB','পর্দাফাস':'NN',
'পর্দাহীন':'JJ','পর্দায়':'NN','পর্নো':'NN','পর্ব':'NN','পর্বগামী':'NN','পর্বণ':'NN','পর্বত-বাসী':'JJ',
'পর্বত':'NN','পর্বতগাত্র':'NN','পর্বতমালা':'NN','পর্বতময়':'JJ','পর্বতরাজ':'NN','পর্বতশৃঙ্খলা':'NN','পর্বতশ্রেণী':'NN',
'পর্বতাকার':'JJ','পর্বতাত্মজা':'NN','পর্বতারোহণ':'NN','পর্বতাস্ত্র':'NN','পর্বতে':'NNP','পর্বতের':'NN','পর্বভুক্ত':'NN',
'পর্বে':'NN','পর্য':'NN','পর্যটকদের':'NNS','পর্যটকরাও':'NN','পর্যটকেরা':'NNS','পর্যটন-স্থল':'NN','পর্যটনপ্রিয়':'JJ',
'পর্যটনপ্রিয়তা':'NN','পর্যন্ত':'IN','পর্যন্তও':'IN','পর্যবসিত':'VB','পর্যবেক্ষক':'NN','পর্যবেক্ষণ':'NN','পর্যবেক্ষিকা':'NN',
'পর্যাণ':'NN','পর্যান্ত':'IN','পর্যাপ্ত':'RB','পর্যাপ্ততা':'NN','পর্যাবৃত্ত':'JJ','পর্যায়ে':'NN','পর্যালোচনা':'NN',
'পর্যায়':'NN','পর্যায়ক্রমে':'NN','পর্যায়েই':'NN','পর্য্যটককেন্দ্রে':'NN','পর্য্যন্ত':'PSP','পর্য্যবসিত':'JJ','পর্য্যবেক্ষক':'NN',
'পর্য্যালোচনা':'NN','পর্য্যায়ে':'NN','পর্শ্বধ':'NN','পর্ষদ':'NNP','পর্ষদে':'NN','পর্ষদের':'NNS','পলওয়াল':'NN',
'পলক':'NN','পলকপীটা':'NN','পলক্কড':'NN','পলঙ্কষা':'NN','পলটি':'NN','পলতা':'NN','পলন':'NN',
'পলল':'JJ','পলা':'NN','পলাইয়া':'NN','পলাণ্ডু':'NN','পলাতক':'JJ','পলাশ':'NN','পলাশবাড়ী':'NN',
'পলায়ন':'NN','পলায়নশীল':'JJ','পলায়নী':'NN','পলায়িত':'NN','পলি':'NN','পলিং':'VBG','পলিইউরেথেন':'NNP',
'পলিউশনের':'NN','পলিটিকস':'NNS','পলিটিক্যাল':'JJ','পলিটিক্স':'NNS','পলিটী':'JJ','পলিটেকনিক':'NN','পলিত':'NN',
'পলিথিন':'NN','পলিমাটি':'NN','পলিমার':'NN','পলিস':'NNP','পলিসি':'NN','পলেস্তরা':'NN','পল্টন':'NN',
'পল্যয়ন':'NN','পল্লব':'NN','পল্লবিত':'NN','পল্লবীতে':'NN','পল্লা':'JJ','পল্লিওয়াহ':'NN','পল্লী':'NN',
'পশম':'NN','পশমিনা':'NN','পশমী':'NN','পশু-পাখির':'NN','পশু':'NN','পশুখামার':'NN','পশুচর্ম':'NN',
'পশুচারণভূমি':'NN','পশুচিকিত্সক':'NN','পশুতুল্য':'NN','পশুদের':'NN','পশুপক্ষী':'NN','পশুপত':'NN','পশুপতোপনিষদ':'NN',
'পশুপাখি':'NN','পশুপালন':'NN','পশুবলি':'NN','পশুযান':'NN','পশুর':'NN','পশুরোগ':'NN','পশুশালা':'NN',
'পশুসম্বন্ধীয়':'JJ','পশুহাট':'NN','পশ্চজল':'NN','পশ্চাত':'NN','পশ্চাতাপ':'NN','পশ্চাত্':'NN','পশ্চাদপসরণকারী':'JJ',
'পশ্চাদাগত':'JJ','পশ্চাদ্দেশ':'NN','পশ্চাদ্বর্তী':'NN','পশ্চাদ্ভাগ':'JJ','পশ্চাদ্ভূমি':'NN','পশ্চারুজ':'NN','পশ্চিম-ঘাট':'NN',
'পশ্চিমঘাট':'NN','পশ্চিমবঙ্গ':'NN','পশ্চিমবঙ্গে':'NNP','পশ্চিমবঙ্গের':'NN','পশ্চিমা':'JJ','পশ্চিমাচল':'NN','পশ্চিমাদের':'NNS',
'পশ্চিমি':'NN','পশ্চিমে':'JJS','পশ্চিমের':'NN','পশ্তু':'NN','পশ্মীনা':'NN','পশ্যন্তী':'NN','পশ্যা':'NN',
'পষ্ট':'JJ','পসন্দ':'NN','পসরা':'NN','পসিবল':'JJ','পস্তানোর':'NN','পস্রয়':'NN','পহরণ':'NN',
'পহলগাঁও':'NN','পহলনী':'NN','পহলবি':'JJ','পহার':'NN','পহুঁছে':'VB','পহুন্নি':'NN','পহুরি':'NN',
'পহেলা':'NNP','পা-দান':'NN','পা':'NN','পাঁ':'CD','পাঁইট':'NN','পাঁক':'NN','পাঁকজন্মা':'NN',
'পাঁকমুক্ত':'JJ','পাঁখার':'NNS','পাঁচ':'NN','পাঁচগুণ':'NNS','পাঁচগুণে':'NN','পাঁচঘুটি':'NN','পাঁচজন':'NN',
'পাঁচজনের':'CD','পাঁচটা':'NN','পাঁচটি':'NN','পাঁচড়া':'NN','পাঁচতারা':'NN','পাঁচদিন':'NN','পাঁচবার':'NNS',
'পাঁচবারের':'NN','পাঁচরঙা':'JJ','পাঁচশো':'JJ','পাঁচিল':'NN','পাঁচেক':'JJ','পাঁচেকের':'NN','পাঁজর':'NN',
'পাঁজা':'NN','পাঁঠার':'NN','পাঁঠি-ছাগল':'NN','পাঁপড়':'NN','পাঁসু':'NN','পাঁয়তা':'NN','পাংকচার':'NN',
'পাংশুক্ষুর':'NN','পাংশুজ':'NN','পাই':'NN','পাইওনিয়ার':'NN','পাইক':'NN','পাইকারী':'NN','পাইগর্ববোধ':'NN',
'পাইছি':'NN','পাইছেন':'NN','পাইত':'VB','পাইতা':'NN','পাইতেছে':'NN','পাইতেন':'VB','পাইন':'NN',
'পাইনা':'RB','পাইনাই':'NN','পাইনিন':'NN','পাইপ':'NN','পাইপলাইন':'NN','পাইবার':'NNV','পাইবে':'VB',
'পাইরার':'NNP','পাইরিডক্সমিন':'NN','পাইল':'NN','পাইলটকে':'NN','পাইলটের':'NN','পাইলাম':'NN','পাইলে':'IN',
'পাইলেও':'NN','পাইস':'NN','পাইয়াছে':'VB','পাউঁরুটি':'NN','পাউডার':'NN','পাউণ্ড':'NN','পাউরুটি':'NN',
'পাএর':'NN','পাও':'NN','পাওড়া':'NN','পাওনাদার':'NN','পাওনাদারদের':'NNS','পাওনার':'NN','পাওয়া':'IN',
'পাওয়াটা':'NN','পাওয়':'NN','পাওয়া':'IN','পাওয়াই':'NN','পাওয়াও':'IN','পাওয়াটা':'NN','পাওয়াতে':'NN',
'পাওয়ার':'NN','পাওয়ারলুম':'NN','পাওয়ায়':'NN','পাওয়েল':'NN','পাক-প্রণালী':'NN','পাক':'NN','পাকড়াও':'NN',
'পাকদন্ডী':'NN','পাকভারত':'NNP','পাকরঞ্জন':'NN','পাকলে':'NN','পাকশালা':'NN','পাকশাসনি':'NN','পাকশাস্ত্র':'NN',
'পাকশৈলী':'NN','পাকসালু':'NN','পাকহন্তা':'NN','পাকা':'NN','পাকাইয়া':'VBN','পাকাতীসার':'NN','পাকাদেখা':'NN',
'পাকানো':'VBN','পাকাপাকি':'JJ','পাকাপোক্ত':'NN','পাকাভাব':'NN','পাকারি':'NN','পাকিদের':'NNS','পাকিপ্রেমীদেরই':'NNS',
'পাকিস্তান':'NN','পাকিস্তান':'NN','পাকিস্তানও':'NN','পাকিস্তানকেই':'NN','পাকিস্তানি':'NN','পাকিস্তানিদের':'NN','পাকিস্তানী':'NN',
'পাকিস্তানে':'NN','পাকিস্তানের':'NN','পাকিস্থানি':'NN','পাকিস্থানিরা':'NN','পাকিস্থানের':'NN','পাকিয়ে':'VBN','পাকী':'NN',
'পাকীপন্থিদের':'NNS','পাকু':'NN','পাকুর':'NN','পাক্কা':'NN','পাকড়':'NN','পাখনা':'NN','পাখনাযুক্ত':'JJ',
'পাখন্ড':'NN','পাখরি':'NN','পাখা':'NN','পাখাওয়ালা':'NN','পাখাবিহীন':'JJ','পাখার':'NN','পাখি':'NN',
'পাখিই':'NNS','পাখিও':'NN','পাখিকরছে':'VBG','পাখিগুলোকে':'NN','পাখিদের':'NN','পাখী':'NN','পাখীর':'NN',
'পাখেব':'NN','পাখোয়াজ':'NN','পাখৌড়া':'NN','পাগ':'NN','পাগড়ি':'NN','পাগল':'NN','পাগলা':'NN',
'পাগলামো':'NN','পাগলী':'NN','পাগলের':'NN','পাগা':'NN','পাঙ্শু':'NN','পাঙ্শুরাগিনী':'NN','পাচ':'CD',
'পাচঁবার':'NN','পাচক':'NN','পাচছেবরত্মানে':'VBG','পাচজনে':'CD','পাচটি':'CD','পাচতোরিয়া':'NN','পাচদিন':'NNS',
'পাচন-তন্ত্র':'NN','পাচন':'NN','পাচনতন্ত্র':'NN','পাচনী':'NN','পাচবছর':'NNS','পাচার':'VBG','পাচারকারী':'NN',
'পাচারকারীদের':'NNS','পাচারকৃত':'VBN','পাচারবিরোধী':'NN','পাচারে':'VBG','পাচি':'NN','পাচিত':'JJ','পাচী':'NN',
'পাচ্':'CD','পাচ্ছি':'VBG','পাচ্ছিনা':'VB','পাচ্ছে':'VBG','পাচ্ছেনা':'VB','পাচ্য':'JJ','পাছা':'NN',
'পাছিনা':'VB','পাছুক':'NN','পাছে':'NN','পাছেলি':'NN','পাজরা':'NN','পাজারু':'NN','পাজি':'JJ',
'পাজী':'NN','পাজেরো':'NN','পাজ্ঞাবী':'NN','পাঞ্চ':'NN','পাঞ্চাল':'NN','পাঞ্চুরা':'NN','পাঞ্জাব':'NN',
'পাঞ্জাবিয়ানা':'NN','পাঞ্জাবী':'NN','পাঞ্জাবের':'NNP','পাঞ্জার':'NN','পাট':'NN','পাটওয়ারি':'NN','পাটকল':'NN',
'পাটকের':'NN','পাটন':'NN','পাটরাণী':'NN','পাটরাণীর':'JJ','পাটর্স':'NN','পাটল':'NN','পাটশণ':'NN',
'পাটশাড়ি':'NN','পাটস':'NN','পাটাই':'NN','পাটাও':'NN','পাটাচ্ছে':'VBG','পাটাতন':'NN','পাটাবাজ':'NN',
'পাটালি':'NN','পাটি':'NN','পাটিগণিতিক':'JJ','পাটিগণিতের':'NN','পাটির':'NN','পাটিসাপ্টা':'NN','পাটিয়ালা':'NN',
'পাটুনি':'NN','পাটুলিপুত্র':'NN','পাটের':'NN','পাট্টা':'NN','পাঠ':'NNS','পাঠক-সমাজের':'NN','পাঠক':'NN',
'পাঠকদের':'NN','পাঠকের':'NN','পাঠগ্রহণ':'NN','পাঠপণ্য':'NNS','পাঠভেদ':'NN','পাঠমঞ্জরী':'NN','পাঠরত':'JJ',
'পাঠশালা':'NN','পাঠা':'NN','পাঠাই':'VB','পাঠাইলো':'VB','পাঠাও':'VB','পাঠাগার':'NN','পাঠাচ্ছি':'VBG',
'পাঠাচ্ছেন':'VBG','পাঠাত':'VB','পাঠাতেন':'VB','পাঠান-রাজের':'NN','পাঠান':'VB','পাঠানকোট':'NN','পাঠানি':'JJ',
'পাঠানের':'NN','পাঠানো':'VB','পাঠানো':'NN','পাঠাবার':'VB','পাঠালে':'VB','পাঠা্ছেএখন':'VB','পাঠায়':'VB',
'পাঠায়ে':'VB','পাঠিকা':'NN','পাঠিয়ে':'VB','পাঠিয়েছিলো':'VB','পাঠীন':'NN','পাঠের':'NN','পাঠ্য-ক্রম':'NN',
'পাঠ্য-পুস্তক':'NN','পাঠ্য':'NN','পাঠ্যক্রমে':'NN','পাঠ্যচর্চা':'NN','পাঠ্যপুস্তক':'NN','পাঠ্যান্তর':'NN','পাড়':'NN',
'পাড়ম':'NN','পাড়ানি':'NN','পাড়ে':'NN','পাড়ের':'JJ','পাণি':'NN','পাণিকুর্চ্চা':'NN','পাণিগ্রহণ':'NN',
'পাণিগ্রহণীয়':'JJ','পাণিনি':'NN','পাণিনির':'NNP','পাণিনীয়':'JJ','পাণিপথের':'NNS','পাণিফল':'NN','পাণ্ডব':'NN',
'পাণ্ডবের':'NNP','পাণ্ডর':'NN','পাণ্ডার':'NN','পাণ্ডিত্য':'NN','পাণ্ডিত্যপূর্ণ':'JJ','পাণ্ডিত্যের':'NN','পাণ্ডু':'NN',
'পাণ্ডুফল':'NN','পাণ্ডুর':'JJ','পাণ্ডুরোগ':'NN','পাণ্ডুলিপি':'NN','পাণ্ডে':'NN','পাত':'NN','পাতক্ষীর':'NN',
'পাতছে':'VBG','পাতত':'JJ','পাততুম':'VB','পাতন':'NN','পাতব':'NN','পাতলা':'NN','পাতা':'NNS',
'পাতাও':'NN','পাতাঝড়া':'NN','পাতাটার':'NN','পাতানো':'NN','পাতাবাসিনী':'NN','পাতাবাহারি':'NN','পাতায়':'NNS',
'পাতাযুক্ত':'JJ','পাতার':'NN','পাতালআমলা':'NN','পাতালকুঠুরী':'NN','পাতালকেতু':'NN','পাতালতুম্বী':'NN','পাতালদন্তি':'NN',
'পাতালনিবাসী':'NN','পাতালরেলের':'NN','পাতাললোক':'NN','পাতালের':'JJ','পাতায়':'NNS','পাতি':'NN','পাতির':'NNS',
'পাতিল':'NN','পাতী':'NN','পাতে':'VB','পাত্তা':'NN','পাত্তাও':'NN','পাত্র':'NN','পাত্রাপাত্র':'NN',
'পাত্রিকার':'NN','পাত্রী':'NN','পাথর':'NN','পাথরকুঁচি':'NN','পাথরচটা':'NN','পাথরবৃষ্টি':'NN','পাথরি':'NN',
'পাথরেরই':'NN','পাথুরি':'NN','পাদ':'NN','পাদগ্রন্থি':'NN','পাদত্রাণ':'NN','পাদদাহ':'NN','পাদদেশ':'NN',
'পাদন':'NN','পাদপদ্মে':'NN','পাদপ্রদীপে':'NN','পাদভৌম':'JJ','পাদরী':'NN','পাদস্ফোট':'NN','পাদহর্ষ':'NN',
'পাদা':'NN','পাদ্য':'NN','পাদ্রিনী':'NN','পান':'NN','পানওয়ালা':'NN','পানকর্পূর':'NN','পানকৌড়ি':'NN',
'পানকৌড়ির':'NN','পানগাও':'NN','পানচাকা':'NN','পানডুবি':'NN','পানতুয়া':'NN','পানদডুব্বা':'NN','পানন':'NN',
'পাননো':'NN','পানফুল':'NN','পানবিছা':'NN','পানবিভ্রম':'NN','পানলোহা':'NN','পানস':'NN','পানসে':'JJ',
'পানহড়া':'NN','পানহাই':'NN','পানামা':'NN','পানালয়':'NN','পানাসক্ত':'NN','পানাহারে':'NN','পানি':'NN',
'পানিগ্রহণ':'NN','পানিটা':'NN','পানিতে':'NN','পানিপথ':'NN','পানিপথের':'NNS','পানিফল':'NN','পানিমন্থ':'NN',
'পানির':'NN','পানিশমেন্ট':'NN','পানী':'JJ','পানীয়':'NN','পানে':'NN','পানো':'NNV','পান্জেরী':'NN',
'পান্ডব':'NN','পান্ডিত্য':'NN','পান্ডিত্যপূর্ণ':'JJ','পান্ডিয়া':'NN','পান্ডুলিপি':'NN','পান্তা':'NN','পান্তুয়া':'NN',
'পান্থশালা':'NN','পান্থারের':'NN','পান্না':'NN','পান্নারঙা':'JJ','পাপ':'NN','পাপকর্ম':'NN','পাপকাজ':'NN',
'পাপড়া':'NN','পাপড়ী':'NN','পাপন':'NN','পাপনাশক':'JJ','পাপনাশিনী':'NN','পাপপূর্ণ':'JJ','পাপভক্ষণ':'NN',
'পাপমুক্ত':'NN','পাপমোচনি':'NN','পাপময়':'JJ','পাপরি':'NN','পাপশূণ্য':'JJ','পাপহা':'NN','পাপহীন':'JJ',
'পাপহীনতা':'NN','পাপাইয়া':'NN','পাপাঙ্কুশা':'NN','পাপাচার':'NN','পাপাচারী':'JJ','পাপাত্মা':'NN','পাপাধন':'NN',
'পাপাধম':'JJ','পাপাশয়':'JJ','পাপিণী':'NN','পাপিষ্ঠ':'JJ','পাপিষ্ঠা':'NN','পাপী':'NN','পাপীয়সী':'NN',
'পাপে':'NN','পাপোঁছা':'NN','পাপোশ':'NN','পাপ্পু':'NN','পাব':'NN','পাবত্য':'NN','পাবনা':'NN',
'পাবনাবাসীর':'NNS','পাবলিক':'NN','পাবলিককে':'JJ','পাবলিশড':'NN','পাবলিসিটি':'NN','পাবা':'NN','পাবিত্রপান':'NN',
'পাবে':'NN','পাবেউইলিয়ামসন':'NN','পাবেতা':'NN','পাবেন':'VB','পাবেনআশা':'NN','পাবেনাএক্ষেত্রে':'NN','পাবো':'NN',
'পাব্লিক':'NN','পাব্লিকের':'NN','পাব্লিসিটিও':'NN','পামর':'NN','পামাড়':'NN','পামুলাপর্তি':'NN','পামেলার':'NNP',
'পামোজ':'NN','পাম্প':'NN','পায':'NN','পায়':'NN','পায়চারী':'JJ','পায়নি':'VB','পায়েও':'NN',
'পার':'NN','পারকুইজিট':'NN','পারগম্য':'JJ','পারচেজ':'NN','পারছি':'JJ','পারছিনা':'NN','পারছিল':'VB',
'পারছিলাম':'NN','পারছে':'NN','পারছেন':'JJ','পারছেনা':'NN','পারছো':'VB','পারণ':'NN','পারত':'MD',
'পারতাছে':'VB','পারতে':'VB','পারতো':'VB','পারদ':'NN','পারদর্শক':'NN','পারদর্শিতা':'NN','পারদর্শী':'JJ',
'পারদের':'NN','পারনা':'VB','পারফরমেন্স':'NN','পারফর্ম':'VB','পারফর্মেন্সের':'NN','পারফিউম':'NN','পারব':'VB',
'পারবি':'VB','পারবেও':'VB','পারবেকারণ':'NN','পারবেন':'VB','পারবেননা':'VB','পারবেনা':'NN','পারবে—এমনটা':'WP',
'পারবো':'VB','পারভিন':'NN','পারমাণবিক':'NN','পারমার':'NN','পারমিট':'NN','পারম্পরিক':'JJ','পারম্পরিকতা':'NN',
'পারর্ফম':'VB','পারল':'VB','পারলাম':'NN','পারলি':'VB','পারলেই':'VB','পারলো':'VB','পারলৌকিক':'NN',
'পারস':'NNS','পারসনাল':'DM','পারসিয়ান':'NN','পারসী':'NN','পারসেন্ট':'RB','পারসেপলিস':'NNP','পারসোনালি':'JJ',
'পারস্পরিক':'JJ','পারস্পরিকতা':'NN','পারস্য':'NN','পারস্যরাজ':'NNP','পারস্যে':'NN','পারস্যের':'NNP','পারা':'VB',
'পারাদায়েস':'NNP','পারানি':'NN','পারাপার':'VBG','পারাপারে':'NN','পারাবত':'NN','পারামারিবো':'NN','পারার':'NN',
'পারায়':'NN','পারায়ণিক':'NN','পারি':'VB','পারিক্ষিত':'NN','পারিজাত':'NN','পারিজাতা':'NN','পারিতোষিক':'NN',
'পারিনা':'VB','পারিনাই':'NN','পারিনাব্যাবসা':'NN','পারিনি':'VB','পারিনিজেমি':'NN','পারিনে':'VB','পারিপার্শ্বিক':'JJ',
'পারিবারিক':'NN','পারিবেন':'NN','পারিল':'VB','পারিলে':'RP','পারিলো':'VB','পারিশ্রমিক':'NN','পারিষদ':'NN',
'পারীতে':'NNP','পারুক':'VB','পারে':'VB','পারেননা':'VB','পারেনাই':'VB','পারেনি':'VB','পারো':'VB',
'পার্ক':'NN','পার্ট-অফ-প্রিন্স':'NN','পার্ট':'NN','পার্টস':'NN','পার্টাইমার':'NN','পার্টি':'NN','পার্টিজান':'NN',
'পার্টিদের':'NN','পার্টিবাজ':'NN','পার্টী':'NN','পার্থক্য':'NN','পার্থক্যস্থানীয়':'NN','পার্থক্যের':'NN','পার্থবাসী':'NN',
'পার্থর':'NN','পার্থহোবার্টের':'NN','পার্থিব':'NN','পার্থীয়':'JJ','পার্থ্যকের':'NN','পার্ফর্মেন্স':'NN','পার্বণ':'NN',
'পার্বতীর':'NNP','পার্বত্য':'NN','পার্বনে':'NN','পার্লামেণ্ট':'NN','পার্লামেণ্টারী':'NNP','পার্লামেণ্টের':'NN','পার্শবর্তী':'NN',
'পার্শি':'NN','পার্শে':'NN','পার্শ্বগায়ক':'NN','পার্শ্ববর্তী':'NN','পার্শ্বমৌলি':'NN','পার্শ্বেকাদশী':'NN','পার্ষত':'NN',
'পার্ষদদের':'NN','পার্স':'NN','পার্সার':'NN','পার্সিয়ান':'NN','পার্সেন্ট':'NN','পার্সেলটি':'NN','পার্সোনাল':'NN',
'পাল-তোলা':'NN','পাল':'NN','পালক':'NN','পালকজুহী':'NN','পালকবিহীন':'JJ','পালকাপ্য':'NN','পালকি':'NN',
'পালকী':'NN','পালঙ্কপোষ':'NN','পালট':'NN','পালটা':'RB','পালটানো':'NN','পালটায়':'NN','পালটে':'NN',
'পালতোলা':'JJ','পালন':'NN','পালনকর্তা':'NN','পালনপুর':'NN','পালনপোষণ':'NN','পালনে':'NN','পালব':'NN',
'পাললা':'NN','পাললিক':'JJ','পালস':'NN','পালা':'NN','পালাগানগুলোকে':'NN','পালাচ্ছেন':'VB','পালাত':'VB',
'পালানো':'VB','পালাবদল':'VB','পালাবারও':'VB','পালামু':'NN','পালি':'NN','পালিঞ্জী':'NN','পালিত':'VBN',
'পালিতমন্দার':'NN','পালিন্ধী':'NN','পালিশ':'NN','পালিশযন্ত্র':'NN','পালিয়া':'NN','পালিয়ে':'VB','পালী':'NN',
'পালে':'NN','পালোয়ান':'NN','পাল্কিবেহারা':'NN','পাল্কী':'NN','পাল্টা':'NN','পাল্টাচ্ছে':'VB','পাল্টানো':'VBG',
'পাল্টি':'NN','পাল্টির':'NN','পাল্টিয়ে':'VB','পাল্টেছে':'VB','পাল্লা':'NN','পাল্লায়':'NN','পাশ':'NN',
'পাশপাণি':'NN','পাশপোর্ট':'NN','পাশব':'JJ','পাশবিকতা':'NN','পাশা':'NN','পাশাপশি':'RB','পাশাপাশি':'NN',
'পাশি':'NN','পাশুপত':'NN','পাশুপতাস্ত্র':'NN','পাশে':'RB','পাশেই':'NN','পাশ্চাত্য':'NN','পাশ্চাত্যের':'NN',
'পাশ্ব':'NN','পাশ্ববর্তি':'NN','পাষণচতুর্দশী':'NN','পাষণ্ড':'NN','পাষন্ড':'NN','পাষাণ':'NN','পাষাণগর্দভ':'NN',
'পাষাণী':'JJ','পাস':'NN','পাসওয়ার্ড':'NN','পাসক':'NN','পাসপোর্ট':'NN','পাসবুক':'NN','পাসা':'NN',
'পাসাডেনিয়া':'NN','পাসিং':'NN','পাসিঘাট':'NN','পাসের':'NN','পাস্':'NN','পাস্ট':'NN','পাস্তোরে':'NN',
'পাস্সী-বাবুল':'NN','পাহঁসুল':'NN','পাহাড়':'NN','পাহাড়া':'VB','পাহাড়ি':'NN','পাহাড়ের':'NN','পাহারাদার':'NN',
'পাহারার':'NN','পাহারিদারি':'NN','পাহাড়':'NN','পাহাড়সম':'NN','পাহাড়ী':'JJ','পাহাড়ে':'NN','পাহী':'JJ',
'পাড়':'NN','পাড়ল':'VB','পাড়া':'NN','পাড়াগায়ে':'NN','পাড়াপড়শির':'NN','পাড়ায়':'NN','পাড়ি':'NN',
'পাড়িকাদের':'NN','পাড়ে':'NN','পায়':'NN','পায়এসব':'NN','পায়ঐ':'NN','পায়খানা':'NN','পায়চারি':'NN',
'পায়জনগণের':'NN','পায়জামা':'NN','পায়তানা':'NN','পায়না':'NN','পায়নাআমেরিকা':'NN','পায়নি':'NN','পায়বেতন':'NN',
'পায়যাইহোক':'NN','পায়রা':'NN','পায়রাবন্দর':'NN','পায়রিয়া':'NN','পায়রী':'NN','পায়সরকারের':'NN','পায়া':'NN',
'পায়াসকে':'NNP','পায়াসম্পন্ন':'JJ','পায়ী':'JJ','পায়ু':'NN','পায়ে-চলা':'NN','পায়ে-পায়ে':'RB','পায়ে':'NNS',
'পায়েও':'NN','পায়েল':'NN','পি.':'NNP','পি':'NN','পিঁজড়াপোল':'NN','পিঁড়ে':'NN','পিঁপড়ারা':'NN',
'পিঁয়াজ':'NN','পিউপা':'NN','পিউর':'NN','পিএ':'NN','পিএইচডি':'NN','পিএনবি':'NN','পিএম':'NN',
'পিএমঈএসী':'NN','পিএমএলএন':'NN','পিএমও':'NN','পিএস':'NN','পিএসএলে':'NN','পিএসজি':'NN','পিএসজির':'NN',
'পিএসসি':'NN','পিএসয়ু':'NN','পিওকে':'NN','পিওন':'NN','পিওর':'JJ','পিক':'NN','পিকচারে':'NN',
'পিকদানী':'NN','পিকনিক':'NN','পিকপ্রিয়':'NN','পিকবন্ধু':'NN','পিকাক্ষ':'NN','পিকেএসএফ':'NN','পিকো':'NN',
'পিকোর':'NNP','পিক্চার':'NN','পিক্সেল':'NN','পিঙ্ক':'NN','পিঙ্গলযুক্ত':'JJ','পিঙ্গলরাগ':'NN','পিঙ্গেশ':'NN',
'পিচ':'NN','পিচকারি':'NN','পিচাই':'NN','পিচুটি':'NN','পিচে':'NN','পিচের':'NN','পিচ্চি':'NN',
'পিচ্ছিলকারক':'NN','পিচ্ছিলকারী':'JJ','পিচ্ছিলপাদ':'NN','পিছ':'NN','পিছটান':'NN','পিছনে':'RB','পিছনেও':'NN',
'পিছনের':'RB','পিছপা':'NNS','পিছমোড়া':'JJ','পিছলিয়ে':'VB','পিছলে':'NN','পিছানো':'VB','পিছিয়ে':'VB',
'পিছিয়ে':'NNS','পিছিয়েছে':'NNS','পিছু':'NN','পিছে':'RB','পিজবন':'NN','পিঞ্জর':'NN','পিটক':'NN',
'পিটপিট':'VB','পিটপিটানির':'JJ','পিটা':'NN','পিটাইতে':'NNS','পিটাতে':'NN','পিটানো':'NN','পিটার্সবার্গ':'NN',
'পিটায়':'NN','পিটিয়ে':'NNS','পিটুনি':'NNS','পিটুলি':'NN','পিটের':'NN','পিট্টু':'NN','পিট্যুইটারি':'NN',
'পিঠ':'NN','পিঠরক':'NN','পিঠা':'NN','পিঠীনস':'NN','পিঠে':'NN','পিডাবলুসি':'NN','পিডিবি':'NN',
'পিণ্ড':'NN','পিণ্ডফল':'NN','পিতরাই':'NN','পিতল':'NN','পিতা-মাতা':'NN','পিতা':'NN','পিতামহী':'NN',
'পিতামাতার':'NN','পিতৃ':'NN','পিতৃকুল্যা':'NN','পিতৃগৃহে':'NN','পিতৃঘাতী':'NN','পিতৃতর্পণ':'NN','পিতৃনাথ':'NN',
'পিতৃপক্ষ':'NN','পিতৃপুরুষের':'JJ','পিতৃযজ্ঞ':'NN','পিতৃরিষ্ট':'NN','পিতৃশুর':'NN','পিতৃহন্তা':'NN','পিতৃহারা':'JJ',
'পিতৃহীন':'JJ','পিতে':'NN','পিত্ত':'NN','পিত্তকোষ':'NN','পিত্তজ্বর':'NN','পিত্তনাড়ি':'NN','পিত্তপাথরি':'NN',
'পিত্তবিদগ্ধ-দৃষ্টি':'NN','পিত্তরুদ্ধ':'NN','পিত্তরোগ':'NN','পিত্তলা':'NN','পিত্তশ্লেষ্মাজ্বর':'NN','পিত্তস্রাব':'NN','পিত্তাগ্নি':'NN',
'পিত্তাতিসার':'NN','পিত্তাভিস্যন্দ':'NN','পিত্তাশয়':'NN','পিত্তের':'NN','পিত্রালয়ে':'NN','পিথৌরাগড়':'NN','পিদড়ী':'NN',
'পিদারা':'NN','পিদ্ধী':'NN','পিধান':'NN','পিনকুশন':'NN','পিনদান':'NN','পিনস':'NNP','পিনাক':'NN',
'পিনাট':'NNS','পিনাবু':'NN','পিন্চ':'NN','পিন্ড-খেজুর':'NN','পিন্ড':'NN','পিন্ডখেজুর':'NN','পিন্ডি':'NN',
'পিন্নী':'NN','পিপলস':'NN','পিপারমিন্ট':'NN','পিপাসা':'NN','পিপাসিত':'JJ','পিপাসু':'NN','পিপিআই':'NN',
'পিপিএম':'NN','পিপিপি':'NN','পিপিপিপারচেজ':'NN','পিপিলিকা':'NN','পিপীতক':'NN','পিপুল':'NN','পিপে':'NN',
'পিপ্পলাদ':'NN','পিবরি':'NN','পিযূষ':'NN','পির':'NN','পিরনের':'NN','পিরানটিতে':'NN','পিরামিড':'NN',
'পিরামিডীয়':'JJ','পিরিচ':'NN','পিরিনস':'NN','পিল':'NN','পিলকিয়া':'NN','পিলখানা':'NN','পিলগ্রিম':'NN',
'পিলভিট':'NN','পিলাই':'NN','পিলু':'NN','পিল্ল':'NN','পিশাচ':'NN','পিষনহারী':'NN','পিষে':'VBN',
'পিষ্ট':'VBN','পিষ্টপ্রমেহ':'NN','পিস':'NN','পিসতুতো':'NN','পিসি':'NN','পিসুরা':'NN','পিসেমশাই':'NN',
'পিস্':'NN','পিস্টোরিয়াসের':'NN','পিস্তল':'NN','পিয়জ':'NNS','পিয়ন':'NN','পিয়র':'NNP','পিয়াজ':'NNS',
'পিয়ানো':'NN','পিয়ারলেসের':'NNP','পিয়াল':'NN','পিয়াসাল':'NN','পিয়ে':'VB','পীকে':'NN','পীঠ':'NN',
'পীঠস্থান':'NN','পীড়া':'NN','পীড়িত':'NN','পীতনী':'NN','পীতবর্ণ':'JJ','পীতবৃক্ষ':'NN','পীতমণি':'NN',
'পীতমস্তক':'NN','পীতমূলক':'NN','পীতলের':'NN','পীতশাল':'NN','পীতাম্বর':'NN','পীতিনী':'NN','পীনসী':'JJ',
'পীপল':'NN','পীযুষ':'NN','পীর':'NN','পীরের':'NN','পীল':'NN','পীলুয়া':'NN','পীষনা':'NN',
'পীস':'NN','পীড়ন':'NN','পীড়িত':'JJ','পীয়র':'NNP','পীয়ুষবর্ষ':'NN','পুঁচকে':'JJ','পুঁছ':'NN',
'পুঁজযুক্ত':'NN','পুঁজি-নিবেশ':'NN','পুঁজি':'NN','পুঁজিগত':'JJ','পুঁজিতন্ত্রের':'NN','পুঁজিপতি':'NN','পুঁজিবাদ':'NN',
'পুঁজিবাদের':'NN','পুঁটলি':'NN','পুঁটি':'NN','পুঁতে':'VBN','পুঁথি':'NN','পুঁথিগত':'JJ','পুঁথিতেই':'NN',
'পুংকেশর':'NN','পুংলিঙ্গ':'NN','পুংসবন':'NN','পুইয়ে':'VB','পুওর':'NN','পুকুর':'NN','পুকুরের':'NN',
'পুঙ্খানুপুঙ্খ':'RB','পুঙ্গ':'NN','পুঙ্গব':'JJ','পুঙ্গরিয়া':'NN','পুচকে':'NN','পুচ্ছ':'NN','পুচ্ছকণ্টক':'NN',
'পুচ্ছদা':'NN','পুচ্ছধারী':'JJ','পুজার':'NN','পুজারা':'NNS','পুজারার':'JJS','পুজারাসর্বশেষ':'NNS','পুজারী':'NN',
'পুজি':'NN','পুজিবাজার':'NN','পুজিবাজারে':'NN','পুজো':'NN','পুজোয়':'NN','পুঞ্জ':'NN','পুঞ্জিকস্থলী':'NN',
'পুঞ্জিভুক্ত':'JJ','পুঞ্জীভূত':'JJ','পুটলি':'NN','পুটিকন্টক':'NN','পুটির':'NN','পুটে':'NN','পুট্টি':'NN',
'পুড়তো':'NN','পুড়িয়ে':'VBN','পুড়িয়া':'NN','পুড়ে':'NN','পুডিং':'NN','পুডিঙ্গ':'NN','পুণরুদ্ধার':'NN',
'পুণা':'NN','পুণোর্মিলনীর':'NN','পুণ্ডরিক':'NN','পুণ্ডু':'NN','পুণ্য':'NN','পুণ্যজনী':'NN','পুণ্যবতী':'JJ',
'পুণ্যভূমিতে':'NN','পুণ্যরহিত':'JJ','পুণ্যসলিলা':'NN','পুণ্যহীন':'JJ','পুণ্যার্থীদের':'NN','পুণ্যে':'NN','পুত':'JJ',
'পুতনা':'NN','পুতলি':'NNP','পুতিকর্ণ':'NN','পুতিকাষ্টক':'NN','পুতিগন্ধ':'NN','পুতিনযুবরাজ':'NN','পুতিনস্য':'NN',
'পুতিযোনি':'NN','পুতিরক্ত':'NN','পুতী':'NN','পুতুল':'NN','পুতুলের':'NNS','পুত্তলিকা':'NN','পুত্র-বধূ':'NN',
'পুত্রকন্দা':'NN','পুত্রকামী':'JJ','পুত্রকামেষ্ঠি':'NN','পুত্রকে':'NN','পুত্রজিবা':'NN','পুত্রতুল্য':'JJ','পুত্রদা':'NN',
'পুত্রন্নাদ':'NN','পুত্রবতী':'JJ','পুত্রবত্সা':'NN','পুত্রবধু':'NN','পুত্রবান':'JJ','পুত্ররা':'NN','পুত্রহীন':'NN',
'পুত্রহীনা':'JJ','পুত্রাভিলাষী':'JJ','পুত্রার্থী':'JJ','পুত্রী':'NN','পুত্রের':'NN','পুত্রোঘ্নি':'NN','পুথিকা':'NN',
'পুদনা':'NN','পুদিনার':'NN','পুদুকোট্টে':'NN','পুনঃ':'RB','পুনঃখুরি':'NN','পুনঃতফসিল':'VBG','পুনঃপ্রতিষ্ঠার':'NN',
'পুনঃবাসন':'NN','পুনঃরাবৃত্তি':'NN','পুনকথন':'NN','পুনধর্মান্তরিত':'JJ','পুননির্মাণ':'NN','পুনপ্রদর্শন':'NN','পুনরাগমন':'NN',
'পুনরাবর্তণ':'NN','পুনরাবলোকন':'NN','পুনরাবির্ভাব':'NN','পুনরাবৃত্ত':'JJ','পুনরাবৃত্তি':'NN','পুনরাবেদক':'NN','পুনরায়':'RB',
'পুনরায়':'NN','পুনরুক্ত':'NN','পুনরুত্থান':'NN','পুনরুদ্ধার':'NN','পুনরুল্লেখের':'NN','পুনর্গঠন':'NN','পুনর্ঘোষণা':'NN',
'পুনর্জন্ম':'NN','পুনর্জাগরণ':'NN','পুনর্জীবন':'NN','পুনর্নবা':'NN','পুনর্নিযুক্ত':'VBN','পুনর্নিযুক্তি':'NN','পুনর্নির্বাচন':'NN',
'পুনর্প্রাপ্য':'JJ','পুনর্বসু':'NNP','পুনর্বহাল':'VBN','পুনর্বার':'NN','পুনর্বাসন':'NN','পুনর্বাসনের':'NN','পুনর্বাসিত':'JJ',
'পুনর্বিচার':'NN','পুনর্বিদ্যমান':'NN','পুনর্বিবাহ':'NN','পুনর্ব্যবহারোপযোগী':'VB','পুনর্ভূ':'NN','পুনর্মতদান':'NN','পুনর্মুদ্রণ':'NN',
'পুনর্মুল্যাঙ্কন':'NN','পুনর্রচনা':'NN','পুনর্স্থাপিত':'JJ','পুনশ্চ':'NNP','পুনা':'NN','পুনাবাসী':'NN','পুনি':'NN',
'পুনুপুন':'NN','পুনেতে':'NNP','পুন্ডরিয়া':'NN','পুন্ডর্য':'NN','পুন্নাগ':'NN','পুন্য':'NN','পুন্যকর্মা':'NN',
'পুন্যবান':'NN','পুন্যভুমি':'NN','পুন্যাত্মা':'NN','পুপ্পুট':'NN','পুবালি':'NN','পুর':'NN','পুরওয়া':'NN',
'পুরওয়ালা':'JJ','পুরগুর':'NN','পুরজ':'NN','পুরটাই':'RB','পুরণ':'NN','পুরনপুরি':'NN','পুরনে':'NN',
'পুরন্দর':'NN','পুরপুরি':'NN','পুরবাসী':'JJ','পুরবে':'RB','পুরম':'NN','পুরমিত্র':'NN','পুরশ্চরণ':'NN',
'পুরষ্কার':'NN','পুরসভার':'NN','পুরস্কারপ্রাপ্ত':'JJ','পুরস্কারের':'NN','পুরস্কৃত':'VBN','পুরা':'NN','পুরাই':'RB',
'পুরাকালীন':'JJ','পুরাখ্যান':'NN','পুরাঘটিত':'NN','পুরাজলবায়ু':'NN','পুরাণ':'NN','পুরাণের':'NN','পুরাণোক্ত':'NN',
'পুরাতত্ত্ব':'NN','পুরাতন':'NN','পুরাতাত্ত্বিক':'NN','পুরান':'NN','পুরাবসু':'NN','পুরাবিদ্যা':'NN','পুরাবে':'NN',
'পুরাশাস্ত্র':'NN','পুরা‌নো':'NN','পুরি':'NN','পুরু':'NN','পুরুকায়স্থ':'NN','পুরুজানু':'NN','পুরুজিত্':'NN',
'পুরুদমে':'NN','পুরুপুরি':'NN','পুরুমিল্ল':'NN','পুরুমীড়':'NN','পুরুরবা':'NN','পুরুলিয়া':'NN','পুরুষ-সংক্রান্ত':'JJ',
'পুরুষ':'NN','পুরুষকে':'NN','পুরুষতান্ত্রীক':'NN','পুরুষত্ব':'NN','পুরুষত্বহীন':'JJ','পুরুষত্বহীনতা':'NN','পুরুষদন্তিকা':'NN',
'পুরুষদের':'NN','পুরুষাঙ্গে':'NN','পুরুষার্থহীন':'JJ','পুরুষালি':'JJ','পুরুষেন্দ্রিয়':'NN','পুরুষের':'NN','পুরুষোপসৃপ্ত':'JJ',
'পুরুস্কার':'NN','পুরুহন':'NN','পুরে':'NN','পুরোটা':'NN','পুরো':'NN','পুরোগামী':'JJ','পুরোচন':'NN',
'পুরোটা':'NN','পুরোটাই':'RB','পুরোডাশ':'NN','পুরোদিন':'NN','পুরোপুরি':'RB','পুরোহিত':'NN','পুরোহিততন্ত্র':'NN',
'পুরোহিতদের':'NN','পুরোহিতরাই':'NN','পুর্ণ':'NN','পুর্ণিয়া':'NN','পুর্ন':'NN','পুর্বে':'NN','পুর্বের':'NN',
'পুল':'NN','পুলওয়ামার':'NN','পুলক':'NN','পুলটা':'NN','পুলবামা':'NN','পুলভুক্ত':'NN','পুলসত্য':'NN',
'পুলসিরাত':'NN','পুলহ':'NN','পুলাই':'NN','পুলি':'NN','পুলিং':'VBG','পুলিপিঠে':'NN','পুলিশ':'NN',
'পুলিশওরা':'NNS','পুলিশকে':'NN','পুলিশথানা':'NN','পুলিশদের':'NN','পুলিশপ্রশাসন':'NN','পুলিশবিহীন':'NN','পুলিশি':'NNS',
'পুলিশে':'NN','পুলিস':'NN','পুলী':'NN','পুলেই':'NN','পুলোম':'NN','পুলোমা':'NN','পুশকিনের':'NNP',
'পুশতু':'NNP','পুশ্তা':'NN','পুষণ':'NN','পুষতেইতো':'NN','পুষা':'NN','পুষিয়ে':'VB','পুষ্কর':'NN',
'পুষ্করসদ':'NN','পুষ্করীনী':'NN','পুষ্কল':'NN','পুষ্ট':'JJ','পুষ্টি':'NN','পুষ্টিকর':'JJ','পুষ্টিতত্ত্ববিদ':'NN',
'পুষ্টিপ্রদ':'JJ','পুষ্টিবিজ্ঞান':'NN','পুষ্টিবিজ্ঞানের':'NN','পুষ্টিমার্গ':'NN','পুষ্টিহীন':'VBN','পুষ্প':'NN','পুষ্পকৃচ্ছ':'NN',
'পুষ্পগন্ধা':'NN','পুষ্পগৃহ':'NN','পুষ্পচন্দন':'NN','পুষ্পজ্ঞ':'NN','পুষ্পদন্তনাথ':'NN','পুষ্পদাম':'NN','পুষ্পদ্রষ্ট':'NN',
'পুষ্পনামী':'NN','পুষ্পন্দন':'NN','পুষ্পফল':'NN','পুষ্পবর্ষা':'NN','পুষ্পবাটিকা':'NN','পুষ্পবৃষ্টি':'NN','পুষ্পভাগ':'NN',
'পুষ্পমাল্য':'NN','পুষ্পযুক্ত':'JJ','পুষ্পরেণু':'NN','পুষ্পরোহিত':'JJ','পুষ্পলোচন':'NN','পুষ্পশকলী':'NN','পুষ্পসার':'NN',
'পুষ্পস্তবক':'NN','পুষ্পহীন':'JJ','পুষ্পাঙ্গ':'NN','পুষ্পাঞ্জলি':'NN','পুষ্পিকা':'NN','পুষ্পিত':'VBG','পুষ্পিতাগ্রা':'NN',
'পুষ্পোত্কটা':'NN','পুষ্যগর্ভা':'NN','পুষ্যস্নান':'NN','পুস্টিহীন':'VBN','পুস্তক':'NN','পুস্তিকা':'NN','পুড়তে':'VB',
'পুড়লো':'VBN','পুড়ালেন':'VB','পুড়িয়ে':'VBN','পুড়িয়েও':'VB','পুড়ে':'VBN','পুয়রক্ত':'NN','পুয়া':'NN',
'পুয়াল':'NN','পু‌লিশের':'JJ','পূ':'FW','পূঁজিবাদী':'NN','পূগ-পুষ্পিকা':'NN','পূজকের':'NN','পূজন':'NN',
'পূজনীয়া':'JJ','পূজা-অর্চনার':'NN','পূজা':'NN','পূজানো':'VB','পূজাপা':'NN','পূজারা':'NNS','পূজারি':'JJS',
'পূজারী':'NN','পূজিত':'NN','পূজিতব্য':'JJ','পূজিবাজারের':'NN','পূজো':'NN','পূজ্য':'NN','পূজ্যমান':'JJ',
'পূণরায়':'NN','পূণ্য':'JJ','পূণ্যাত্মা':'JJ','পূতদক্ষ':'NN','পূত্র':'NN','পূননিরীক্ষণে':'NN','পূননিলাম':'NN',
'পূনরীক্ষণ':'NN','পূনর্বেক্ত':'NN','পূবে':'NN','পূরক':'NN','পূরণে':'NN','পূরন':'VBN','পূরবী':'NN',
'পূরাণ':'NN','পূরিয়াকল্যাণ':'NN','পূরোপুরী':'RB','পূর্ণ':'NN','পূর্ণকাম':'JJ','পূর্ণকায়':'NN','পূর্ণগ্রাস':'NN',
'পূর্ণচন্দ্র':'NN','পূর্ণচাঁদ':'NN','পূর্ণত':'RB','পূর্ণতা':'NN','পূর্ণদর্শন':'NN','পূর্ণবসু':'NN','পূর্ণবিরাম':'NN',
'পূর্ণমান':'NN','পূর্ণযৌবনা':'JJ','পূর্ণসংখ্যার':'NN','পূর্ণহোম':'NN','পূর্ণাঙ্ক':'NN','পূর্ণাবয়ব':'JJ','পূর্ণাশা':'NN',
'পূর্ণাহুতি':'NN','পূর্ণিমা':'NN','পূর্ণিয়ার':'NNP','পূর্ণেন্দু':'NN','পূর্তি':'NN','পূর্তী':'JJ','পূর্ন':'NN',
'পূর্ব-মধ্য':'JJ','পূর্ব':'NN','পূর্বকথা':'NN','পূর্বকথিত':'JJ','পূর্বকর্ম':'NN','পূর্বকালীন':'JJ','পূর্বকৃত্য':'NN',
'পূর্বগঙ্গা':'NN','পূর্বঘাট':'NN','পূর্বচিত্তি':'NN','পূর্বজ':'NN','পূর্বতঃসিদ্ধ':'JJ','পূর্বদিকে':'NN','পূর্বদেশীয়':'JJ',
'পূর্বধারণা':'NN','পূর্বনির্ধারিত':'JJ','পূর্বপরিকল্পিত':'JJ','পূর্বপুরুষ':'NN','পূর্বফাল্গুনী':'NN','পূর্ববঙ্গে':'NN','পূর্ববত্':'RB',
'পূর্ববর্তী':'JJ','পূর্বভাদ্রপদ':'NN','পূর্বমুখ':'NN','পূর্বরাগ':'NN','পূর্বলব্ধ':'JJ','পূর্বসূরি':'NN','পূর্বা-ফাল্গুনী':'NN',
'পূর্বাগ্রহ':'NN','পূর্বাচল':'NN','পূর্বানুমতি':'NN','পূর্বাভাস':'NN','পূর্বার্ধ':'NN','পূর্বাষাঢ়া':'NN','পূর্বাহ্ণ':'NN',
'পূর্বীয়':'JJ','পূর্বে':'NN','পূর্বেই':'IN','পূর্বেকার':'NN','পূর্বের':'JJ','পূর্বোক্ত':'JJ','পৃতিবিয়োগের':'NN',
'পৃথক.':'JJ','পৃথককরণ':'NN','পৃথকচর':'JJ','পৃথকতা':'NN','পৃথকীকরণ':'VB','পৃথা':'NN','পৃথিবির':'NN',
'পৃথিবীঅন্য':'NN','পৃথিবীই':'NNV','পৃথিবীকে':'NN','পৃথিবীটাকে':'NN','পৃথিবীতীর্থ':'NN','পৃথিবীব্যাপী':'JJ','পৃথিবীর':'NN',
'পৃথু':'NN','পৃথুদর':'JJ','পৃথুশ্রবা':'NN','পৃথ্বীরাজ':'NN','পৃষদশ্ব':'NN','পৃষ্টপোষকতা':'NN','পৃষ্ঠতলই':'NN',
'পৃষ্ঠদেশ':'NN','পৃষ্ঠপোষক':'NN','পৃষ্ঠপোষকতায়':'NN','পৃষ্ঠভূমি':'NN','পৃষ্ঠা':'NN','পৃষ্ঠাঙ্কিত':'JJ','পৃষ্ঠায়':'NN',
'পৃষ্ঠে':'RB','পৃয়োদ':'NN','পে':'NN','পেঁচ':'NN','পেঁচা':'NN','পেঁড়':'NN','পেঁপে':'NN',
'পেঁয়াজ':'NN','পেঁয়াজের':'NNS','পেইজাস্ক্রীলনেটেলার':'NN','পেইজে':'NN','পেইড':'VBN','পেইড়ী':'NN','পেইণ্ট':'NN',
'পেইন':'NN','পেউস':'NN','পেউসী':'NN','পেও':'NN','পেওনিওঅ':'NN','পেওনিয়ার':'NN','পেকিং':'NN',
'পেকে':'NN','পেখম':'NN','পেখমওয়ালা':'JJ','পেখমদার':'JJ','পেগ':'NN','পেগাসাস':'NNP','পেঙ্গুইন':'NN',
'পেঙ্গুইনরা':'NNP','পেঙ্ঘট':'NN','পেচুলী':'NN','পেছন':'JJ','পেছনে-পেছনে':'RB','পেছনে':'NN','পেছানো':'VB',
'পেছানোর':'NNS','পেছিলেন':'NN','পেজ':'NN','পেজেন্ট':'JJ','পেট':'NN','পেটাইনো':'VB','পেটানো':'VBG',
'পেটাবে':'VB','পেটি':'NN','পেটুক':'NN','পেটে':'NN','পেটেনট':'NN','পেটের':'NN','পেট্টোল':'NN',
'পেট্টোলবোমার':'NN','পেট্রল':'NN','পেট্রোল':'NN','পেট্রোল':'NN','পেট্রোলবোমা':'NN','পেট্রোলিয়াম':'NN','পেড়া':'NN',
'পেড়ে':'NN','পেণ্ট':'NN','পেণ্ডুলাম':'NN','পেত':'NN','পেতল':'NN','পেতাম':'NN','পেতে':'NN',
'পেতেও':'NN','পেতেন':'NN','পেতো':'NN','পেত্নী':'NN','পেদর':'NN','পেদো':'JJ','পেন':'NN',
'পেনশনর':'NN','পেনশানের':'NN','পেনসন':'NN','পেনসনারদের':'NN','পেনাল':'NN','পেনি':'NN','পেনিসিলভেনিয়া':'NN',
'পেন্ট':'NN','পেন্টিং':'NN','পেন্টেড':'JJ','পেন্নাম':'NN','পেন্সন':'NN','পেন্সিলভানিয়া':'NN','পেপার':'NN',
'পেপারসে':'NNS','পেপারিং':'VBG','পেপারে':'NN','পেপারের':'IN','পেপাল':'NN','পেপে':'NN','পেপ্যাল':'NN',
'পেবেন':'NN','পেমক':'NN','পেমচা':'NN','পেমেট':'NN','পেম্বা':'NN','পেয়ে':'VBG','পেয়েও':'NN',
'পেয়েছে':'VB','পেরমিক':'NNP','পেরম্বলুর':'NN','পেরা':'NN','পেরিস্কোপ':'NN','পেরিয়ে':'JJ','পেরু':'NN',
'পেরুতে':'NNP','পেরে':'VB','পেরেই':'DT','পেরেক':'NN','পেরেছি':'VB','পেরেছিলেন':'VB','পেরেছেন':'VB',
'পেরেজ':'NN','পেরোটেট':'NN','পেরোতে':'VB','পেল':'VB','পেলবতা':'NN','পেলাগ্রা':'NN','পেলাম':'VB',
'পেলিকান':'NN','পেলে':'VB','পেলেও':'VB','পেলেট':'NN','পেলেন':'VB','পেলো':'VB','পেশ':'NN',
'পেশওয়া':'NN','পেশকারী':'NN','পেশাগত':'JJ','পেশাজীবী':'NN','পেশাজীবীরা':'NNS','পেশাদার':'NN','পেশাদারি':'JJ',
'পেশাদারিত্ব':'NN','পেশায়':'NN','পেশায়':'NN','পেশিতন্ত্র':'NN','পেশিশক্তি':'NN','পেশী':'NN','পেশীবহুল':'JJ',
'পেশীশক্তির':'NN','পেশে':'NN','পেশোবারা':'NNP','পেশোয়ার':'NN','পেষক':'NN','পেষণকারী':'NN','পেষন':'NN',
'পেষাই-এর':'NN','পেষানো':'VB','পেষার':'NN','পেষিত':'JJ','পেস':'NN','পেসমেকার':'NN','পেসারদের':'NNS',
'পেসারের':'NN','পেসেটা':'NN','পেসো':'NN','পেস্ট':'NN','পেস্তা':'NN','পেহঁটা':'NN','পোরা':'NN',
'পোষাকটা':'NN','পোষ্টার':'NN','পোহাতে':'NN','পৌছাতে':'VB','পেয়':'NN','পেয়াঁজ':'NN','পেয়াজের':'NNS',
'পেয়াদা':'NN','পেয়ারে':'NNS','পেয়ালা':'NN','পেয়ে':'VBG','পেয়েও':'VB','পেয়েছি':'VB','পেয়েছিলাম':'VB',
'পেয়েছিলো':'VB','পেয়েছে':'NN','পেয়েছেন':'VB','পৈগনি':'NN','পৈগম্বর':'NN','পৈঙ্গল':'NN','পৈঙ্গলোপনিষদ':'NN',
'পৈডি':'NN','পৈতা':'NN','পৈতৃক':'NN','পৈতে':'NN','পৈত্রিক':'NN','পৈল':'NN','পো':'NN',
'পোঁটা':'NN','পোঁতা':'NN','পোঁতানো':'VB','পোঁয়াকারে':'NN','পোঁয়াতি':'NN','পোই':'NN','পোকা-মাকড়':'NN',
'পোকা':'NN','পোকায়':'NNS','পোক্ত':'JJ','পোখরাজ':'NN','পোখরার':'NNP','পোঙ্গল':'NN','পোজ':'NN',
'পোজিশনিং':'NN','পোটগল':'NN','পোটারত':'NN','পোটাশিয়াম':'NN','পোড়া':'NN','পোড়ার':'NN','পোত':'NN',
'পোতনহর':'NN','পোতা':'NN','পোতাশ্রয়':'NN','পোতিযোগিতায়':'NN','পোথকী':'NN','পোথা':'NN','পোদ্দার':'NN',
'পোনা':'NN','পোপ':'NN','পোপদের':'NN','পোপের':'NN','পোবন':'NN','পোরব':'NNP','পোরবন্দর':'NN',
'পোরা':'VB','পোরোমপট':'NN','পোর্ট':'NN','পোর্টফোলিও':'NN','পোর্টার':'NN','পোল':'NNP','পোলক':'NN',
'পোলচা':'NN','পোলট্রি':'NN','পোলা':'NN','পোলাও':'NN','পোলাপাইনদের':'NN','পোলার':'NN','পোলারা':'NN',
'পোলায়':'NN','পোলিং':'NN','পোলিশ':'NN','পোলো':'NN','পোলোনিয়াম':'NN','পোল্ট্রি':'NN','পোল্যান্ড':'NN',
'পোল্যান্ডীয়':'JJ','পোল্লনারুয়াতে':'NNP','পোশাক':'NN','পোশাকশিল্প':'NN','পোশাকে':'NN','পোষক':'NN','পোষন':'NN',
'পোষা':'NNS','পোষাক':'NN','পোষাকের':'NN','পোষানো':'VB','পোষার':'NNS','পোষ্ট':'NN','পোষ্য':'JJ',
'পোসটে':'NN','পোসাক':'NN','পোসালিয়া':'NN','পোস্ট-অফিস':'NN','পোস্ট-গ্র্যাজুয়েট':'JJ','পোস্ট-বক্স':'NN','পোস্ট':'NN',
'পোস্টকার্ড':'NN','পোস্টমর্টেম':'NN','পোস্টার':'NN','পোস্টে':'NN','পোস্ত':'NN','পোস্তীন':'NN','পোহানো':'VB',
'পোহাবার':'NN','পোড়লে':'NN','পোড়া':'NNS','পোড়াও':'NN','পোড়ানো':'VB','পোয়া':'NN','পৌঁচিয়াছে':'VB',
'পৌঁছতে':'VB','পৌঁছবার':'NNV','পৌঁছবেন':'VB','পৌঁছল':'VB','পৌঁছাতে':'VB','পৌঁছানো':'NN','পৌঁছাবে':'VB',
'পৌঁছায়':'VB','পৌঁছে':'VBG','পৌঁছেছি':'VBN','পৌঁছেছে':'VB','পৌছবে':'VB','পৌছাতেই':'VB','পৌছায়':'VB',
'পৌছায়নি':'VBN','পৌছে':'VBN','পৌত্র':'NN','পৌনঃপুনিক':'JJ','পৌনা':'NN','পৌনে':'JJ','পৌন্ডা':'NN',
'পৌরপ্রধাণ':'NN','পৌরব':'JJ','পৌরবী':'NN','পৌরষ':'NN','পৌরসভা':'NN','পৌরাণিক':'NN','পৌরি':'NN',
'পৌরুষ':'NN','পৌরুষহীন':'JJ','পৌরুষহীনতা':'NN','পৌর্ণমাসী':'JJ','পৌর্ণমাস্য':'NN','পৌলমি':'NN','পৌলুষি':'NN',
'পৌষ-কৃষ্ণা':'NN','পৌষ-শুক্ল':'NN','পৌষ':'NN','প্বেম':'NN','প্যকেটে':'NN','প্যাঁচ':'NN','প্যাঁচওয়ালা':'JJ',
'প্যাঁচকলে':'NN','প্যাঁচযুক্ত':'JJ','প্যাঁচানো':'JJ','প্যাঁচের':'NN','প্যাক':'NN','প্যাকিংবাক্স':'NN','প্যাকেজ':'NN',
'প্যাকেজে':'NN','প্যাকেটও':'NN','প্যাগোডা':'NN','প্যাঙ্গাসিয়াস':'NN','প্যাঙ্গোলিন':'NN','প্যাচ':'NN','প্যাটার্ন':'NN',
'প্যাটেল':'NN','প্যাটেলের':'NNP','প্যাট্রিক':'NN','প্যাড':'NN','প্যাণ্ট':'NNP','প্যাণ্টোথিন':'NN','প্যাথোলজি':'NN',
'প্যাথোলজিস্ট':'NN','প্যান':'NN','প্যানপ্যানকারী':'JJ','প্যানে':'NN','প্যানেলগুলো':'NNS','প্যানেলে':'NN','প্যান্ট':'NNS',
'প্যান্টের':'NN','প্যাভিলিয়ন':'NN','প্যারা':'NN','প্যারাও':'NNP','প্যারাগুয়ান':'NN','প্যারাগুয়েবাসী':'NN','প্যারাগুয়ের':'JJ',
'প্যারাগ্লাইডিং':'NN','প্যারাডাইস':'NN','প্যারাথাইরয়েড':'NN','প্যারানয়েড':'NNP','প্যারালাইজ্ড':'NN','প্যারাশুট':'NN','প্যারিস':'NN',
'প্যারিসের':'NNP','প্যারীবিশ্ববিদ্যালয়ের':'NNP','প্যারেড':'NN','প্যারোল':'NN','প্যালেস্তাইন':'NNP','প্যাল্প':'NN','প্যাসিফিকের':'NNP',
'প্যোংগ্যাং':'NN','প্যোস্টম্যান':'NN','প্রঃআঃর':'NN','প্রকট':'JJS','প্রকটিত':'JJ','প্রকটীকরণ':'NN','প্রকম্পন':'NN',
'প্রকরণ':'NN','প্রকল্প':'NN','প্রকল্পগুলো':'NN','প্রকল্পগুলোর':'NN','প্রকল্পটি':'NN','প্রকল্পতা':'NN','প্রকল্পের':'NN',
'প্রকাণ্ড':'NN','প্রকারন্তরে':'NN','প্রকারবাচী':'NN','প্রকারভেদ':'NN','প্রকারান্তে':'NN','প্রকারে':'NNP','প্রকারেণ':'VB',
'প্রকারের':'NNS','প্রকাশ':'VBN','প্রকাশই':'NN','প্রকাশকের':'NN','প্রকাশনা':'NN','প্রকাশনীয়':'JJ','প্রকাশনো':'VB',
'প্রকাশম':'NN','প্রকাশস্বরূপ':'NN','প্রকাশিত':'VBN','প্রকাশিতা':'NN','প্রকাশে':'JJ','প্রকাশের':'NN','প্রকাশ্য':'JJ',
'প্রকাশ্যে':'NN','প্রকাস':'VBN','প্রকিৃতির':'NN','প্রকৃতপক্ষে':'RB','প্রকৃতভাবে':'NN','প্রকৃতিই':'NN','প্রকৃতিপ্রত্যয়শূণ্য':'JJ',
'প্রকৃতিবাদ':'NN','প্রকৃতির':'NN','প্রকৃষ্ট':'NN','প্রকোপ':'NN','প্রকোষ্ঠ':'NN','প্রকৌশল':'NN','প্রকৌশলীদের':'NNS',
'প্রকৌশলীরা':'NN','প্রক্টর':'NN','প্রক্টরের':'NN','প্রক্রিয়া':'NN','প্রক্রিয়া-কৌমুদী':'JJ','প্রক্রিয়া':'NN','প্রক্রিয়াতে':'NN',
'প্রক্রিয়ায':'NN','প্রক্রিয়ায়':'NN','প্রক্ষলন':'NN','প্রক্ষাপটে':'NN','প্রক্ষিপ্ত':'JJ','প্রখণ্ড':'NN','প্রখর':'NN',
'প্রখরবুদ্ধি':'JJ','প্রখ্যাত':'NN','প্রখ্যাপন':'VB','প্রগতি':'NN','প্রগতিশীল':'JJ','প্রগতীশীলদের':'NN','প্রগলতা':'NN',
'প্রগলভ্':'JJ','প্রগাঢ়':'NN','প্রঘস':'NN','প্রচণ্ড':'NN','প্রচণ্ডতম':'JJ','প্রচণ্ডভাবে':'RB','প্রচন্ড':'NN',
'প্রচলন':'VB','প্রচলিত':'JJ','প্রচার-প্রসার':'NN','প্রচার':'VB','প্রচারক':'NN','প্রচারকার্যে':'NN','প্রচারকুশলী':'NN',
'প্রচারণা':'NN','প্রচারণায়':'NN','প্রচারনায়':'NN','প্রচারে':'NN','প্রচীন':'JJ','প্রচুর':'NNS','প্রচেতস':'NN',
'প্রচেষ্টা':'VB','প্রচেষ্টাকে':'NN','প্রচেষ্টার':'NN','প্রচ্ছন্ন':'JJ','প্রজনন':'NN','প্রজননগত':'JJ','প্রজননের':'NN',
'প্রজনিত':'JJ','প্রজন্ঘ':'NN','প্রজন্মই':'NN','প্রজন্মের':'NN','প্রজয্য':'NN','প্রজা':'NN','প্রজাগরা':'NN',
'প্রজাতন্ত্র':'NN','প্রজাতান্ত্রিক':'JJ','প্রজাতি':'NN','প্রজাতিতে':'NN','প্রজাপতি':'NN','প্রজাবর্গ':'NN','প্রজাসত্তা':'NN',
'প্রজুক্তিতে':'NN','প্রজেক্ট':'NN','প্রজেক্টের':'NN','প্রজ্জ্বলন':'NN','প্রজ্ঞা':'NN','প্রজ্ঞাপন':'VB','প্রজ্ঞাপনের':'NN',
'প্রজ্বলক':'JJ','প্রজ্বলিত':'VB','প্রজ্বলিয়া':'NN','প্রজ্ভটিকা':'NN','প্রটেকশন':'NN','প্রডাক্ট':'NN','প্রডিউসার':'NN',
'প্রণতপাল':'NN','প্রণব':'NN','প্রণবমন্ত্র':'NN','প্রণবেশ':'VB','প্রণম্য':'JJ','প্রণয়ন':'VB','প্রণয়নে':'NN',
'প্রণাম':'NN','প্রণামী':'NN','প্রণিধান':'NN','প্রণীত':'JJ','প্রণেতা':'NN','প্রণোদনা':'VB','প্রণয়':'NN',
'প্রণয়কৌতুক':'NN','প্রণয়ন':'VB','প্রণয়নছাপা':'NN','প্রণয়নের':'NN','প্রতঙ্গ':'NN','প্রতর্দন':'NN','প্রতাপ':'NN',
'প্রতাপগড়ে':'VB','প্রতাপশালী':'JJ','প্রতাপের':'NN','প্রতারকদের':'NN','প্রতারণা':'VBG','প্রতারণামূলক':'NN','প্রতারনা':'NN',
'প্রতারনার':'NN','প্রতারিত':'VBN','প্রতি':'IN','প্রতিই':'NN','প্রতিক':'NN','প্রতিকন্নবর্ত্ম':'NN','প্রতিকা':'NN',
'প্রতিকারক':'NN','প্রতিকী':'JJ','প্রতিকুল':'NN','প্রতিকূল-গ্রহ':'NN','প্রতিকূলগ্রহ':'NN','প্রতিকৃতি':'NN','প্রতিক্রিয়া':'NN',
'প্রতিক্রিয়া':'NN','প্রতিক্রিয়াশীল':'NN','প্রতিক্ষত্র':'NN','প্রতিগমন':'NN','প্রতিগামী':'JJ','প্রতিঘাত':'NN','প্রতিঘাতবিহীন':'JJ',
'প্রতিচ্ছবি':'NN','প্রতিজল্প':'NN','প্রতিজ্ঞা-বিরোধ':'NN','প্রতিজ্ঞা-সন্যাস':'NN','প্রতিজ্ঞা':'NN','প্রতিজ্ঞান্তর':'NN','প্রতিজ্ঞাবদ্ধ':'JJ',
'প্রতিজ্ঞাবদ্ধতা':'NN','প্রতিজ্ঞাসন্যাস':'NN','প্রতিটা':'NN','প্রতিটি':'JJ','প্রতিটিত':'NN','প্রতিদান':'NN','প্রতিদিন':'RB',
'প্রতিদিনই':'NN','প্রতিদিনের':'JJ','প্রতিদ্বন্দিতা':'NN','প্রতিদ্বন্দীতা':'NN','প্রতিদ্বন্দ্বিতা':'NN','প্রতিদ্বন্দ্বিতার':'NN','প্রতিদ্বন্দ্বিবিহীন':'JJ',
'প্রতিদ্বন্দ্বীকে':'NN','প্রতিধ্বণিত':'NN','প্রতিধ্বনি':'NNS','প্রতিধ্বনিত':'VB','প্রতিনিধি':'NN','প্রতিনিধিমণ্ডল':'NN','প্রতিনিধিরা':'NN',
'প্রতিনিবাসন':'NN','প্রতিনিয়ত':'NN','প্রতিপ':'NN','প্রতিপক্ষকে':'NN','প্রতিপক্ষী':'JJ','প্রতিপক্ষের':'NN','প্রতিপত্তি':'VB',
'প্রতিপত্তিশালী':'JJ','প্রতিপত্র':'NN','প্রতিপন্ন':'NN','প্রতিপাদিত':'NN','প্রতিপালক':'NN','প্রতিপালনীয়':'JJ','প্রতিপাল্য':'JJ',
'প্রতিপ্রভ':'NN','প্রতিফল':'NN','প্রতিফলন':'NN','প্রতিফলনশীল':'JJ','প্রতিফলিত':'JJ','প্রতিবছর':'RB','প্রতিবছরের':'NN',
'প্রতিবদ্ধ':'NN','প্রতিবন্ধক':'NN','প্রতিবন্ধকতাকে':'NN','প্রতিবন্ধকতাযুক্ত':'JJ','প্রতিবন্ধরহিত':'NN','প্রতিবন্ধহীন':'JJ','প্রতিবন্ধহীনতা':'NN',
'প্রতিবন্ধী':'NN','প্রতিবর্তী':'NN','প্রতিবাদ':'NN','প্রতিবাদী':'NN','প্রতিবাদের':'NN','প্রতিবারই':'NN','প্রতিবাহ':'NN',
'প্রতিবিদ্বেষই':'NN','প্রতিবিধানের':'NN','প্রতিবিন্ধ্য':'NN','প্রতিবিম্বই':'NN','প্রতিবিম্বকে':'NN','প্রতিবিম্বিত':'JJ','প্রতিবিম্বের':'NN',
'প্রতিবেদক':'NN','প্রতিবেদন':'NN','প্রতিবেদনটা':'NN','প্রতিবেদনটির':'NN','প্রতিবেদনের':'NN','প্রতিবেশি':'NN','প্রতিবেশীদের':'NN',
'প্রতিব্রত':'NN','প্রতিভা':'NN','প্রতিভানু':'NN','প্রতিভাবান':'NN','প্রতিভাময়ী':'JJ','প্রতিভার':'NN','প্রতিভাশালী':'NN',
'প্রতিভাসম্পন্ন':'JJ','প্রতিভাহীন':'JJ','প্রতিভাহীনতা':'NN','প্রতিভূ':'NN','প্রতিম':'NNP','প্রতিমন্ডক':'NN','প্রতিমা':'NN',
'প্রতিমূর্তি':'NN','প্রতিযোগিতা':'NN','প্রতিযোগিতার':'NN','প্রতিযোগী':'NN','প্রতিযোগীতামুলক':'NN','প্রতিযোগীদের':'NN','প্রতিরক্ষা':'NN',
'প্রতিরক্ষামূলক':'NN','প্রতিরাতে':'NN','প্রতিরূপী':'JJ','প্রতিরোধ':'NN','প্রতিরোধক':'NN','প্রতিরোধকারক':'JJ','প্রতিরোধশক্তি':'NN',
'প্রতিলিপি':'NN','প্রতিলিপিত':'JJ','প্রতিলেখ':'NN','প্রতিলোমবিবাহ':'NN','প্রতিশব্দ':'NN','প্রতিশোধকামী':'JJ','প্রতিশোধপরায়ন':'NN',
'প্রতিশ্রুত':'JJ','প্রতিশ্রুতি':'NN','প্রতিশ্রুতিবদ্ধ':'JJ','প্রতিশ্রুতিবদ্ধতা':'NN','প্রতিশ্রুতিভঙ্গকারী':'JJ','প্রতিশ্রুতির':'NN','প্রতিশ্রুতিসম্পন্ন':'JJ',
'প্রতিশ্রূতি':'NN','প্রতিষেধক':'NN','প্রতিষ্টান':'NN','প্রতিষ্টানের':'NN','প্রতিষ্ঠাণের':'NN','প্রতিষ্ঠান':'NN','প্রতিষ্ঠানও':'NN',
'প্রতিষ্ঠানকেও':'NN','প্রতিষ্ঠানগুলির':'NN','প্রতিষ্ঠানগুলোকে':'NN','প্রতিষ্ঠানে':'NN','প্রতিষ্ঠান০১৯':'NN','প্রতিষ্ঠায়':'NN','প্রতিসরণ':'NN',
'প্রতিসারক':'JJ','প্রতিসারণ':'NN','প্রতিসৃত':'JJ','প্রতিস্কন্ধ':'NN','প্রতিস্থাপিত':'NN','প্রতিস্পর্ধা':'NN','প্রতিহত':'NN',
'প্রতিহন্তা':'NN','প্রতিহিংসা':'NN','প্রতিয়গিতা':'NN','প্রতীক':'NN','প্রতীকার':'NN','প্রতীকীবাদী':'NN','প্রতীকে':'NN',
'প্রতীক্ষা':'NN','প্রতীক্ষাকারী':'NN','প্রতীক্ষানো':'VB','প্রতীক্ষিত':'JJ','প্রতীত':'VBN','প্রতীতি':'NN','প্রতীয়মান':'NN',
'প্রতুল':'NNP','প্রতুলচন্দ্র':'NNP','প্রতুলদা':'NNP','প্রত্তাবসানের':'NN','প্রত্ত্যান্ত':'NN','প্রত্ন-বিজ্ঞান':'NN','প্রত্নতত্ত্ব':'NN',
'প্রত্নতাত্ত্বিক':'NN','প্রত্নবিজ্ঞান':'NN','প্রত্যক':'NN','প্রত্যক্ষ':'JJ','প্রত্যক্ষই':'NN','প্রত্যক্ষণকৃত':'JJ','প্রত্যক্ষদর্শী':'NN',
'প্রত্যক্ষদর্শীর':'NN','প্রত্যক্ষিত':'JJ','প্রত্যক্ষীকরণ':'NN','প্রত্যঙ্গিরা':'NN','প্রত্যন্ত':'NN','প্রত্যর্পণ':'NN','প্রত্যশা':'NN',
'প্রত্যাখ্যাত':'VBN','প্রত্যাখ্যান':'NN','প্রত্যাখ্যানকারী':'JJ','প্রত্যাখ্যানকারীদের':'NN','প্রত্যাগমন':'NN','প্রত্যাঘাত':'NN','প্রত্যাবনের':'NN',
'প্রত্যাবাসন':'NN','প্রত্যাশা':'NNS','প্রত্যাশানুকূল':'JJ','প্রত্যাশারহিত':'JJ','প্রত্যাশায়':'NN','প্রত্যাশিত':'JJ','প্রত্যাহার':'NN',
'প্রত্যুতপন্নমতি':'JJ','প্রত্যুত্তর':'NN','প্রত্যুত্পন্নমতিত্ব':'NN','প্রত্যুষ':'NN','প্রত্যেক':'NN','প্রত্যেককে':'NN','প্রত্যেকটাই':'NN',
'প্রত্যেকটি':'NN','প্রত্যেকবার':'RB','প্রত্যেকে':'NN','প্রত্যেকের':'NN','প্রত্যয়ক':'NN','প্রত্যয়িত':'JJ','প্রত্যয়ী':'NN',
'প্রত্রিকা':'NN','প্রত‌িবাদ':'NN','প্রথম':'RB','প্রথমআলো':'NN','প্রথমআলোকেও':'NN','প্রথমআলোর':'NN','প্রথমটাও':'NN',
'প্রথমটার্মের':'NN','প্রথমত':'RB','প্রথমদিকে':'NNP','প্রথমবার':'NN','প্রথমসারীর':'NN','প্রথমাংশ':'NN','প্রথমার্ধে':'NN',
'প্রথমিক':'NN','প্রথমে':'RB','প্রথমোক্তদের':'NN','প্রথর':'JJ','প্রথা':'NN','প্রথাগত':'JJ','প্রথার':'NN',
'প্রথ্ম':'NN','প্রদ':'JJ','প্রদক্ষিণ-পথ':'NN','প্রদক্ষিণ':'NN','প্রদত্ত':'NN','প্রদর':'NN','প্রদর্শন':'NN',
'প্রদর্শনবাংলাদেশ':'NN','প্রদর্শনী':'NN','প্রদর্শনীয়':'JJ','প্রদর্শনেও':'NN','প্রদাতা':'NN','প্রদানকারী':'NN','প্রদানের':'NN',
'প্রদিপ':'NN','প্রদীপক':'NN','প্রদীপদার':'NNP','প্রদীপন':'NN','প্রদীপের':'NN','প্রদেশ':'NN','প্রদেশের':'NN',
'প্রদোষ-ব্রত':'NN','প্রদ্বেষী':'NN','প্রদ্যুমন':'NN','প্রধস':'NN','প্রধাণ-মন্ত্রী':'NN','প্রধাণ':'NN','প্রধাণমন্ত্রী':'NN',
'প্রধান':'NN','প্রধানত':'RB','প্রধানতঃ':'NN','প্রধানমন্ত্রি':'NN','প্রধানমন্ত্রীই':'NN','প্রধানমন্ত্রীকে':'NN','প্রধানমন্ত্রীর':'NN',
'প্রধানরা':'NN','প্রধানাচার্যে':'NN','প্রধানাধ্যাপিকা':'NN','প্রধানের':'NN','প্রধামন্ত্রীর':'NN','প্রনদনা':'NN','প্রনাতনী':'NN',
'প্রনাম':'NN','প্রন্তায়ন':'NN','প্রনয়ণ':'VB','প্রপঞ্চ':'NN','প্রপাগাণ্ডা':'NN','প্রপাগান্ডার':'NN','প্রপাত':'NN',
'প্রপার্টি':'NN','প্রপিতামহ':'NN','প্রপোজাল':'NN','প্রপৌত্র':'NN','প্রফিট':'NN','প্রফিডেন্ড':'NN','প্রফুল্ল':'NN',
'প্রফুল্লকুমার':'NNP','প্রফুল্লতা':'NN','প্রফুল্লিত':'JJ','প্রফেশনাল':'JJ','প্রফেশনালিজম':'NN','প্রফেসর':'NN','প্রবচন':'NN',
'প্রবঞ্চনা':'NN','প্রবণ':'JJ','প্রবণতা':'NN','প্রবত':'NN','প্রবন্ধ-কর্তা':'NN','প্রবন্ধ':'NN','প্রবন্ধকর্তা':'NN',
'প্রবন্ধগাননিষ্ণাত':'NN','প্রবন্ধটি':'NN','প্রবন্ধন':'NN','প্রবন্ধিত':'JJ','প্রবন্ধে':'NN','প্রবন্ধের':'NNS','প্রবরললিতা':'NN',
'প্রবর্তক':'NN','প্রবর্তনও':'NN','প্রবর্তনের':'NN','প্রবর্ধন':'NN','প্রবল':'JJ','প্রবলতা':'NN','প্রবলবেগে':'RB',
'প্রবলেম':'NN','প্রবসিস':'NN','প্রবাদ-প্রবচন':'NN','প্রবাদ':'NN','প্রবাদও':'NNS','প্রবাল':'NN','প্রবালদ্বীপ':'NN',
'প্রবাশে':'NN','প্রবাসি':'NN','প্রবাসিরা':'NNS','প্রবাসী':'NN','প্রবাসীদের':'NNS','প্রবাসে':'NN','প্রবাহ':'NN',
'প্রবাহমান':'JJ','প্রবাহমানা':'NN','প্রবাহহীন':'JJ','প্রবাহিত':'VBG','প্রবাহী':'JJ','প্রবাহের':'IN','প্রবিধান':'NN',
'প্রবিষ্ট':'VBD','প্রবিষ্টি':'NN','প্রবীণ':'JJ','প্রবীণতা':'NN','প্রবৃত্ত':'JJ','প্রবৃত্তি':'NN','প্রবৃত্তিসম্পন্ন':'JJ',
'প্রবৃদ্ধ':'NN','প্রবৃদ্ধিটা':'NN','প্রবেলেম':'NN','প্রবেশদ্বার':'NN','প্রবেশনীয়':'JJ','প্রবেশনো':'VB','প্রবেশপথ':'NN',
'প্রবেশাধিকার':'NN','প্রবেশে':'NN','প্রবেশ্য':'JJ','প্রবোধন':'NN','প্রবোসিস':'NN','প্রব্লেম':'NN','প্রভ':'JJ',
'প্রভদ্রক':'NN','প্রভব':'JJ','প্রভা':'NN','প্রভাতকুমার':'NNP','প্রভাতফেরী':'NN','প্রভাতে':'NN','প্রভানন্দ':'NNP',
'প্রভাব':'NN','প্রভাবতী':'NN','প্রভাবতীও':'NNP','প্রভাবতীনগর':'NN','প্রভাবমুক্ত':'JJ','প্রভাবশালি':'JJ','প্রভাবশালিতা':'NN',
'প্রভাবশালীদের':'NN','প্রভাবশীল':'JJ','প্রভাবশীলতা':'NN','প্রভাবিত':'JJ','প্রভাবে':'RB','প্রভাবের':'NN','প্রভামণ্ডল':'NN',
'প্রভারক':'NN','প্রভাস':'NN','প্রভাহীন':'JJ','প্রভিডেণ্ড':'NN','প্রভিডেন্ড':'NN','প্রভু':'NN','প্রভুত্ব':'NN',
'প্রভুহীন':'JJ','প্রভূকে':'NN','প্রভূত':'JJ','প্রভূতি':'NN','প্রভৃতি':'RP','প্রভৃতিকে':'NN','প্রভৃতিতে':'NN',
'প্রভেদ':'NN','প্রমত্তা':'NN','প্রমাণ-পত্র':'NN','প্রমাণও':'NN','প্রমাণকর্তা':'NN','প্রমাণপত্র':'NN','প্রমাণবিহীণ':'NN',
'প্রমাণাভাব':'NN','প্রমাণিত':'NN','প্রমাণীকরণ':'JJ','প্রমাণের':'NN','প্রমাতা':'NN','প্রমাথ':'NN','প্রমাথী':'NN',
'প্রমান':'NN','প্রমানিত':'NN','প্রমার্থী':'NN','প্রমিতাক্ষরা':'NN','প্রমিস':'NN','প্রমীলা':'NN','প্রমুখ':'NN',
'প্রমূর্ত':'JJ','প্রমেহ':'NN','প্রমেহী':'JJ','প্রমোট':'NN','প্রমোদকামী':'JJ','প্রমোদন':'NN','প্রমোশনের':'NN',
'প্রম্লোচা':'NN','প্রযত্ন':'RB','প্রযত্নশীল':'JJ','প্রযত্নহীন':'RB','প্রযত্নে':'NN','প্রয়াস':'NN','প্রয়োজন':'VBN',
'প্রয়োগ':'NN','প্রয়োগে':'NN','প্রয়োজন':'VBN','প্রয়োজনগুলি':'NN','প্রয়োজনযেমন':'VBN','প্রয়োজনীয়':'JJ','প্রয়োজনের':'NN',
'প্রযুক্ত':'NN','প্রযুক্তিকে':'NN','প্রযুক্তিতে':'NN','প্রযুক্তিবীদ':'JJ','প্রযুক্তির':'NN','প্রযোজক':'NN','প্রযোজনা':'NN',
'প্রযোজ্য':'JJ','প্ররক্ষক':'NN','প্ররিক্রমা':'NN','প্ররোচনা':'NN','প্ররোচিত':'VBD','প্রলম্ব':'NN','প্রলম্বিত':'VBD',
'প্রলাপ':'NN','প্রলাপী':'JJ','প্রলুব্ধ':'VB','প্রলেপ':'NN','প্রলোভন':'NN','প্রল্হাদ':'NN','প্রলয়':'NN',
'প্রশংসক':'NN','প্রশংসা':'NN','প্রশংসাযোগ্যে':'JJ','প্রশংসার':'NN','প্রশংসিত':'JJ','প্রশংসোপমা':'NN','প্রশমক':'NN',
'প্রশমনকারী':'JJ','প্রশমিত':'JJ','প্রশস্ত':'NN','প্রশস্তি':'NN','প্রশাখা':'NN','প্রশান্ত':'NN','প্রশান্তিতে':'NN',
'প্রশামক':'NN','প্রশাসকই':'NN','প্রশাসকীয়':'JJ','প্রশাসকের':'NN','প্রশাসনিক':'NN','প্রশাসনের':'NN','প্রশাসিত':'JJ',
'প্রশিক্ষক':'NN','প্রশিক্ষণ':'NN','প্রশুশ্রুক':'NN','প্রশোজন':'VBN','প্রশ্তুতি':'NN','প্রশ্ন-পত্র':'NN','প্রশ্ন':'NN',
'প্রশ্নই':'NN','প্রশ্নকর্তা':'NN','প্রশ্নকর্ত্তা':'JJ','প্রশ্নগুলো':'NN','প্রশ্নচিহ্ন':'NN','প্রশ্নটা':'NN','প্রশ্নপত্র':'NN',
'প্রশ্নপত্রের':'NN','প্রশ্নফাঁসকারীদের':'NNS','প্রশ্নফাস':'VBN','প্রশ্নবাচক':'NN','প্রশ্নবিদ্ধ':'JJ','প্রশ্নবোধক':'NN','প্রশ্নমালা':'NN',
'প্রশ্নাতিতভাবে':'RB','প্রশ্নাতীত':'JJ','প্রশ্নাবলী':'NN','প্রশ্নের':'NN','প্রশ্নোপনিষদ':'NN','প্রশ্বাস':'NN','প্রশ্রয়ে':'NN',
'প্রশ্রয়দাতা':'NN','প্রশয়':'NN','প্রসংগে':'NN','প্রসংসার':'NN','প্রসঙ্গ':'NN','প্রসঙ্গসম্বন্ধীয়':'JJ','প্রসঙ্গে':'NN',
'প্রসতুতি':'NN','প্রসন্ন':'JJ','প্রসন্নকে':'NNP','প্রসন্নচিত্ত':'JJ','প্রসন্নতা':'NN','প্রসন্নতাদায়ক':'JJ','প্রসন্নতাপূর্বক':'RB',
'প্রসন্নবদন':'JJ','প্রসন্নবদনা':'NN','প্রসন্নমনা':'JJ','প্রসন্নান্ধ':'NN','প্রসব':'NN','প্রসবকারিনী':'NN','প্রসবজনিত':'NN',
'প্রসবা':'NN','প্রসাদ':'NN','প্রসাধণ':'NN','প্রসাধন':'NN','প্রসাধনী':'NNS','প্রসাধিকা':'NN','প্রসার':'NN',
'প্রসারক':'JJ','প্রসারণ':'NN','প্রসারিতনো':'VB','প্রসারে':'NN','প্রসাশনে':'NN','প্রসিদ্ধ':'JJ','প্রসিদ্ধি':'NN',
'প্রসুত':'NNP','প্রসুতা':'NN','প্রসুতিকা':'NN','প্রসূত':'NN','প্রসূতিকাল':'NN','প্রসূন':'NN','প্রসৃতজ':'NN',
'প্রসেনজিত':'NN','প্রসেনজিৎ':'NN','প্রসেবক':'NN','প্রসেসটা':'NN','প্রসেস্টা':'NN','প্রস্কণ্ড':'NN','প্রস্তত':'NN',
'প্রস্তর':'NN','প্রস্তরবর্ষণ':'NN','প্রস্তরবেষ্টনী':'NN','প্রস্তরারোহণ':'NN','প্রস্তাব':'NN','প্রস্তাবনা':'NN','প্রস্তাবমত':'NN',
'প্রস্তাবের':'NN','প্রস্তারপংক্তি':'NN','প্রস্তুত-কর্তা':'NN','প্রস্তুতকরণ':'NN','প্রস্তুতকারী':'NN','প্রস্তুতির':'NN','প্রস্তোক':'NN',
'প্রস্থান':'NN','প্রস্থাপিত':'JJ','প্রস্ন':'NN','প্রস্ফুটিত':'VBN','প্রস্বাপিনী':'NN','প্রস্রাব':'NN','প্রস্রাবঘর':'NN',
'প্রস্রাবনো':'VB','প্রহর':'NN','প্রহরণকলিকা':'NN','প্রহরী':'NN','প্রহসন':'NN','প্রহস্ত':'NN','প্রহার':'VBG',
'প্রহারও':'NN','প্রহৃত':'NN','প্রহেলিকা':'NN','প্রাংশু':'NN','প্রাইজমানি':'NN','প্রাইড':'NN','প্রাইম':'NN',
'প্রাইমারি':'JJ','প্রাইমারী':'NN','প্রাইস':'NN','প্রাককথন':'NN','প্রাকটিস':'NN','প্রাকাম্য':'NN','প্রাকারের':'NN',
'প্রাকাশ':'VBN','প্রাকৃত':'NN','প্রাক্কালিন':'VBN','প্রাক্কালে':'NN','প্রাক্টিস':'NN','প্রাগ':'NN','প্রাগদ্বার':'NN',
'প্রাগৈতিহাসিক':'JJ','প্রাগ্বশ':'NN','প্রাঙ্গণে':'NN','প্রাঙ্গণের':'NN','প্রাঙ্গনে':'NN','প্রাচী':'NN','প্রাচীনকাল':'NN',
'প্রাচীনকূল':'NN','প্রাচীনত্ব':'NN','প্রাচীনদের':'NNS','প্রাচীনপন্থী':'NN','প্রাচীনযোগ':'NN','প্রাচুর্য':'NN','প্রাচ্য-বিদ্যায়':'NN',
'প্রাচ্য':'NN','প্রাজ্ঞ':'NN','প্রাঞ্জল':'JJ','প্রাণ':'NN','প্রাণকৃষ্ণবাবুকেই':'NN','প্রাণকে':'NNS','প্রাণঘাতী':'NN',
'প্রাণঢালা':'NN','প্রাণত্যাগ':'NN','প্রাণদণ্ড':'NN','প্রাণদানের':'NN','প্রাণনাথ':'NN','প্রাণনাশের':'RB','প্রাণপণ':'VB',
'প্রাণপণে':'RB','প্রাণপ্রতিষ্ঠা':'NN','প্রাণবন্ত':'RB','প্রাণবায়ু':'NN','প্রাণভরে':'RB','প্রাণময়':'NN','প্রাণরোধ':'NN',
'প্রাণশক্তি':'NN','প্রাণহন্তা':'JJ','প্রাণহরণকারী':'JJ','প্রাণহানি':'NN','প্রাণহীনতা':'NN','প্রাণাগ্নি-হোত্র':'NN','প্রাণাধিক':'JJ',
'প্রাণান্ত':'RB','প্রাণান্তক':'JJ','প্রাণাহূতি':'NN','প্রাণায়াম':'NN','প্রাণিগ্রাহিক':'JJ','প্রাণিজগতের':'NN','প্রাণিমন':'NN',
'প্রাণীই':'NN','প্রাণীজ':'NN','প্রাণীটির':'NN','প্রাণীবিজ্ঞান':'NN','প্রাণীমাত্র':'NN','প্রাণীয়':'NN','প্রাণেও':'NN',
'প্রাণোচ্ছলতা':'NN','প্রাতঃকর্ম':'NN','প্রাতঃকালে':'RB','প্রাতঃরাশ':'NN','প্রাতঃস্মরণ':'NN','প্রাতভক্ত':'NN','প্রাতর':'NN',
'প্রাতিপীয়':'NN','প্রাতিবোধিক':'JJ','প্রাতিষ্ঠানিক':'NN','প্রাতৃদ':'NN','প্রাথনা':'NN','প্রাথমিক':'NN','প্রাথমিকের':'JJ',
'প্রাথর-প্রতিম':'JJ','প্রাদেশিক':'NN','প্রাধন্ন':'NN','প্রাধান্য':'NN','প্রাধান্যে':'RB','প্রাধিকারপ্রাপ্ত':'VBN','প্রাধ্যাপক':'NN',
'প্রান':'NN','প্রানকে':'NN','প্রানিবিজ্ঞান':'NN','প্রানী':'NN','প্রানে':'NN','প্রান্ত':'NN','প্রান্তগামী':'JJ',
'প্রান্তভাগ':'NN','প্রান্তরে':'NN','প্রান্তিক':'JJ','প্রান্তে':'NN','প্রাপক':'NN','প্রাপ্ত':'VBN','প্রাপ্তকর্তা':'NN',
'প্রাপ্তকারী':'JJ','প্রাপ্তবয়স্ক':'NN','প্রাপ্তরা':'NNS','প্রাপ্তাঙ্ক':'NN','প্রাপ্তিকা':'NN','প্রাপ্তির':'NN','প্রাপ্যই':'VBN',
'প্রাপ্যচতা':'NN','প্রাভাকর':'JJ','প্রামতি':'NN','প্রামাণিক':'JJ','প্রামাণ্য':'NN','প্রামান্যসূত্রে':'NN','প্রায়':'NN',
'প্রায়শই':'RB','প্রারম্ভ':'NN','প্রারম্ভিক':'NN','প্রারম্ভে':'RB','প্রার্থক্য':'NN','প্রার্থণাকারী':'NN','প্রার্থনাকারী':'NN',
'প্রার্থনীয়':'JJ','প্রার্থি':'NNS','প্রার্থিত':'JJ','প্রার্থিতা':'NN','প্রার্থিদের':'NNS','প্রার্থী':'NN','প্রার্থীকে':'NN',
'প্রার্থীদের':'NNS','প্রার্থীর':'NN','প্রার্থীরা':'NNS','প্রাশ্ন':'NN','প্রাসঙ্গিক':'NN','প্রাসাদ-সরকার':'NN','প্রাসাদ':'NN',
'প্রাসাদে':'NN','প্রাসাসন':'NN','প্রায়-অনির্বাচ্য':'JJ','প্রায়-নির্জনতার':'NN','প্রায়':'RB','প্রায়শ':'RB','প্রায়শঃই':'JJ',
'প্রায়শই':'RB','প্রায়শ্চিত্ত':'NN','প্রায়শ্চিত্ব':'NN','প্রায়োগিক':'JJ','প্রিঅর্ডার':'NN','প্রিএমপটিভ':'NN','প্রিজন':'NN',
'প্রিজাইডিং':'NN','প্রিটার':'NN','প্রিন্ট':'NN','প্রিন্টারে':'NN','প্রিন্সিপাল':'NN','প্রিন্সে':'NN','প্রিমিয়ম':'NN',
'প্রিমিয়ার':'NN','প্রিয়া':'NN','প্রিয়':'JJ','প্রিয়ংবদ':'NN','প্রিয়ঙ্গু':'NN','প্রিয়জন':'NN','প্রিয়তম':'JJ',
'প্রিয়তমা':'NN','প্রিয়দর্শন':'NN','প্রিয়বাদী':'JJ','প্রিয়ব্রত':'NN','প্রিয়ভাষী':'JJ','প্রিয়মেধ':'NN','প্রিয়ম্বদা':'NN',
'প্রিয়ম্বাদী':'JJ','প্রিয়া':'NN','প্রীত':'JJ','প্রীতরাম':'NNP','প্রীতি':'NN','প্রীতিকর':'JJ','প্রীতিভোজ':'NN',
'প্রুফ':'NN','প্রুস্তুতি':'NN','প্রূস্তের':'NN','প্রে':'NN','প্রেক্ষণিকা':'NN','প্রেক্ষাগৃহ':'NN','প্রেক্ষাগৃহের':'NN',
'প্রেক্ষাপট':'NN','প্রেজেন্টের':'JJ','প্রেত-বাধা':'NN','প্রেত':'NN','প্রেতবাধা':'NN','প্রেতভূমি':'NN','প্রেতাত্না':'NN',
'প্রেতোন্মাদ':'NN','প্রেথিত':'JJ','প্রেম-প্রসঙ্গ':'NN','প্রেম':'VB','প্রেমই':'NN','প্রেমকাহিনী':'NN','প্রেমচাঁদ':'NNP',
'প্রেমজা':'NN','প্রেমডিভোর্স':'NN','প্রেমধর':'NNP','প্রেমধর্মের':'NN','প্রেমপিয়াসী':'JJ','প্রেমবারি':'NN','প্রেমশর':'NN',
'প্রেমাশ্রু':'NN','প্রেমাসক্ত':'JJ','প্রেমাসক্তি':'NN','প্রেমিক-প্রেমিকার':'NN','প্রেমিক':'NN','প্রেমিকসুলভ':'JJ','প্রেমিকা':'NN',
'প্রেমী':'NN','প্রেমে':'VB','প্রেমের':'NN','প্রেরকগণের':'NN','প্রেরণযন্ত্র':'NN','প্রেরণা':'NN','প্রেরণাত্মক':'JJ',
'প্রেরণাদানকারী':'JJ','প্রেরণাদায়ী':'NN','প্রেরণাস্পদ':'JJ','প্রেরন':'NN','প্রেরনের':'VBG','প্রেরিত':'NN','প্রেশক্রিপশানে':'NN',
'প্রেশার':'NN','প্রেষণা':'NN','প্রেষাণিতে':'VBN','প্রেস':'NN','প্রেসক্লাবে':'NN','প্রেসবার্গ':'NN','প্রেসবার্গার':'NNP',
'প্রেসবার্তা':'NN','প্রেসিং':'VBG','প্রেসিডেণ্ট':'NN','প্রেসিডেন্টই':'NN','প্রেসিডেন্টদেড়':'NN','প্রেসিডেন্সি':'NNP','প্রেস্টিজ':'NNP',
'প্রোসেসটা':'NN','প্রেয়':'NN','প্রেয়িং':'VBG','প্রেয়োজন':'NN','প্রোগ্রাম':'NN','প্রোজেক্ট':'NN','প্রোজেক্টে':'NN',
'প্রোটন':'NNS','প্রোটাগোরস':'NNP','প্রোটিন':'NN','প্রোটেকশন':'NN','প্রোটেস্টাণ্ট':'NNP','প্রোটেস্টান্ট':'NN','প্রোটোকল':'NN',
'প্রোটোজোয়া':'NNP','প্রোটোপ্লাজম':'NN','প্রোড়োকিত':'NN','প্রোডাকশন':'NN','প্রোডাকশনএর':'NNP','প্রোডাক্ট':'NN','প্রোডাক্টগুলি':'NNS',
'প্রোডাক্টটি':'NN','প্রোডিউসার':'NN','প্রোতিস্রূতি':'NN','প্রোত্সাহিত':'VB','প্রোথিত':'JJ','প্রোথিতনো':'VB','প্রোপাগাণ্ডা':'NN',
'প্রোফাইল':'NN','প্রোফেশনালিজম':'NN','প্রোফেসর':'NNP','প্রোভাইডর':'NN','প্রোমেথিয়াম':'NN','প্রোষিত':'JJ','প্রোষ্ঠপদী':'NN',
'প্রোস্টেট':'NN','প্রৌড়':'NN','প্রৌড়াবস্হা':'NN','প্রৌঢ়':'NN','প্র্যাকটিসের':'NN','প্রয়জনে':'NN','প্রয়ত্নশীল':'NN',
'প্রয়াগ':'NN','প্রয়াণগীতি':'NN','প্রয়াস':'NN','প্রয়াসশীল':'JJ','প্রয়াসা':'NN','প্রয়াসী':'JJ','প্রয়োজন':'VBN',
'প্রয়োজনঅন্যথায়':'NN','প্রয়োজনসেই':'NN','প্রয়োগ':'NN','প্রয়োগাত্মক':'JJ','প্রয়োগে':'NN','প্রয়োগের':'NN','প্রয়োজন':'VBN',
'প্রয়োজনই':'NN','প্রয়োজনডায়াল':'VBN','প্রয়োজনঢাকায়':'NN','প্রয়োজনতা':'NNS','প্রয়োজনবতী':'NN','প্রয়োজনহলি':'JJ','প্রয়োজনিয়তাও':'NN',
'প্রয়োজনীয়তা':'NN','প্রয়োজনে':'JJ','প্রয়োজনের':'NN','প্রয়োজন২':'VBN','প্র‍্যাকটিসও':'NN','প্লক্ষ':'NN','প্লট':'NN',
'প্লবতা':'NN','প্লাজমা':'NN','প্লাজার':'NN','প্লাটফরম':'NN','প্লাটফর্মে':'NN','প্লাতোই':'NNP','প্লান':'NN',
'প্লাবন':'NN','প্লাবিকা':'NN','প্লাম্বার':'NN','প্লাস':'NN','প্লাস্টিক':'NN','প্লাস্টিকের':'JJ','প্লিজ':'VB',
'প্লিডার':'NN','প্লীজ':'VB','প্লীহা':'NN','প্লুটো':'NN','প্লুটোর':'NNP','প্লুত':'NN','প্লে':'NN',
'প্লেইংফিল্ড':'NN','প্লেইদেউস':'NNP','প্লেগ':'NN','প্লেটো':'NN','প্লেনে':'NN','প্লেয়ার':'NN','প্লেস':'NN',
'প্লেয়ার':'NN','প্লেয়ারগুলো':'NNS','প্লেয়ারদের':'NNS','প্লেয়ারদেরও':'NN','প্লেয়ারের':'NN','প্লেয়িং':'VB','প্লে–তৃতীয়':'NN',
'প্ল্যাটফর্ম':'NN','প্ল্যাটিনামের':'NN','প্ল্যান':'NN','প্ল্যানেটরিয়াম':'NN','প্্রতিশোধের':'NN','প্ৰকাশ':'NN','প্ৰথম':'RB',
'পড়':'VB','পড়ছি':'VBG','পড়ছিল':'VB','পড়ছিলাম':'NN','পড়ছিলেন':'VBG','পড়ছে':'VBG','পড়ত':'VB',
'পড়তাম':'NN','পড়তি':'VBG','পড়তে':'NN','পড়তেই':'VBG','পড়তে২':'NN','পড়ব':'NN','পড়বার':'NNV',
'পড়বে':'NN','পড়বেন':'VB','পড়ল':'NN','পড়লুম':'VB','পড়লে':'NN','পড়লেও':'NNS','পড়লেন':'VB',
'পড়লো':'NN','পড়লোপরীক্ষার':'NN','পড়া':'NN','পড়াইতে':'NN','পড়াতেন':'VB','পড়াতো':'NN','পড়ানো':'VBG',
'পড়ানোর':'NN','পড়ালেখা':'NN','পড়াশুনা':'NN','পড়াশোনা':'VB','পড়াশোনার':'NN','পড়ায়':'VBG','পড়ি':'VB',
'পড়িবে':'VB','পড়িয়া':'VB','পড়িয়েছেন':'VB','পড়ুক':'VB','পড়ুনতারেক':'VB','পড়ে':'VB','পড়েও':'VB',
'পড়েছি':'VB','পড়েছিলাম':'VB','পড়েছিলেন':'VB','পড়েছে':'VB','পড়েছেআমরা':'VBP','পড়েছেন':'VB','পড়েনা':'VB',
'পড়ের':'JJ','পড়ো':'VB','পয়রা':'NNS','পয়লা':'NN','পয়স':'NN','পয়সাও':'NN','পয়সাওয়ালা':'JJ',
'পয়সার':'NN','পয়সা্এক':'NN','পয়সায়':'NN','পয়স্বিনী':'NN','পয়েণ্ট':'NNS','পয়েণ্টার':'NN','পয়েন্ট':'NNS',
'পয়েন্টলেস':'NN','পয়েন্টের':'NNS','পয়োজ':'NN','পয়োধর':'NN','প‌রিণতি':'NN','প‌রিনত':'JJR','প‌রিমান':'NN',
'প‌রিসংখ্যান':'NN','প‌্যাকেজের':'NN','প‌ড়ে':'VB','প‍্যকেজ':'NN','প‍্যাটেন্ট':'NN','ফ':'NN','ফঁরাসডাঙ্গা':'NNP',
'ফঁরাসি':'JJ','ফঁরাসিদের':'NN','ফকফকা':'NN','ফকরুল':'NN','ফকারান্ত':'JJ','ফকির':'NN','ফকিররা':'NN',
'ফকিরানা':'JJ','ফকিরাপুল':'NN','ফকিরি':'NN','ফকিরী':'JJ','ফকিরেরে':'NN','ফখরুল':'NN','ফখরুলেরা':'NN',
'ফজল':'NN','ফজলে':'NN','ফঞ্জী':'NN','ফট':'NN','ফটক':'NN','ফটকিরি':'NN','ফটকী':'NN',
'ফটকের':'NN','ফটফটি':'NN','ফটিকছড়ির':'NN','ফটিকা':'NN','ফটির':'NN','ফটো':'NN','ফটোগ্রাফার':'NN',
'ফটোগ্রাফের':'NN','ফট্কা':'NN','ফড়কাপেলন':'NN','ফড়ফড়':'NN','ফড়িং':'NN','ফণা':'NN','ফণিকেসর':'NN',
'ফণিজা':'NN','ফণী':'NN','ফণ্ট':'NN','ফতার':'NN','ফতুয়া':'NN','ফতে':'NNP','ফতেগড়':'NN',
'ফতেহপুর':'NN','ফতেহপুরসিক্রী':'NN','ফতেহাবাদ':'NN','ফতেহ্':'NNP','ফতোয়া':'NN','ফদকা':'NN','ফনা':'NNP',
'ফনাম':'NN','ফনালাপ':'NN','ফনীন্দ্র':'NN','ফন্দি':'NN','ফপসা':'NN','ফফোর':'NN','ফয়সাল':'NN',
'ফর-ফর':'NN','ফর':'NN','ফরওযার্ড':'NNP','ফরগেট':'NN','ফরফর':'NN','ফরফরানির':'NN','ফরম':'NN',
'ফরমান':'NN','ফরমালিটি':'NN','ফরমুলা':'NN','ফরমে':'NN','ফরম্যাট':'NN','ফরম্যাটেই':'NN','ফরলো':'NN',
'ফরশী':'NN','ফরসেপ':'NN','ফরহাদ':'NNP','ফরহ্যান্স':'NNP','ফরাসি':'JJ','ফরাসী':'NN','ফরাসীতে':'NNP',
'ফরিদকোট':'NN','ফরিদপুর':'NNP','ফরিদাবাদ':'NN','ফরিদুল':'NN','ফরিয়া':'NN','ফরিয়াদী':'JJ','ফরুখাবাদ':'NN',
'ফরেন':'NN','ফরেষ্টস':'NNP','ফরোদস্ত':'NN','ফর্দ':'NN','ফর্বেস':'NNP','ফর্ম':'NN','ফর্মাটগুলোতে':'NNS',
'ফর্মালিটি':'NN','ফর্মুলা':'NN','ফর্মে':'NN','ফর্মের':'NN','ফর্শী':'NN','ফর্সা':'NN','ফল':'NN',
'ফলওলা':'JJ','ফলক':'NN','ফলকক্ষ':'NN','ফলকাবন':'NN','ফলকী':'NN','ফলকের':'NN','ফলগুলি':'NN',
'ফলগুলির':'NN','ফলত':'RB','ফলদ':'JJ','ফলদান':'NN','ফলদায়ক':'JJ','ফলদায়ী':'NN','ফলন':'NN',
'ফলনশীল':'NN','ফলনা':'NN','ফলনের':'NN','ফলন্ত':'JJ','ফলপুচ্ছ':'NN','ফলপুষ্পা':'NN','ফলপ্রদ':'JJ',
'ফলপ্রসূ':'NN','ফলবিক্রেতা':'NN','ফলবিহীন':'JJ','ফলবে':'NN','ফলমূল':'NN','ফললাভ':'NN','ফলশ্রুতিতে':'NN',
'ফলস':'NNS','ফলসা':'NN','ফলস্বরূপ':'RB','ফলহারিণী':'JJ','ফলা':'NN','ফলাও':'NN','ফলাওকরে':'NNS',
'ফলাঙ্গ':'NN','ফলাতে':'VB','ফলানো':'NN','ফলাফর':'NNS','ফলাফল':'NN','ফলাফলইসম্ভব':'NN','ফলাফলও':'NNS',
'ফলাফলে':'NN','ফলাফলের':'NNS','ফলাযুক্ত':'JJ','ফলাহার':'NN','ফলায়':'NN','ফলায়তেছেন':'VBG','ফলিত-জ্যোতিষ':'NN',
'ফলিত':'NN','ফলিয়ার':'NN','ফলীভূত':'JJ','ফলুই':'NN','ফলে':'NN','ফলেট':'NN','ফলেসু':'NN',
'ফলো-অন':'NN','ফলো':'NN','ফল্গু':'NN','ফল্গুধারায়':'NN','ফল্গুবাটিকা':'NN','ফল্য':'NN','ফষ্টিনষ্টি':'NN',
'ফসকালে':'NN','ফসদ':'NN','ফসফরিক':'NN','ফসফেট':'NN','ফসফোরাস':'NN','ফসল':'NNS','ফসলী':'JJ',
'ফসলের':'NN','ফসিদ':'NN','ফসিলস্':'NN','ফসেট':'NNP','ফসোস':'NN','ফস্':'NN','ফস্কে':'NN',
'ফা':'NN','ফাঁক':'NN','ফাঁকাই':'NN','ফাঁকিবাজ':'JJ','ফাঁকিবাজরা':'NN','ফাঁকে':'NN','ফাঁড়ি':'NN',
'ফাঁদ':'NN','ফাঁপা':'NN','ফাঁশ':'NN','ফাঁস':'VBN','ফাঁসকারীদের':'NNS','ফাঁসা':'VBN','ফাঁসানো':'NN',
'ফাঁসানো':'VB','ফাঁসি':'NN','ফাঁসিতে':'NN','ফাঁসী':'NN','ফাঁসীতে':'NN','ফাঁসের':'NN','ফাংস':'NNP',
'ফাই-ফরমাইশ':'NN','ফাই':'NN','ফাইইনাল':'NN','ফাইকাস':'NNP','ফাইজলামি':'NN','ফাইট':'NN','ফাইনাল':'NN',
'ফাইনালে':'JJ','ফাইনালেও':'NN','ফাইন্যান্স':'NN','ফাইপ':'NN','ফাইবার':'NN','ফাইব্রিনোজেন':'NN','ফাইভ':'NN',
'ফাইল':'NN','ফাউ':'NN','ফাউনটেন':'NN','ফাউন্ডেশনে':'NN','ফাউল':'NN','ফাও':'NN','ফাকা':'NN',
'ফাকিয়ে':'NN','ফাগ':'NN','ফাগুনসুদী':'NN','ফাগুনের':'NN','ফাগুয়া':'NN','ফাগুয়ারা':'NN','ফাজলামী':'NN',
'ফাজলেমিও':'NN','ফাট':'NN','ফাটল':'NN','ফাটা':'VBN','ফাটাচ্ছে':'NN','ফাটানো':'NN','ফাটাফাটি':'NN',
'ফাটাবে':'NN','ফাটিয়ে':'VBN','ফাণ্ড':'NN','ফাতনা':'NN','ফাতিমা':'NN','ফাতে':'VB','ফাত্':'NN',
'ফাদার':'NN','ফাদি':'NN','ফান':'NN','ফানগাস':'NN','ফানেল':'NN','ফান্ড':'NN','ফান্ডামেন্টাল':'NN',
'ফান্ডে':'NN','ফাপিয়ে':'NN','ফাফরা':'NN','ফাবড়া':'NN','ফামিলি':'NN','ফারইস্ট':'NN','ফারদার':'NNP',
'ফারমারস':'NN','ফারমার্সকে':'NN','ফারসি':'JJ','ফারহান':'NN','ফারাক':'NN','ফারাহ':'NNP','ফারুই':'NN',
'ফারুহী':'NN','ফারেন্দ':'NN','ফারোদস্ত':'NN','ফার্টিলাইজার':'NN','ফার্নিচার':'NN','ফার্নেস':'NN','ফার্ম':'NN',
'ফার্মগুলোর':'NN','ফার্মাররা':'NN','ফার্মার্স':'NN','ফার্মিয়াম':'NN','ফার্মের':'NN','ফার্সিতে':'NNP','ফার্সী':'JJ',
'ফার্স্ট':'NN','ফাল':'NN','ফালতু':'NN','ফালাইসিলেন':'NN','ফালি':'NN','ফালুকে':'NN','ফাল্গুন-কৃষ্ণ':'NN',
'ফাল্গুন':'NN','ফাল্গুনী':'NN','ফাল্তু':'JJ','ফাল্লা':'NN','ফাস':'NN','ফাসকারী':'NN','ফাসযুক্ত':'NN',
'ফাসি':'NN','ফাসেরো':'NN','ফাস্ট':'NN','ফাস্টদ্রুত':'JJ','ফাস্টবোলার':'NN','ফাস্সেল':'NN','ফাহিম':'NN',
'ফায়দা':'NN','ফায়ারওয়াল':'NN','ফায়ারিং':'NN','ফা‌দে':'NN','ফি':'NN','ফিংকেলস্টাইনের':'NNP','ফিউচার':'NN',
'ফিউজযুক্ত':'JJ','ফিউস':'NNP','ফিকশন':'NNP','ফিকে':'NN','ফিক্কি':'NN','ফিক্সড':'NN','ফিক্স্ড':'NN',
'ফিঙ্গলটন':'NNP','ফিঙ্গা':'NN','ফিচার':'NN','ফিচারগুলোর':'NN','ফিজ':'NN','ফিজিও':'NN','ফিজিওথেরাপিস্ট':'NN',
'ফিজিওর':'NN','ফিজের':'NN','ফিঞ্চ':'NN','ফিট':'NN','ফিটকারি':'NN','ফিটন':'NN','ফিটনেসের':'NN',
'ফিটিং':'NN','ফিডব্যাক':'NN','ফিতা':'NN','ফিতে':'NN','ফিনফিনে':'JJ','ফিনল্যান্ড':'NN','ফিনল্যান্ডীয়':'NN',
'ফিনাইল':'NN','ফিনিক্স':'NN','ফিনিপিনস':'NNP','ফিনিশ':'NN','ফিনিসার':'NN','ফিন্গার':'NN','ফিন্যান্স':'NN',
'ফিফটি':'NN','ফিফা':'NN','ফিবছর':'RB','ফিবুলা':'NN','ফিমার':'NN','ফিরওয়া':'NN','ফিরকি':'NN',
'ফিরঙ্গ':'NN','ফিরঙ্গিস্তান':'NN','ফিরছেন':'NN','ফিরতি':'NN','ফিরনি':'NN','ফিরবার':'NNV','ফিরবে':'NN',
'ফিরবেন':'VB','ফিরমিনহো':'NN','ফিরল':'NN','ফিরলেই':'NN','ফিরলেন':'VB','ফিরাক':'NN','ফিরি':'VB',
'ফিরিঙ্গি':'NN','ফিরিঙ্গীবাত':'NN','ফিরিতে':'VB','ফিরিহারা':'NN','ফিরিয়া':'VB','ফিরিয়ে':'RB','ফিরুন':'NN',
'ফিরে':'NN','ফিরেছেতার':'NN','ফিরোজ':'NN','ফিরোজা':'NN','ফিলডিং':'NN','ফিলস্তিনরা':'NN','ফিলাডেলফিয়া':'NN',
'ফিলিপ':'NNP','ফিলিপাইন':'NN','ফিলিপাইনের':'NN','ফিলিপিনী':'JJ','ফিলিপিনীয়':'NN','ফিলিপিন্স':'NN','ফিলিপের':'NNP',
'ফিলিস্তিন':'NN','ফিলিস্তিনের':'NN','ফিল্টার':'NN','ফিল্ড':'NN','ফিল্ডস':'NNS','ফিল্ডিং':'NN','ফিল্ডের':'NN',
'ফিল্ম':'NN','ফিল্মগুলোর':'NN','ফিল্মি':'NN','ফিল্মী':'JJ','ফিল্মের':'NN','ফিশপ্লেটের':'NN','ফিস':'NN',
'ফিসন':'RB','ফিসফিস':'IN','ফিসফিসানি':'NN','ফিসিকাল':'NN','ফিসে':'VB','ফিয়ার্ড':'NN','ফিয়ে':'VB',
'ফীতি':'NN','ফীল্ড':'NN','ফুঁ':'NN','ফুঁপিয়ে':'VB','ফুঁসে':'NN','ফুইট্যা':'NN','ফুওয়ার্ক':'NN',
'ফুকন':'NN','ফুকুশিমা':'NN','ফুকুসীমার':'NN','ফুগড়ি':'NN','ফুচকা':'NN','ফুট':'NN','ফুটওভার':'NN',
'ফুটকি':'NN','ফুটকীযুক্ত':'JJ','ফুটতে':'VB','ফুটতেছে':'NN','ফুটপাত':'NN','ফুটপাতের':'JJ','ফুটপাথের':'NN',
'ফুটফুটে':'NN','ফুটবল':'NN','ফুটবলকে':'NN','ফুটবলবোদ্ধা':'NN','ফুটবলার':'NN','ফুটবলারা':'NN','ফুটবলীয়':'NN',
'ফুটবলের':'NN','ফুটি':'NN','ফুটিফাটা':'JJ','ফুটিয়ে':'NN','ফুটিয়েছিলব্যাঙ':'NN','ফুটে':'NN','ফুটের':'NN',
'ফুটো':'NN','ফুটোগুলো':'NN','ফুডের':'NN','ফুনাফুটি':'NN','ফুফু':'NN','ফুরকান':'NN','ফুরফুরা':'NN',
'ফুরফুরে':'JJ','ফুরবিরঞ্জ':'NN','ফুরসত্':'NN','ফুরালে':'NN','ফুরিয়ে':'VB','ফুরিয়ে':'NN','ফুরেরি':'NN',
'ফুর্তি':'NN','ফুল-দূর্বা-নৈবেদ্য':'NN','ফুল':'NNS','ফুলআঁকা':'JJ','ফুলওয়ার':'NN','ফুলকপি':'NN','ফুলকারী':'NN',
'ফুলকি':'NN','ফুলঙ্গো':'NN','ফুলঝুড়ি':'NN','ফুলঝুরিতে':'NN','ফুলটস':'NN','ফুলতেই':'NN','ফুলদানী':'NN',
'ফুলপ্যান্ট':'NN','ফুলবাতী':'NN','ফুলভাঙ':'NN','ফুলমালা':'NN','ফুলযুক্ত':'JJ','ফুলসয্যা':'NN','ফুলসরা':'NN',
'ফুলানোর':'NN','ফুলিশ':'NN','ফুলুন':'NN','ফুলে':'NNP','ফুলের':'NN','ফুলেহরা':'NN','ফুলে–ফেঁপে':'NN',
'ফুলো':'NN','ফুসকা':'NN','ফুসকুড়ি':'NN','ফুসফুস':'NN','ফুস্কুরি':'NN','ফুয়েল':'NN','ফূর্তি':'NN',
'ফূর্তিবাজ':'JJ','ফেঁদে':'NN','ফেঁসে':'NN','ফেঁসোগুলো':'NN','ফেঁসোর':'NN','ফেইক':'NN','ফেইজবুকের':'NN',
'ফেইল':'NN','ফেইস':'NN','ফেইসবুককে':'NN','ফেক':'NN','ফেক্টরীতে':'NN','ফেজার':'NN','ফেটা':'NN',
'ফেটানো':'VB','ফেটে':'NNP','ফেড':'NN','ফেডরেটেড':'NN','ফেডাররেশন':'NNP','ফেডারেল':'NN','ফেডারেশনের':'NN',
'ফেদ্রে':'NN','ফেদ্রের':'NNP','ফেন':'NN','ফেনদুগ্ধা':'NN','ফেনমেহ':'NN','ফেনা':'NN','ফেনাযুক্ত':'JJ',
'ফেনি':'NN','ফেনী':'NN','ফেপে':'NN','ফেফড়ী':'NN','ফেবরুয়ারি':'NNP','ফেবারিট':'NN','ফেবু':'NN',
'ফেব্রুয়ারি':'NNP','ফেব্রুয়ারি':'NN','ফেব্রুয়ারী':'NN','ফেভারিট':'NN','ফেমিলির':'RB','ফের':'NN','ফেরতও':'NN',
'ফেরতের':'NN','ফেরত্্':'NN','ফেরদৌস':'NN','ফেরদৌসির':'NNP','ফেরদৌসী':'NN','ফেরবদল':'NN','ফেরা':'RB',
'ফেরাত':'NN','ফেরানোর':'NN','ফেরানোর':'NN','ফেরাম':'NN','ফেরারী':'NN','ফেরাল':'VBN','ফেরি':'NN',
'ফেরিওয়ালা':'NN','ফেরেন':'VB','ফেরেস্তা':'NNS','ফেরৎ':'NN','ফেল':'NN','ফেলছে':'VB','ফেলত':'VB',
'ফেলতে':'VB','ফেলতো':'VB','ফেলনা':'VB','ফেলব':'VB','ফেলবার':'NNV','ফেলবে':'VB','ফেলল':'NN',
'ফেললাম':'VB','ফেললেন':'VB','ফেলা':'NN','ফেলানো':'VB','ফেলার':'NN','ফেলিক':'NN','ফেলিযা':'VB',
'ফেলিয়ে':'VB','ফেলুন':'VB','ফেলে':'VBN','ফেলেছি':'VB','ফেলেছে':'VB','ফেলেছে৩':'VB','ফেলেন':'VB',
'ফেলো':'NNP','ফেল‌তে':'VB','ফেস':'NN','ফেসবুক':'NN','ফেসবুকটুইটারের':'NN','ফেসবুকিংয়ের':'NN','ফেসবুকের':'NN',
'ফেসর':'NNP','ফেসান্ট':'NN','ফোন':'NN','ফোর':'NN','ফেয়ারপ্লে':'NN','ফেয়ারভাবে':'RB','ফেয়ারে':'NN',
'ফৈজাবাদ':'NN','ফৈসো':'NN','ফৈয়াজ':'NNP','ফোঁকা':'VB','ফোঁটা':'NNS','ফোঁটানো':'NN','ফোঁড়':'NN',
'ফোঁড়াহীন':'NN','ফোঁদল':'NN','ফোঁপর':'NN','ফোঁপানো':'NN','ফোঁস':'NN','ফোঁসফোঁস':'VB','ফোকর':'NN',
'ফোকলা':'JJ','ফোকাস':'NN','ফোকাসে':'NN','ফোকী':'NN','ফোক্কড়':'JJ','ফোকড়ে':'NN','ফোট':'NN',
'ফোটাতে':'NN','ফোটানো':'VBG','ফোটাল':'VB','ফোটালেন':'VBD','ফোটো':'NN','ফোটোগ্রাফি':'NN','ফোড়া':'NN',
'ফোন':'NN','ফোনগুলোর':'NNS','ফোনটা':'NN','ফোনটিই':'NN','ফোনালাপ':'NN','ফোনিসিয়া':'NNP','ফোনে':'NN',
'ফোনেটিক':'NNP','ফোনের':'NN','ফোনোগ্রাফ':'NN','ফোপর':'NN','ফোবর্স':'NN','ফোবিয়া':'NN','ফোর':'CD',
'ফোরজি':'NN','ফোরণ':'NN','ফোরামে':'NN','ফোরিন্ট':'NN','ফোরে':'NN','ফোর্ট-লেমী':'NN','ফোর্ট':'NNP',
'ফোর্থ':'NN','ফোলা':'NN','ফোলেট':'NN','ফোল্ডারবেসড':'VBN','ফোল্ডিং':'NN','ফোস্কা':'NN','ফোয়ারা':'NN',
'ফৌজ':'NN','ফৌজদার':'NN','ফৌজদারী':'NN','ফৌজি':'NN','ফৌর':'CD','ফ্যাকটার':'NN','ফ্যাকাল্টি':'NN',
'ফ্যাক্টর':'NN','ফ্যাক্টরির':'NN','ফ্যাক্টারী':'NN','ফ্যাট':'NN','ফ্যাদম':'NN','ফ্যানদের':'NN','ফ্যানরা':'NNS',
'ফ্যান্সি':'NN','ফ্যামিলি':'NN','ফ্যারাও':'NN','ফ্যারেনহাইট':'NN','ফ্যাশন':'NN','ফ্যাশান':'NN','ফ্যাসাদ':'NN',
'ফ্রক্':'NN','ফ্রডগিরি':'NN','ফ্রণ্টও':'NNP','ফ্রণ্টের':'NN','ফ্রম':'IN','ফ্রাংকেনস্টাইন':'NN','ফ্রাংকেনস্টেইনের':'NN',
'ফ্রাই':'NN','ফ্রাইদে':'NN','ফ্রাঙ্ক':'NNP','ফ্রান্স':'NN','ফ্রান্সিয়াম':'NN','ফ্রান্সের':'NN','ফ্রি':'JJ',
'ফ্রিকোএনসি':'NN','ফ্রিজ':'NN','ফ্রিটাউন':'NN','ফ্রিল্যান্সিং':'NN','ফ্রিল্যান্সিারদের':'NNS','ফ্রী':'NN','ফ্রীলান্সারদের':'NNS',
'ফ্রুটিকা':'NN','ফ্রুটোর':'NN','ফ্রেইন্ডশিপ':'NN','ফ্রেঞ্চ':'NN','ফ্রেডরিক':'NN','ফ্রেতারনিতে':'NNP','ফ্রেনল':'NNP',
'ফ্রেন্ড':'NN','ফ্রেব্রুয়ারি':'NNP','ফ্রেম':'NN','ফ্র্যাক্চার':'NN','ফ্লপ':'NN','ফ্লাইং':'NN','ফ্লাইওভার':'NN',
'ফ্লাইক্যাচার':'NN','ফ্লাইট':'NN','ফ্লাওয়ার':'NN','ফ্লাট':'JJ','ফ্লাটে':'NN','ফ্লাটেই':'JJ','ফ্লানেল':'NN',
'ফ্লু':'NN','ফ্লুনিট্রাজপেন':'NN','ফ্লুরোস্কোপ':'NN','ফ্লেক্সিলোডের':'NN','ফ্লেমিং':'VBG','ফ্লেমিঙ্গো':'NN','ফ্লোর':'NN',
'ফ্লোরিঙ্গান':'NN','ফ্লোরিডা':'NNP','ফ্লোরিন':'NN','ফ্ল্যাগ':'NN','ফ্ল্যাটগুলোতে':'NN','ফ্ল্যাটটা':'NN','ফ্ল্যাটের':'NN',
'ফ্ল্যাশব্যাক':'NN','ফড়িং':'NN','ফয়সলাবাদ':'NN','ফয়সসালরা':'NN','ফয়সালা':'NN','ফয়েল':'NN','ব-দ্বীপ':'NN',
'ব':'NN','বঁদে':'NN','বংগালি':'NN','বংগোপসাগরের':'NNP','বংলাদেশ':'NN','বংশ-ধান':'NN','বংশ':'NN',
'বংশগতি':'NN','বংশজ':'NN','বংশধর':'NN','বংশধররা':'NN','বংশধরা':'NN','বংশনাম':'NN','বংশপত্রী':'NN',
'বংশপরম্পরা':'JJ','বংশপুরক':'NN','বংশপ্রদীপ':'NN','বংশবজ্রা':'NN','বংশবলী':'NN','বংশবৃক্ষ':'NN','বংশরহিত':'JJ',
'বংশলোচন':'NN','বংশস্থ':'NN','বংশানুক্রমিক':'NN','বংশী':'NN','বংশীয়':'JJ','বংশে':'NN','বংশোদ্ভুত':'JJ',
'বংশোদ্ভূতরা':'NN','বংসা':'NN','বংসী':'JJ','বংোভবন':'NN','বই-য়ের':'NN','বই':'NN','বইকি':'RP',
'বইকিতাবে':'NN','বইখানা':'NN','বইছে':'NN','বইটই':'NN','বইটি':'NN','বইটির':'NN','বইতে-বইতেই':'NN',
'বইতে':'NN','বইবার':'NNV','বইমেলায়':'NN','বইলেন':'VB','বইসম্ম':'NN','বইসা':'VB','বইয়ে':'VB',
'বইয়ের':'NN','বউ':'NN','বউনি':'NN','বউপোলাপান':'NN','বউভক্তি':'NN','বউভাত':'NN','বওয়া':'NN',
'বওয়ানো':'VB','বওয়ার':'NN','বক':'NN','বকচম্পক':'NN','বকছেন':'VBG','বকতেন':'VB','বকনা':'NN',
'বকবক':'NN','বকবৃত্তি':'NN','বকব্রতী':'JJ','বকর':'NN','বকরি-ঈদ':'NN','বকরিপু':'NN','বকলেস':'NN',
'বকশাল':'NNP','বকশিশ':'NN','বকা-ঝকা':'NN','বকা':'NN','বকাঝকা':'NN','বকাবলী':'NN','বকারান্ত':'JJ',
'বকারি':'NN','বকাল':'NN','বকাসুর':'NN','বকীয়':'JJ','বকুনি':'NN','বকুল':'NN','বকুলতলা':'NNP',
'বকে':'NN','বকেল':'NN','বকেয়া':'NN','বক্কম':'NN','বক্ত':'NN','বক্তব্যকে':'NN','বক্তব্যে':'NN',
'বক্তা':'NN','বক্তৃতা':'NN','বক্তৃতার':'NN','বক্র':'NN','বক্রগামী':'JJ','বক্রতা':'NN','বক্রপুষ্প':'NN',
'বক্রহীন':'JJ','বক্রাঙ্গ':'JJ','বক্রোক্তি':'NN','বক্ষ-স্থল':'NN','বক্ষ':'NN','বক্ষবন্ধনী':'NN','বক্ষীর':'NN',
'বক্ষোগ্রীব':'NN','বক্স':'NN','বক্সারের':'NNP','বক্সিং':'NN','বখর':'NN','বখরাবাজ':'NN','বখশিশ':'NN',
'বখাটেগুলোকে':'NNS','বগই':'NN','বগড়':'NN','বগদাওয়ত':'NN','বগমা':'NN','বগর্':'NN','বগল':'NN',
'বগলকোট':'NN','বগলদাবা':'NNS','বগলীটাঙ্গ':'NN','বগলেস':'NN','বগি':'NNP','বগিতে':'NN','বগুড়ার':'NN',
'বগুলপতোখ':'NN','বগুড়া':'NN','বগুড়ার':'NN','বগুড়া–৪':'NN','বগ্গী':'NN','বঘাতী':'NN','বঙ্কিম':'NNP',
'বঙ্কিমচন্দ্র':'NNP','বঙ্কৌরা':'NN','বঙ্গ':'NNP','বঙ্গবন্ধু':'NN','বঙ্গবন্ধুর':'NN','বঙ্গবাণী':'NNP','বঙ্গবাসী':'NN',
'বঙ্গরঙ্গমঞ্চের':'NN','বঙ্গা':'NN','বঙ্গাইগাঁও':'NN','বঙ্গানুবাদ':'NN','বঙ্গালী':'NN','বঙ্গীয়':'NNP','বঙ্গের':'NN',
'বঙ্গোপসাগের':'NNP','বঙ্গোপসাগর':'NN','বচন':'NN','বচনকে':'NN','বচনবাগীশ':'NN','বচনে':'NN','বচ্ছ':'JJ',
'বছর':'NNS','বছরই':'NN','বছরও':'NNS','বছরকী':'JJ','বছরকে':'NN','বছরনির্বাচিত':'VBN','বছরব্যাপী':'NN',
'বছরে':'NN','বছরেআমার':'NN','বছরেই':'NN','বছরের':'NN','বছিল':'VB','বছেন':'VB','বছ‌রের':'NN',
'বজকা':'NN','বজবজ':'NNP','বজয়':'NN','বজরং':'NNP','বজরা':'NN','বজলো':'NN','বজায়':'NN',
'বজায়':'NN','বজায়ে':'VB','বজীফা':'NN','বজীরিস্তান':'NN','বজ্ঞ':'NNP','বজ্র-সূচি':'NN','বজ্র':'NN',
'বজ্রকণ্টক':'NN','বজ্রকেতু':'NN','বজ্রজ্বালা':'NN','বজ্রদংষ্ট্র':'NN','বজ্রদন্ত':'NN','বজ্রদেহ.বকবৈরী':'NN','বজ্রধর':'NN',
'বজ্রনাভ':'NN','বজ্রশনি':'NN','বজ্রাঘাত':'NN','বজ্রাঙ্কুশের':'NNP','বজ্রোদরী':'NN','বজয়ী':'JJ','বঝার':'NN',
'বঞ্চনা':'NN','বঞ্চিত':'NN','বট-পূর্ণিমা':'NN','বট':'NN','বটগাছ':'NN','বটপূর্ণিমা':'NN','বটফল':'NN',
'বটবৃক্ষ':'NN','বটমুলে':'NN','বটসাবিত্রী':'NN','বটানিক্যাল':'NNP','বটিকা':'NN','বটী':'NN','বটুক':'NN',
'বটুয়া':'NN','বটে':'NN','বটের':'NN','বট্টন':'NN','বড়':'JJ','বড়ই':'NN','বড়তারপরও':'NNP',
'বড়মামা':'NN','বড়লোক':'NN','বড়হংস-সারং':'NN','বড়হংসিকা':'NN','বড়া':'NN','বড়াই':'VBG','বড়ি':'NN',
'বড়ে':'VB','বড়ো-জাল':'NN','বড়ো':'NN','বড়োমামাকে':'NN','বডি':'NN','বডিগার্ড':'NN','বডির':'NN',
'বড্ড':'NN','বণকে':'NN','বণতা':'NN','বণিক':'NN','বণিকের':'NN','বণ্টনে':'NN','বতঃই':'NN',
'বতা':'NN','বতার':'NN','বতীও':'NNP','বতীর':'NN','বতীয়':'JJ','বতেই':'NN','বতেন':'VB',
'বতের':'NN','বত্তীসা':'NN','বত্তৃতা':'NN','বত্থ':'NN','বত্র':'NN','বত্রিশটা':'NN','বত্রিশতম':'JJ',
'বত্স':'NNS','বত্সনাভ':'NN','বত্সর':'NNS','বত্সরে':'NN','বত্সল':'JJ','বত্সাসুর':'NN','বদ':'NN',
'বদগা':'NN','বদজেদ':'NN','বদন':'NN','বদনতোল':'NN','বদননিকাল':'NN','বদনা':'NN','বদনামকারী':'JJ',
'বদনে':'NN','বদভ্যাস':'NNS','বদভ্যেস':'NN','বদমাইশী':'NN','বদমায়েশদের':'NN','বদমেজাজ':'NN','বদমেজাজী':'NN',
'বদর':'NN','বদরাগ':'JJ','বদল':'NN','বদলনো':'VB','বদলা':'NN','বদলাইছে':'VBN','বদলাতে':'NN',
'বদলানো':'NN','বদলাবার':'NNV','বদলাবে':'NN','বদলালেই':'VBN','বদলায়':'NN','বদলি':'NN','বদলিনো':'VB',
'বদলিয়ে':'VBG','বদলে':'RB','বদলেছে':'VBN','বদলের':'NN','বদহজম':'NN','বদাই':'NNP','বদাওনী':'NNP',
'বদান':'NN','বদান্যতা':'NN','বদাযুঁ':'NN','বদি':'NN','বদুল':'NNP','বদের':'NN','বদৌলতে':'NNS',
'বদ্ধ':'NN','বদ্ধপরিকর':'VBN','বদ্ধমূল':'JJ','বদ্রিনারায়ণ':'NNP','বদ্রীকাশ্রম':'NN','বদ্রীনাথ':'NN','বধ':'NN',
'বধগরাড়ী':'NN','বধবে':'VB','বধান':'NN','বধির':'NN','বধু':'NN','বধুরাও':'NN','বধূ':'NN',
'বধের':'NN','বধ্য':'JJ','বধ্যতামূলক':'NN','বধ্যবাদ্য':'NN','বধ্যভূমি':'NN','বন-বিভাগ':'NN','বন':'NN',
'বনআলু':'NN','বনকন্ডা':'NN','বনকর্মীকে':'NN','বনকল্লা':'NN','বনকস':'NN','বনকোকিল':'NN','বনখরা':'NN',
'বনড়া':'NN','বনড়াদেবগরী':'NN','বনতি':'NN','বনতুলসি':'NN','বনদ':'IN','বনদ্যোপাধ্যায়':'NNP','বনধ':'NN',
'বনধো':'IN','বননির্মূলীকরণ':'NN','বনপিণ্ডালু':'NN','বনপ্রস্থ':'NN','বনপ্রান্তর':'NN','বনফশ':'NN','বনবকরা':'NN',
'বনবাসী':'NN','বনবিড়াল':'NN','বনবিবি':'NN','বনবিভাগ':'NN','বনবেড়াল':'NN','বনভূমি':'NN','বনমাছি':'NN',
'বনমানুশবিশেষ':'NN','বনমালী':'NNP','বনমালীকে':'NNP','বনমাষ':'NN','বনমুরগী':'NN','বনমুর্গী':'NN','বনময়':'JJ',
'বনরাজ':'NN','বনরোপণ':'NN','বনসানাই':'NN','বনস্পতি':'NN','বনস্পতিহীন':'JJ','বনস্পতীয়':'NN','বনহটী':'NN',
'বনাঞ্চল':'NN','বনাত':'NN','বনাতি':'JJ','বনাথ':'NNP','বনাম':'NN','বনাশ':'NN','বনাসকাঁঠা':'NN',
'বনাসুর':'NN','বনিতা':'NN','বনিয়াদি':'JJ','বনীর':'NNP','বনীয়':'JJ','বনুরিয়া':'NN','বনে':'NN',
'বনের':'JJS','বনেশান':'NN','বন্চিত':'NN','বন্টন':'NN','বন্টিত':'JJ','বন্ড':'NN','বন্ডেড':'VBN',
'বন্ডের':'NN','বন্ত':'JJ','বন্দ':'IN','বন্দকপত্র':'NN','বন্দন':'NN','বন্দনায়':'NN','বন্দনী':'NN',
'বন্দনীয়':'JJ','বন্দবস্ত':'NN','বন্দর':'NN','বন্দরনায়েক':'NNP','বন্দরের':'NN','বন্দাল':'NN','বন্দিত':'JJ',
'বন্দিশ':'NN','বন্দী':'JJ','বন্দুক':'NN','বন্দুকবাজ':'NN','বন্দুকযুদ্ধও':'NN','বন্দুকে':'NN','বন্দোবস্ত':'NN',
'বন্দোবস্তই':'NN','বন্দ্যোপাধ্যায়':'NNP','বন্ধ':'NN','বন্ধই':'IN','বন্ধক':'NN','বন্ধকবিহীন':'JJ','বন্ধকযোগ্য':'JJ',
'বন্ধকরার':'NN','বন্ধকী':'NN','বন্ধকীয়':'JJ','বন্ধন':'VBG','বন্ধনমুক্ত':'JJ','বন্ধনমুক্তি':'NN','বন্ধনাঙ্গুরি':'NN',
'বন্ধনী':'NN','বন্ধনো':'VB','বন্ধি':'NN','বন্ধী':'JJ','বন্ধু-বান্ধব':'NN','বন্ধু':'NN','বন্ধুকধারী':'NN',
'বন্ধুগণের':'NNS','বন্ধুজীব':'NN','বন্ধুটিই':'NN','বন্ধুত্ব':'NN','বন্ধুত্বপূর্ণ':'JJ','বন্ধুত্বের':'NN','বন্ধুবান্ধবদের':'NNS',
'বন্ধুযুক্ত':'JJ','বন্ধুর':'NN','বন্ধুরহিত':'JJ','বন্ধুরা':'NN','বন্ধুরাষ্ট্রের':'NNS','বন্ধুরাস্ট্র':'NN','বন্ধুহীন':'JJ',
'বন্ধে':'NN','বন্ধেজ':'NN','বন্ধ্যত্ব':'NN','বন্ধ্যাকরণ':'NN','বন্ধ্যাত্ব':'NN','বন্নাস':'NN','বন্য':'NN',
'বন্যজন্তু':'NN','বন্যজীব':'NN','বন্যতাপূর্ণ':'JJ','বন্যপশুর':'NN','বন্যপ্রাণী':'NN','বন্যা-পীড়িত':'JJ','বন্যা':'NN',
'বন্যাকবলিত':'JJ','বন্যাপীড়িত':'JJ','বন্যায়':'NN','বপন':'VBG','বপনকারী':'NN','বপনযোগ্য':'JJ','বপু.তনু':'NN',
'বপুর':'NNP','বপ্ন':'NN','বববেলিয়া':'JJ','ববর':'NN','ববার':'NNV','ববিদ':'NN','ববেন':'VB',
'বভনেটী':'NN','বভাব':'NN','বভৌম':'JJ','বভ্রু':'NN','বমন':'VBG','বমননো':'VB','বমা':'NN',
'বমি':'NN','বমিনো':'VB','বমুখ':'NN','বমূল':'JJ','বম্-বম্':'NN','বম্':'NN','বম্বের':'NNP',
'বম্হানী':'NN','বয়স':'NN','বয়সী':'JJ','বয়সের':'NN','বয়স্ক':'JJ','বয়ে':'VB','বর-সুন্দরী':'NN',
'বর':'NN','বরংচ':'RB','বরংবরা':'NN','বরকত':'VBN','বরকতময়':'NN','বরকিনা':'NN','বরকে':'NNP',
'বরখাস্ত':'NN','বরগাঁও':'NN','বরগেল':'NN','বরগ্রাম':'NN','বরজ':'NN','বরঞ্চ':'RB','বরটা':'NN',
'বরণ':'VB','বরণে':'NN','বরতন্তু':'NN','বরতমান':'NN','বরতেলা':'NN','বরদবান':'NN','বরদলইতে':'NNP',
'বরদান':'NN','বরদাশত':'VBN','বরদাস্ত':'VB','বরন':'NN','বরপণ':'NN','বরফ':'NN','বরফকণা':'NN',
'বরফযুক্ত':'JJ','বরফাচ্ছাদিত':'JJ','বরফাবৃত':'JJ','বরফি':'NN','বরফের':'NN','বরবটি':'NN','বরবরা':'NNP',
'বরবরানি':'NN','বরবর্ণিনী':'NN','বরবাদ':'NN','বরমালা':'NN','বরমুডাবাসী':'NN','বরযাত্রী':'NN','বররে':'NN',
'বরশালে':'NN','বরশি':'NN','বরসাতি':'NN','বরসু':'NN','বরহা':'NN','বরাও':'NN','বরাঙ্গী':'NN',
'বরাট':'NN','বরাদ্দ':'NN','বরাদ্দে':'NN','বরাদ্ধ':'NN','বরাদ্বের':'NN','বরান':'NN','বরাবর':'IN',
'বরাবরই':'NNS','বরাবরের':'IN','বরাম':'NNP','বরারী':'NN','বরারীশ্যাম':'NN','বরাল':'NN','বরাসাতি':'NN',
'বরাহ':'NN','বরাহকর্ণ':'NN','বরাহকান্তা':'NN','বরাহপুরাণ':'NN','বরাহমিহির':'NNP','বরাহমুক্তো':'NN','বরাহোপনিষদ':'NN',
'বরায়ন':'NN','বরিশাল':'NN','বরিষ্ঠ':'NN','বরিষ্ঠা':'JJ','বরীধরা':'NN','বরীষ':'NNP','বরীয়':'JJ',
'বরুণ':'NNP','বরুণেশ':'NN','বরুথিনী':'NN','বরুনদেবতা':'NN','বরুন্ডি':'NN','বরুন্ডির':'JJ','বরুন্ডিয়ান':'NN',
'বরুন্ডীয়':'JJ','বরুয়া':'NNP','বরূপ':'NN','বরেণ্য':'NN','বরের':'NN','বরেলি':'RB','বরোলী':'NN',
'বর্কর':'NN','বর্গ':'NN','বর্গকিমি':'NN','বর্গফল':'NN','বর্গমাইলের':'NNS','বর্গহীন':'JJ','বর্গাকার':'NN',
'বর্গাকারে':'RB','বর্গাকৃতির':'JJ','বর্গীকরণ':'NN','বর্গীয়':'JJ','বর্জন':'NN','বর্জনীয়':'JJ','বর্জনের':'NN',
'বর্জ্য':'NN','বর্ডার':'NN','বর্ণ-বিন্যাস':'NN','বর্ণ':'NN','বর্ণগত':'JJ','বর্ণজ্যেষ্ঠ':'NN','বর্ণনা':'NN',
'বর্ণনাকারী':'JJ','বর্ণনাত্মক':'JJ','বর্ণনাদুটোই':'NNS','বর্ণনামূলক':'JJ','বর্ণনায়':'NN','বর্ণনীয়':'JJ','বর্ণপুর':'NN',
'বর্ণবাদী':'NN','বর্ণবৃত্ত':'NN','বর্ণভেদ':'NN','বর্ণমালা':'NN','বর্ণময়':'JJ','বর্ণান্ধ':'JJ','বর্ণান্ধতা':'NN',
'বর্ণান্ধতায়':'JJ','বর্ণিক':'NN','বর্ণীত':'JJ','বর্ণে-গন্ধে':'NN','বর্ণে':'NN','বর্ত':'JJ','বর্তক':'NN',
'বর্তমান':'NN','বর্তমানজীবী':'JJ','বর্তমানে':'RB','বর্তমানেও':'NN','বর্তাচ্ছে':'NN','বর্তিকা':'NN','বর্তুলীকরণ':'NN',
'বর্তে':'JJ','বর্ত্তমান':'JJ','বর্ধক':'NN','বর্ধনকারী':'JJ','বর্ধনের':'NN','বর্ধমানের':'NNP','বর্ধা':'NN',
'বর্ধিত':'JJ','বর্ন':'NN','বর্নিত':'JJ','বর্ফি':'NN','বর্বর':'JJ','বর্বরতা':'NN','বর্বরতাপূর্বক':'RB',
'বর্বরতার':'NN','বর্ম':'NN','বর্মণের':'NNP','বর্মন':'NN','বর্য':'NN','বর্রা':'NN','বর্শী':'NN',
'বর্ষ':'NN','বর্ষণের':'NN','বর্ষসেরা':'IN','বর্ষা':'NN','বর্ষাকালীন':'NN','বর্ষার':'NN','বর্ষিক':'JJ',
'বর্ষিত':'VB','বর্ষীয়':'JJ','বর্ষে':'NN','বর্হস্রক':'NN','বর্হি':'NN','বর্হিভূতভাবে':'RB','বর্হী':'NN',
'বল':'NN','বলকে':'NN','বলগা':'NN','বলগাহরিণ':'NN','বলগুলো':'NNS','বলছি':'NN','বলছিলাম':'VBG',
'বলছিলো':'VB','বলছিস':'VBG','বলছে':'VBG','বলছেন':'NN','বলটার':'NN','বলত':'VB','বলতম':'JJ',
'বলতা':'NN','বলতাছে':'VB','বলতে':'NN','বলতেই':'VB','বলতেছিলো':'VBG','বলতেছে':'NN','বলতো':'NN',
'বলদ':'NN','বলনেনা':'VB','বলনেহ':'NN','বলপার্ক':'NN','বলপূর্বক':'RB','বলপ্রয়োগের':'NN','বলব':'NN',
'বলবতী':'JJ','বলবত্':'VB','বলবত্করণ':'NN','বলবর্ধক':'NN','বলবান':'NN','বলবার':'NNV','বলবে':'VB',
'বলবেনই':'VB','বলবো':'VB','বলবৎ':'NN','বলভদ্র':'NN','বলরাম':'NN','বলরামকে':'NNP','বলরামপুর':'NN',
'বলরামবাবু':'NNP','বলল':'VB','বললুম':'VB','বললে':'VB','বললেও':'VB','বললেম':'VB','বললো':'VB',
'বলসাড':'NN','বলহীনতা':'NN','বলা':'NN','বলাক':'NN','বলাকাশ্ব':'NN','বলাকী':'NN','বলাঙ্গক':'NN',
'বলাটা':'NN','বলাতেও':'VB','বলাত্কারী':'NN','বলানো':'NN','বলাম':'VB','বলার':'NN','বলাল':'VB',
'বলাস':'NN','বলাহক':'NN','বলায়':'NNS','বলি':'NN','বলিক':'JJ','বলিচিহ্ন':'NN','বলিতে':'VB',
'বলিদান':'NN','বলিনি':'VB','বলিপশু':'NN','বলিভার':'NN','বলিভিয়ান':'JJ','বলিভিয়েনো':'NN','বলিভীয়':'JJ',
'বলিভুক':'NN','বলির':'NN','বলিল':'VB','বলিশ':'NN','বলিষ্ঠ':'NN','বলিস':'VB','বলিয়া':'NN',
'বলিয়াছে':'VB','বলিয়েন':'VBG','বলী':'JJ','বলীন':'NN','বলীর':'NNP','বলীয়ান':'JJ','বলুক':'VB',
'বলুকআপনি':'VB','বলুন':'VB','বলুম':'VB','বলে':'VB','বলেআমার':'NN','বলেই':'VB','বলেএটা':'NN',
'বলেও':'NN','বলেকি':'VB','বলেগায়েবি':'NN','বলেছি':'VB','বলেছিলাম':'VB','বলেছিলো':'VB','বলেছে':'VB',
'বলেছেনখুনি':'VB','বলেছেনতাতে':'VB','বলেছেনবিনা':'VB','বলেন':'VB','বলেনা':'VB','বলের':'NN','বলো':'VB',
'বল্কল':'NN','বল্কলপরিহিত':'JJ','বল্খ':'NN','বল্গা':'NN','বল্টু':'NN','বল্প':'VB','বল্বজ':'NN',
'বল্বল':'NN','বল্লভা':'NN','বল্লভাচার্য্য':'NNP','বল্লম':'NN','বল্লমধারী':'JJ','বল্লর':'NN','বল্লারশাহ':'NNP',
'বল্লারী':'NN','বল্লেই':'VB','বল্লো':'NN','বলয়':'NN','বলয়াকৃতি':'NN','বল‌ছে':'VB','বশ':'NN',
'বশতঃ':'NN','বশবর্তী':'NN','বশিত্ব':'NN','বশিষ্ঠ':'NN','বশীকরণ':'NN','বশীকরণকারী':'JJ','বশীভূত':'NN',
'বশীরি':'NN','বশুর':'NN','বশে':'NN','বশেষ':'JJ','বশ্য':'NN','বস':'NN','বসকর':'JJ',
'বসকে':'NN','বসকো':'NNP','বসছে':'VB','বসতা':'VB','বসতি':'NN','বসতিহীন':'JJ','বসতে':'VB',
'বসতেন':'VB','বসনহীন':'JJ','বসন্ত-পঞ্চমী':'NN','বসন্ত-মহোত্সব':'NN','বসন্ত':'NN','বসন্তকালীন':'JJ','বসন্তকালে':'NN',
'বসন্ততিলক':'NN','বসন্তদ্রুম':'NN','বসন্তভৈরবী':'NN','বসন্তমারু':'NN','বসন্তোত্সব':'NN','বসপা':'NN','বসবাস':'NN',
'বসবাসকারী':'NN','বসবাসের':'NN','বসবে':'VB','বসবেন':'NN','বসর':'NN','বসরে':'NN','বসল':'VB',
'বসলুম':'VB','বসলে':'NN','বসলেন':'VB','বসলো':'VB','বসা':'VBG','বসাই':'NN','বসাইলে':'RP',
'বসাতি':'NN','বসাদ':'NN','বসানো':'NN','বসাপ্রমেহ':'NN','বসার':'VBG','বসালে':'RP','বসাস':'NNP',
'বসায়':'NN','বসি':'NN','বসিওরা':'NN','বসিক':'NN','বসিকাদার':'NN','বসিত':'JJ','বসিতে':'VB',
'বসিনি':'VB','বসির':'NN','বসিয়া':'VB','বসিয়ে':'NN','বসিয়েআনকারা':'NN','বসিয়েও':'NN','বসিয়েছিলেন':'VB',
'বসিয়েছেন':'VB','বসু':'NN','বসুকর্ণ':'NN','বসুকৃত':'NN','বসুক্র':'NN','বসুটোল্যান্ড':'NN','বসুদা':'NN',
'বসুধাসুর':'NN','বসুনীথ':'NN','বসুন্ধরা':'NN','বসুন্ধরার':'NN','বসুপ্রদ':'NN','বসুবাহু':'NN','বসুবিদ':'NN',
'বসুমতী':'NN','বসুমনা':'NN','বসুর':'NNP','বসুরুচি':'NN','বসুসারা':'NN','বসুস্থলী':'NN','বসুহংস':'NN',
'বসৃত':'JJ','বসে':'NN','বসেও':'NN','বসেছিল':'VB','বসেছে':'NN','বসেছেন':'VB','বসেন':'NN',
'বসেরা':'NNP','বস্ত':'JJ','বস্তনাভ':'NN','বস্তর':'NN','বস্তাটা':'NN','বস্তাবন্দী':'JJ','বস্তায়':'NN',
'বস্তিই':'NN','বস্তিকুন্ডলিকা':'NN','বস্তিতে':'NN','বস্তিবাসী':'NN','বস্তির':'NN','বস্তু-ভাগ':'NN','বস্তুকে':'NN',
'বস্তুগুলি':'NN','বস্তুটার':'NN','বস্তুত':'NN','বস্তুতঃ':'RB','বস্তুতে':'NN','বস্তুত্প্রেক্ষা':'NN','বস্তুনিষ্ঠ':'JJ',
'বস্তুবাদ':'NN','বস্তুর':'NN','বস্তুসমূহ':'NN','বস্তুহীনতা':'NN','বস্ত্র':'NN','বস্ত্রধারী':'JJ','বস্ত্রবিপণী':'NN',
'বস্ত্রভান্ডার':'NN','বস্ত্রহীন':'NN','বস্ত্রাগার':'NN','বস্ত্রাবরণ':'NN','বস্ত্রাভূষিত':'JJ','বস্ত্রালয়':'NN','বস্থ':'JJ',
'বস্থুনিষ্ঠ':'JJ','বস্ব':'NN','বহছর':'NN','বহন':'NN','বহনকারী':'NN','বহননো':'VB','বহনযোগ্য':'JJ',
'বহনর':'NN','বহমান':'NN','বহর':'NN','বহরমপুর':'NN','বহরমপুরের':'NNP','বহরাইচ':'NN','বহরে':'NN',
'বহলা':'NN','বহাবলপুর':'NN','বহার':'NN','বহালতবিয়তে':'NN','বহিঃ':'NN','বহিঃঅঙ্গ':'NN','বহিঃপ্রকাশ':'NN',
'বহিঃবিশ্ব':'NN','বহিঃসমর্পণ':'NN','বহিঃস্থ':'JJ','বহিঃস্রাবী':'NN','বহিত':'JJ','বহিন':'NN','বহিবিশ্বে':'NN',
'বহিরঙ্গ':'JJ','বহিরঙ্গের':'NN','বহিরাগত':'JJ','বহিরাগতরা':'NN','বহিরিন্দ্রিয়':'NN','বহির্গমন':'NN','বহির্গ্রহের':'NN',
'বহির্চাপ':'NN','বহির্দেশীয়':'JJ','বহির্ভিমুখী':'JJ','বহির্ভূত':'JJ','বহির্মাঠের':'NN','বহির্মুখী':'NN','বহির্লাপিকা':'NN',
'বহির্ষি':'NN','বহিষ্ককরণ':'NN','বহিষ্কারাদেশ':'NN','বহিষ্কৃত':'NN','বহিস্কার':'NN','বহীন':'JJ','বহু':'NN',
'বহুঁটা':'NN','বহুকন্যা':'NN','বহুকাল':'RB','বহুকৃতি':'JJ','বহুক্ষণ':'NN','বহুগুণ':'NN','বহুগুণে':'RB',
'বহুগুনা':'NN','বহুগ্রন্থি':'NN','বহুঘাত':'JJ','বহুচর্চিত':'JJ','বহুজঙ্গি':'NN','বহুজন':'NN','বহুজনেরই':'NN',
'বহুত':'JJ','বহুতল':'NN','বহুদক':'NN','বহুদলীয়':'JJ','বহুদলীয়গনতন্ত্র':'NN','বহুদিন':'NN','বহুদূর':'NN',
'বহুদেশ':'NN','বহুদেশীয়':'JJ','বহুধার':'NN','বহুধার্মিক':'JJ','বহুপদ':'JJ','বহুপ্রসূ':'JJ','বহুপ্রাচীন':'JJ',
'বহুবচন':'NN','বহুবর্শী':'NN','বহুবর্ষজীবি':'JJ','বহুবার':'NN','বহুবিধ':'JJ','বহুবিবাহ':'NN','বহুবীধ':'NN',
'বহুবৃচ':'NN','বহুবৃচোপনিষদ':'NN','বহুব্রীহি':'NN','বহুভাষাবিদ':'NN','বহুভাষিক':'JJ','বহুভাষী':'JJ','বহুভুজ':'JJ',
'বহুমত':'NN','বহুমাত্রিক':'JJ','বহুমার্গাবলম্বী':'JJ','বহুমুখী':'NN','বহুমুত্র':'NN','বহুমূল্য':'NN','বহুর':'NN',
'বহুরঙা':'JJ','বহুরাষ্ট্রীয়':'JJ','বহুরূপী':'NN','বহুল':'NN','বহুলাংশে':'NN','বহুশিল্প':'NN','বহুশ্রূত':'JJ',
'বহুসংখ্যক':'JJ','বহৃত':'JJ','বহেড়া':'NN','বহ্নি':'NN','বহ্বাক্ষর':'JJ','বহ্বার্থক':'NN','বহ‌িষ্কার':'NN',
'বা':'NN','বাঁ-হাতি':'NN','বাঁ':'NN','বাঁকড়া':'NN','বাঁকবহনকারী':'NN','বাঁকা':'NN','বাঁকাও':'VB',
'বাঁকী':'NN','বাঁকুড়া':'NN','বাঁকুড়া':'NNP','বাঁগ':'NN','বাঁঙ্গড়ু':'NN','বাঁচতে':'NN','বাঁচবেন':'NN',
'বাঁচলাম':'VB','বাঁচলে':'NN','বাঁচা':'JJ','বাঁচাতে':'NN','বাঁচাতেই':'VB','বাঁচান':'NN','বাঁচানোর':'NN',
'বাঁচিতে':'VB','বাঁচিয়ে':'NN','বাঁজ':'NN','বাঁটোয়ারা':'NN','বাঁদনা':'NN','বাঁদরি':'NN','বাঁদিকে':'NN',
'বাঁধ':'NN','বাঁধতে':'VB','বাঁধন':'NN','বাঁধনমুক্ত':'NN','বাঁধনি':'NN','বাঁধবে':'NN','বাঁধাই':'NN',
'বাঁধাধরা':'JJ','বাঁধানো':'NN','বাঁধার':'NN','বাঁধাহীন':'JJ','বাঁধিয়ে':'VB','বাঁধের':'NN','বাঁবলি':'NN',
'বাঁশ':'NN','বাঁশখালীর':'NN','বাঁশজাতীয়':'JJ','বাঁশঝাড়':'NN','বাঁশপুর':'NN','বাঁশবেড়িয়া':'NNP','বাঁশমতি':'NN',
'বাঁশা':'NN','বাঁশিবাদক':'NN','বাঁশুলি':'NN','বাঁশের':'NN','বাঁশেরকেল্লা':'NN','বাঁসবাড়া':'NN','বাঁহাতি':'NN',
'বাঁয়া':'NN','বাংক':'NN','বাংগাদেশেও':'NN','বাংগালী':'NN','বাংগালীরা':'NN','বাংলদেশকে':'NN','বাংলা':'NN',
'বাংলাকে':'NN','বাংলাদশের':'NN','বাংলাদেশ-এ':'NNP','বাংলাদেশ':'NN','বাংলাদেশইনশাল্লাহ':'NN','বাংলাদেশও':'NN','বাংলাদেশকেও':'NN',
'বাংলাদেশটাই':'NN','বাংলাদেশপুরো':'NN','বাংলাদেশফিলিস্তিন':'NN','বাংলাদেশভারত':'NN','বাংলাদেশর':'NN','বাংলাদেশি':'NN','বাংলাদেশিদেরও':'NN',
'বাংলাদেশিরা':'NN','বাংলাদেশীগুলা':'NN','বাংলাদেশীদেরকেও':'NN','বাংলাদেশীরা':'NN','বাংলাদেশীসত্যিই':'NN','বাংলাদেশে':'NN','বাংলাদেশেও':'NN',
'বাংলাদেশের':'NN','বাংলাদেশেরও':'NN','বাংলাদেেশ':'NN','বাংলাভাই':'NN','বাংলাভাষী':'NN','বাংলায়':'NN','বাংলালিংক':'NN',
'বাংলালিঙ্কই':'NN','বাংলােদশকে':'NN','বাংলা্দেশি':'NN','বাংলায়':'NN','বাংলা‌দেশ':'NN','বাংলো':'NN','বাংলোর':'NNP',
'বাই':'NN','বাইকেই':'NN','বাইজা':'NN','বাইজেন্তীয়':'JJ','বাইটে':'NN','বাইদ':'NN','বাইনারি':'NN',
'বাইপাস':'NN','বাইবেল':'NN','বাইভ্যালেণ্ট':'NN','বাইর':'RB','বাইরিকী':'NN','বাইরে':'NN','বাইরেও':'NN',
'বাইশ':'NN','বাইস্পোরাস':'NNP','বাইড়ে':'NN','বাঈ':'NN','বাউটি':'NN','বাউণ্ডলে':'JJ','বাউণ্ডুলে':'NN',
'বাউন্ডারি':'NN','বাউন্ডুলেপনা':'NN','বাউন্ড্রি':'NN','বাউন্সি':'NN','বাউরী':'NN','বাউল':'NN','বাওয়া':'NN',
'বাওয়েরিয়া':'NN','বাক':'NN','বাকচতুর':'NN','বাকচি':'NNP','বাকপটু':'NN','বাকপ্রতিবন্ধি':'NN','বাকযন্ত্র':'NN',
'বাকযুদ্ধ':'NN','বাকরুকা':'NN','বাকরুদ্ধ':'JJ','বাকরুদ্ধ্য':'NN','বাকল':'NN','বাকলপরিহিত':'JJ','বাকলাভার':'NN',
'বাকশক্তি':'NN','বাকশক্তিসম্পন্ন':'JJ','বাকশাল':'NN','বাকশালী':'NN','বাকশালে':'NNP','বাকশালের':'NN','বাকসিদ্ধ':'NN',
'বাকস্বাধীনতা':'NN','বাকা':'NN','বাকিঅন্যান্য':'NN','বাকিটা':'NN','বাকিদের':'NN','বাকিরা':'JJS','বাকিসব':'NN',
'বাকী':'NN','বাকীদের':'JJS','বাকু':'NN','বাকুম':'NN','বাকে':'NN','বাক্য':'NN','বাক্যটা':'NN',
'বাক্যতত্ত্বকে':'NN','বাক্যবাগীশ':'NN','বাক্যবিনিময়':'NN','বাক্যবিশারদ':'NN','বাক্যার্থ':'NN','বাক্যালঙ্কার':'NN','বাক্যে':'NN',
'বাক্যের':'NNS','বাক্স':'NN','বাক্‌স্বাধীনতা':'NN','বাখার':'NN','বাখারি':'VB','বাগ':'NN','বাগড়ম':'VB',
'বাগডুম':'NN','বাগডোর':'NN','বাগত':'JJ','বাগদত্ত':'NN','বাগদত্তা':'VB','বাগদা':'NN','বাগদাদিও':'NN',
'বাগধারা':'NN','বাগপত':'NN','বাগবাজারের':'NN','বাগবাটোয়ারা':'NN','বাগমতী':'NN','বাগলি':'NN','বাগা':'NN',
'বাগাড়ম্বর':'NN','বাগান':'NN','বাগানগুলোর':'NNS','বাগানে':'NN','বাগাবার':'NN','বাগারম্ভর':'NN','বাগাল':'NN',
'বাগিয়ে':'VB','বাগীচা':'NN','বাগুর':'NN','বাগেড়ী':'NN','বাগেরহাটে':'NN','বাগেশ্বরী':'NN','বাগ্দত্তা':'NN',
'বাগ্দীদের':'NN','বাগ্মী':'NN','বাঘ-চিতা-নেকড়ের':'NN','বাঘ':'NN','বাঘছাল':'NN','বাঘটি':'NN','বাঘনখ':'NN',
'বাঘনহাঁ':'NN','বাঘমারা':'NN','বাঘিনী':'NN','বাঘিনীরা':'NNS','বাঘী':'NN','বাঘেও':'NN','বাঘেলখণ্ড':'NN',
'বাঙলা':'NN','বাঙলাদেশ':'NNP','বাঙলাদেশকে':'NN','বাঙলাদেশে':'NNP','বাঙাল':'NN','বাঙালির':'NN','বাঙালী':'NN',
'বাঙালীদের':'NNS','বাঙালীর':'NN','বাঙুর':'NNP','বাঙ্ক':'NN','বাঙ্কার':'NN','বাঙ্গর':'NN','বাঙ্গার':'NN',
'বাঙ্গালা':'NN','বাঙ্গালি':'NN','বাঙ্গালী':'NN','বাঙ্গালীদের':'NN','বাঙ্গালীরা':'NN','বাঙ্গুই':'NN','বাচঁতে':'NN',
'বাচক':'JJ','বাচচু':'NN','বাচড়া':'NN','বাচতে':'NN','বাচন':'NN','বাচবিচার':'NN','বাচস্পতি':'NN',
'বাচা':'VB','বাচাঁনোর':'NN','বাচাটা':'NN','বাচাতে':'VB','বাচানো':'VB','বাচানোর':'NN','বাচাল':'NN',
'বাচি':'NNS','বাচিঁ':'JJ','বাচিনা':'NNP','বাচিসৌদি':'NN','বাচিয়ে':'VB','বাচীতা':'NN','বাচুয়া':'NN',
'বাচে':'JJ','বাচেন':'NN','বাচো':'NN','বাচ্চ':'NN','বাচ্চাকে':'NN','বাচ্চাদের':'NN','বাচ্চারা':'NNS',
'বাচ্চু':'NN','বাচ্চুকে':'NN','বাচ্চুর':'NN','বাচ্ছা':'NN','বাচ্যার্থ':'NN','বাছতে':'VB','বাছা':'NN',
'বাছানো':'VB','বাছিয়া':'VB','বাছুর':'NN','বাজ':'NN','বাজকন্দ':'NN','বাজছিল':'VB','বাজছে':'VBG',
'বাজছেপুলিশ':'NN','বাজতে':'NN','বাজদের':'NNS','বাজনদার':'NN','বাজন্ত্রী':'NN','বাজপাখি':'NN','বাজপেয়ী':'NN',
'বাজপ্য':'NN','বাজবে':'NN','বাজরবট্টুর':'NN','বাজরহাঁড়':'NN','বাজরার':'NN','বাজলে':'RP','বাজা':'VB',
'বাজাইছে':'VBG','বাজাইয়া':'VB','বাজাচ্ছে':'VBG','বাজাচ্ছেন':'NN','বাজাজ':'NN','বাজাতে':'NN','বাজান':'VB',
'বাজানে':'NN','বাজানোর':'NN','বাজারই':'NN','বাজারজাত':'VBN','বাজারটা':'NN','বাজারব্যবস্থা':'NN','বাজাররিজার্ভ':'NN',
'বাজারসহ':'NN','বাজারী':'NN','বাজারেও':'NN','বাজায়':'NN','বাজি':'NN','বাজিকররা':'NNS','বাজিকরে':'NNP',
'বাজিগরী':'NN','বাজিবাহন':'NN','বাজিমাত্':'NN','বাজিয়ে':'VBG','বাজির':'NNP','বাজিশিরা':'NN','বাজিয়ে':'VBG',
'বাজী':'NN','বাজীদার':'NN','বাজু':'NN','বাজুবন্ধ':'NN','বাজে':'NN','বাজেটঢাকায়':'NNP','বাজেটে':'NN',
'বাজেটের':'NN','বাজেমানুষ':'NN','বাজেয়াপ্ত':'NN','বাজেয়াপ্তকারী':'NN','বাজেয়াপ্তকৃত':'JJ','বাজেয়াপ্তর':'NN','বাজেয়াপ্রাপ্ত':'VBN',
'বাঞ্চনীয়':'VBN','বাঞ্ছা':'NN','বাঞ্ছিত':'JJ','বাঞ্জারা':'NN','বাঞ্জারী':'NN','বাট':'NNP','বাটকারা':'NN',
'বাটন':'NN','বাটপার':'NN','বাটপারি':'NNP','বাটমারি':'NN','বাটলারের':'NN','বাটসম্যান':'NNP','বাটা':'NN',
'বাটাম':'NN','বাটারিস':'NN','বাটি':'NN','বাটির':'NN','বাটিয়ারা':'NN','বাটে':'NN','বাটোর':'NN',
'বাটোয়ারায়':'NN','বাট্যুপুষ্পী':'NN','বাড়কঙ্ঘী':'NN','বাড়গুল্লা':'NN','বাড়ঙ্গু':'NN','বাড়তি':'NN','বাড়ন্ত':'JJ',
'বাড়বে':'NN','বাড়া':'NN','বাড়াচ্ছেন':'VBG','বাড়াতে':'NN','বাড়ানোর':'NN','বাড়ানোর':'NN','বাড়াবাড়ি':'NN',
'বাড়ার':'NN','বাড়ি-বাড়ি':'RB','বাড়ি':'NN','বাড়িওয়ালা':'NN','বাড়িতে':'NN','বাড়িয়ে':'VB','বাড়ির':'NN',
'বাড়ী':'NN','বাড়ীতে':'NN','বাড়ে':'NNS','বাডি':'NN','বাডুজ':'NN','বাডে':'NN','বাঢ়েল':'NN',
'বাণ-ফলা':'NN','বাণ':'NN','বাণগঙ্গা':'NN','বাণাবতী':'NN','বাণাসুতা':'NN','বাণিজ্য':'NN','বাণিজ্যকারী':'JJ',
'বাণিজ্যকেন্দ্র':'NN','বাণিজ্যমন্ত্রীতো':'NN','বাণিজ্যসুবিধাও':'NN','বাণিজ্যিক':'NN','বাণিজ্যিকীকরণের':'NN','বাণিজ্যে':'NN','বাণিজ্যেরই':'NN',
'বাণিনী':'NN','বাণু':'NN','বাণ্ডিল':'NN','বাত':'NN','বাতকর্মকারী':'NN','বাতগুল্ম':'NN','বাতঘ্নী':'NN',
'বাতঙ্কটক':'NN','বাতজ্বর':'NN','বাতণ্ড':'NN','বাতনাড়ী':'NN','বাতপর্যয়':'NN','বাতমৃগ':'NN','বাতরক্ত':'NN',
'বাতরোগ':'NN','বাতরোহিণী':'NN','বাতলান':'NN','বাতশূণ্য':'JJ','বাতানুকুল':'VBG','বাতানুকুলন':'NN','বাতানুকূলিত':'JJ',
'বাতান্ড':'NN','বাতাপি':'NN','বাতাশা':'NN','বাতাসা':'NN','বাতাসে':'NN','বাতাসের':'IN','বাতায়ন':'NN',
'বাতি':'NN','বাতিকগ্রস্ত':'JJ','বাতিকের':'NN','বাতির':'NN','বাতিলের':'NN','বাতেলা':'VB','বাতেলাবাজ':'JJ',
'বাতোদর':'NN','বাতোলম্বন':'NN','বাত্':'NN','বাত্সরিক':'JJ','বাত্সল্য':'NN','বাত্সায়ন':'NN','বাথান':'NN',
'বাদ-বিবাদ':'NN','বাদ':'NN','বাদই':'IN','বাদক':'NN','বাদগা':'NN','বাদবাকি':'JJS','বাদর':'NN',
'বাদলকে':'NNP','বাদলা':'JJ','বাদলের':'NNP','বাদশ':'CD','বাদশা':'NN','বাদশাহ':'NN','বাদশাহী':'NN',
'বাদসা':'NN','বাদানুবাদ':'NN','বাদাবন':'NN','বাদামা':'NN','বাদি':'NN','বাদিত':'JJ','বাদিয়া':'NN',
'বাদী':'NN','বাদীপক্ষ':'NN','বাদুনা':'NN','বাদুরজোলা':'NNP','বাদে':'NN','বাদ্ধ':'VBN','বাদ্য':'NN',
'বাদ্যযন্ত্র':'NN','বাধ':'NN','বাধক':'JJ','বাধবেই':'NN','বাধা':'NN','বাধাগ্রস্ত':'NN','বাধাদানকারী':'NN',
'বাধানিষেধ':'NN','বাধাপ্রদানকারী':'NN','বাধাবিঘ্নকে':'NN','বাধার':'NN','বাধাহীন':'JJ','বাধায়':'RB','বাধিত':'VBN',
'বাধিয়ে':'IN','বাধূল':'NN','বাধে':'NNS','বাধেঁর':'NN','বাধ্য':'NN','বাধ্যকারী':'JJ','বাধ্যতামুলক':'NN',
'বাধ্যবকরার':'NN','বাধ্যবাধ্যকতার':'NN','বাধ্যভদ্রলোক':'NN','বাধ্যলগি':'NN','বান':'NN','বানচাল':'NNP','বানপ্রস্থাশ্রমী':'JJ',
'বানপ্রস্থী':'NN','বানবর':'NN','বানবাসিকা':'NN','বানর':'NN','বানরের':'JJ','বানাই':'VB','বানাইতাম':'VB',
'বানাইবেন':'VB','বানাইলে':'IN','বানাইসে':'VB','বানাইয়া':'VBN','বানাচ্ছে':'VB','বানাচ্ছেন':'VBG','বানাতে':'VB',
'বানানকে':'NN','বানানটি':'VBG','বানানের':'VBG','বানানো':'NN','বানানোটা':'VBN','বানানোর':'NN','বানাবার':'VB',
'বানাবেন':'NN','বানারি':'NN','বানালে':'VBN','বানালেই':'NN','বানালেন':'VBN','বানায়':'NNS','বানায়উত্তর':'NNS',
'বানি':'NN','বানিজ্যর':'NN','বানিজ্যিক':'JJ','বানিয়ে':'NN','বানিয়েছিল':'VBN','বানিয়েছে':'VBN','বানিয়েছেন':'NN',
'বানী':'NN','বানুআটু':'NN','বানে':'NN','বানোয়াট':'NN','বান্জুল':'NN','বান্ডেল২':'NNP','বান্দরবন':'NN',
'বান্দ্রা':'NN','বান্ধব':'NN','বান্ধবীরা':'NN','বাপ-মা':'NN','বাপ':'NN','বাপকেও':'NN','বাপি':'NN',
'বাপুরে':'NN','বাপের':'NN','বাপ্':'NN','বাফতা':'NN','বাফুফে':'NN','বাফুফের':'NN','বাব-মার':'NN',
'বাবদ':'IN','বাবর':'NN','বাবরনামা':'NN','বাবরনেট':'NN','বাবরি':'NN','বাবলা':'NN','বাবস্থা':'NN',
'বাবা-মা':'NN','বাবাআমরা':'NN','বাবাও':'NN','বাবাছোড়ী':'NN','বাবাজী':'NNP','বাবামা':'NN','বাবামার':'NNS',
'বাবার':'NN','বাবু':'NN','বাবুকে':'NN','বাবুজী':'NN','বাবুনা':'NN','বাবুরা':'NNS','বাবুর্চি':'NN',
'বাবুল':'NN','বাবুলের':'NN','বাব্দ':'NN','বাব্বারে':'NN','বাম':'NN','বামকক্ষ':'NN','বামকী':'NN',
'বামদলের':'NN','বামদেবী':'NN','বামন':'NN','বামনদ্বাদশী':'NN','বামনপুরান':'NN','বামনাবতার':'NN','বামপন্থা':'NN',
'বামফ্রণ্ট':'NNP','বামফ্রণ্টের':'NN','বামফ্রন্টের':'NN','বামবার্গী':'NN','বামহাত':'NN','বামাকো':'NN','বামাক্ষ্যাপার':'NNP',
'বামাচরণ':'NNP','বামাচারী':'NN','বামাবর্ত':'NN','বামাবর্তী':'JJ','বামারের':'NNP','বামী':'NN','বামুনের':'NN',
'বাম্পার':'IN','বাযুপায়ী':'JJ','বাযেয়াপ্ত':'VBN','বার':'NN','বারংবার':'NN','বারই':'NN','বারওয়া':'NN',
'বারকাত':'NN','বারকোশ':'NN','বারগড়':'NN','বারজনমে':'NN','বারটা':'NN','বারণ':'NN','বারন':'NNP',
'বারনো':'VB','বারপেটা':'NN','বারবধূ':'NN','বারবাডোজ-বাসী':'NN','বারবাডোজের':'JJ','বারবাডোস':'NN','বারবাডোসীয়':'JJ',
'বারবানী':'NN','বারবারার':'NNP','বারবুডা':'NN','বারবেই':'NN','বারবেলায়':'NN','বারমুডা':'NN','বারমের':'NN',
'বারলে':'VBN','বারলো':'NN','বারসা':'NN','বারহবান':'NN','বারাঁ':'NN','বারাংবকি':'NN','বারাইছেন':'NN',
'বারাইতো':'NN','বারাকপুর':'NNP','বারাকাত':'NN','বারাঙ্গনা':'NN','বারাণসী':'NN','বারানো':'NN','বারান্দায়':'NN',
'বারাবানী':'NN','বারাবেন':'VB','বারামুলা':'NN','বারাসাত':'NN','বারি':'NN','বারিধি':'NN','বারিযন্ত্র':'NN',
'বারিরাশি':'NN','বারিরুহ':'NN','বারী':'NN','বারীন':'NNP','বারীন্দ্র':'NN','বারুণা':'NN','বারুণী':'NNP',
'বারুদ-গোলা':'NN','বারুদ':'NN','বারূণী':'NN','বারে':'NN','বারেখী':'NN','বারেবারে':'RB','বারের':'NN',
'বারো':'NN','বারোটার':'NN','বারোমাসী':'NN','বারোমাসের':'JJ','বারোমাস্যা':'NN','বার্কলিয়াম':'NN','বার্ণস্ট্যাণ্ডার্ডের':'NN',
'বার্ণিক':'JJ','বার্ণিকতা':'NN','বার্তাকার':'NN','বার্তালাপ':'NN','বার্থ':'NN','বার্ধক্য':'NN','বার্নিং':'VBG',
'বার্নিশ':'NN','বার্বিটিউরেট':'NN','বার্মা':'NN','বার্মাবাসী':'NN','বার্লিন':'NN','বার্ষিক':'NN','বার্ষিকোত্সব':'NN',
'বার্সা':'NN','বার্সাকে':'NN','বার্সায়':'NN','বার্সেলোনা':'NNP','বার্সেলোনাকে':'NN','বার্সেলোনায়':'NN','বাল':'NN',
'বালককে':'NN','বালকদের':'NN','বালকৃষ্ণ':'NN','বালকের':'NNP','বালখিল্য':'NN','বালগঙ্গাধর':'NN','বালগোবিন্দ':'NN',
'বালঙ্গা':'NN','বালচন্দ্র':'NN','বালটা':'NN','বালতি':'NN','বালন্তক্বাথ':'NN','বালপত্র-অধিকন্টক':'NN','বালপশ্যা':'NN',
'বালবন্ধু':'NN','বালভৃত':'NN','বালশশি':'NN','বালসূর্য':'NN','বালা':'NN','বালাঘাট':'NN','বালাদেশীদের':'NN',
'বালার্ক':'NN','বালাশি':'NN','বালাসোর':'NN','বালি':'NN','বালিকাকে':'NN','বালিকার':'NN','বালিগঞ্জ':'NNP',
'বালিপাথর':'NN','বালিময়':'JJ','বালির':'NN','বালিয়াড়ি':'NN','বালী-':'NNP','বালী-দেওয়ানগঞ্জ':'NNP','বালী-দেওয়ানগঞ্জের':'NNP',
'বালী':'NN','বালু':'NN','বালুকণাতে':'NN','বালুকাময়':'JJ','বালুচর':'NN','বালুচি':'NNP','বালুচিস্তান':'NN',
'বালুদানি':'NN','বালুভূমি':'NN','বালুর':'NN','বালুশাহী':'NN','বালেশ্বর':'NN','বাল্মিকী':'NN','বাল্মীকির':'NNP',
'বাল্মীকী':'NN','বাল্যকাল':'NN','বাল্যকালীন':'JJ','বাল্যখিল্য':'NN','বাল্যবিবাহ':'NN','বাল্যলীলা':'NN','বাল্যাবস্হা':'NN',
'বালয়':'NN','বাল‍্যবিবাহের':'NN','বাশ':'NN','বাশিত্ব':'NN','বাশিম':'NN','বাশুলীর':'NNP','বাশের':'NN',
'বাষট্টি':'NN','বাষট্টিতম':'JJ','বাষ্কল':'NN','বাষ্পকে':'NN','বাষ্পচালিত':'NN','বাষ্পমোচন':'NNP','বাষ্পরুদ্ধ':'JJ',
'বাষ্পশীল':'JJ','বাষ্পীকরণ':'NN','বাষ্পীভবন':'NN','বাষ্পীভূত':'VB','বাস':'NN','বাসও':'NN','বাসওয়ালাদের':'NNS',
'বাসক':'NN','বাসগুলির':'NNS','বাসগুলোতে':'NNS','বাসটা':'NN','বাসতবে':'NN','বাসদ':'NN','বাসনপত্র':'NN',
'বাসনা':'NN','বাসনাহীন':'JJ','বাসনের':'NN','বাসন্তি':'JJ','বাসন্তী':'NN','বাসব':'NNP','বাসবার':'NN',
'বাসভবন':'NN','বাসমতি':'NN','বাসযোগ্য':'JJ','বাসর':'NN','বাসরঘরের':'NN','বাসস্থান':'NN','বাসা':'NN',
'বাসাওয়ালাদের':'NNS','বাসার':'NN','বাসি':'NN','বাসিন্দা':'NN','বাসিন্দাদের':'NN','বাসিন্দারা':'NNS','বাসিন্দারাবিস্তারিত':'NNS',
'বাসির':'NN','বাসিষ্ঠী':'NN','বাসী':'NN','বাসীর':'NN','বাসু':'NN','বাসুদেব':'NN','বাসুদেবের':'NNP',
'বাসুদেবোপনিষদ':'NN','বাসুন':'NN','বাসুপূজ্য':'NN','বাসে':'NN','বাসের':'NN','বাসো':'NN','বাসোন্ধি':'NN',
'বাস্কেট':'NN','বাস্তব':'JJ','বাস্তবটা':'NN','বাস্তবতার':'NN','বাস্তববোধের':'NN','বাস্তবভিত্তিক':'JJ','বাস্তবসম্মত':'JJ',
'বাস্তবায়ন':'NN','বাস্তবায়ন':'NN','বাস্তবায়নে':'NN','বাস্তবায়িত':'NN','বাস্তবায়িতও':'VBN','বাস্তবায়োন':'NN','বাস্তবিক':'NN',
'বাস্তবে':'RB','বাস্তবের':'JJ','বাস্তবে্‌':'NN','বাস্তসম্মত':'JJ','বাস্তু-কাঠ':'NN','বাস্তুকলা':'NN','বাস্তুতন্ত্র':'NN',
'বাস্তুবিদ':'NN','বাস্তুশাস্ত্র':'NN','বাস্তুশিল্প':'NN','বাস্তুসাপ':'NN','বাস্প':'NN','বাহ':'NN','বাহদূরা':'NN',
'বাহন':'NN','বাহনহীন':'JJ','বাহবা':'NN','বাহভালোই':'NN','বাহরিন':'NN','বাহরিনি':'NN','বাহলীক':'NN',
'বাহাত্তর':'NN','বাহাত্তরতম':'JJ','বাহাদুর':'NN','বাহাদুরির':'NN','বাহাদুরের':'VB','বাহানা':'NN','বাহানায়':'NN',
'বাহান্নতম':'JJ','বাহামা-বাসী':'NN','বাহামাবাসী':'NN','বাহামাস':'NN','বাহার':'NN','বাহারগুর্জরী':'NN','বাহারনশাখ':'NN',
'বাহাস':'NN','বাহাসে':'NN','বাহিকা':'NN','বাহিনি':'NN','বাহিনির':'NNS','বাহিনী':'NN','বাহিনীর':'NNS',
'বাহির':'RB','বাহিরমুখী':'JJ','বাহিরে':'NN','বাহী':'NN','বাহীনির':'NNS','বাহীনিরই':'NN','বাহীনী':'NNS',
'বাহু':'NN','বাহুদা':'NN','বাহুবন্ধনী':'NN','বাহুবল':'NN','বাহুবিশিষ্ট':'JJ','বাহুভেদে':'NN','বাহুমূল':'NN',
'বাহুযুক্ত':'JJ','বাহুল':'NN','বাহুশালী':'NN','বাহুহীন':'JJ','বাহে':'NN','বাহ্মনী':'NN','বাহ্য-পথ':'NN',
'বাহ্যকর্ণ':'NN','বাহ্যজ্ঞানরহিত':'JJ','বাহ্যত্বক':'NN','বাহ্যবিদ্রধি':'NN','বাহ্যাড়ম্বর':'NN','বাহ্যিক':'NN','বাহ্যেন্দ্রিয়':'NN',
'বাহ্লিক':'NN','বা্চ্চু':'NN','বাৎসরিক':'NN','বাড়ছিলো':'VBG','বাড়ছে':'RB','বাড়ছেই':'NN','বাড়ছেপোশাক':'NN',
'বাড়তি':'NN','বাড়তেই':'NN','বাড়তেছে':'VB','বাড়তো':'NN','বাড়বে':'VB','বাড়বেই':'NN','বাড়বেতাহলে':'NNS',
'বাড়বেপকেট':'NN','বাড়বে২০৩০':'NN','বাড়ল':'NN','বাড়লেই':'NN','বাড়লো':'NN','বাড়া':'NN','বাড়াইলেই':'NN',
'বাড়াচ্ছে':'NN','বাড়াটা':'NN','বাড়াতে':'NN','বাড়ান':'NN','বাড়ানসামনে':'VB','বাড়ানো':'NN','বাড়ানোর':'NN',
'বাড়াবাড়ি':'NN','বাড়াবে':'VB','বাড়ার':'NN','বাড়াল':'VBN','বাড়ালে':'RB','বাড়ালেই':'NN','বাড়ালেনকলচার্জ':'NN',
'বাড়ায়':'NN','বাড়ি-ঘর':'NN','বাড়িওয়ালার':'NN','বাড়িওয়ালারা':'NNS','বাড়িঘর':'NN','বাড়িজিপিওপূর্ত':'NN','বাড়িটি':'NN',
'বাড়িতে':'NN','বাড়িভাড়া':'NN','বাড়ির':'NN','বাড়িয়ে':'NN','বাড়িয়েও':'NN','বাড়িয়েছেন':'NN','বাড়ী':'NN',
'বাড়ীওয়ালা':'NN','বাড়ীঘর':'NN','বাড়ীতে':'NN','বাড়ুক':'NN','বাড়ে':'NN','বাড়েগার্মেন্টসের':'NN','বাড়েদুই':'NN',
'বাড়েনি':'NN','বাড়োলে':'NN','বাঢ়ালে':'NN','বায়কঙ্কত':'NN','বায়গীর':'NN','বায়জীদ':'NN','বায়না':'NN',
'বায়বরঙ্গ':'NN','বায়বিড়ঙ্গ':'NN','বায়বীয়':'JJ','বায়রণের':'NN','বায়রিকী':'NN','বায়ানদ':'NN','বায়াররা':'NN',
'বায়াসড':'NN','বায়িং':'NN','বায়ু':'NN','বায়ুকণার':'NN','বায়ুগতিচালিত':'JJ','বায়ুগতিবিজ্ঞান':'NN','বায়ুচাপ':'NN',
'বায়ুতে':'NN','বায়ুদূষণও':'NN','বায়ুদেব':'NN','বায়ুনিরোধী':'JJ','বায়ুপ্রবাহ':'NN','বায়ুবাদ্য':'NN','বায়ুমণ্ডল':'NN',
'বায়ুমন্ডল':'NN','বায়ুমন্ডলীয়':'JJ','বায়ুযন্ত্র':'NN','বায়ুযান-চালক':'NN','বায়ুর':'NN','বায়ুশুল':'NN','বায়ুশূণ্য':'JJ',
'বায়ুসেনা':'NN','বায়ুস্তর':'NN','বায়ুহীন':'JJ','বায়ো':'NN','বায়োটেকনোলজি':'NN','বায়োডাটা':'NN','বায়োফ্লেবিনোইড':'NN',
'বায়োমেট্রিক':'NN','বায়োলজি':'NN','বি-ভিটামিনের':'NN','বি.':'NNP','বি':'NN','বিঁধানো':'NN','বিংশ':'NN',
'বিংশতিতম':'JJ','বিআইডব্লিইটিএ':'NN','বিআরটিএ':'NN','বিউগল':'NN','বিএ':'NN','বিএইচবিএফসি':'NN','বিএএফ':'NN',
'বিএড':'NN','বিএনপি':'NN','বিএনপিও':'NN','বিএনপিওয়ালাদের':'NN','বিএনপিওয়ালারাতো':'NN','বিএনপিকে':'NN','বিএনপিজামাকে':'NN',
'বিএনপিজামাতিদের':'NN','বিএনপিজামাতের':'NN','বিএনপিজামায়তিরা':'NN','বিএনপিজামায়াতের':'NN','বিএনপিজীবিদের':'NN','বিএনপিতে':'NN','বিএনপিপুলিশের':'NN',
'বিএনপিফোবিয়া':'NN','বিএনপির':'NN','বিএনপি–জামাত':'NN','বিএম':'NN','বিএমডব্লিউ':'NN','বিএমডিসি':'NN','বিএসআই':'NN',
'বিএসএফ':'NN','বিএসছি':'NN','বিএসপি':'NN','বিওআই':'NN','বিকট':'NN','বিকম্পন':'NN','বিকর্ণ':'NN',
'বিকল':'NN','বিকলাঙ্গ':'NN','বিকল্প':'NN','বিকল্পধারার':'NN','বিকল্পহীন':'JJ','বিকল্পহীনতা':'NN','বিকল্পী':'JJ',
'বিকল্পের':'NN','বিকল্পয়ুক্ত':'JJ','বিকশিত':'NN','বিকা':'NN','বিকানির':'NN','বিকার':'NN','বিকারগ্রস্ত':'JJ',
'বিকারতত্ত্ব':'NN','বিকারতাত্ত্বিক':'JJ','বিকারবিজ্ঞানী':'NN','বিকারহীনতা':'NN','বিকাল':'NN','বিকালের':'NN','বিকাশ':'NN',
'বিকাশমূলক':'JJ','বিকাশে':'NN','বিকিকিনি':'NN','বিকিরণ-চিকিত্সা':'NN','বিকিরণ':'NN','বিকিরিত':'JJ','বিকুক্ষি':'NN',
'বিকৃত':'NN','বিকৃতির':'NN','বিকেন্দ্রীকরণ':'NN','বিকেল':'NN','বিকেলবেলায়':'NN','বিকেলেই':'NN','বিকেশ':'NN',
'বিকোক':'NN','বিক্রম':'NN','বিক্রমাদিত্য':'NN','বিক্রমার্ক':'NN','বিক্রমী-সংবত':'NN','বিক্রমীয়':'JJ','বিক্রমে':'NN',
'বিক্রান্ত':'NN','বিক্রি':'NN','বিক্রিনো':'VB','বিক্রিয়া':'NN','বিক্রিয়া':'NN','বিক্রিয়ায়':'NN','বিক্রী-কক্ষ':'NN',
'বিক্রীত':'NN','বিক্রেতা':'NN','বিক্রেতার':'NN','বিক্রয়-কক্ষ':'NN','বিক্রয়কর':'NN','বিক্রয়যোগ্য':'JJ','বিক্রয়ের':'NN',
'বিক্ষত':'NN','বিক্ষুব্ধ':'JJ','বিক্ষেপ':'NN','বিক্ষোব্ধ':'NN','বিক্ষোভ':'NN','বিক্ষোভকারীদের':'NN','বিখন্ডন':'NN',
'বিখ্যাত':'NN','বিগ':'NN','বিগড়ানো':'NN','বিগত':'NN','বিগলন':'NN','বিগলিত':'JJ','বিগহর্ন':'NN',
'বিগা':'NN','বিগ্রহ':'NN','বিগ্রহবাক্যহীন':'JJ','বিগড়ে':'VB','বিঘটন':'NN','বিঘা':'NN','বিঘ্ন':'NN',
'বিঘ্নকারী':'JJ','বিঘ্নহর':'NN','বিচ':'NN','বিচক্র':'NN','বিচক্ষণ':'JJ','বিচক্ষণতা':'NN','বিচরণ':'NN',
'বিচল':'JJ','বিচলন':'NN','বিচার-বিমর্শ':'NN','বিচার':'NN','বিচারক':'NN','বিচারকদের':'NN','বিচারটা':'NN',
'বিচারণীয়':'NN','বিচারনো':'VB','বিচারপতি':'NN','বিচারপতিরা':'NN','বিচারবহিরভুতভাবে':'NN','বিচারবান':'NN','বিচারবুদ্ধি':'NN',
'বিচারশীল':'NN','বিচারসম্পন্ন':'NN','বিচারাধীন':'JJ','বিচারালয়':'NN','বিচারালয়ের':'NN','বিচারু':'NN','বিচারে':'RB',
'বিচারের':'NN','বিচার্য':'JJ','বিচার্যের':'NN','বিচালি':'NN','বিচিত্র':'NN','বিচিত্রবীর্য':'NN','বিচিত্রানুষ্ঠান':'NN',
'বিচেতন':'NN','বিচেতনাবস্থা':'NN','বিচ্ছিন্ন':'NN','বিচ্ছিন্নতাবাদী':'JJ','বিচ্ছিন্নতাবাদীদের':'NN','বিচ্ছুরণ':'NN','বিচ্ছুরিত':'JJ',
'বিচ্ছেদ':'NN','বিচ্ছেদে':'NN','বিচ্যুত':'NN','বিচ্যূত':'NN','বিছা':'NN','বিছানাপত্র':'NN','বিছানো':'NN',
'বিছায়েছ':'NN','বিছের':'NN','বিজকোষ':'NN','বিজন':'NN','বিজনোর':'NN','বিজয়':'NN','বিজরা':'NN',
'বিজল':'NN','বিজলী':'NN','বিজলীর':'NN','বিজাতীয়':'JJ','বিজানু':'NN','বিজারণ':'NN','বিজিএমইএ':'NN',
'বিজিগীষু':'JJ','বিজিঘৃক্ষু':'JJ','বিজিত':'JJ','বিজিবি':'NN','বিজিয়ানগরম':'NN','বিজুরি':'NN','বিজেপি':'NN',
'বিজেপির':'NN','বিজোড়':'NN','বিজোহা':'NN','বিজোড়':'JJ','বিজ্জুহা':'NN','বিজ্ঞ':'NN','বিজ্ঞর':'NN',
'বিজ্ঞাত':'JJ','বিজ্ঞান':'NN','বিজ্ঞানবিভাগের':'NN','বিজ্ঞানভিত্তিক':'JJ','বিজ্ঞানমনষ্ক':'NN','বিজ্ঞানিরা':'NN','বিজ্ঞানীদের':'NN',
'বিজ্ঞানীর':'NN','বিজ্ঞানী‌দের':'NN','বিজ্ঞানের':'NN','বিজ্ঞাপন':'NN','বিজ্ঞাপনের':'NN','বিজয়':'NN','বিজয়গুপ্তের':'NNP',
'বিজয়দশমী':'NN','বিজয়নন্দন':'NN','বিজয়লক্ষ্মী':'NN','বিজয়স্তম্ভ':'NN','বিজয়া':'NN','বিজয়াভিলাষী':'JJ','বিজয়াসপ্তমী':'NN',
'বিজয়ী':'NN','বিজয়ের':'NN','বিজয়োল্লাস':'NN','বিট':'NN','বিটকয়েন':'NN','বিটপ':'NN','বিটপে':'NN',
'বিটভূত':'NN','বিটরুট':'NN','বিটা':'NN','বিটিআরসি':'NN','বিটিআরসির':'NN','বিটিভি':'NN','বিঠুরে':'NNP',
'বিড':'NN','বিড়বিড়':'NN','বিড়ম্বনা':'NN','বিড়াল':'NN','বিড়ালাক্ষী':'NN','বিড়ালিনী':'NN','বিড়ে':'NN',
'বিণ্ডহোক':'NN','বিতণ্ডা':'NN','বিতণ্ডাবাদী':'JJ','বিতরণ':'NN','বিতরণকারী':'NN','বিতরণকেন্দ্র':'NN','বিতরণনো':'VB',
'বিতরণে':'NN','বিতরন':'NN','বিতরিত':'JJ','বিতরে':'NN','বিতর্কমূলক':'JJ','বিতর্করচনার':'NN','বিতর্কহীন':'NN',
'বিতর্কাতীত':'JJ','বিতর্কে':'NN','বিতল':'NN','বিতশ্রদ্ধ':'NN','বিতস্রদ্ধ':'VB','বিতা':'NN','বিতাড়িত':'VB',
'বিতান':'NN','বিতারণের':'NN','বিতারন':'VB','বিতাড়ণে':'VB','বিতাড়িত':'JJ','বিতৃষ্ণ':'NN','বিতে':'NN',
'বিত্ত':'NN','বিত্তপ্রদানকারী':'JJ','বিত্তবান':'VB','বিত্তবানদের':'NN','বিত্তমন্ত্রী':'NN','বিত্তসম্পর্কিত':'JJ','বিত্তায়ন':'NN',
'বিথুয়া':'NN','বিদগ্ধাজীর্ণ':'NN','বিদগ্ধাম্লদৃষ্টি':'NN','বিদদের':'NN','বিদর্ভ':'NN','বিদর্ভি':'NN','বিদায়':'NN',
'বিদারক':'NN','বিদারিত':'JJ','বিদায়':'NN','বিদায়ে':'NN','বিদিত':'JJ','বিদিশা':'NN','বিদীর্ণ':'JJ',
'বিদু':'NN','বিদুষক':'NN','বিদুৎ':'NN','বিদূষক':'NN','বিদূষী':'JJ','বিদেঘ':'NN','বিদেশ-বিদেশ':'NN',
'বিদেশ':'NN','বিদেশনীতি':'NN','বিদেশযাত্রা':'NN','বিদেশি':'NN','বিদেশী':'NN','বিদেশীদের':'NN','বিদেশীরা':'NNS',
'বিদেশীয়':'JJ','বিদেশে':'NN','বিদেশেও':'NN','বিদেহ':'NN','বিদ্ঘুটে':'NN','বিদ্ধ':'NN','বিদ্ধস্থ':'VBN',
'বিদ্বজ্জনের':'NN','বিদ্বান':'NN','বিদ্বেষধিক্‌':'NN','বিদ্বেষপূর্ণ':'JJ','বিদ্বেষমূলক':'JJ','বিদ্বেষিণী':'NN','বিদ্যমান':'NN',
'বিদ্যা':'NN','বিদ্যাকে':'NN','বিদ্যাচর্চার':'NN','বিদ্যাধর':'NN','বিদ্যাপতি':'NN','বিদ্যাপীঠের':'NN','বিদ্যাপ্রেমী':'NN',
'বিদ্যার্থিনী':'NN','বিদ্যালয়':'NN','বিদ্যালয়গুলির':'NN','বিদ্যালয়ের':'JJ','বিদ্যাশূণ্য':'JJ','বিদ্যাসাগর':'NNP','বিদ্যুঃ':'NN',
'বিদ্যুচ্চুম্বকীয়':'JJ','বিদ্যুত':'NN','বিদ্যুতজ্জিহ্বা':'NN','বিদ্যুতপাত':'NN','বিদ্যুতমালী':'NN','বিদ্যুতশক্তি':'NN','বিদ্যুতা':'NN',
'বিদ্যুতের':'NN','বিদ্যুত্':'NN','বিদ্যুত্কেন্দ্র':'NN','বিদ্যুত্গতিতে':'NN','বিদ্যুত্পর্ণী':'NN','বিদ্যুত্প্রভ':'NN','বিদ্যুত্্':'NN',
'বিদ্যুবিহ্বা':'NN','বিদ্যুল্লেখা':'NN','বিদ্যুুতের':'NN','বিদ্যুৎকেন্দ্রের':'NN','বিদ্যুৎতের':'NN','বিদ্রধি':'NN','বিদ্রাবণ':'NN',
'বিদ্রুপ':'NN','বিদ্রোহী':'NN','বিদ্রোহের':'NN','বিধবংসী':'NN','বিধবা':'NN','বিধবার':'JJ','বিধবাশ্রম':'NN',
'বিধর্মীদের':'NNS','বিধস্ত':'VBN','বিধা':'NN','বিধান-পরিষদ্':'NN','বিধান':'NN','বিধানপরিষদ':'NN','বিধানবাদ':'NN',
'বিধানমূলক':'JJ','বিধানসভা':'NN','বিধারা':'NN','বিধায়':'IN','বিধায়ক':'NN','বিধি-পালন':'NN','বিধি':'NN',
'বিধিকারি':'NN','বিধিনিষেধ':'NN','বিধিপূর্বক':'RB','বিধিবদ্ধকরণ':'NN','বিধিবিধান':'NN','বিধিবিরুদ্ধ':'JJ','বিধিমত':'RB',
'বিধিমালা':'NNS','বিধির':'NN','বিধিসম্মত':'JJ','বিধিহীনভাবে':'RB','বিধু':'NN','বিধুপ্রিয়া':'NN','বিধূলী':'NN',
'বিধে':'NN','বিধেয়ের':'NN','বিধেয়':'NN','বিধ্বংস':'NN','বিধ্বংসী':'JJ','বিধ্বস্ত':'VB','বিন':'NN',
'বিনজবাদ':'NN','বিনটিয়ন':'NN','বিনত':'NN','বিনতানন্দন':'NN','বিনতি':'NN','বিনদু':'NN','বিনপি':'NN',
'বিনমন':'NN','বিনম্র':'JJ','বিনম্রতা':'NN','বিনয়':'NN','বিনষ্ট':'NN','বিনা':'NN','বিনাপ্রতিদ্বন্দ্বিতায়':'VBN',
'বিনামুল্যে':'JJ','বিনামূল্য':'NN','বিনামূল্যের':'JJ','বিনাশ':'NN','বিনাশক':'JJ','বিনাশকর্তা':'NN','বিনাশকারক':'JJ',
'বিনাশকারী':'NN','বিনাশন':'NN','বিনাশশীল':'JJ','বিনাশাভাব':'NN','বিনাশিত':'JJ','বিনাশুল্কে':'NN','বিনাশোন্মুখ':'JJ',
'বিনাসুদে':'JJS','বিনায়ক':'NN','বিনি':'NNP','বিনিদ্র':'JJ','বিনিময়':'NN','বিনিময়কৃত':'JJ','বিনিময়পত্র':'NN',
'বিনিময়েই':'NN','বিনিয়োগ':'NN','বিনিয়োগকারী':'NNS','বিনির্মাণের':'NN','বিনিষ্ট':'JJ','বিনিয়োগ':'NN','বিনিয়োগ-তালিকা':'NN',
'বিনিয়োগ':'NN','বিনিয়োগকারীদের':'NNS','বিনিয়োগকে':'NN','বিনিয়োগযোগ্য':'NN','বিনিয়োগিরা':'NN','বিনিয়োগের':'NN','বিনী':'JJ',
'বিনীতভাবে':'NN','বিনুনি':'NN','বিনে':'NN','বিনেপয়সায়':'NN','বিনোদ':'NN','বিনোদনপ্রিয়তা':'NN','বিনোদনের':'NN',
'বিনোদিত':'JJ','বিনোদিনী':'NNP','বিনোদোন':'NN','বিনোবা':'NNP','বিনোভা':'NN','বিনোয়োগ':'NN','বিন্ডুল':'NN',
'বিন্তি':'NN','বিন্দাস':'JJ','বিন্দি':'NN','বিন্দু':'NN','বিন্দুকে':'NN','বিন্দুগামী':'JJ','বিন্দুগুলিতে':'NN',
'বিন্দুতে':'NN','বিন্দুমাত্র':'RB','বিন্দুর':'NN','বিন্ধাবলি':'NN','বিন্ধ্য':'NN','বিন্ধ্যায়ন':'NN','বিন্নাঘাস':'NN',
'বিন্নি':'NN','বিন্যস্ত':'NN','বিনয়':'NN','বিনয়পূর্বক':'RB','বিনয়বিধি':'NN','বিনয়ী':'JJ','বিনয়ের':'NN',
'বিপক্ষ':'NN','বিপক্ষী':'JJ','বিপক্ষে':'NN','বিপক্ষেই':'IN','বিপক্ষের':'NN','বিপজ্জনক':'NN','বিপঞ্চী':'NN',
'বিপণন':'NN','বিপণি':'NN','বিপত্নীক':'NN','বিপথ':'NN','বিপথে':'VB','বিপদ':'NN','বিপদগর্ভ':'JJ',
'বিপদগ্রস্থ':'JJ','বিপদজনক':'JJ','বিপদাপন্ন':'JJ','বিপদে':'NN','বিপনন':'NN','বিপনীবিতান':'NN','বিপন্ন':'JJ',
'বিপরিতে':'NN','বিপরীতপন্থী':'JJ','বিপরীতমুখী':'JJ','বিপরীতার্থক':'NN','বিপরীতে':'JJ','বিপর্যস্ত':'NN','বিপর্যয়':'NN',
'বিপর্যয়জনিত':'JJ','বিপর্যয়ের':'NN','বিপাক':'NN','বিপাপা':'NN','বিপাসনা':'NN','বিপি':'NN','বিপিএলকে':'NN',
'বিপিন':'NN','বিপিনতিলকা':'NN','বিপিনবিহারী':'JJ','বিপিসির':'NN','বিপুল':'NN','বিপুলভাবে':'RB','বিপুলসংখ্যাক':'JJ',
'বিপুলা':'NN','বিপ্র':'NN','বিপ্লব':'NN','বিপ্লববাদী':'JJ','বিপ্লবাত্মক':'JJ','বিপ্লবী':'NN','বিপ্লবে':'NN',
'বিফ':'NN','বিফলতা':'NN','বিফলেও':'NN','বিবত্সা':'NN','বিবর':'NN','বিবরণী':'NN','বিবরন':'NN',
'বিবরিতিটিতে':'NN','বিবর্ণ':'NN','বিবর্তনের':'NN','বিবর্তিত':'JJ','বিবর্ধক':'JJ','বিবসন':'JJ','বিবস্ত্র':'NN',
'বিবস্বান':'NN','বিবাগী':'NN','বিবাদগ্রস্থ':'JJ','বিবাদরহিত':'JJ','বিবাদাস্পদ':'JJ','বিবাদে':'NN','বিবাহ-বিচ্ছেদ':'NN',
'বিবাহ':'NN','বিবাহবিচ্ছিন্ন':'JJ','বিবাহবিচ্ছেদ':'NN','বিবাহযোগ্য':'JJ','বিবাহিত':'NN','বিবাহে':'NN','বিবি':'NNP',
'বিবিএস':'NN','বিবিক্ত':'NN','বিবিত্সু':'NN','বিবিধ':'NN','বিবির':'NN','বিবুধপ্রিয়া':'NN','বিবৃতি':'NN',
'বিবৃতিতে':'NN','বিবেক':'NN','বিবেকজ্ঞান':'NNP','বিবেকবান':'JJ','বিবেকবানদের':'NNS','বিবেকবোধ':'NN','বিবেকভাই':'NN',
'বিবেকশীল':'JJ','বিবেকহীনদের':'JJ','বিবেকাধিকার':'NN','বিবেকানন্দ':'NN','বিবেকে':'NN','বিবেগহীনা':'NN','বিবেচক':'NN',
'বিবেচনাবোধ':'NN','বিবেচনার':'NN','বিবেচনায়':'VBG','বিবেচানায়':'NN','বিবেচিত':'JJ','বিবেব':'NN','বিবোচনা':'NN',
'বিব্রত':'VBN','বিব্রতবধ':'NN','বিভক্ত':'NN','বিভক্তির':'NN','বিভত্স':'NN','বিভব':'NN','বিভাকর':'NN',
'বিভাগ':'NN','বিভাগীয়':'JJ','বিভাগে':'NN','বিভাগের':'NN','বিভাজক':'JJ','বিভাজন':'NN','বিভাজিত':'NN',
'বিভাজ্য':'JJ','বিভাণ্ডক':'NN','বিভাবসু':'NN','বিভিন্ন':'NN','বিভীষণ':'NN','বিভূ':'NN','বিভূতি':'NN',
'বিভূষিত':'JJ','বিভেদ':'NN','বিভোর':'NN','বিভ্রম':'NN','বিভ্রাটে':'NNP','বিভ্রান্ত':'NN','বিভ্রান্তকর':'JJ',
'বিভ্রান্তি':'NN','বিভৎসতার':'NN','বিমর্ষ':'NN','বিমলধ্বনি':'NN','বিমলনাথ':'NN','বিমলাদ্রি':'NN','বিমা':'NN',
'বিমাতাকে':'NN','বিমান-বিজ্ঞান':'NN','বিমান':'NN','বিমানচালকও':'NN','বিমানবন্দর':'NN','বিমানবন্দরের':'NN','বিমানবাহিনীর':'NN',
'বিমানম':'NN','বিমানযাত্রা':'NN','বিমানযাত্রীদের':'NNS','বিমানশালা':'NN','বিমানসেবিকা':'NN','বিমানের':'NN','বিমুখ':'JJ',
'বিমুখতা':'NN','বিমূর্ত':'NN','বিমোচন':'NN','বিমোহক':'NN','বিম্পি':'NN','বিম্পির':'NN','বিম্পি–জামাতের':'NN',
'বিম্ব':'NN','বিয়ে':'NN','বিরক্ত':'NN','বিরক্তভাবে':'RB','বিরক্তি':'NN','বিরক্তিকর':'VBG','বিরচিত':'JJ',
'বিরজ':'NN','বিরঞ্জক':'NN','বিরণ':'NN','বিরতি':'NN','বিরতো':'NN','বিরদ্দ':'IN','বিরধি':'NN',
'বিরধী':'NNS','বিরপাড়া':'NN','বিরল':'JJ','বিরলিকা':'NN','বিরস':'JJ','বিরহ-বেদনা':'NN','বিরহ':'NN',
'বিরহহীন':'JJ','বিরহা':'NN','বিরহিণী':'NN','বিরহিনী':'JJ','বিরহী':'NN','বিরা':'NN','বিরাগভাজন':'NN',
'বিরাজমান':'NN','বিরাজে':'VB','বিরাট':'NN','বিরাটভাবে':'NN','বিরাটস্বরাজ':'NN','বিরাণভূমি':'NN','বিরাধ':'NN',
'বিরানব্বই':'NN','বিরানব্বইতম':'JJ','বিরাম':'NN','বিরাশিতম':'JJ','বিরিয়ানি':'NN','বিরিয়ানে':'NNP','বিরুঢ়ক':'NN',
'বিরুদ্দহে':'IN','বিরুদ্ধ':'NN','বিরুদ্ধরূপক':'NN','বিরুদ্ধাচারী':'JJ','বিরুদ্ধে':'RB','বিরুদ্ধেই':'IN','বিরুদ্বে':'NN',
'বিরুধনগর':'NN','বিরুধী':'NNS','বিরুধ্যে':'IN','বিরুপ':'NN','বিরু‌দ্ধে':'IN','বিরূদ্দের':'NN','বিরূপ':'NN',
'বিরে':'NN','বিরোধিদল':'NN','বিরোধীতা':'NN','বিরোধীদল':'NN','বিরোচন-সুত':'NN','বিরোচনা':'NN','বিরোদ্দে':'NN',
'বিরোধ':'NN','বিরোধকৃত':'JJ','বিরোধাভাস':'NN','বিরোধি':'NNS','বিরোধিতা':'NN','বিরোধিতাকারিদের':'NNS','বিরোধিতায়':'NN',
'বিরোধিদের':'NN','বিরোধী':'NN','বিরোধীও':'NNS','বিরোধীতা':'NN','বিরোধীতার':'NN','বিরোধীদের':'NN','বিরোধীদেরকে':'NNS',
'বিরোধে':'NN','বিরোধোপমা':'NN','বিল':'NN','বিলকুল':'RB','বিলক্ষণতা':'NN','বিলগী':'NN','বিলটিতে':'NN',
'বিলনা':'NN','বিলনী':'NN','বিলবিদ্যুৎ':'NN','বিলবোর্ড':'NNP','বিলবোর্ডে':'NN','বিলম্ব':'NN','বিলম্বি':'NN',
'বিলম্বিতগতি':'NN','বিলম্বের':'NN','বিলা':'NN','বিলাতি':'JJ','বিলাপ':'NN','বিলাবলী':'NN','বিলাস':'NN',
'বিলাসবহুল':'JJ','বিলাসহীনতা':'NN','বিলাসিতার':'NN','বিলাসিনী':'NN','বিলাসী':'JJ','বিলাসীতার':'NN','বিলি':'NN',
'বিলিন':'VBD','বিলিয়ন':'NN','বিলিয়ন':'NN','বিলিয়নপতি':'JJ','বিলিয়নিয়ার':'NN','বিলিয়ার্ড':'NN','বিলীন':'NN',
'বিলুপুরম':'NN','বিলুপ্ত':'NN','বিলুপ্তি':'NN','বিলে':'NN','বিলেতী':'JJ','বিলেপন':'VB','বিলোকিত':'JJ',
'বিলোটক':'NN','বিলোড়িত':'JJ','বিলোপ':'NN','বিল্টু':'NNP','বিল্ডার':'NN','বিল্না':'NN','বিল্ব':'NN',
'বিল্বমঙ্গলে':'NNP','বিল্লীলোটন':'NN','বিলয়':'NN','বিশ':'NN','বিশকোপরা':'NN','বিশখাপর':'NN','বিশগুণ':'NNS',
'বিশদ':'NN','বিশসন':'NN','বিশাখ':'NN','বিশাখাপত্তনম':'NN','বিশারদ':'NN','বিশাল':'NN','বিশালকায়':'JJ',
'বিশালতম':'JJ','বিশালতা':'NN','বিশালাকায়':'JJ','বিশালাক্ষ':'NN','বিশালাক্ষী':'JJ','বিশিষ্ট':'NN','বিশুদ্ধ':'NN',
'বিশুদ্ধকরনেরও':'NN','বিশুদ্ধতা':'NN','বিশুদ্ধরূপে':'JJ','বিশুদ্ধি':'NN','বিশৃংখলা':'NN','বিশৃঙ্কহলা':'NN','বিশৃঙ্খলতা':'NN',
'বিশৃঙ্খলায়':'NN','বিশে':'NN','বিশেষ':'NN','বিশেষঅজ্ঞদের':'NNS','বিশেষক':'NN','বিশেষকরে':'RB','বিশেষজ্ঞ':'NN',
'বিশেষজ্ঞদের':'NNS','বিশেষজ্ঞের':'NN','বিশেষণ':'NN','বিশেষণযুক্ত':'JJ','বিশেষত':'NN','বিশেষতঃ':'RB','বিশেষত্ব':'NN',
'বিশেষত্বহীন':'JJ','বিশেষন':'NN','বিশেষভাবে':'RB','বিশেষাধিকার':'NN','বিশেষার্থালঙ্কার':'NN','বিশেষিত':'JJ','বিশেষীকরণ':'NN',
'বিশেষে':'RB','বিশেষের':'NN','বিশেষ্যের':'NN','বিশোকষষ্টী':'NN','বিশোধক':'JJ','বিশোধণ':'NN','বিশোয়াস':'NNP',
'বিশোয়াসের':'NN','বিশ্ব-চরাচর':'NN','বিশ্ব':'NN','বিশ্বকর্মা':'NN','বিশ্বকাপএবং':'NN','বিশ্বকাপকে':'NN','বিশ্বকাপটি':'NN',
'বিশ্বকাপপাকিস্তান':'NN','বিশ্বকাপে':'NN','বিশ্বকাপের':'NN','বিশ্বকোষ':'NN','বিশ্বগন্ধি':'NN','বিশ্বগুরু':'NN','বিশ্বচ্যাম্পিয়ন':'NN',
'বিশ্বজগত্':'NN','বিশ্বজনীন':'JJ','বিশ্বজনীনতায়':'NN','বিশ্বজয়':'NN','বিশ্বজিত্':'NN','বিশ্বজুড়ে':'RB','বিশ্বজুড়ে':'NN',
'বিশ্বজ্যোতিষ':'NN','বিশ্বজয়ী':'JJ','বিশ্বদেব':'NN','বিশ্বদ্যালয়ের':'NNP','বিশ্বধাত্রী':'NN','বিশ্বধেনু':'NN','বিশ্বনন্দিত':'RB',
'বিশ্বনাথ':'NN','বিশ্বনাথকেও':'NNP','বিশ্বনাথপ্রতাপ':'NNP','বিশ্বপতি':'NN','বিশ্বপ্রসিদ্ধ':'NN','বিশ্ববর':'NN','বিশ্ববানী':'JJ',
'বিশ্ববাসী':'IN','বিশ্ববাসীকে':'NN','বিশ্ববাসু':'NN','বিশ্ববিখ্যাত':'NN','বিশ্ববিদ্যলয়েই':'NN','বিশ্ববিদ্যালয়':'NNP','বিশ্ববিদ্যালয়':'NN',
'বিশ্ববিদ্যালয়ই':'NNP','বিশ্ববিদ্যালয়কে':'NN','বিশ্ববিদ্যালয়গুলু':'NNS','বিশ্ববিদ্যালয়সমুহেও':'NN','বিশ্ববিদ্যালয়ী':'JJ','বিশ্ববিদ্যালয়ে':'NNP','বিশ্ববিদ্যালয়েও':'NN',
'বিশ্ববিমোহন':'NN','বিশ্বব্যাংক':'NN','বিশ্বব্যাংককে':'NN','বিশ্বব্যাপী':'RB','বিশ্বব্রহ্মাণ্ড':'NN','বিশ্বভারতীর':'NN','বিশ্বভিখারি':'NNP',
'বিশ্বভুজা':'NN','বিশ্বমনা':'NN','বিশ্বমহাযুদ্ধ':'NN','বিশ্বমানের':'NN','বিশ্বময়া':'NN','বিশ্বযুদ্ধ':'NN','বিশ্বযুদ্ধের':'NN',
'বিশ্বর':'NN','বিশ্বরাজনীতি':'NNS','বিশ্বরূপ':'NN','বিশ্বরূপের':'NN','বিশ্বশক্তি':'NN','বিশ্বশ্রবা':'NN','বিশ্বসনীয়তা':'NN',
'বিশ্বসাহিত্যের':'NN','বিশ্বসেরা':'NN','বিশ্বস্ততা':'NN','বিশ্বস্থ':'JJ','বিশ্বা':'NN','বিশ্বাবিদ্যালয়ের':'NNP','বিশ্বামিত্র':'NN',
'বিশ্বাষ':'NN','বিশ্বাসও':'NN','বিশ্বাসকে':'NNP','বিশ্বাসঘাতক':'NN','বিশ্বাসঘাতিনী':'NN','বিশ্বাসজয়':'NN','বিশ্বাসদের':'NNP',
'বিশ্বাসপূর্বক':'RB','বিশ্বাসভাজন':'NN','বিশ্বাসমত':'NN','বিশ্বাসযোগ্য':'JJ','বিশ্বাসযোগ্যকারন':'NNS','বিশ্বাসহীনতা':'NN','বিশ্বাসে':'NN',
'বিশ্বাসেরও':'NN','বিশ্বায়ন':'NN','বিশ্বে':'NN','বিশ্ময়':'NN','বিশ্রবণ':'NN','বিশ্রান্ত':'JJ','বিশ্রাম':'NN',
'বিশ্রামস্থল':'NN','বিশ্রামাগার':'NN','বিশ্রামের':'NN','বিশ্রি':'RB','বিশ্রী':'NN','বিশ্লিষ্ট':'NN','বিশ্লেষক':'NN',
'বিশ্লেষণকর্তা':'NN','বিশ্লেষণের':'NN','বিশ্লেষনের':'NN','বিষ':'NN','বিষকাঁটালি':'NN','বিষণ্ণ':'JJ','বিষদন্ত':'NN',
'বিষদাত':'NNS','বিষধর':'NN','বিষধ্বংসী':'NN','বিষপাথর':'NN','বিষপান':'VB','বিষফোড়া':'NN','বিষবাষ্প':'NN',
'বিষবৃক্ষ':'NN','বিষভদ্রা':'NN','বিষম':'NN','বিষমকামী':'NN','বিষমগোত্রীয়':'JJ','বিষমপলাশ':'NN','বিষমবাহু':'JJ',
'বিষমরূপী':'JJ','বিষমলিঙ্গীয়':'JJ','বিষমাখা':'JJ','বিষময়':'JJ','বিষয়':'JJ','বিষয়ক':'NNS','বিষয়বস্তু':'NN',
'বিষয়বস্তুসমূহের':'NNS','বিষয়ে':'NN','বিষযে':'NN','বিষরহিত':'JJ','বিষর্জন':'NN','বিষহরির':'NN','বিষহীন':'NN',
'বিষাক্ত':'NN','বিষাখমূল':'NN','বিষাণ':'NN','বিষাণবাদক':'NN','বিষাণী':'JJ','বিষাদ':'NN','বিষাদময়':'JJ',
'বিষাদে':'NN','বিষিয়ে':'VBN','বিষুব':'NN','বিষুবরেখীয়':'JJ','বিষুবীয়':'NN','বিষুবৃত্ত':'NN','বিষুয়া':'NN',
'বিষে':'NN','বিষোদগারে':'NN','বিষ্টরাশ্র':'NN','বিষ্ঠা':'NN','বিষ্ণু':'NN','বিষ্ণুক্রান্তা':'NN','বিষ্ণুগিরি':'NN',
'বিষ্ণুপুর':'NNP','বিষ্ণুপুরাণ':'NN','বিষ্ণুপ্রিয়া':'NN','বিষ্ণুপ্রিয়ার':'NN','বিষ্ণুভক্ত':'NN','বিষ্ণুশর্মা':'NNP','বিষ্বক্ষেন':'NN',
'বিষ্যুত':'NN','বিষয়-বস্তু':'NN','বিষয়':'NN','বিষয়ই':'JJ','বিষয়ক':'NN','বিষয়কে':'JJ','বিষয়গত':'JJ',
'বিষয়গুলি':'NNS','বিষয়গুলিতে':'NN','বিষয়গুলো':'NNS','বিষয়জ্ঞানশূণ্য':'JJ','বিষয়টা':'NN','বিষয়টি':'NN','বিষয়টিকে':'NN',
'বিষয়টির':'NN','বিষয়ত্যাগ':'NN','বিষয়বস্তু':'NN','বিষয়বোধশূণ্য':'JJ','বিষয়াতীত':'JJ','বিষয়াসক্ত':'JJ','বিষয়াসক্তি':'NN',
'বিষয়ে':'IN','বিষয়েও':'NN','বিষয়েরই':'NN','বিস':'NN','বিসংক্রমণ':'NN','বিসখপরা':'NN','বিসদৃশ':'JJ',
'বিসফাপর':'NN','বিসমাথ':'NN','বিসমিল্লাহ':'NN','বিসম্বাদ':'NN','বিসর্গ':'NN','বিসর্জন':'NN','বিসর্জ্জন':'NN',
'বিসর্প':'NN','বিসর্পী':'JJ','বিসসাস':'NN','বিসাত-খানা':'NN','বিসাত':'NN','বিসাতবান':'NN','বিসাপুর':'NN',
'বিসারেসা':'NN','বিসিএস':'NN','বিসিএসতাই':'NN','বিসিক':'NN','বিসিবি':'NN','বিসিবিযতদিন':'NN','বিসিবির':'NN',
'বিসিসিআই':'NN','বিসূচিকা':'NN','বিস্কিট':'NN','বিস্কেক':'NN','বিস্তর':'JJ','বিস্তার':'NN','বিস্তারলাভ':'VB',
'বিস্তারহীন':'JJ','বিস্তারিত':'NN','বিস্তারিতভাবে':'RB','বিস্তারের':'NN','বিস্তীর্ণ':'NN','বিস্তৃত':'IN','বিস্তৃতি':'NN',
'বিস্ফারিত':'NN','বিস্ফোরকের':'NNS','বিস্ফোরণ':'NN','বিস্ফোরণকারী':'JJ','বিস্ফোরণে':'NN','বিস্ফোরণের':'VB','বিস্ফোরন':'NN',
'বিস্বস্ত':'NN','বিস্বাদ':'JJ','বিস্বাদে':'NN','বিস্ময়কর':'NN','বিস্মরণযোগ্য':'JJ','বিস্মরণীয়':'JJ','বিস্মিত':'NN',
'বিস্মিতা':'NN','বিস্মৃত':'JJ','বিস্মৃতি':'NN','বিস্ময়কর':'JJ','বিস্ময়জনক':'JJ','বিস্ময়বোধক':'NN','বিস্ময়সূচক':'NN',
'বিস্ময়াবিষ্টা':'NN','বিস্রস্ত':'NN','বিস্রিংখলা':'NN','বিহগ':'NN','বিহঙ্গম':'NN','বিহাগরা':'NN','বিহারি':'JJ',
'বিহারী':'NN','বিহারীলালের':'NNP','বিহিত':'JJ','বিহিন':'NN','বিহী':'NN','বিহীদানা':'NN','বিহ্বলতা':'NN',
'বিড়লা':'NNP','বিড়াল':'NNS','বিড়ি':'NN','বিয়ন':'NN','বিয়রসা':'NN','বিয়াড়ি':'NN','বিয়ার':'NN',
'বিয়াল্লিশ':'NN','বিয়াল্লিশতম':'JJ','বিয়াস':'NN','বিয়ে':'NN','বিয়েতে':'NN','বিয়েতেই':'VBG','বিয়ের':'NN',
'বিয়োগ':'NN','বিয়োগফল':'NN','বিয়োজন-মাত্রা':'NN','বি‌দে‌শে':'NN','বি‌দ্বেস':'VBN','বীঈদা':'NN','বীকে':'NN',
'বীজ':'NN','বীজকোষ':'NN','বীজগণিত':'NN','বীজজাত':'JJ','বীজপত্রযুক্ত':'JJ','বীজফল':'JJ','বীজবিহীন':'JJ',
'বীজযুক্ত':'JJ','বীজা':'NN','বীজাণু':'NN','বীজারোপন':'NN','বীজু':'NN','বীজের':'NN','বীটি':'NN',
'বীড়িয়া':'NN','বীণা':'NN','বীণাদণ্ড':'NN','বীণাবতী':'NN','বীণাবাদক':'NN','বীণার':'NN','বীতভীত':'NN',
'বীতরাগ':'NN','বীতশোক':'JJ','বীতহব্য':'NN','বীতে':'NN','বীন':'NN','বীনকার':'NN','বীনতিয়েন':'NN',
'বীনবাদক':'NN','বীপে':'NN','বীভত্স':'JJ','বীমা-কিস্তি':'NN','বীমা':'NN','বীমাকর্তা':'JJ','বীমাকারী':'NN',
'বীর':'NN','বীরকথা':'NN','বীরগতি':'NN','বীরগাথা':'NN','বীরত্ব':'NN','বীরত্বপূর্ণ':'JJ','বীরত্বের':'NN',
'বীরদর্পেজিয়ার':'NN','বীরন':'NN','বীরপুরের':'NNP','বীরপ্রমোক্ষা':'NN','বীরবত্স':'NN','বীরবল':'NN','বীরবাহু':'NN',
'বীরভদ্র':'NN','বীরভূম':'NN','বীরমণি':'NN','বীরমত্স্য':'NN','বীরমর্দন':'NN','বীরমাতা':'NN','বীরমুদ্রিকা':'NN',
'বীরশূণ্য':'JJ','বীরসেন':'NN','বীরহীন':'JJ','বীরা':'NN','বীরাঙ্গনা':'NN','বীরুধ্':'NN','বীরেন্দর':'NN',
'বীর্য':'NN','বীর্যবর্ধক':'NN','বীর্যরহিত':'JJ','বীর্যাণু':'NN','বীহী':'NN','বুঁদ':'VB','বুঁদিয়া':'NN',
'বুই':'NN','বুইঝবার':'NN','বুক-জলে':'NN','বুক':'NN','বুকখোলা':'NN','বুকজ্বালি':'NN','বুকটা':'JJS',
'বুকিং':'NN','বুকুবা':'NN','বুকুরেস্টী':'NN','বুকে':'NN','বুকের':'NN','বুগদা':'NN','বুগি':'NN',
'বুচারেস্ট':'NN','বুজত':'NN','বুজনী':'NN','বুজবে':'NN','বুজলই':'NN','বুজলেন':'NN','বুজা':'NN',
'বুজিয়ে':'NN','বুজী':'JJ','বুজুম্বুরা':'NN','বুজে':'VB','বুজ্জা':'NN','বুঝ':'NN','বুঝছি':'VB',
'বুঝতাছি':'VB','বুঝতে':'NN','বুঝতেই':'VB','বুঝতেছি':'VB','বুঝতেন':'VB','বুঝনো':'VB','বুঝবা':'VB',
'বুঝবেন':'VB','বুঝল':'VB','বুঝলাম':'VB','বুঝলামনাকি':'VB','বুঝলে':'VB','বুঝলেওকুটিল':'VB','বুঝলেন':'VB',
'বুঝা':'VB','বুঝাচ্ছেন':'VB','বুঝাতে':'VB','বুঝানো':'VB','বুঝাবেন':'VB','বুঝার':'NN','বুঝালেন':'VB',
'বুঝায়':'VB','বুঝি':'VB','বুঝিনি':'VB','বুঝিবে':'VB','বুঝিয়া':'VB','বুঝিয়ে':'VBD','বুঝুন':'NN',
'বুঝে':'NN','বুঝেই':'NN','বুঝেছ':'VB','বুঝেছিল':'VB','বুঝেছিলেন':'VB','বুঝেছেনযে':'VB','বুঝেতাই':'NN',
'বুঝেন':'VB','বুঝেননাকি':'NN','বুঝেনসকালে':'NN','বুঝেনা':'VB','বুঝেশুনেই':'VB','বুঝ‌তে‌ছে':'VB','বুট':'NN',
'বুটি':'NN','বুটিদার':'JJ','বুটিযুক্ত':'JJ','বুড়ি':'NN','বুড়িয়াবৈঠক':'NN','বুড়িয়ে':'VB','বুড়ো':'NN',
'বুতু':'NNP','বুত্পত্তিটা':'NN','বুত্পন্ন':'JJ','বুথ':'NN','বুথের':'NN','বুদবুদ':'NNS','বুদবুদ্':'NN',
'বুদাপেস্ট':'NN','বুদোর':'NN','বুদ্দ্বিমত্তা':'NN','বুদ্ধ':'NN','বুদ্ধদেব':'NNP','বুদ্ধদেবের':'NNP','বুদ্ধমূর্তির':'NN',
'বুদ্ধি-মতী':'JJ','বুদ্ধি':'NN','বুদ্ধিগন্ডতার':'NN','বুদ্ধিজীবি':'NN','বুদ্ধিজীবী':'NN','বুদ্ধিজীবীরা':'NN','বুদ্ধিটা':'NN',
'বুদ্ধিদীপ্ত':'NN','বুদ্ধিবৃক্ষ':'NN','বুদ্ধিভ্রংশ':'NN','বুদ্ধিমতি':'NN','বুদ্ধিমত্তায়':'NN','বুদ্ধিমন্ত':'NNP','বুদ্ধিমান':'NN',
'বুদ্ধির':'NN','বুদ্ধিশুদ্ধি':'NN','বুদ্ধিহীন':'JJ','বুদ্ধু':'NN','বুদ্ধের':'NNP','বুদ্বি':'NN','বুদ্বুদের':'NN',
'বুধ':'NN','বুধবার':'NNP','বুনন':'VBG','বুননকার্য':'NN','বুনলে':'RP','বুনা':'NN','বুনিয়াদ':'NN',
'বুনিয়াদি':'JJ','বুনিয়াদী':'NN','বুনুয়েল':'NNP','বুনো':'NN','বুন্দকী':'NN','বুন্দেলখণ্ড':'NN','বুন্দেলখণ্ডী':'JJ',
'বুন্দেলা':'NNP','বুন্দেস':'NN','বুবাসটিস':'NNP','বুমবাস্ট':'NN','বুমরা':'NN','বুমরাহ':'NN','বুয়েট':'NN',
'বুরকিনা':'NN','বুরবুর':'VB','বুরহানপুর':'NN','বুরা':'NN','বুরুজ':'NN','বুরুসিয়া':'NN','বুর্কা':'NN',
'বুর্জোয়া':'NNP','বুলগেরিয়া':'NN','বুলগেরিয়ারবাসী':'NN','বুলগেরীয়':'NN','বুলডগ':'NN','বুলডোজার':'NN','বুলঢানা':'NN',
'বুলন্দশহর':'NN','বুলবুল':'NN','বুলবুলের':'NN','বুলাক':'NN','বুলি':'NN','বুলিয়ে':'NN','বুলুর':'NN',
'বুলেট':'NN','বুলেলী':'NN','বুল্গেরিয়ান':'JJ','বুশ':'NNP','বুশবাক্':'NNP','বুশবিরোধী':'JJ','বুশশার্টখানা':'NN',
'বুশের':'NNP','বুশোচিত':'JJ','বুড়া':'NN','বুড়াগুলা':'NN','বুড়ি':'NN','বুড়িগঙ্গায়':'NN','বুড়ো':'NN',
'বুড়োশিবতলায়':'NN','বুঢ়ন':'NN','বুয়া':'NN','বুয়েট':'NN','বুয়েনেস':'NN','বূহ্য':'NN','বৃংহণ':'VB',
'বৃংহন':'NN','বৃক':'NN','বৃকদন্ত':'NN','বৃকদেব':'NN','বৃকাসুর':'NN','বৃক্ক':'NN','বৃক্কশ্রেণী':'NN',
'বৃক্কের':'NN','বৃক্ষ':'NN','বৃক্ষবাসী':'JJ','বৃক্ষরাজ':'NN','বৃক্ষরোপক':'JJ','বৃক্ষরোপণ':'NN','বৃক্ষহীন':'JJ',
'বৃক্ষের':'NN','বৃগেডকে':'NN','বৃটিশ':'NN','বৃটিশপাকিস্তান':'NN','বৃত্ত':'NN','বৃত্তানুপ্রাস':'NN','বৃত্তান্ততার':'NN',
'বৃত্তি':'NN','বৃত্তিপ্রাপ্তদেরকে':'NN','বৃত্তীয়':'JJ','বৃত্তের':'NN','বৃত্রঘ্ন':'NN','বৃত্রাসুর':'NN','বৃথা-':'JJ',
'বৃথা':'NN','বৃদ্ধ':'NN','বৃদ্ধঙ্গুষ্ঠ':'NN','বৃদ্ধরাজ':'NN','বৃদ্ধাঙ্গুলি':'NN','বৃদ্ধাবস্থা':'NN','বৃদ্ধার':'NN',
'বৃদ্ধি':'NN','বৃদ্ধিটা':'NN','বৃদ্ধিযুক্ত':'JJ','বৃদ্ধির':'NN','বৃদ্ধিরহিত':'JJ','বৃদ্ধিহোল্ডিং':'NN','বৃন্ত':'NN',
'বৃন্দা':'NNP','বৃন্দাবন':'NN','বৃন্দারক':'NN','বৃর্দ্ধনশীল':'NN','বৃশ্চিক':'NN','বৃশ্চী':'NN','বৃষ':'NN',
'বৃষগন্ধা':'NN','বৃষণ':'NN','বৃষণাক্ষ':'NN','বৃষপতি':'NN','বৃষপর্বা':'NN','বৃষফর্ণিকা':'NN','বৃষভ':'NN',
'বৃষভাসুর':'NN','বৃষরাশি':'NN','বৃষাকপায়ী':'NN','বৃষাঙ্কজ':'NN','বৃষারণী':'NN','বৃষাশ্রিতা':'NN','বৃষাসুর':'NN',
'বৃষোত্সর্গ':'NN','বৃষ্ট':'NN','বৃষ্টিনির্ভর':'JJ','বৃষ্টিপাত':'NN','বৃষ্টিভেজা':'NN','বৃষ্টিমাপক':'NN','বৃষ্টিস্নাত':'JJ',
'বৃষ্টিহীন':'JJ','বৃষ্টিহীনতা':'NN','বৃষ্ণিক':'NN','বৃহকীর্তি':'NN','বৃহচ্ছক':'NN','বৃহজ্জাবাল':'NN','বৃহত':'NN',
'বৃহতী':'NN','বৃহত্':'NN','বৃহত্কায়':'JJ','বৃহত্তম':'JJ','বৃহত্তর':'NN','বৃহত্তিক্তা':'NN','বৃহত্ফল':'NN',
'বৃহদঙ্গ':'NN','বৃহদল':'NN','বৃহদান্ত্র':'NN','বৃহদারণ্যক':'NN','বৃহদায়তন':'JJ','বৃহদিষু':'NN','বৃহদ্ধানু':'NN',
'বৃহদ্রথ':'NN','বৃহষ্পতি':'NNP','বৃহষ্পতিবার':'NN','বৃহস্পতিবার':'NN','বৃহস্পতিবারে':'NNP','বৃহৎ':'NN','বে-আইনী':'JJ',
'বে':'NN','বেঁকা':'NN','বেঁকিয়ে':'VB','বেঁকে':'NN','বেঁচে':'JJ','বেঁচেও':'NN','বেঁধে':'NN',
'বেঁহুশ':'JJ','বেআইনি':'JJ','বেআইনিভাবে':'NN','বেআক্কেল':'NN','বেআরাম':'JJ','বেইজিং':'NN','বেইজ্জত্':'NN',
'বেইমান':'JJ','বেইমানি':'NN','বেওকুফ':'NN','বেওয়ার':'NN','বেকদর':'JJ','বেকার':'VBN','বেকারই':'NN',
'বেকারত্ব':'NN','বেকারত্বেন':'NN','বেকারদের':'NN','বেকারি':'NN','বেকারেরা':'NN','বেকুব':'NN','বেকুবচাঁদের':'NNP',
'বেকুবের':'NN','বেক্কল':'NN','বেক্তিবরগের':'NN','বেক্সিমকো':'NN','বেখুর':'NN','বেগ':'NN','বেগদর্শী':'NN',
'বেগদা':'NN','বেগম':'NN','বেগমহাসপাতাল':'NN','বেগমী':'JJ','বেগার':'NN','বেগুণ':'NN','বেগুনি':'NN',
'বেগুনে':'NN','বেগুসরায়':'NN','বেগে':'NN','বেঘর':'NN','বেঘোরে':'RB','বেঙ্গনপল্লী':'NN','বেঙ্গলী':'NNP',
'বেঙ্গসরকর':'JJ','বেঙ্গালুরু':'IN','বেচতে':'NN','বেচা-কেনা':'NNP','বেচা':'NN','বেচাবিক্রি':'NN','বেচার':'NN',
'বেচারাকে':'NN','বেচারি':'JJ','বেচে':'NN','বেছে':'VB','বেজ':'NN','বেজাশাহকে':'NNP','বেজায়':'NN',
'বেজিং':'NN','বেজির':'JJ','বেজে':'NN','বেজেছে':'VB','বেঞ্চ':'NN','বেঞ্চে':'NN','বেঞ্জিন':'NN',
'বেটরী':'NN','বেটা':'NN','বেঠিক':'NN','বেড়া':'NN','বেড়াতে':'NN','বেড়ানো':'VBG','বেড়াবার':'IN',
'বেড়াল':'NN','বেড়িচা':'NN','বেড়ী':'NN','বেড়েছিল':'VBN','বেড়েছে':'NN','বেডা':'NN','বেঢপ':'JJ',
'বেঢ়া':'NN','বেণ':'NN','বেণী':'NN','বেণীয়াদের':'NN','বেণু':'NN','বেণ্ণা':'NNP','বেত':'NN',
'বেতনই':'NN','বেতনকে':'NN','বেতনধারী':'NN','বেতনবৃদ্ধি':'NN','বেতনভুক্ত':'NN','বেতনভোগী':'JJ','বেতনভোগীদের':'NN',
'বেতনহীন':'NN','বেতনে':'NN','বেতাইতলা':'NNP','বেতাজ':'JJ','বেতান্ত':'JJ','বেতার':'NN','বেতারযন্ত্র':'NN',
'বেতাল':'NN','বেতালা':'JJ','বেতিয়া':'NN','বেতে':'NN','বেতোয়া':'NNP','বেত্র':'NN','বেত্রাসুর':'NN',
'বেতড়':'NN','বেথা':'NN','বেথুনকে':'NNP','বেদ':'NN','বেদখল':'JJ','বেদগর্ভা':'NN','বেদন':'NN',
'বেদনজনূঁ':'NN','বেদনরোগ':'NN','বেদনা':'NN','বেদনাদায়ক':'NN','বেদনার':'NN','বেদন্ত':'NN','বেদবতী':'NN',
'বেদবাহু':'NN','বেদবিদ্যা':'NN','বেদমন্ত্র':'NN','বেদমাল':'NN','বেদমুণ্ড':'NN','বেদরকারী':'NN','বেদলৈলা':'NN',
'বেদশির':'NN','বেদশ্ব':'NN','বেদশ্রুতি':'NN','বেদস্মৃতা':'NN','বেদাধ্যয়ন':'NN','বেদানা':'NN','বেদানারঙা':'JJ',
'বেদান্ত':'NN','বেদান্তবাদী':'JJ','বেদান্তশাস্ত্র':'NN','বেদান্তি':'NN','বেদি':'NN','বেদিজা':'NN','বেদী':'NN',
'বেদীমূলে':'NN','বেদীর':'NN','বেদুয়া':'JJ','বেদে':'NN','বেদো':'JJ','বেধ':'NN','বেধুয়া':'JJ',
'বেধে':'NN','বেন':'NN','বেনই':'VB','বেনগাজী':'NN','বেনঙ্গ':'NN','বেনজামা':'NN','বেনজির':'NNP',
'বেনজীর':'NNP','বেনজীরের':'NNP','বেনজু':'NN','বেনপি':'NN','বেনসন':'NN','বেনা':'NN','বেনানি':'JJ',
'বেনাপোলের':'NN','বেনামী':'NN','বেনার':'NN','বেনারসবাসী':'NN','বেনিডিক্ট':'NNP','বেনিতেজ':'NN','বেনিন':'NN',
'বেনিনি':'NN','বেনিফিট':'NNS','বেনিয়ম':'NN','বেনিয়মে':'RB','বেনিয়া':'NN','বেনেডিক্ট':'NN','বেনেডিয়াম':'NN',
'বেনেফিট':'NNS','বেনেফিটসহ':'NN','বেনেবউ':'NN','বেনেহাট':'NN','বেপড়োয়া':'RB','বেপরোয়া':'NN','বেপার':'NN',
'বেপারীদের':'NNS','বেপারে':'NN','বেবস্থা':'NN','বেবালয়':'NN','বেবী':'NN','বেবুন':'NN','বেভান':'NN',
'বেমক্কা':'NN','বেমতলব':'JJ','বেমানান':'JJ','বেমামুল':'NN','বের':'VB','বেরগড়':'NN','বেরঙা':'JJ',
'বেরতা':'NN','বেরসিক':'JJ','বেরাখী':'NN','বেরালে':'NN','বেরাহিম':'NNP','বেরায়':'NN','বেরি':'NN',
'বেরিবেরি':'NN','বেরিয়ে':'NN','বেরিলিয়াম':'NN','বেরিয়াম':'NN','বেরিয়েছিলেন':'VB','বেরিয়েছেন':'VB','বেরী':'NNP',
'বেরুকী':'NN','বেরুচ্ছে':'NN','বেরুট':'NN','বেরুত':'VB','বেরুনোর':'NN','বেরুবার':'NNV','বেরে':'NN',
'বেরেনাইস':'NNP','বেরৈ':'NN','বেরোজগার':'NN','বেরোতে':'VB','বেরোনো.':'VB','বেরোনো':'NN','বেরোয়':'NN',
'বেল-পত্র':'NN','বেল':'NN','বেলখজী':'NN','বেলগাঁও':'NN','বেলগাগরা':'NN','বেলচা':'NN','বেলজিয়ান':'NN',
'বেলজিয়ামবাসী':'NN','বেলডাঙ্গা':'NNP','বেলন':'NN','বেলপাতা':'NN','বেলফাস্ট':'NN','বেলবন':'NN','বেলবাগুর':'NN',
'বেলা':'NN','বেলাগাম':'RB','বেলাডোনা':'NN','বেলাতেও':'NN','বেলানো':'VB','বেলাভূমি':'NN','বেলার':'NN',
'বেলারুসবাসী':'NN','বেলারুসী':'NN','বেলায়':'VBG','বেলায়ই':'NN','বেলায়ও':'VBG','বেলিজ':'NN','বেলিজী':'NN',
'বেলিজীয়':'JJ','বেলুচিস্তানে':'NN','বেলুন':'NN','বেলে':'NN','বেলেডোনা':'NN','বেলেদে':'NN','বেলেপাহাড়ে':'VB',
'বেলো':'NN','বেল্ট':'NN','বেল্টহীন':'JJ','বেল্লারি':'NN','বেল্লিক':'JJ','বেল্লিকবাজার':'NN','বেল্লুর':'NN',
'বেশ-ভূষা':'NN','বেশ':'NN','বেশভূষা':'NN','বেশমি':'JJ','বেশরম':'NN','বেশলি':'NN','বেশি':'RBR',
'বেশিই':'NN','বেশিওই':'JJ','বেশিক্ষন':'NN','বেশিদিন':'VB','বেশিদূর':'JJ','বেশিভাগেরই':'NN','বেশিমাত্রায়':'NN',
'বেশিযদিও':'NN','বেশির':'RBR','বেশিরভাগ':'RB','বেশিহাজার':'NN','বেশি১১২০টাকা':'NN','বেশী':'RBR','বেশীই':'JJ',
'বেশীদিন':'NN','বেশীর':'RBR','বেশীরভাগ':'JJS','বেশে':'VBN','বেশ্যা':'IN','বেশ্যাগমন':'NN','বেশ্যাটির':'NNP',
'বেশ্যাবাজ':'JJ','বেশ্যাবৃত্তি':'NN','বেশ্যার':'NN','বেষই':'NN','বেষণ':'NN','বেষী':'JJ','বেষ্টক':'NN',
'বেষ্টনীতে':'NN','বেষ্টিত':'JJ','বেস':'NN','বেসনের':'NN','বেসরকরি':'RB','বেসরকারি':'NN','বেসরকারীকরণ':'NN',
'বেসরকারীভাবে':'RB','বেসামাল':'VB','বেসিক':'NN','বেসিকে':'JJ','বেসিন':'NN','বেসুর':'JJ','বেসুরো':'NN',
'বেসে':'VB','বেস্ট':'JJS','বেহাগ':'NN','বেহাত':'VB','বেহাল':'NN','বেহায়া':'NN','বেহায়াদের':'JJ',
'বেহায়াপনা':'NN','বেহি':'NN','বেহিসেবী':'NN','বেহুঁশ':'JJ','বেহুঁশের':'NN','বেহুদা':'NN','বেহেরি':'NN',
'বেহেশত':'NN','বেহ্যায়ারা':'JJ','বোকা':'NN','বোঝা':'VBG','বোঝাবে':'NN','বোঝে':'NN','বোধ':'VBG',
'বোধহয়':'NN','বোনাস':'NN','বোমারুদের':'NN','বো‌ঝে':'NN','বেড়':'NN','বেড়া':'NN','বেড়াচ্ছ':'VB',
'বেড়াচ্ছেন':'VB','বেড়াজাল':'NN','বেড়াতে':'VB','বেড়ানো':'VB','বেড়াবে':'VB','বেড়াবো':'VB','বেড়াল':'NN',
'বেড়ালের':'NN','বেড়ায়':'VB','বেড়িয়েছে':'VBD','বেড়ে':'VBN','বেড়েছে':'VBN','বেড়েছেতাদের':'NN','বেড়েছেনয়তো':'NN',
'বেড়েছেপ্রতিটা':'NN','বেয়ং':'NN','বেয়াই':'NN','বেয়াইবাড়ি':'NN','বেয়াড়া':'JJ','বেয়াদপ':'JJ','বেয়াদপি':'NN',
'বেয়ান':'NN','বেয়াবার':'NN','বেয়ারার':'NN','বেয়াড়া':'JJ','বেয়ে':'NN','বৈকল্পিক':'NN','বৈকাল':'NN',
'বৈকি':'NN','বৈকুণ্ঠ':'NN','বৈক্রান্তমণি':'NN','বৈখানসি':'NN','বৈগাই':'NN','বৈচিএ':'NN','বৈচিএের':'NNP',
'বৈচিত্র':'NN','বৈচিত্রপূর্ণ':'JJ','বৈচিত্র্য':'NN','বৈচিত্র্যপূর্ণ':'JJ','বৈচিত্র্যময়':'NN','বৈজন্তি-মালা':'NN','বৈজন্তিমালা':'NN',
'বৈজন্তী':'NN','বৈজ্ঞানিক':'NN','বৈজ্ঞানিকের':'NN','বৈজয়ন্তী':'NN','বৈঠক':'NN','বৈঠকখানা':'NN','বৈঠকে':'VBG',
'বৈঠা':'NN','বৈণ':'NN','বৈতণ্ডী':'NN','বৈতনিক':'JJ','বৈতরণী':'NN','বৈতুল':'NN','বৈদজ্ঞ':'JJ',
'বৈদর্ভী':'NN','বৈদিক':'NN','বৈদুর্য্য':'NN','বৈদেশিক':'RB','বৈদ্য':'NN','বৈদ্যদের':'NN','বৈদ্যনাথ':'NN',
'বৈদ্যুতিক':'NN','বৈদ্যুতিন':'JJ','বৈধ':'NN','বৈধগৃহ':'NN','বৈধতা':'NN','বৈধব্য':'NN','বৈধভাবে':'RB',
'বৈধশালা':'NN','বৈধ্য':'NN','বৈনতেয়':'NN','বৈপরীত্য':'NN','বৈপ্লবিক':'JJ','বৈবর্ত':'NN','বৈবস্বতমনু':'NN',
'বৈবাহ':'JJ','বৈবাহিক':'NN','বৈভণ্ডি':'NN','বৈভব':'NN','বৈভ্রাজ':'NN','বৈমত্যতা':'NN','বৈমাত্রেয়':'NN',
'বৈমানিকী':'NN','বৈম্য':'NN','বৈরাগী':'NN','বৈরাগ্য':'NN','বৈরাট':'NN','বৈরিণী':'NN','বৈরিতাপূর্ণ':'JJ',
'বৈরী':'NN','বৈশম্পায়ন':'NN','বৈশম্য':'NN','বৈশাখ':'NN','বৈশাখী':'NN','বৈশিষিক':'JJ','বৈশিষ্ট':'NN',
'বৈশিষ্ট্য':'NNS','বৈশিষ্ট্যগত':'JJ','বৈশিষ্ট্যের':'NN','বৈশিষ্ঠমূলক':'JJ','বৈশিষ্ঠ্য':'NN','বৈশেষিক':'NN','বৈশেষিকশাস্ত্র':'NN',
'বৈশ্বানর':'NN','বৈশ্বিক':'NN','বৈশ্য':'NN','বৈশ্রম্ভক':'NN','বৈষম্য':'NN','বৈষম্যতা':'NN','বৈষম্যমূলক':'NN',
'বৈষম্যের':'NN','বৈষ্ণব':'NN','বৈষ্ণবরা':'NN','বৈষ্ণবী':'NN','বৈষয়িক':'JJ','বৈসৃপ':'NN','বোঁটা':'NN',
'বোঁদে':'NN','বোংগাইগাঁও':'NN','বোকা':'NN','বোকাখাট':'NN','বোকামি':'NN','বোকার':'NN','বোকারো':'NN',
'বোখা':'JJ','বোগাস':'NN','বোগেন-ভিলিয়া':'NN','বোগোটা':'NN','বোজা':'NN','বোঝ':'VB','বোঝলে':'NN',
'বোঝা':'NN','বোঝাইনো':'VB','বোঝাটা':'VBG','বোঝাতে':'NN','বোঝান':'VB','বোঝানো':'NN','বোঝাপড়া':'NN',
'বোঝাবার':'NNV','বোঝাবে':'NN','বোঝামাল':'JJ','বোঝায়':'VB','বোঝার':'VBG','বোঝালেন':'VBD','বোঝাহীন':'JJ',
'বোঝায়':'NN','বোঝায়ই':'NNS','বোঝে':'NNS','বোঝেন':'NN','বোঝেনা':'NN','বোঝো':'NN','বোট':'NN',
'বোড়':'NN','বোড়া':'NN','বোডো':'NN','বোত':'NN','বোতলটাই':'NN','বোতলে':'NN','বোতাম-ঘর':'NN',
'বোত্সবানন':'NN','বোত্সবানাবাসী':'NN','বোত্সবানার':'JJ','বোদড়ে':'NN','বোদানি':'NN','বোদ্ধার':'NN','বোদয়':'NNP',
'বোধ':'NN','বোধগম্য':'NN','বোধদয়':'NN','বোধপূর্ণ':'JJ','বোধপ্রাপ্তি':'NN','বোধবুদ্ধি':'NN','বোধবৃক্ষ':'NN',
'বোধশক্তি':'NN','বোধসম্পন্ন':'JJ','বোধহয়':'RB','বোধি':'NN','বোধিবৃক্ষ':'NN','বোধিসত্ত্ব':'NN','বোধের':'NN',
'বোধোদয়':'NN','বোধ্য':'JJ','বোধয়':'RB','বোন':'NN','বোনঝি':'NN','বোনদের':'NN','বোনপো':'NN',
'বোনরা':'NN','বোনসহ':'NNS','বোনা':'RB','বোনাই':'NN','বোনানো':'VB','বোনাপার্ট':'NN','বোনাস':'NN',
'বোনি':'VB','বোনেদের':'NN','বোনেরা':'NNS','বোপঙ্গ':'NN','বোপোমাফো':'NN','বোবন':'NN','বোবার':'NN',
'বোম':'NN','বোমডিলা':'NN','বোমাবর্ষক':'NN','বোমাবাজ':'NN','বোমাবাজির':'VBG','বোমার':'NNP','বোমারু':'JJ',
'বোমাসহ':'NNS','বোমায়':'NN','বোম্বাই':'NN','বোম্বাইএর':'JJ','বোম্বাইবাসী':'NN','বোম্বে':'NN','বোরকা':'NN',
'বোরন':'NN','বোরা':'NNS','বোরিং':'NN','বোরিক':'JJ','বোরিয়াম':'NN','বোরে':'NN','বোরো':'IN',
'বোরোগ্লিসারিন':'NNP','বোর্ড':'NN','বোর্ডকে':'NN','বোর্ডে':'NN','বোর্ণিও':'NNP','বোল':'NN','বোলগীবাঁশ':'NN',
'বোলতা':'NN','বোলাঙ্গির':'NN','বোলানো':'VBG','বোলানোর':'NN','বোলারকে':'NN','বোলারদেরকে':'NNS','বোলাররা':'NN',
'বোলারা':'NN','বোলি':'NN','বোলিংএই':'VBG','বোলিংয়ের':'NN','বোল্টহেনরিফার্গুসনকে':'NN','বোল্টা':'NN','বোল্ড':'JJ',
'বোল্ডার':'NN','বোস':'NN','বোসনিয়া-হার্জগোভিনা':'NN','বোসনিয়া':'NN','বোসনিয়াবাসী':'NN','বোসনিয়ার':'JJ','বোসের':'NNP',
'বোহরা':'NN','বোয়কিকে':'NNP','বোয়াম':'NN','বোয়ালদের':'NNS','বোয়ালের':'NN','বৌ':'NN','বৌটিই':'NN',
'বৌদ':'NN','বৌদ্ধ-স্তুপ':'NN','বৌদ্ধ':'NN','বৌদ্ধকালিন':'NN','বৌদ্ধদের':'NN','বৌদ্ধধর্মাবলম্বী':'NN','বৌদ্ধধর্মের':'NN',
'বৌদ্ধবিহার':'NN','বৌদ্ধযুগ':'NN','বৌধ':'NN','বৌধায়ন':'NN','বৌর':'NN','ব্বাপরে':'NNP','ব্যঁগু':'NN',
'ব্যংক':'NNP','ব্যংকটিকে':'NN','ব্যংকে':'NN','ব্যংস':'NN','ব্যকরণ':'JJ','ব্যকরণগত':'NN','ব্যকরণের':'JJ',
'ব্যকুলতা':'NN','ব্যক্ত':'VBN','ব্যক্তগত':'JJ','ব্যক্তি-চিন্তা':'NN','ব্যক্তি':'NN','ব্যক্তিও':'NN','ব্যক্তিকে':'NN',
'ব্যক্তিগণ':'NN','ব্যক্তিগতভাবে':'RB','ব্যক্তিতে':'NN','ব্যক্তিত্বহীন':'NN','ব্যক্তিত্বের':'NN','ব্যক্তিদের':'NNS','ব্যক্তির':'NN',
'ব্যক্তিরাও':'NN','ব্যখ্যা':'NN','ব্যঘ্র':'NN','ব্যঙ্গ':'NN','ব্যঙ্গাত্নক':'RB','ব্যঙ্গাত্মক':'JJ','ব্যঙ্গার্থ':'NN',
'ব্যঙ্গোক্তি':'NN','ব্যঞ্জন':'NN','ব্যঞ্জনবর্ণের':'NN','ব্যঞ্জনরহিত':'JJ','ব্যঞ্জনসূচী':'NN','ব্যঞ্জনার্থ':'NN','ব্যঞ্জো':'NN',
'ব্যটিং':'NN','ব্যতিক্রম':'NN','ব্যতিক্রমধর্মী':'JJ','ব্যতিক্রমের':'NN','ব্যতিত':'RB','ব্যতিরেকে':'JJ','ব্যতীত':'IN',
'ব্যতীপাত':'NN','ব্যত্যয়':'NN','ব্যথা':'NN','ব্যথায়':'NN','ব্যথিত':'NNP','ব্যনার্জি':'NN','ব্যপক':'JJ',
'ব্যপকতার':'NN','ব্যপকভাবে':'RB','ব্যপার':'NN','ব্যপারটি':'NN','ব্যপারেতো':'NN','ব্যবচ্ছেদ':'NN','ব্যবধাণ':'NN',
'ব্যবধানকে':'NN','ব্যবধানে':'NN','ব্যবধানেই':'NNS','ব্যবর্তন':'NN','ব্যবসতা':'NN','ব্যবসা':'NN','ব্যবসাআমাদের':'NNS',
'ব্যবসাই':'NN','ব্যবসাকেন্দ্র':'NN','ব্যবসাতে':'NN','ব্যবসাবাণিজ্য':'NN','ব্যবসায়':'NN','ব্যবসায়ী':'NN','ব্যবসায়':'NN',
'ব্যবসায়ি':'NN','ব্যবসায়িদের':'NNS','ব্যবসায়িরা':'NN','ব্যবসায়ীই':'NN','ব্যবসায়ীক':'NN','ব্যবসায়ীকেই':'NN','ব্যবসায়ীদের':'NNS',
'ব্যবসায়ীর':'NN','ব্যবসায়ীরাই':'NN','ব্যবসায়ে':'NN','ব্যবস্তা':'NN','ব্যবস্থাই':'NN','ব্যবস্থাকে':'NN','ব্যবস্থাটাও':'NN',
'ব্যবস্থাপক':'NN','ব্যবস্থাপকদের':'NNS','ব্যবস্থাপত্র':'NN','ব্যবস্থাপনা':'NN','ব্যবস্থাপনার':'NN','ব্যবস্থাপনায়':'NN','ব্যবস্থাপূর্বক':'RB',
'ব্যবস্থাবিচার':'NN','ব্যবস্থায়':'NN','ব্যবস্থিত':'VBN','ব্যবস্যায়':'NN','ব্যবহার':'NN','ব্যবহারকরীরা':'NNS','ব্যবহারকারী':'NN',
'ব্যবহারকারীর':'NN','ব্যবহারগুলি':'NN','ব্যবহারযোগ্য':'JJ','ব্যবহারিক':'NN','ব্যবহারে':'NN','ব্যবহার্য':'NN','ব্যবহৃত':'NN',
'ব্যবহ্রত':'VBN','ব্যবিলোনরাজ':'NN','ব্যভিচার':'NN','ব্যভিচারী':'NN','ব্যম':'NN','ব্যয়':'NN','ব্যয়বহুল':'JJ',
'ব্যর্থ':'NN','ব্যর্থতা':'NN','ব্যর্থতাবড়':'NN','ব্যর্থতায়':'NN','ব্যলন':'NN','ব্যলেনের':'NNP','ব্যশ্ব':'NN',
'ব্যস্':'RB','ব্যস্ত':'JJ','ব্যস্ততা':'NN','ব্যস্ততার':'JJ','ব্যস্তবাগীশ':'JJ','ব্যা':'VB','ব্যাঁকা':'NN',
'ব্যাং':'NN','ব্যাংকই':'NNP','ব্যাংকএর':'NN','ব্যাংকও':'NNP','ব্যাংকক':'NN','ব্যাংককেও':'NN','ব্যাংকগুল':'NNS',
'ব্যাংকগুলি':'NN','ব্যাংকগুলিরে':'NNS','ব্যাংকগুলোই':'NNS','ব্যাংকগুলোও':'NN','ব্যাংকগুলোতে':'NNS','ব্যাংকগুলোতেও':'NN','ব্যাংকটাকে':'NN',
'ব্যাংকটি':'NNP','ব্যাংকটিও':'NN','ব্যাংকটিতে':'NN','ব্যাংকতো':'NNP','ব্যাংকরাই':'NN','ব্যাংকর্মকর্তার':'NN','ব্যাংকলুটেরাদের':'NNS',
'ব্যাংকলুটেরাদেরও':'NN','ব্যাংকার':'NN','ব্যাংকাররা':'NNS','ব্যাংকি':'NN','ব্যাংকে':'NN','ব্যাংকেই':'NN','ব্যাংকের':'NN',
'ব্যাকআপ':'NN','ব্যাকওয়াটর্স':'NN','ব্যাকটিরিয়া':'NNP','ব্যাকটিরিয়াল':'NN','ব্যাকরণ':'NN','ব্যাকরণগত':'JJ','ব্যাকরণচর্চা':'NN',
'ব্যাকরণটিকে':'NN','ব্যাকরণবিদেরা':'NN','ব্যাকরণেই':'NN','ব্যাকারণ':'NN','ব্যাকুব':'NN','ব্যাকুলতা':'NN','ব্যাক্টিরিয়া':'NN',
'ব্যাক্ট্রিয়া':'NNP','ব্যাক্তি':'NN','ব্যাক্তিকে':'NN','ব্যাক্তিটি':'NN','ব্যাক্তিত্বের':'NN','ব্যাক্তিিটি':'NN','ব্যাক্ষা':'NN',
'ব্যাখাকারী':'JJ','ব্যাখ্যা':'NN','ব্যাখ্যান':'NN','ব্যাখ্যাযুক্ত':'JJ','ব্যাখ্যার':'NN','ব্যাগ':'NN','ব্যাগ্রতা':'NN',
'ব্যাঘাত':'NN','ব্যাঘাতকারী':'JJ','ব্যাঘাতশূণ্য':'NN','ব্যাঘাতহীন':'NN','ব্যাঘ্র':'NN','ব্যাঘ্রভট':'NN','ব্যাঘ্রাক্ষ':'NN',
'ব্যাঙ':'NN','ব্যাঙ্ক-হুন্ডি':'NN','ব্যাঙ্ক':'NN','ব্যাঙ্ককর্মী':'NN','ব্যাঙ্কগুলো':'NNS','ব্যাঙ্কগুলোতে':'NN','ব্যাঙ্কার':'NN',
'ব্যাঙ্কিং':'JJ','ব্যাঙ্কের':'NN','ব্যাঙ্গাত্মক':'NN','ব্যাঙ্গালোর':'IN','ব্যাঙ্গেল':'NN','ব্যাচেলরের':'NN','ব্যাজ':'NN',
'ব্যাজার':'NN','ব্যাঞ্জন':'NN','ব্যাট':'NN','ব্যাটটা':'NN','ব্যাটমসম্যান':'NNP','ব্যাটল':'NN','ব্যাটসম্যান':'NN',
'ব্যাটসম্যানদের':'NNS','ব্যাটসম্যানরা':'NNP','ব্যাটসম্যানেরো':'NN','ব্যাটস্ম্যান':'NNP','ব্যাটস্‌ম্যান':'NN','ব্যাটা':'NN','ব্যাটারী':'NN',
'ব্যাটালিয়ান':'NN','ব্যাটিং':'NN','ব্যাটিংএমন':'NNP','ব্যাটিংটি':'NN','ব্যাটিংয়ের':'NN','ব্যাটেনিয়ন':'NN','ব্যাট্সম্যান':'NN',
'ব্যাড':'NN','ব্যাডমিণ্টন':'NNP','ব্যাডমিন্টন':'NN','ব্যাণ্ড':'NN','ব্যাতীত':'NN','ব্যাথা':'NN','ব্যাথাহীনতা':'NN',
'ব্যাধ':'NN','ব্যাধিতে':'NN','ব্যান':'NN','ব্যানার':'NN','ব্যানারফেষ্টুন':'NN','ব্যানার্জি':'NNP','ব্যানার্জী':'NN',
'ব্যান্ড':'NN','ব্যান্ডউইথ':'NN','ব্যান্ডের':'NN','ব্যাপক':'JJ','ব্যাপকতা':'NN','ব্যাপকভাবে':'RB','ব্যাপন':'NN',
'ব্যাপার':'NN','ব্যাপারই':'NN','ব্যাপারটাই':'NN','ব্যাপারটার':'NN','ব্যাপারলাভ':'NN','ব্যাপারে':'NN','ব্যাপারেও':'NN',
'ব্যাপী':'NN','ব্যাপৃত':'JJ','ব্যাপ্ত':'NN','ব্যাপ্তিরহিত':'JJ','ব্যাবধানে':'NN','ব্যাবসার':'NN','ব্যাবসায়ীদের':'NN',
'ব্যাবসায়ীরা':'NN','ব্যাবস্তা':'NN','ব্যাবস্থাটা':'NN','ব্যাবস্থার':'NN','ব্যাবহার':'VB','ব্যাবহারে':'NN','ব্যাভিচার':'NN',
'ব্যাম্বো':'NN','ব্যায়াম':'NN','ব্যারাক':'NN','ব্যারিস্টার':'NN','ব্যারেল':'NN','ব্যারোমিটার':'NN','ব্যার্থ':'NN',
'ব্যালকনি':'NN','ব্যালটপেপার':'NN','ব্যালটের':'NN','ব্যালানডিঅর':'NN','ব্যালেট-বক্স':'NN','ব্যালেটেও':'NN','ব্যালেন্সের':'NN',
'ব্যাল্ক':'NN','ব্যাশ':'NN','ব্যাসনের':'JJ','ব্যাসার্ধ':'NN','ব্যাস্ত':'JJ','ব্যাহত':'NN','ব্যা্ংক':'NN',
'ব্যায়':'NNS','ব্যায়ও':'NN','ব্যায়নিয়োজ':'NNP','ব্যায়াম':'NN','ব্যায়ামনো':'VB','ব্যায়ামশালা':'NN','ব্যায়ামের':'NN',
'ব্যুতপত্তি':'NN','ব্যুতপত্তিহীন':'JJ','ব্যুরো':'NN','ব্যুষিতাশ্ব':'NN','ব্যূহ':'NN','ব্যোম':'NN','ব্য্যংক':'NN',
'ব্যয়':'NN','ব্যয়বহুল':'NN','ব্যয়শীল':'JJ','ব্যয়াম':'NN','ব্যয়ী':'JJ','ব্যয়ের':'NN','ব্য‌ক্তিগত':'NN',
'ব্রক্ষচর্য':'NN','ব্রক্ষদেশ':'NN','ব্রক্ষমন্ডুকী':'NN','ব্রজ':'NN','ব্রজবাসী':'NN','ব্রজভাষা':'NN','ব্রজমুষ্টি':'NN',
'ব্রজেন্দ্রলালের':'NNP','ব্রড':'NN','ব্রডব্যাণ্ড':'JJ','ব্রডব্যান্ড':'NN','ব্রণ':'NN','ব্রতও':'NN','ব্রতগামী':'NN',
'ব্রতরহিত':'JJ','ব্রতলঙ্ঘনকারী':'JJ','ব্রতহীন':'NN','ব্রতি':'NN','ব্রতের':'NN','ব্রমপুত্র':'NN','ব্রম্হীভূত':'JJ',
'ব্রহ্ম-বিদ্যা':'NN','ব্রহ্ম':'NN','ব্রহ্মকুন্ড':'NNP','ব্রহ্মগিরি':'NN','ব্রহ্মগ্রন্থি':'NN','ব্রহ্মচর্য':'NN','ব্রহ্মচারী':'JJ',
'ব্রহ্মজ্ঞানি':'NN','ব্রহ্মজ্ঞানী':'JJ','ব্রহ্মজ্ঞানে':'NN','ব্রহ্মতাল':'NN','ব্রহ্মতিথি':'NN','ব্রহ্মদেশ':'NNP','ব্রহ্মদৈত্য':'NN',
'ব্রহ্মনদী':'NN','ব্রহ্মপর্ণী':'NN','ব্রহ্মপুত্রী':'NN','ব্রহ্মপূরাণ':'NN','ব্রহ্মবর্চস':'NN','ব্রহ্মবিদ্যা':'NN','ব্রহ্মবৈবর্ত':'NN',
'ব্রহ্মমণ্ডূকী':'NN','ব্রহ্মমেধ্যা':'NN','ব্রহ্মযজ্ঞ':'NN','ব্রহ্মরন্ধ্র':'NN','ব্রহ্মরেখা':'NN','ব্রহ্মলোক':'NN','ব্রহ্মসতী':'NN',
'ব্রহ্মসাবর্ণি':'NN','ব্রহ্মসুত্র':'NN','ব্রহ্মা':'NN','ব্রহ্মাণ্ড':'NN','ব্রহ্মানন্দ':'NN','ব্রহ্মাবর্ত':'NN','ব্রহ্মার':'NNP',
'ব্রহ্মের':'NN','ব্রহ্মোপনিষদ':'NN','ব্রাউজ':'NN','ব্রাউজারএর':'NN','ব্রাউজিং':'NN','ব্রাউনকে':'NNP','ব্রাক':'NN',
'ব্রাকের':'NN','ব্রাক্ষণবাড়ীয়া':'NN','ব্রাজবিল':'NN','ব্রাজিলকে':'NN','ব্রাজিলবাসী':'NN','ব্রাজিলীয়':'NN','ব্রাজিলেরও':'NN',
'ব্রাঞ্চ':'NN','ব্রাতিস্লাভা':'NN','ব্রাদার':'NN','ব্রান্ড':'NN','ব্রাফেট':'NN','ব্রাভো':'NN','ব্রাযিলিয়ান':'NN',
'ব্রাশ':'NN','ব্রাসিল':'NN','ব্রাস্ট':'NN','ব্রাহ্মণ-কায়স্থ':'NN','ব্রাহ্মণ-পুত্র':'NN','ব্রাহ্মণ-সন্তানকে':'NN','ব্রাহ্মণ':'NN',
'ব্রাহ্মণকাণ্ডের':'NN','ব্রাহ্মণগণের':'NN','ব্রাহ্মণপান':'NN','ব্রাহ্মণেটা':'NN','ব্রাহ্মণেরা':'NN','ব্রাহ্মধর্মে':'NN','ব্রাহ্মনী':'NN',
'ব্রাহ্মপুত্র':'NN','ব্রাহ্মসমাজেই':'NNP','ব্রাহ্মাণী':'NN','ব্রাহ্মীউষ্ণিক':'NN','ব্রাহ্মীগায়ত্রী':'NN','ব্রাহ্মীত্রিষ্টুপ':'NN','ব্রাহ্মীপংক্তি':'NN',
'ব্রাহ্মীবৃহতী':'NN','ব্রাহ্ম্যবেলা':'NN','ব্রাহ্ম্যমূহুর্ত':'NN','ব্রায়ন':'NN','ব্রায়োফাইটা':'NN','ব্রিগেড':'NN','ব্রিগেডে':'NN',
'ব্রিজ':'NN','ব্রিটানিকাস':'NNP','ব্রিটিশ':'NN','ব্রিটিশরা':'NN','ব্রিটেন':'NNP','ব্রিটেনেরই':'NN','ব্রিড':'NN',
'ব্রিফিং':'NN','ব্রিলিয়্যান্ট':'NN','ব্রীজ':'NN','ব্রীড়া':'NN','ব্রীফিং':'NN','ব্রুক্স':'NN','ব্রুনেই':'NN',
'ব্রে':'NN','ব্রেইল':'NNP','ব্রেওয়ারী':'NN','ব্রেক':'NN','ব্রেকফার্স্ট':'NNP','ব্রেকার':'NN','ব্রেড':'NN',
'ব্রেনান':'NNP','ব্রেল':'NN','ব্রো':'NN','ব্রোকিং':'NN','ব্রোঞ্জ':'NN','ব্রোমাইন':'NN','ব্র্যাক':'NN',
'ব্র্যান্ডি':'NN','ব্র্যান্ডের':'NN','ব্লক':'NN','ব্লগদুনিয়ায়':'NN','ব্লগাররা':'NN','ব্লগিং':'NNV','ব্লাউজ':'NN',
'ব্লাকবেরির':'NN','ব্লাড':'NN','ব্লাডগ্রুপ':'NN','ব্লাডপ্রেশার':'NN','ব্লাফ':'NN','ব্লাস্ট':'NN','ব্লিভনত্রীগের':'NNP',
'ব্লিস্টার':'NN','ব্লু':'NN','ব্লুমফিল্ডের':'NNP','ব্লেক':'NN','ব্লেজার':'NN','ব্লেড':'NN','ব্লেয়ার':'NN',
'ব্লোটিং':'NN','ব্লোয়ার':'NN','ব্ল্যাক':'NN','ব্ল্যাকমেইল':'NN','ব্ল্যাকমেলার':'NN','ব্ল্যাঙ্ক':'NN','বৎসর':'NN',
'বৎসরে':'NN','বৎসরেতো':'NN','বৎ্যবসায়ীদের':'NN','বড়':'JJ','বড়ই':'NN','বড়ঋণের':'NN','বড়ও':'JJ',
'বড়জোর':'NN','বড়দিন':'NN','বড়দের':'NN','বড়বাড়ি':'NN','বড়বড়':'JJ','বড়মাপের':'JJ','বড়রা':'NN',
'বড়লোক':'JJ','বড়লোকদের':'NN','বড়সড়':'NN','বড়া':'JJ','বড়াই':'NN','বড়ানো':'VB','বড়ানোর':'NN',
'বড়াল':'NN','বড়ি':'NN','বড়িশায়':'NNP','বড়ুয়া':'NN','বড়েে':'NN','বড়ো-বড়ো':'JJ','বড়ো':'NN',
'বয়':'NN','বয়কট':'NN','বয়ড়া':'NN','বয়ন':'NN','বয়ফ্রেণ্ডের':'NN','বয়বে':'VB','বয়মাকৃতি':'JJ',
'বয়স':'NN','বয়সজনিত':'NN','বয়সভিত্তিক':'NN','বয়সসীমা':'NN','বয়সে':'NN','বয়সেও':'NN','বয়সেরই':'NN',
'বয়স্ক':'NN','বয়স্কা':'JJ','বয়া':'NN','বয়ানে':'NN','বয়েজউদ্দিন':'NNP','বয়ের':'NN','বয়েসে':'NN',
'বয়োজ্যেষ্ঠদের':'NN','বয়োবৃ':'NN','বয়োবৃদ্ধ':'JJ','ব‌লে':'NN','ব‌িশ্বকাপ':'NN','ব‍্যবসার':'NN','ব‍্যবহার':'NN',
'ব‍্যর্থ':'NN','ব‍্যাংকিং':'NN','ব‍্যাংকের':'NN','ব‍্যার্থতা':'NN','ভ':'NN','ভং':'NN','ভংগুর':'NN',
'ভআলো':'VB','ভইরাই':'NN','ভকভক':'VB','ভক্ত-বত্সল':'JJ','ভক্ত':'NN','ভক্তগণের':'NN','ভক্ততূর্য':'NN',
'ভক্তদের':'NN','ভক্তনা':'NN','ভক্তবত্সল':'JJ','ভক্তমানসে':'NN','ভক্তরা':'NN','ভক্তাদের':'NN','ভক্তি':'NN',
'ভক্তিপক্ষে':'NN','ভক্তিপূর্ণ':'JJ','ভক্তিবাদ':'NN','ভক্তিমতী':'JJ','ভক্তিহীন':'NN','ভক্তের':'NN','ভক্ষ':'NN',
'ভক্ষকদের':'NN','ভক্ষণ':'NN','ভক্ষণকারী':'JJ','ভক্ষনকারী':'NN','ভক্ষিত':'JJ','ভক্ষ্য':'NN','ভখী':'NN',
'ভগ':'NN','ভগত্':'NN','ভগন্দর':'NN','ভগবতি':'NN','ভগবদ':'NN','ভগবদভাবে':'RB','ভগবদ্গীতায়':'NN',
'ভগবান':'NN','ভগবানপ্রদত্ত':'JJ','ভগবানের':'NN','ভগাঙ্কুর':'NN','ভগালি':'NN','ভগাস':'NN','ভগিনী':'NN',
'ভগিনেয়':'NN','ভগীরথ':'NN','ভগ্ন':'NNP','ভগ্নদূত':'NN','ভগ্নপৃষ্ঠ':'JJ','ভগ্নসন্ধি':'NN','ভগ্নস্তুপ':'NN',
'ভগ্নাংশ':'NN','ভগ্নাবশেষ':'NN','ভগৎ':'NN','ভঙ্ক্ষণ':'NN','ভঙ্গ':'NN','ভঙ্গকারী':'JJ','ভঙ্গকারীকে':'NN',
'ভঙ্গরা':'NN','ভঙ্গি':'NN','ভঙ্গিমা':'NN','ভঙ্গীর':'NN','ভঙ্গুরতা':'NN','ভজ':'NNP','ভজন':'NN',
'ভঞ্জন':'NN','ভটতীতর':'NN','ভটুরা':'NN','ভট্টাচার্য্য':'NNP','ভড়ঁভাড়ঁ':'NN','ভড়ুয়া':'NN','ভড্ডর':'NN',
'ভণ্ড':'NN','ভণ্ডাসুর':'NN','ভণ্ডিত':'NN','ভণ্ডের':'NN','ভতরোড়':'NN','ভতর্সনা':'NN','ভতিণ্ডা':'NN',
'ভতৃহরি':'NN','ভদ্র':'NN','ভদ্রকালী':'NN','ভদ্রতা':'NN','ভদ্রতার':'NN','ভদ্রদন্তী':'NN','ভদ্রদেব':'NN',
'ভদ্রবাহু':'NN','ভদ্রবিন্দ':'NN','ভদ্রভাবে':'NN','ভদ্রমদা':'NN','ভদ্রলোক':'NN','ভদ্রলোকটি':'NN','ভদ্রসীমা':'NN',
'ভদ্রসেন':'NN','ভদ্রসোমা':'NN','ভদ্রাযুধ':'NN','ভনভন':'NN','ভন্ড':'JJ','ভন্ডকে':'NN','ভন্ডামি':'NN',
'ভন্ডের':'NN','ভব-চক্র':'NN','ভব-জাল':'NN','ভব-বন্ধন':'NN','ভব':'NN','ভবকে':'NN','ভবঘুরে':'NN',
'ভবচক্র':'NN','ভবজাল':'NN','ভবতঃ':'RB','ভবতারিণী':'NNP','ভবতি':'NN','ভবদা':'NN','ভবন':'NN',
'ভবনএমনকি':'NN','ভবনাশিনী':'NN','ভবনে':'NN','ভবপর':'NN','ভববন্ধন':'NN','ভবভূতি':'NN','ভবরুত':'NN',
'ভবলিয়া':'NN','ভবসাগর':'NN','ভবসিন্ধু':'NN','ভবান':'NN','ভবানী':'NNP','ভবানীপাটনা':'NN','ভবিতব্য':'NN',
'ভবিশ্যতকে':'NN','ভবিষতে':'NN','ভবিষ্য-তহবিল':'NN','ভবিষ্য':'NN','ভবিষ্যতএ':'NN','ভবিষ্যতবক্তা':'NN','ভবিষ্যতে':'RB',
'ভবিষ্যতেই':'NN','ভবিষ্যতের':'NN','ভবিষ্যত্দ্রষ্টা':'JJ','ভবিষ্যত্বাণীর':'NN','ভবিষ্যদ্দ্রষ্টা':'NN','ভবিষ্যদ্বাণী':'NN','ভবিষ্যপুরাণ':'NN',
'ভবিষ্যৎ':'NN','ভবিসসতে':'NN','ভবের':'NN','ভবোদয়':'NN','ভব্য':'NN','ভভুয়া':'NN','ভভ্যতা':'NN',
'ভমূল':'JJ','ভম্ব':'NN','ভয়':'NN','ভয়ংকর':'NN','ভয়ই':'NN','ভয়ঙ্কর':'JJ','ভয়টা':'NN',
'ভয়ানক':'JJ','ভয়াবহ':'JJ','ভয়ে':'NN','ভর':'NN','ভরছে':'NN','ভরণপোষণ':'NN','ভরণী':'NN',
'ভরত':'NN','ভরতনাট্যম':'NN','ভরতপাখি':'NN','ভরতপুর':'NNP','ভরতবীণা':'NN','ভরতুকি':'NN','ভরতুকিপ্রদত্ত':'JJ',
'ভরতে':'NN','ভরদ্বাজ':'NN','ভরপুর':'NN','ভরপেট':'RB','ভরব':'NN','ভরম':'NN','ভরলো':'VBN',
'ভরশা':'NN','ভরসা':'NNP','ভরসাযোগ্য':'JJ','ভরসায়':'RB','ভরা':'VBN','ভরাই':'NN','ভরাট':'VBN',
'ভরাডুবি':'VBG','ভরাডুবির':'NN','ভরানো':'VB','ভরার':'VBG','ভরি':'NN','ভরিয়ে':'VBN','ভরুচ':'JJ',
'ভরে':'VBN','ভরেনা':'NN','ভরের':'NN','ভর্তা':'NN','ভর্তিনো':'VB','ভর্তুকি':'NNS','ভলান্টিয়ার':'NN',
'ভলিবল':'NN','ভলেস':'NNP','ভলো':'NN','ভল্ট':'NN','ভল্লক':'NN','ভল্লুক':'NN','ভসাকু':'NN',
'ভস্তকের':'NNP','ভস্ত্রা':'NN','ভস্ম':'NN','ভস্মকারী':'JJ','ভস্মাসুর':'NN','ভস্মীভূত':'JJ','ভস্মোপনিষদ':'NN',
'ভাঁওতাবাজি':'NN','ভাঁজ':'NN','ভাঁটা':'NN','ভাঁড়':'NN','ভাঁড়ার':'NN','ভাঁবর':'NN','ভাঁড়':'NN',
'ভাঁড়ামি':'VBG','ভাং-এর':'NN','ভাং':'NN','ভাংখোর':'NN','ভাংগতে':'NN','ভাংগার':'NN','ভাংঙ্গাচোড়া':'NN',
'ভাংচুর':'NN','ভাংতির':'NN','ভাংলোনা':'NN','ভাই':'NN','ভাইইহা':'NN','ভাইএক':'NN','ভাইকিন্ত':'NN',
'ভাইকে':'NN','ভাইজান':'NN','ভাইঝি':'NN','ভাইটাকা':'NN','ভাইড':'IN','ভাইতার':'NNS','ভাইনিজের':'NN',
'ভাইপো':'NN','ভাইফোঁটা':'NN','ভাইবা':'NN','ভাইবার':'NNP','ভাইবেননা':'NN','ভাইবোন':'NNS','ভাইবোনদের':'NN',
'ভাইয়া':'NN','ভাইরা':'NNS','ভাইরাল':'NN','ভাইরাসকে':'NN','ভাইরাসঘটিত':'NN','ভাইরোলজি':'NN','ভাইস-প্রেসিডেন্ট':'NN',
'ভাইস':'NN','ভাইসাধিনতা':'NN','ভাইয়া':'NN','ভাইয়ের':'NN','ভাউ':'NN','ভাওতাবাজি':'NN','ভাওতাবাজী':'NN',
'ভাওয়াইয়া':'NN','ভাকর':'JJ','ভাগ-ফল':'NN','ভাগ':'NN','ভাগকারী':'NN','ভাগচাষ':'NN','ভাগচাষের':'NN',
'ভাগনেটির':'NN','ভাগনো':'VB','ভাগফল':'NN','ভাগবতপন্থা':'NN','ভাগবতী':'NN','ভাগবত্পূরাণ':'NN','ভাগবাটোয়ারা':'NN',
'ভাগরা':'NN','ভাগলপুর':'NNP','ভাগলপুরী':'JJ','ভাগশেষ':'NN','ভাগানো':'VB','ভাগাভাগি':'NN','ভাগারে':'NN',
'ভাগাড়':'NN','ভাগাড়ে':'NN','ভাগি':'NN','ভাগিনেয়':'NN','ভাগিয়ে':'VB','ভাগীদার':'NN','ভাগীরথ':'NN',
'ভাগে':'NN','ভাগ্নিকে':'NN','ভাগ্য':'NN','ভাগ্যবাদী':'JJ','ভাগ্যবান':'NN','ভাগ্যশালী':'JJ','ভাগ্যহীনতা':'NN',
'ভাগ্যান্বেষী':'JJ','ভাগ্যিস':'NN','ভাগ্যের':'NN','ভাঙ':'NN','ভাঙচুর':'NN','ভাঙছে':'VBG','ভাঙতি':'NNS',
'ভাঙতে':'VB','ভাঙনের':'IN','ভাঙবার':'NNV','ভাঙবেন':'NN','ভাঙল':'VB','ভাঙলেও':'NNS','ভাঙা':'NNP',
'ভাঙাচোরা':'NN','ভাঙানি':'VB','ভাঙানো':'NN','ভাঙায়':'NNS','ভাঙিয়ে':'VBG','ভাঙে':'VB','ভাঙের':'NN',
'ভাঙ্গছে':'VB','ভাঙ্গড়া':'NN','ভাঙ্গতে':'NN','ভাঙ্গলো':'VBD','ভাঙ্গা-চোড়া':'JJ','ভাঙ্গা':'VB','ভাঙ্গানো':'NN',
'ভাঙ্গেনি':'VB','ভাজ':'NN','ভাজকরা':'NN','ভাজন':'NN','ভাজপা':'NN','ভাজার':'VBG','ভাজিয়াউর':'NN',
'ভাজেন':'VB','ভাজ্য':'NN','ভাটকলাগাছি':'NN','ভাটনাস':'NN','ভাটার':'NN','ভাটি':'NN','ভাটিখানা':'NN',
'ভাটির':'NN','ভাটিয়ারিন':'NN','ভাটিয়াল':'NN','ভাটিয়ালী':'NN','ভাড়':'NN','ভাড়ভুঁজা':'NN','ভাড়া-বঞ্চিত':'JJ',
'ভাড়া':'NN','ভাড়াটে':'NN','ভাণ্ডার-এ':'NN','ভাণ্ডারা':'NN','ভাত':'NN','ভাতখোর':'JJ','ভাতা':'NN',
'ভাতিজা':'NN','ভাতী':'JJ','ভাতৃজ':'NN','ভাতৃদ্বিতীয়া':'NN','ভাতে':'NN','ভাত্রা':'NN','ভাদই':'JJ',
'ভাদু':'NN','ভাদোই':'NN','ভাদোদরা':'NN','ভাদ্র':'NN','ভাদ্রপদ-কৃষ্ণ':'NN','ভাদ্রমাসের':'JJ','ভান':'NN',
'ভানুজা':'NN','ভানুদেব':'NN','ভানুপ্রতাপ':'NN','ভানুবাবু':'NNP','ভানুমতি':'NN','ভানুমান':'NN','ভান্ডার':'NN',
'ভাপ':'NN','ভাপবড়ি':'NN','ভাব-ভঙ্গিমা':'NN','ভাব':'NN','ভাবই':'NN','ভাবক':'NN','ভাবগত':'JJ',
'ভাবছি':'VB','ভাবছিলাম':'VBG','ভাবছে':'VB','ভাবছেন':'VBG','ভাবজ':'JJ','ভাবটা':'NN','ভাবত':'NN',
'ভাবতাম':'VB','ভাবতেই':'VBG','ভাবতেও':'NN','ভাবতেন':'VB','ভাবন':'NN','ভাবনা-চিন্তাকে':'NN','ভাবনা':'NN',
'ভাবনাও':'VB','ভাবনাজনক':'JJ','ভাবনাটি':'NN','ভাবনাহীন':'JJ','ভাবনোপনিষদ':'NN','ভাবপূর্ণ':'NN','ভাবপ্রকাশ':'NN',
'ভাবপ্রবণ':'NN','ভাববাচক':'NN','ভাববিলাসীদের':'NN','ভাববে':'VB','ভাববেওনা':'NN','ভাববেন':'VB','ভাবভঙ্গিমা':'NN',
'ভাবমূর্তি':'NN','ভাবর':'NN','ভাবলাম':'VB','ভাবলে':'NN','ভাবলোনা':'NN','ভাবস':'NNS','ভাবসন্ধি':'NN',
'ভাবসবলতা':'NN','ভাবহীন':'JJ','ভাবা':'VB','ভাবাত্মক':'JJ','ভাবাবশে':'NN','ভাবাবেগে':'NN','ভাবাভিব্যক্ত':'VB',
'ভাবার্থ':'NN','ভাবার্থদীপিকা':'NN','ভাবায়ব্য':'NN','ভাবি':'NN','ভাবিত':'JJ','ভাবিনা':'NN','ভাবিনী':'NN',
'ভাবিলাম':'VB','ভাবী':'NN','ভাবুক':'NN','ভাবুন':'NN','ভাবে':'NN','ভাবেই':'NNP','ভাবেইবিএনপির':'NN',
'ভাবেন':'NNS','ভাবেনা':'NN','ভাবের':'NN','ভাবো':'NN','ভাভর':'NN','ভাম':'NN','ভামপলাশি':'NN',
'ভামবিড়াল':'NN','ভামা':'NN','ভামিনী':'NN','ভায়':'NN','ভার':'NN','ভারকর্ণ':'NN','ভারগ্রস্ত':'JJ',
'ভারঙ্গী':'NN','ভারচুয়াল':'NN','ভারজিনিয়া':'NN','ভারত-ইতিহাসে':'NNP','ভারত':'NN','ভারতঅষ্ট্রেলিয়া':'NNS','ভারতই':'NNP',
'ভারতকে':'NNP','ভারততত্ত্ব':'NNP','ভারতপ্রীতি':'NN','ভারতবর্ষ':'NN','ভারতবর্ষটাকে':'NNP','ভারতবর্ষের':'NNP','ভারতবাসী':'NN',
'ভারতবাসীকে':'NNS','ভারতিয়':'JJ','ভারতিয়রা':'NN','ভারতী':'NNS','ভারতীয়':'NN','ভারতীয়গুলাকে':'NN','ভারতীয়ত্ব':'NN',
'ভারতীয়দের':'NNS','ভারতীয়ভিত্তিক':'JJ','ভারতীয়র':'JJ','ভারতীয়রা':'NNS','ভারতীয়রাও':'NN','ভারতে':'NNP','ভারতেরই':'NN',
'ভারতেরটা':'NN','ভারবাহক':'NN','ভারবোঝাই':'JJ','ভারসাম্য':'NN','ভারসাম্যহীন':'NN','ভারা':'NN','ভারাক্রান্ত':'NN',
'ভারি':'NN','ভারী':'NNP','ভারুই':'NN','ভারে':'NNP','ভারোত্তলন':'NN','ভারৌন্ট':'NN','ভার্গব':'NN',
'ভার্চুয়াল':'JJ','ভার্জিনিয়া':'NNP','ভার্জিল':'NNP','ভার্টেক্স':'NN','ভার্যা':'NN','ভার্সন':'NN','ভার্সিটি':'NN',
'ভার্সিটির':'NN','ভাল':'JJ','ভালইতো':'NN','ভালএবার':'NN','ভালও':'NN','ভালচন্দ্র':'NN','ভালতবে':'NN',
'ভালবাসতে':'VB','ভালবাসব':'VB','ভালবাসাও':'VB','ভালবাসায়':'VB','ভালবাসে':'NNS','ভালবাসেন':'VB','ভালভাবে':'RB',
'ভালমত':'NN','ভালযেমন':'NN','ভালর':'JJ','ভালুক':'NN','ভালেটা':'NN','ভালো':'JJ','ভালো':'NN',
'ভালোই':'JJ','ভালোইতো':'NN','ভালোত্ব':'NN','ভালোপরিবেশে':'NN','ভালোবাস':'VB','ভালোবাসতাম':'NN','ভালোবাসতে':'VB',
'ভালোবাসা-ভালোবাসা':'NN','ভালোবাসা':'VB','ভালোবাসাভালো':'NN','ভালোবাসি':'VB','ভালোবাসিয়াছি':'NN','ভালোবাসুন':'NN','ভালোবাসে':'VB',
'ভালোবেসে':'NN','ভালোভাবে':'RB','ভালোমত':'NN','ভালোমন্দ':'VB','ভালোমানুষি':'NN','ভালোমান্সের':'NN','ভালোর':'JJ',
'ভালোলাগা':'VB','ভালোলাগার':'NN','ভালোয়':'NN','ভাল্ব':'NN','ভাল্লাগেনা':'NN','ভাল্লাগ্লো':'NN','ভাল্লুক':'NN',
'ভাষ':'NN','ভাষণদাতা':'NN','ভাষণে':'NN','ভাষা-বিজ্ঞান':'NN','ভাষা':'NN','ভাষাকে':'NN','ভাষাগুলি':'NN',
'ভাষাজিজ্ঞাসার':'NN','ভাষাতত্ত্ব':'NN','ভাষাতত্ত্বের':'NN','ভাষাতাত্ত্বিক':'JJ','ভাষাতাত্ত্বিকেরা':'NN','ভাষাতে':'NN','ভাষানটেকে':'NN',
'ভাষান্তর':'NN','ভাষান্তরণ':'NN','ভাষাপ্রয়োগ':'NN','ভাষাবাকরীতির':'NN','ভাষাবিজ্ঞান-বিষয়ক':'NN','ভাষাবিজ্ঞান':'NNP','ভাষাবিজ্ঞানী':'NN',
'ভাষাবিজ্ঞানীরা':'NN','ভাষাবিজ্ঞানের':'NNP','ভাষাবিদ':'NN','ভাষাবিদ্যা':'NN','ভাষাবিষয়ক':'NN','ভাষাবৈজ্ঞানিক':'JJ','ভাষাবোধ':'NN',
'ভাষাভাষী':'VBG','ভাষায়':'NN','ভাষাসমূহের':'NN','ভাষায়':'NN','ভাষিক':'JJ','ভাষিত':'NN','ভাষী':'JJ',
'ভাষ্য':'JJ','ভাষ্যকার':'NN','ভাস':'VBG','ভাসছে':'VBG','ভাসছেন':'NN','ভাসত':'VB','ভাসতে':'NN',
'ভাসমান':'JJ','ভাসা':'NN','ভাসাননি':'NNP','ভাসানো':'VBG','ভাসাবে':'NN','ভাসালেন':'VBN','ভাসায়ে':'VBG',
'ভাসিয়ে':'VB','ভাসুর':'NN','ভাসুরপুত্র':'NN','ভাসে':'VBG','ভাস্কর':'NN','ভাস্করাচার্য্য':'NNP','ভাস্কর্য':'NN',
'ভাস্কর্য্যশিল্প':'NN','ভাস্কো':'NN','ভাস্বর':'NNP','ভাড়া':'NN','ভাড়ামী':'NN','ভায়রাভাই':'NN','ভায়া':'NN',
'ভায়োলিন':'NN','ভায়োলেন্ট':'JJ','ভি':'NN','ভিংস':'NNP','ভিআইপি':'NN','ভিআইপিদের':'NNS','ভিউ':'NN',
'ভিওআইপি':'NN','ভিওিতে':'NN','ভিওয়াইপি':'NN','ভিওয়াপি':'NN','ভিকটিম':'NN','ভিক্টেরিয়া':'NN','ভিক্টোরিয়া':'NN',
'ভিক্টোরিয়ান':'JJ','ভিক্ষা':'NN','ভিক্ষান্ন':'NN','ভিক্ষাপাত্র':'NN','ভিক্ষাবৃত্তি':'NN','ভিক্ষার':'NN','ভিক্ষার্থী':'JJ',
'ভিক্ষু':'NN','ভিক্ষুকও':'NN','ভিক্ষুকের':'NN','ভিক্ষুকোপনিষদ':'NN','ভিক্ষে':'NN','ভিখারিনী':'NN','ভিখিরি':'NN',
'ভিগো্র':'NN','ভিজতেছে':'NN','ভিজা':'NN','ভিজিট':'NN','ভিজিলেন্স':'NN','ভিজিয়ে':'NN','ভিট':'NN',
'ভিটামাটি':'NNS','ভিটামিন':'NN','ভিটে':'NN','ভিড়-ভাট্টা':'NN','ভিড়':'NN','ভিড়িয়ে':'VB','ভিড়ে':'NN',
'ভিডিও':'NN','ভিণ্ড':'NN','ভিত':'NN','ভিতর':'IN','ভিতরে-বাইরে':'NN','ভিতরে':'IN','ভিতরেই':'NN',
'ভিতরের':'IN','ভিতল্লী':'NN','ভিতু':'NN','ভিত্তি':'NN','ভিত্তিক':'NN','ভিত্তিচিত্র':'NN','ভিত্তিতেই':'NN',
'ভিত্তিপ্রস্তর':'NN','ভিত্তিভূমি':'NN','ভিত্তিস্তম্ভ':'NN','ভিত্তিহীন':'JJ','ভিত‌রে':'IN','ভিদে':'NN','ভিন':'NN',
'ভিনগোত্রের':'NN','ভিনগ্রহী':'JJ','ভিনগ্রহে':'NN','ভিনদেশ':'NN','ভিনদেশে':'NN','ভিনব':'JJ','ভিনভিন':'NN',
'ভিনসেন্ট':'NN','ভিনে':'NN','ভিন্ন':'NN','ভিন্নতর':'JJ','ভিন্নতা':'NN','ভিন্নমত':'JJ','ভিন্নমতালম্বিদের':'NNS',
'ভিন্নমতের':'NN','ভিন্নরূপী':'JJ','ভিনয়':'NN','ভিবানি':'NN','ভিভ':'NN','ভিভিআইপি':'NN','ভিভূতি':'NN',
'ভিমত':'JJ','ভিমরুল':'NN','ভিরাট':'NN','ভিরেমিয়া':'NN','ভিল':'NN','ভিলওয়ারা':'NN','ভিলনী':'NN',
'ভিলাই':'NN','ভিলারিয়াল':'NN','ভিলিয়ার্সের':'NN','ভিলীয়':'JJ','ভিলেজ':'NN','ভিলের':'JJ','ভিশক':'NN',
'ভিশনারি':'NN','ভিসকস':'NN','ভিসন':'NN','ভিসাও':'NN','ভিসার':'NNP','ভিসি':'NN','ভিসিবিলিটি':'NN',
'ভিসির':'NN','ভিড়':'NN','ভিড়াতে':'NN','ভিড়ালেন':'VBN','ভিড়েছেন':'VB','ভিড়ের':'NN','ভিয়াকুরো':'NN',
'ভিয়েতনাম':'NN','ভিয়েতনামি':'NN','ভিয়েতনামী':'NN','ভিয়েতনামের':'NNP','ভিয়েনা':'NN','ভীওয়াইপি':'NN','ভীত':'NN',
'ভীতিকর':'NN','ভীতু':'NN','ভীতুর':'RB','ভীনমাল':'NN','ভীম':'NN','ভীমকুন্ড':'NN','ভীমপরাক্রম':'NN',
'ভীমপলশ্রী':'NN','ভীমবল':'NN','ভীমবিক্রম':'NN','ভীমরতি':'NNS','ভীমরথ':'NN','ভীমরিকা':'NN','ভীমসেন':'NN',
'ভীমাশংকর':'NN','ভীমাষ্টমী':'NN','ভীর':'VB','ভীরা':'NN','ভীরুতা':'NN','ভীরে':'NN','ভীষণ':'RB',
'ভীষণতা':'NN','ভীষণভাবে':'RB','ভীষন':'NN','ভীষ্ম':'NN','ভীষ্মপঞ্চক':'NN','ভীষ্মমণি':'NN','ভীষ্মের':'NN',
'ভীড়':'JJ','ভীড়ে':'NN','ভুঁই-কুমড়ো':'NN','ভুঁইআওলা':'NN','ভুঁইকাঁড়া':'NN','ভুঁইকুমড়ো':'NN','ভুঁইফোড়':'NN',
'ভুঁড়িওয়ালা':'JJ','ভুঁরি':'NN','ভুকাক':'NN','ভুক্ত':'JJ','ভুক্তভুগি':'NN','ভুক্তভোগি':'JJ','ভুক্তভোগীর':'NN',
'ভুক্তাবশেষ':'JJ','ভুখা':'NN','ভুগছি':'NN','ভুগছেন':'VBG','ভুগতে':'NN','ভুগে':'VB','ভুগেছি':'NN',
'ভুজ':'NN','ভুজকোটর':'NN','ভুজঙ্গ':'NN','ভুজঙ্গপ্রয়াত':'NN','ভুজঙ্গম':'NN','ভুজঙ্গসঙ্গতা':'NN','ভুজঙ্গী':'NN',
'ভুজপত্র':'NN','ভুজস্তম্ভ':'NN','ভুজা':'NN','ভুটান':'NN','ভুটানি':'NNP','ভুটানের':'NN','ভুট্টা':'NN',
'ভুট্টো':'NNP','ভুড়ভুড়':'VB','ভুড়ারী':'NN','ভুত':'NNS','ভুতুড়ে':'NN','ভুতেরতাইনা':'NN','ভুনগি':'NN',
'ভুনা':'VB','ভুনিয়া':'NN','ভুন্ডী':'NN','ভুবন':'NN','ভুবু':'NNP','ভুমি':'NN','ভুমিকাই':'NN',
'ভুমিতে':'NN','ভুরত':'NN','ভুরলী':'NN','ভুরলোখরিয়া':'NN','ভুরি':'NN','ভুরুণ্ড':'NN','ভুরুতে':'NN',
'ভুল-ভুলাইয়া':'NN','ভুল-ভ্রান্তি':'NN','ভুল':'JJ','ভুলকরে':'NN','ভুলকাবাটি':'NN','ভুলগুলো':'NN','ভুলচুক':'NN',
'ভুলটা':'NN','ভুলটি':'VB','ভুলতে':'NN','ভুলত্রুটি':'NN','ভুলপথ':'NN','ভুলবে':'VB','ভুলবেন':'NN',
'ভুলভাল':'NN','ভুলভ্রান্তি':'NN','ভুলাইয়া':'NN','ভুলি':'NN','ভুলিয়ে':'VB','ভুলে':'NN','ভুলেও':'NN',
'ভুলেগেছেন':'NN','ভুলেছি':'VB','ভুলেনি':'NN','ভুলোমন':'NN','ভুলোমনা':'JJ','ভুষি':'NN','ভুষুন্ডি':'NN',
'ভুস':'NNP','ভুসরা':'NN','ভুসি':'NN','ভুয়া':'NN','ভূ-ক্ষরণ':'NN','ভূ-খণ্ড':'NN','ভূ-গর্ভ-শাস্ত্র':'NN',
'ভূ-পদার্থ':'NN','ভূ-পৃষ্ঠ':'NN','ভূ-বিজ্ঞান':'NN','ভূ-ভাগ':'NN','ভূ-ভৌতিকী':'NN','ভূ-শাস্ত্র':'NN','ভূ':'NN',
'ভূঁইয়ার':'NN','ভূঁড়িয়াল':'NN','ভূঅভ্যন্তরস্থ':'JJ','ভূকম্প':'NN','ভূকে':'NN','ভূক্ত':'NN','ভূক্তভোগী':'NN',
'ভূক্ষরণ':'NN','ভূখণ্ড':'NN','ভূগজা':'NN','ভূগর্ভ-শাস্ত্র':'NN','ভূগর্ভ':'NN','ভূগর্ভশাস্ত্র':'NN','ভূগোল':'NN',
'ভূগোলবিজ্ঞানী':'NN','ভূগোলবিদ':'NN','ভূগোলশাস্ত্র':'NN','ভূগোলশাস্ত্রী':'NN','ভূগোলীয়':'JJ','ভূগোলের':'NNP','ভূজ':'NN',
'ভূজঙ্গ':'NN','ভূজবল':'NN','ভূজস্তম্ভ':'NN','ভূজহীন':'JJ','ভূটানবাসী':'NN','ভূটানি':'NN','ভূটিয়া':'JJ',
'ভূত-প্রেত':'NN','ভূত':'NN','ভূতকাল':'NN','ভূতকালীন':'JJ','ভূতকেতু':'NN','ভূতজাত':'JJ','ভূতধাম':'NN',
'ভূতনায়িকা':'NN','ভূতপূর্ব':'NN','ভূতবাধা':'NN','ভূতবিদ্যা':'NN','ভূতল':'NN','ভূতহাস':'NN','ভূতাঙ্কুশ':'NN',
'ভূতাবেশ':'NN','ভূতি':'NNP','ভূতুরে':'NN','ভূতের':'NNS','ভূদান':'NNP','ভূদেব':'NN','ভূধর':'NN',
'ভূপতি':'NN','ভূপতিত':'VB','ভূপদার্থ':'NN','ভূপাল':'NNP','ভূপালী':'NN','ভূপৃষ্ঠে':'NN','ভূপ্রকৃতি':'NN',
'ভূব':'NN','ভূবনমোহন':'NNP','ভূবনেশ্বর':'NN','ভূবিজ্ঞান':'NN','ভূবিদ্যা':'NNP','ভূভাগ':'NN','ভূভৌতিকী':'NN',
'ভূমণ্ডল':'NN','ভূমধ্যরেখা':'NN','ভূমধ্যসাগর':'NN','ভূমধ্যসাগরীয়':'JJ','ভূমন্ডলীকরণ':'NN','ভূমন্ডলীয়':'JJ','ভূমি-বায়ু':'NN',
'ভূমি':'NN','ভূমিকম্প':'NN','ভূমিকা':'NN','ভূমিকাগুলো':'NN','ভূমিকার':'NN','ভূমিক্ষয়':'VB','ভূমিখণ্ড':'NN',
'ভূমিজ':'NN','ভূমিজাতদ্রব্য':'NN','ভূমিজীবী':'NN','ভূমিতে':'NN','ভূমিধর':'NN','ভূমিপুত্র':'NN','ভূমিরাজস্ব':'NN',
'ভূমিরূপ':'NN','ভূমিলবণ':'NN','ভূমিষ্ঠ':'JJ','ভূমিসেন':'NN','ভূমিস্তোম':'NN','ভূমিহার':'NN','ভূরাজনৈতিক':'NN',
'ভূরিবল':'NN','ভূরিশ্রবা':'NN','ভূর্তুকি':'NNS','ভূল':'NN','ভূলন্ঠিত':'JJ','ভূশাস্ত্র':'NN','ভূশয়ান':'NN',
'ভূষণ':'NN','ভূষণ্ডী':'NN','ভূষিত':'NN','ভূসমীক্ষা':'NN','ভূসম্পত্তি':'NN','ভূসুত':'NN','ভূস্খলন':'NN',
'ভূয়সী':'JJ','ভূয়া':'NN','ভূ‌মিধ্বস':'NNS','ভৃগু':'NN','ভৃগুনন্দন':'NN','ভৃগুনাথ':'NN','ভৃগুপতি':'NN',
'ভৃগুরেখা':'NN','ভৃগুলতা':'NN','ভৃঙ্গ':'NN','ভৃঙ্গারিকা':'NN','ভৃতি':'NN','ভৃত্য':'NN','ভৃত্য':'NN',
'ভৃমি':'NN','ভৃম্যশ্ব':'NN','ভেঁধে':'VB','ভেঁপু':'NN','ভেংগে':'NN','ভেইকল':'NN','ভেগ':'NN',
'ভেঙে':'NN','ভেঙেও':'VB','ভেঙেছিল':'NN','ভেঙ্কট':'NN','ভেঙ্গে':'NN','ভেজলিন':'NN','ভেজা':'NN',
'ভেজাল':'NN','ভেজালেও':'VBN','ভেঞ্চার':'NN','ভেট':'NN','ভেড়া':'NN','ভেড়ানো':'VB','ভেড়ার':'NN',
'ভেতর':'NN','ভেতরে':'IN','ভেতরের':'NN','ভেতো':'JJ','ভেদ':'NN','ভেদক':'JJ','ভেদনীয়':'JJ',
'ভেদভাব':'NN','ভেদাভেদ':'NN','ভেদাভেদ':'NN','ভেদাশি':'NN','ভেদিত':'JJ','ভেদী':'JJ','ভেদে':'NN',
'ভেদ্দসদের':'NNP','ভেদ্য':'JJ','ভেনাস':'NN','ভেনিজুয়েলার':'NN','ভেনিস':'NN','ভেনেজুয়েলা':'NN','ভেনেজুয়েলান':'NN',
'ভেনেজুয়েলার':'JJ','ভেন্যু':'NN','ভেপসে':'NN','ভেবে':'VB','ভেবেই':'NN','ভেবেচিন্তে':'NN','ভেবেছিলাম':'NN',
'ভেবেছিলুম':'VB','ভেবেছিলো':'VB','ভেবেছেন':'VB','ভেবো':'VB','ভেভম':'NN','ভেরিফাই':'VB','ভেরিফাইড':'NN',
'ভেরিফিকেসন':'NN','ভেরিবাদক':'NN','ভেরী':'NN','ভের্ডে':'NN','ভেল':'NN','ভেলগ্রেড':'NN','ভেলপুরি':'NN',
'ভেলভেট':'NN','ভেলা':'NN','ভেলিয়া':'NNP','ভেল্কি':'NN','ভেল্ডে':'NN','ভেষজ':'NN','ভেসলনি':'NN',
'ভেসে':'VBG','ভেসেছিল':'VB','ভেসেলিন':'NN','ভেস্তে':'NN','ভোক্তা':'NN','ভোগ':'VB','ভোট':'NN',
'ভো‌টে':'NN','ভেড়া':'NN','ভেড়ার':'NN','ভে‌ঙ্গে':'NN','ভৈমী':'NN','ভৈরব':'NN','ভৈরবাঞ্জন':'NN',
'ভৈরবী':'NN','ভোঁ-ভোঁ':'NN','ভোঁতা':'NN','ভোঁদর':'NN','ভোঁসলে':'NN','ভোই':'NN','ভোক্তা':'NN',
'ভোক্তার':'NN','ভোগ-বিলাস':'NN','ভোগ':'NN','ভোগকারীদের':'NN','ভোগছে':'NN','ভোগত্যাগ':'NN','ভোগপরায়ণ':'JJ',
'ভোগবাদ':'NN','ভোগবিলাসী':'JJ','ভোগবৃত্তি':'NN','ভোগমণ্ডপ':'NN','ভোগলিক':'NN','ভোগা':'VB','ভোগাচ্ছেন':'NN',
'ভোগানো':'VB','ভোগান্তি':'NN','ভোগান্তির':'NN','ভোগাবে':'NN','ভোগাসক্ত':'JJ','ভোগায়':'NN','ভোগি':'NN',
'ভোগী':'JJ','ভোগীন্দ্র':'NN','ভোগে':'NN','ভোগেন':'VB','ভোগের':'NN','ভোগ্য':'NN','ভোগ্যবস্তু':'JJ',
'ভোগ্যবস্তুর':'NN','ভোজ':'NN','ভোজন':'VBG','ভোজনকারী':'JJ','ভোজননো':'VB','ভোজনপাত্র':'NN','ভোজনরসিক':'JJ',
'ভোজনলোলুপ':'JJ','ভোজনালয়':'NN','ভোজনের':'NN','ভোজপতি':'NN','ভোজপুর':'NN','ভোজাতিথি':'NN','ভোজালী':'NN',
'ভোজী':'JJ','ভোজের':'NN','ভোজ্য':'NN','ভোট':'NN','ভোটকে':'NN','ভোটকেন্দ্র':'NN','ভোটকেন্দ‌্রের':'NN',
'ভোটগণক':'NN','ভোটটা':'NN','ভোটতো':'NN','ভোটদাতা':'NN','ভোটদান':'NN','ভোটপ্রদান':'NN','ভোটবিহীন':'NN',
'ভোটভোটারপ্রার্থী':'NN','ভোটাধিকার':'NN','ভোটাধিকারী':'JJ','ভোটাধিকারে':'NN','ভোটার':'NN','ভোটারদের':'NN','ভোটারদেরকে':'NN',
'ভোটারবিহীন':'NN','ভোটাররা':'NN','ভোটারের':'NN','ভোটিং':'NN','ভোটে':'NN','ভোটেআন্দোলনের':'NN','ভোটেই':'NN',
'ভোদকা':'NN','ভোন্ডী':'NN','ভোপাল':'NNP','ভোর':'NN','ভোরবেলায়':'NN','ভোররাতে':'NN','ভোরা':'NN',
'ভোরেই':'NN','ভোল':'NN','ভোলা-ভালা':'JJ','ভোলা':'NN','ভোলাতে':'VB','ভোলানো':'VB','ভোলিটানস':'NN',
'ভোলে':'VB','ভোলেনি':'NN','ভোল্গা':'NN','ভোল্টটি':'NN','ভোড়ার':'NN','ভৌ-ভৌ':'NN','ভৌ':'NN',
'ভৌগলিক':'JJ','ভৌগোলিক':'NN','ভৌতবাদ':'NN','ভৌতবিজ্ঞান':'NN','ভৌতিক':'NN','ভৌত্য':'NN','ভৌম':'JJ',
'ভৌমজল':'NN','ভৌমবতী':'NN','ভৌমাসুর':'NN','ভৌমিক':'JJ','ভৌলিয়া':'NN','ভ্যাকসিন':'NN','ভ্যাকুয়াম':'NN',
'ভ্যাজভ্যাজ':'NN','ভ্যাট':'NN','ভ্যাটট্যাক্স':'NN','ভ্যাটিকান':'NN','ভ্যাটে':'NN','ভ্যান':'NN','ভ্যানিশ':'NN',
'ভ্যানের':'NN','ভ্যাপসানো':'JJ','ভ্যাবাচাকা':'NN','ভ্যাবাচ্যাকা':'NNP','ভ্যারিয়েশন':'NN','ভ্যালি':'NN','ভ্যালেন্সিয়া':'NN',
'ভ্যাল্প্যাঁসো':'NNP','ভ্যাসলিন':'NN','ভ্রম-জাল':'NN','ভ্রম':'NN','ভ্রমণ-প্রেমী':'JJ','ভ্রমণ':'NN','ভ্রমণপিপাসু':'JJ',
'ভ্রমণপ্রেমী':'NN','ভ্রমণার্থী':'NN','ভ্রমণে':'VB','ভ্রমন':'NN','ভ্রমরচ্ছলী':'NN','ভ্রমরবিলাসিতা':'NN','ভ্রমরী':'NN',
'ভ্রমহীন':'NN','ভ্রমিত':'VB','ভ্রষ্ট':'JJ','ভ্রষ্টা':'NN','ভ্রষ্টাচারী':'NN','ভ্রাত়ৃত্ব':'NN','ভ্রাতা':'NN',
'ভ্রাতৃত্ববোধ':'NN','ভ্রাতৃবধূর':'NN','ভ্রান্ত':'JJ','ভ্রান্তি':'NN','ভ্রান্তিশূণ্য':'NN','ভ্রামমান':'NN','ভ্রাম্যমান':'NN',
'ভ্রুকুটি':'NN','ভ্রুণ':'NN','ভ্রূ':'NN','ভ্রূকুটি-ভঙ্গিতে':'NN','ভ্রূকুটি':'NN','ভ্রূক্ষেপ':'NN','ভ্রূণ':'NN',
'ভ্রূণহত্যা':'NN','ভ্লাদিমির':'NN','ভড়কি':'NN','ভয়':'NN','ভয়ংকর':'NN','ভয়আড়ালের':'NN','ভয়ই':'NN',
'ভয়ও':'NN','ভয়ঙ্কর':'JJ','ভয়টা':'NN','ভয়তে':'NN','ভয়ত্রাসডর':'NN','ভয়নক':'NN','ভয়ভীত':'VBD',
'ভয়ভীতিহীন':'NN','ভয়হীন':'JJ','ভয়হীনতা':'NN','ভয়া':'NN','ভয়াবহ':'NN','ভয়াবহন':'NN','ভয়ার্ত':'JJ',
'ভয়াল':'NN','ভয়ে':'NN','ভয়ের':'NN','ভয়েসে':'NN','ভ​র্তি':'NN','মংগল':'NN','মই':'NN',
'মইনুল':'NN','মউদুদ':'NN','মঊ':'NN','মওকফ':'NN','মওকুফ':'NN','মওদুদ':'NN','মওদুদেরা':'NN',
'মওসন':'NNP','মকওয়ানপুর':'NN','মকড়া':'NN','মকর':'NN','মকরধ্বজ':'NN','মকরন':'NN','মকরন্দিকা':'NN',
'মকররাশি':'NN','মকরা':'NN','মকরালয়':'NN','মকাই':'NN','মকারান্ত':'JJ','মকাল':'NN','মকুনি':'NN',
'মকের':'NN','মকেরুক':'NN','মক্কল':'NN','মক্কার':'NN','মক্কেল':'NN','মক্ষণ':'NN','মক্ষদৃগ':'NN',
'মক্ষিকা':'NN','মক্ষ্মী':'NN','মখনী':'NN','মখমল':'NN','মখমলী':'JJ','মখা':'NN','মখে':'NN',
'মগ':'NN','মগজে':'NN','মগণ':'NN','মগধ':'NN','মগবা':'NN','মগহপতি':'NN','মগহী':'NN',
'মগা':'NN','মগের':'NN','মগ্ন':'NN','মগ্নচৈতন্য':'NN','মগ্র':'NN','মঘা':'NN','মঙ্কলক':'NN',
'মঙ্খী':'NN','মঙ্গল':'NN','মঙ্গলগ্রহ':'NN','মঙ্গলগ্রহে':'NNS','মঙ্গলঘট':'NN','মঙ্গলজনক':'JJ','মঙ্গলদাই':'NN',
'মঙ্গলপ্রস্থ':'NN','মঙ্গলবস্ত্র':'NN','মঙ্গলবাদ্য':'NN','মঙ্গলবার':'NNP','মঙ্গলভাষণ':'NN','মঙ্গলসুতো':'NN','মঙ্গলা':'NNS',
'মঙ্গলাচরণ':'NN','মঙ্গলার্থে':'NN','মঙ্গলোত্সব':'NN','মঙ্গা':'NN','মঙ্গাপীড়িত':'JJ','মঙ্গাবে':'NN','মঙ্গেশকর':'NN',
'মঙ্গোল':'NN','মঙ্গোলিয়ান':'NN','মঙ্গোলীয়া':'NN','মচকানো':'NN','মচমচ':'VB','মচিলীপটনম':'NN','মচুলা':'NN',
'মচ্-মচ্':'NN','মচ্ছব':'NN','মছিন্দরনাথ':'NN','মছোদরী':'NN','মজদুরনি':'NN','মজদুরের':'NN','মজনু':'NN',
'মজনুশাহ':'NNP','মজনুশাহের':'NNP','মজবুত':'JJ','মজলিশ':'NN','মজলিসি':'NN','মজলুমের':'NN','মজা':'NN',
'মজাও':'NN','মজাটাই':'NN','মজাদার':'JJ','মজানো':'VB','মজার':'NN','মজিলাও':'NN','মজীঠের':'JJ',
'মজীনার':'NN','মজুত':'NN','মজুতাদরীদের':'NN','মজুদ':'NN','মজুদের':'NN','মজুমদারের':'NNP','মজুর':'NN',
'মজুরির':'NN','মজুরের':'NN','মজ্জা':'NN','মঞ্চ-যাদুর':'NN','মঞ্চ':'NN','মঞ্চকাসুর':'NN','মঞ্চটি':'NN',
'মঞ্চপত্রী':'NN','মঞ্চস্থ':'JJ','মঞ্চায়ন':'NN','মঞ্চায়িত':'VBD','মঞ্চে':'NN','মঞ্জরি':'NN','মঞ্জরিত':'JJ',
'মঞ্জরী':'NN','মঞ্জরীযুক্ত':'JJ','মঞ্জিষ্ঠামেহ':'NN','মঞ্জীরা':'NN','মঞ্জুঘোষা':'NN','মঞ্জুর':'NN','মঞ্জুরীপ্রাপ্ত':'JJ',
'মঞ্জুশ্রী':'NNP','মঞ্জুষা':'NN','মটকানো':'VB','মটকার':'NN','মটকোড়বা':'NN','মটখৌরা':'NN','মটন':'NN',
'মটমট':'NN','মটর':'NN','মটরওয়ালা':'JJ','মটরভাজা':'NN','মটরশুঁটির':'NN','মটা':'NN','মটিয়াশকুন':'NN',
'মটের':'NN','মটোরবাইক':'NN','মঠ':'NN','মঠরী':'NN','মঠাদক্ষা':'NN','মঠাধিকারিনী':'NN','মঠাধ্যক্ষ':'NN',
'মঠিয়া':'NN','মঠে':'NN','মড়মড়':'VB','মডারেটর':'NN','মডার্ন':'NN','মডিকেরি':'NN','মডেল':'NN',
'মডেলিং':'NN','মডেলের':'NN','মডেস্টি':'NN','মণ':'NN','মণকে':'NN','মণি-মাণিক্য':'NN','মণি':'NN',
'মণিকণ্ঠ':'NN','মণিকর্ণ':'NNS','মণিকর্ণিকা':'FW','মণিকা':'NN','মণিখচিত':'JJ','মণিগুণ':'NN','মণিগ্রীব':'NN',
'মণিচূড়':'NN','মণিজলা':'NN','মণিপুর':'NN','মণিপুরী':'NN','মণিপুষ্পক':'NN','মণিবন্ধ':'NN','মণিবাবার':'NNV',
'মণিভদ্র':'NN','মণিমঞ্জরী':'NN','মণিমণ্ডিত':'JJ','মণিমন্থ':'NN','মণিমালা':'NN','মণিমুক্তা':'NN','মণিমেঘ':'NN',
'মণিময়':'JJ','মণির':'NNP','মণিস্কন্ধ':'NN','মণীশ':'NN','মণে':'NN','মণ্ড':'NN','মণ্ডল':'NN',
'মণ্ডলব্রাহ্মণ':'NN','মণ্ডলা':'NN','মণ্ডলীতে':'NN','মণ্ডি':'NNP','মণ্ডিয়ালী':'NN','মণ্ডুক':'NN','মণ্ডয়া':'NN',
'মণ্ত্রীদের':'NNS','মত-পত্র':'NN','মত':'NN','মতআর':'NN','মতই':'IN','মতকিনতু':'NN','মতকে':'NN',
'মতঙ্গ':'NN','মতদাতা':'NN','মতদান-পত্র':'NN','মতদ্বৈততা':'NN','মতন':'NN','মতপার্থক্য':'NN','মতবাদ':'NN',
'মতবাদের':'NN','মতবিনিময়ের':'NNS','মতবিরোধ':'NN','মতবিরোধ':'NN','মতভেদ':'NN','মতযাক':'NN','মতলব':'NN',
'মতাও':'NN','মতাদর্শ':'NN','মতাধিকার':'NN','মতানৈক্য':'NN','মতান্তর':'NN','মতান্ধ':'JJ','মতান্ধতা':'NN',
'মতাবলম্বী':'NN','মতামত':'NN','মতামতই':'NNS','মতামতটি':'NN','মতার':'NN','মতিউর':'NN','মতিও':'NN',
'মতিচুর':'NN','মতিঝিলে':'NN','মতিন':'NN','মতিভ্রম':'NN','মতিহারী':'NN','মতিয়া':'NN','মতে':'NN',
'মতেই':'RB','মতের':'NN','মতৈক্য':'NN','মতো':'IN','মতোআচ্ছা':'NN','মতোই':'NN','মতোডিমটা':'NN',
'মত্ত':'NN','মত্তগয়ন্দ':'NN','মত্ততা':'NN','মত্ততারহিত':'JJ','মত্তমাতঙ্গ-লীলাকার':'NN','মত্তময়ুর':'NN','মত্তা':'NN',
'মত্তাক্রীড়া':'NN','মত্লা':'NN','মত্স':'NN','মত্সকন্যা':'NN','মত্সপুরাণ':'NN','মত্সাঙ্গনা':'NN','মত্সাবতার':'NN',
'মত্সালয়':'NN','মত্সাসুর':'NN','মত্স্য':'NN','মত্স্যদ্বাদশী':'NN','মত্স্যরাজ':'NN','মত্স্যসূক্ত':'NN','মত্স্যেন্দ্রনাথ':'NN',
'মথানী':'NN','মথিত':'JJ','মথির':'NN','মথুরবাবুও':'NNP','মথুরা':'NN','মদ':'NN','মদকারী':'NN',
'মদখোর':'NN','মদগু':'NN','মদত':'NN','মদতে':'VBN','মদদ':'NN','মদন-মহোত্সব':'NN','মদন':'NN',
'মদনগৌড়':'NN','মদনত্রয়োদশী':'NN','মদনদেব':'NN','মদনদ্বাদশী':'NN','মদনপাখি':'NN','মদনমনোরমা':'NN','মদনা':'NNP',
'মদনাগ্রক':'NN','মদনোত্সব':'NN','মদমত্ত':'NN','মদরিচ':'NN','মদলেখা':'NN','মদাঢ্য':'NN','মদাতঙ্ক':'NN',
'মদার':'NNP','মদালসা':'NN','মদিরা-পান':'NN','মদিরাক্ষী':'NN','মদিরাপান':'NN','মদিরালয়':'NN','মদুরা':'NN',
'মদের':'NN','মদ্দা':'NN','মদ্ধে':'NN','মদ্য-পান':'NN','মদ্য':'NN','মদ্যপান':'VBG','মদ্যব্যবসায়ী':'NN',
'মদ্রিচ':'NN','মধন':'NN','মধাম':'NNP','মধিক':'JJ','মধু':'NN','মধুকরি':'NN','মধুকুম্ভা':'NN',
'মধুকোষ':'NN','মধুছন্দা':'NN','মধুত্থ':'NN','মধুপ':'NN','মধুপর্ণী':'NN','মধুপাত্র':'NN','মধুপিলু':'NN',
'মধুপুরে':'NNP','মধুপ্রিয়':'NN','মধুবনি':'NN','মধুবর্ণ':'NN','মধুবাহী':'NN','মধুব্রত':'NN','মধুভরা':'JJ',
'মধুমতি':'NN','মধুমাত':'NN','মধুমাধবী':'NN','মধুমেহ':'NN','মধুযষ্টি':'NN','মধুযষ্ঠী':'NN','মধুর':'NN',
'মধুরজ্বর':'NN','মধুরতা':'NN','মধুরব্য':'NN','মধুরস':'NN','মধুরসিক':'NN','মধুরা':'NN','মধুরাত':'NN',
'মধুরী':'NN','মধুশক্কর':'NN','মধুশালিকা':'NN','মধুসুদন':'NN','মধুসূদন':'NNP','মধুস্পদী':'NN','মধূত্সব':'NN',
'মধূলিকা':'NN','মধেপুরা':'NN','মধ্য প্রদেশ':'NN','মধ্য-রাত্রি':'NN','মধ্য':'NN','মধ্যকাল':'NN','মধ্যচ্ছদা':'NN',
'মধ্যপন্থার':'JJ','মধ্যপ্রদেশ':'NN','মধ্যপ্রদেশও':'NNP','মধ্যপ্রদেশে':'NN','মধ্যপ্রদেশের':'NNP','মধ্যপ্রাচ্য':'NN','মধ্যপ্রাচ্যের':'NN',
'মধ্যবর্তী':'NN','মধ্যবর্তীকালে':'RB','মধ্যবিত্ত':'JJ','মধ্যবিত্তরাও':'NN','মধ্যবিথিকা':'NN','মধ্যবয়স্ক':'NN','মধ্যভাগ':'NN',
'মধ্যভারতীয়':'JJ','মধ্যম':'NN','মধ্যমণিরূপে':'NN','মধ্যমা':'NN','মধ্যযুগ':'NN','মধ্যযুগীয়':'JJ','মধ্যরাত':'NN',
'মধ্যশিক্ষা':'NNP','মধ্যসত্তভোগীর':'JJ','মধ্যসত্ত্ববোগীরাই':'NNS','মধ্যস্থ':'NN','মধ্যস্থতার':'NN','মধ্যস্থিত':'JJ','মধ্যস্বত্বভোগী':'NN',
'মধ্যস্বত্বভোগীরা':'NNS','মধ্যস্বত্যদের':'NNS','মধ্যা':'NN','মধ্যান্তরাল':'NN','মধ্যাবকাশ':'NN','মধ্যাহ্ণ':'NN','মধ্যাহ্নের':'NN',
'মধ্যে':'NN','মধ্যেও':'NN','মধ্যের':'NN','মন':'NN','মনঃ':'JJ','মনঃসমীক্ষককে':'NN','মনঃস্থিতি':'NN',
'মনই':'NN','মনও':'NN','মনকি':'NN','মনগড়া':'JJ','মনগড়া':'NN','মনজিত':'NN','মনট':'NN',
'মনটাই':'NN','মনটি':'NN','মনন':'NN','মননকে':'VBG','মননশীল':'JJ','মননশীলতা':'NN','মননিবেশ':'NN',
'মনবল':'NN','মনভাব':'NN','মনমাঝি':'NN','মনমোহন':'NN','মনযোগ':'NN','মনযোগী':'JJ','মনরন':'NN',
'মনসা-মঙ্গল':'NNP','মনসা':'NN','মনসাদেবী':'NN','মনসাপঞ্চমী':'NN','মনসুখ':'NN','মনসুর':'NN','মনসুরদ্দীনের':'NNP',
'মনস্ক':'NN','মনস্ত':'NN','মনস্তাত্ত্বিক':'JJ','মনস্তাত্বিকভাবে':'RB','মনস্তাপ':'NN','মনস্তুষ্টি':'NN','মনস্থির':'NN',
'মনহংস':'NN','মনহরণ':'NN','মনা':'NN','মনাক্কা':'NN','মনাম':'NN','মনায়':'NN','মনি':'NN',
'মনিটর':'NN','মনিটরিং':'VBG','মনিদি':'NNP','মনির':'NNP','মনিহার':'NN','মনিহারিনী':'NN','মনীর':'NN',
'মনীলা':'NN','মনীষী':'NN','মনীয়':'JJ','মনু-সংহিতা':'NN','মনু-স্মৃতি':'NN','মনু':'NN','মনুমেণ্টটি':'NN',
'মনুরাজ':'NN','মনুষ্য':'NN','মনুষ্যজাতি':'NN','মনুষ্যত্তের':'NN','মনুষ্যত্ত্বের':'NN','মনুষ্যত্বহীনতা':'NN','মনুষ্যধর্ম':'NN',
'মনুষ্যপূর্ব':'NN','মনুষ্যভোজী':'JJ','মনুষ্যমূর্তিই':'NN','মনুষ্যেতর':'NN','মনুষ্যোচিত':'JJ','মনুসংহিতা.':'NN','মনুস্মৃতি':'NNP',
'মনে':'NN','মনেও':'NN','মনেক':'NNP','মনেকরি':'NN','মনেট':'NN','মনেনো':'VB','মনের':'NN',
'মনেহয়':'NN','মনোনয়ন':'NN','মনোইনবস্থানাত্্':'NN','মনোকামনা':'JJ','মনোক্সাইড':'NN','মনোগত':'JJ','মনোগ্রাম':'NN',
'মনোগ্রাহী':'JJ','মনোজ':'NN','মনোদশা':'NN','মনোধ্যান':'NN','মনোনায়ন':'NN','মনোনিত':'VBN','মনোনিবেশ':'NN',
'মনোনীত':'VBN','মনোন্নয়ন':'NN','মনোনয়নপত্রে':'NN','মনোনয়নপ্রত্যাশী':'NNS','মনোপলির':'NN','মনোবতী':'NN','মনোবস্থা':'NN',
'মনোবাঞ্ছিত':'JJ','মনোবাসনা':'NN','মনোবিকার':'NN','মনোবিজ্ঞান':'NN','মনোবিদ':'NN','মনোবিদ্যা':'NN','মনোবৃত্তি':'NN',
'মনোবেগ':'NN','মনোবৈজ্ঞনিক':'JJ','মনোবৈজ্ঞানিক':'NN','মনোব্যথা':'NN','মনোভাব':'NN','মনোভাবাপন্ন':'NN','মনোভাবের':'NN',
'মনোভাষাবিজ্ঞান':'NNP','মনোভিরকাম':'JJ','মনোমত':'JJ','মনোমালিন্য':'NN','মনোমুগ্ধকারী':'JJ','মনোযাগ':'NN','মনোযোগী':'NN',
'মনোরঞ্জক':'NN','মনোরঞ্জনপূর্ণ':'JJ','মনোরঞ্জনের':'NN','মনোরঞ্জিত':'JJ','মনোরথ':'NN','মনোরথপূর্ণতা':'NN','মনোরম':'NN',
'মনোরম্যস':'JJ','মনোরোগ-বিশেষজ্ঞ':'NN','মনোরোগ':'NN','মনোহরণ':'NN','মনোহরি':'NN','মনোহারী':'JJ','মনোয়ন':'NN',
'মন্টু':'NN','মন্টেনিগ্রো':'NN','মন্টেভিডিয়ো':'NN','মন্ঠ':'NN','মন্ডল':'NN','মন্ডলপুচ্ছক':'NN','মন্ডলাকার':'JJ',
'মন্ডলী':'NN','মন্ত':'NN','মন্তব্যই':'NNS','মন্তব্যকারী':'NN','মন্তব্যকারীদের':'NNS','মন্তব্যকারীর':'NN','মন্তব্যগুলিও':'NNS',
'মন্তব্যটি':'NN','মন্তব্যপেইজের':'NN','মন্তব্যবাজরা':'NNS','মন্তব্যর':'NN','মন্তব্যে':'NNS','মন্তর':'NN','মন্তি':'NNP',
'মন্ত্র':'NN','মন্ত্রঃপুত':'VB','মন্ত্রক':'NN','মন্ত্রজ্ঞানী':'NN','মন্ত্রণা':'NN','মন্ত্রণালয়':'NNP','মন্ত্রণালয়':'NN',
'মন্ত্রণালয়ের':'NN','মন্ত্রণায়ের':'NNP','মন্ত্রতন্ত্র':'NN','মন্ত্রনাণয়':'NN','মন্ত্রনালয়':'NNP','মন্ত্রনালয়ের':'NNP','মন্ত্রনায়ল':'NNP',
'মন্ত্রপুত':'NN','মন্ত্রমুগ্দ্ধ':'VB','মন্ত্রমুগ্ধ':'VBN','মন্ত্রানয়ালয়ের':'NNP','মন্ত্রালয়':'NN','মন্ত্রালয়ের':'NNP','মন্ত্রি':'NNP',
'মন্ত্রিজনমত':'NN','মন্ত্রির':'NNP','মন্ত্রিসভা':'NN','মন্ত্রিসভায়':'NN','মন্ত্রী-মন্ডল':'NN','মন্ত্রী':'NN','মন্ত্রীএমপিআমলারা':'NN',
'মন্ত্রীকে':'NN','মন্ত্রীত্ব':'NNP','মন্ত্রীদের':'NNS','মন্ত্রীবর্গ':'NN','মন্ত্রীমণ্ডলীয়':'JJ','মন্ত্রীমন্ডল':'NN','মন্ত্রীর':'NN',
'মন্ত্রীরা':'NNS','মন্ত্রীসভা':'NN','মন্ত্রী–সাংসদেরা':'NN','মন্ত্রে':'NN','মন্থক':'NN','মন্থন':'VBG','মন্থনী':'NN',
'মন্থর':'NN','মন্থরার':'NN','মন্থানক':'NN','মন্থিত':'JJ','মন্দ':'NN','মন্দগতি':'JJ','মন্দবাচক':'NN',
'মন্দবুদ্ধি':'NN','মন্দর':'NN','মন্দরু':'NN','মন্দা':'NN','মন্দাকিনী':'NNP','মন্দাবস্থা':'NN','মন্দার':'NN',
'মন্দারষষ্ঠী':'NN','মন্দাস্য':'NN','মন্দির':'NN','মন্দিরময়':'JJ','মন্দিরে':'NN','মন্দীল':'NN','মন্দের':'NN',
'মন্দ্রাক্রান্তা':'NN','মন্নথকর':'NN','মন্বন্তর':'NN','মন্মথপ্রিয়া':'NN','মন্যাস্তম্ভ':'NN','মন্যুদেব':'NN','মন্হনযোগ্য':'JJ',
'মফঃস্বলের':'NN','মফস্বলের':'NN','মফিজ':'NN','মফিজুল':'NN','মবকে':'NN','মবাগ':'NN','মবাহ':'NN',
'মবোধ':'NN','মব্রোকা':'NN','মভাব':'NN','মভের':'NN','মভ্স':'NNP','মমতা':'NN','মমতার':'NN',
'মমতাহীন':'NN','মমত্ব':'NN','মমম':'NN','মমান':'JJ','মমালা':'NN','মমিত':'NN','মমিনুল':'NN',
'মমিনুলদের':'NNS','মমীরা':'NN','মমেট':'NN','ময়মনসিংহ':'NNP','ময়ে':'VB','মর-মর':'NN','মর':'NN',
'মরকত':'NN','মরকোটী':'NN','মরক্কান':'NN','মরচে':'NN','মরছে':'VBG','মরণ':'NN','মরণব্যাধি':'NN',
'মরণশীল':'JJ','মরণাপন্ন':'NN','মরণে':'NN','মরণোত্তর':'RB','মরত':'NN','মরতো':'NNP','মরদ':'NN',
'মরনপণ':'NN','মরনাস্ত্র':'NN','মরব':'NN','মরবে':'NN','মরবেনাশকুনও':'NN','মরমর':'JJ','মরমরানি':'NN',
'মরল':'VBD','মরলুম':'VB','মরলে':'NNS','মরলো':'VBD','মরশুম':'NN','মরশুমে':'NN','মরসুমি':'JJ',
'মরহুম':'RB','মরা':'VB','মরাই':'NN','মরাজ':'NN','মরাঠওয়াড়া':'NN','মরামাস':'NN','মরার':'NN',
'মরিক':'JJ','মরিগাঁও':'NN','মরিচ':'NN','মরিনহো':'NN','মরিশাস':'NN','মরিশাসের':'JJ','মরিশিয়ান':'NN',
'মরিস':'NNP','মরিয়া':'NN','মরীচি':'NN','মরু':'NN','মরুত্ত':'NN','মরুদান্দোল':'NN','মরুভূমি':'NN',
'মরুভূমির':'NN','মরুস্থল':'NN','মরুয়া':'NN','মরূদান':'NN','মরে':'VB','মরেঠি':'NN','মরেনা':'NNP',
'মরের':'NN','মরোক্কান':'JJ','মরোক্কো':'NN','মরোক্কোর':'JJ','মরোড়ফলী':'NN','মর্ক':'NN','মর্কটক':'NN',
'মর্গ':'NN','মর্টন':'NN','মর্তবান':'NN','মর্তমুখ':'NN','মর্ত্য':'NN','মর্থ':'JJ','মর্দন':'NN',
'মর্দা':'JJ','মর্দ্':'NN','মর্নিং-ওয়াক':'NN','মর্ম':'NN','মর্মঘাতী':'JJ','মর্মন্তুদ':'JJ','মর্মপীড়াদায়ক':'JJ',
'মর্মভেদী':'JJ','মর্মরপ্রস্তর':'NN','মর্মস্থল':'NN','মর্মস্পর্শী':'NN','মর্মান্তিক':'NN','মর্মাহত':'JJ','মর্যদা':'NN',
'মর্যাদশীল':'VBN','মর্যাদা':'NN','মর্যাদাসম্পন্ন':'NN','মর্যাদাহীন':'JJ','মর্য্যাদার':'NN','মর্শ':'NN','মর্ষণীয়':'JJ',
'মল':'NN','মলকরন':'NN','মলগোবা':'NN','মলঙ্গ':'NN','মলজ্বর':'NN','মলঝন':'NN','মলত্যাগ':'NN',
'মলদল':'NN','মলদোভান':'NN','মলদ্বার':'NN','মলপাত্র':'NN','মলম':'NN','মলমলের':'NN','মলমাস':'NN',
'মলস্তম্ভ':'NN','মলা':'NN','মলাট':'NN','মলাটের':'JJ','মলাধার':'NN','মলাবরোধ':'NN','মলাভি':'NN',
'মলার':'NN','মলাল':'NNP','মলাশয়':'NN','মলায়াচল':'NN','মলিউড':'NN','মলিকিউল':'NN','মলিত':'NN',
'মলিদা':'NN','মলিন':'NN','মলিনা':'NN','মলির':'RB','মলিস':'NN','মলিয়া':'NN','মলীদা':'NN',
'মলে':'NN','মলেন':'VB','মলের':'NN','মল্কানগিরি':'NN','মল্ল':'NN','মল্লযুদ্ধ':'NN','মল্লার':'NN',
'মল্লারী':'NN','মল্লিক':'NN','মল্লিকার':'NN','মল্লিনাথ':'NN','মলয়':'NN','মলয়গিরি':'NN','মলয়বাসী':'NN',
'মলয়ালম':'NN','মলয়ের':'NNP','মশক':'NN','মশকরা':'NNS','মশকারা':'NNS','মশগুল':'NN','মশরু':'NN',
'মশলা':'NN','মশলাদানি':'NN','মশলাযুক্ত':'JJ','মশলার':'NN','মশাই':'NN','মশার':'NNS','মশারি':'NN',
'মশাল':'NN','মশালাদানি':'NN','মশাহীন':'JJ','মশায়':'NNS','মশায়ই':'NN','মসকলা':'NN','মসজিদ':'NN',
'মসজিদের':'NN','মসনদ':'NN','মসনবী':'NN','মসরু':'NN','মসলা':'NNS','মসলার':'NN','মসলিনশিল্পের':'NN',
'মসি':'NN','মসিদানি':'NN','মসিনা':'NN','মসিপত্র':'NN','মসূলা':'NN','মসৃণ':'NN','মসৃণকারী':'JJ',
'মসৃন':'NN','মসের':'NN','মস্কট':'NN','মস্কারা':'NN','মস্কো':'NN','মস্ত':'NN','মস্তকচালিত':'JJ',
'মস্তকহীন':'NN','মস্তকের':'NN','মস্তাকাধান':'NN','মস্তি':'NN','মস্তিষ্ক':'NN','মস্তিষ্কের':'NN','মস্তো':'JJ',
'মহংস':'NNP','মহকুমা':'NN','মহড়া':'NN','মহত':'JJ','মহতভাবে':'RB','মহতী':'NN','মহত্ত্বের':'NN',
'মহত্বহীন':'NN','মহত্বাণী':'NN','মহত্বের':'NN','মহত্য':'NN','মহফা':'NN','মহম্মদ':'NN','মহর':'NN',
'মহরথী':'NN','মহরম':'NN','মহর্ষি':'NN','মহল':'NN','মহলীপটেলা':'NN','মহলে':'NN','মহল্লার':'NN',
'মহসচিব':'NN','মহসীন':'NN','মহা-প্লাবন':'NN','মহা':'NN','মহাউৎসব':'NN','মহাকন্য':'NN','মহাকপাল':'NN',
'মহাকবি':'NN','মহাকর্ষ':'NN','মহাকর্ষজ':'JJ','মহাকাব্য':'NN','মহাকার্তিকী':'NN','মহাকাল':'NN','মহাকাশ':'NN',
'মহাকাশযান':'NN','মহাকাশে':'NN','মহাকায়':'JJ','মহাকিপ্টে':'NN','মহাকুণ্ড':'NN','মহাকৃপণ':'NN','মহাকেলেংকারি':'NNP',
'মহাক্ষমতাধর':'NN','মহাখালী':'NN','মহাগঙ্গা':'NN','মহাগজ':'NN','মহাগণপতি':'NN','মহাগর্ভ':'NN','মহাগুরু':'NN',
'মহাগৌরী':'NN','মহাঘৃত':'NN','মহাচক্র':'NN','মহাচিত্তা':'NN','মহাচুড়া':'NN','মহাচ্ছায়':'NN','মহাজন':'NN',
'মহাজনি':'NN','মহাজনের':'NN','মহাজবা':'NN','মহাজম্ভ':'NN','মহাজলকাক':'NN','মহাজাগতিক':'NN','মহাজানু':'NN',
'মহাজালিয়াতির':'NN','মহাজিহ্ব':'NN','মহাজীবনের':'NN','মহাজোট':'NN','মহাজোটের':'NN','মহাতল':'NN','মহাতারকা':'NN',
'মহাতোপ':'NN','মহাত্ত':'NN','মহাত্রিফলা':'NN','মহাথির':'NN','মহাদজী':'NN','মহাদশা':'NN','মহাদারু':'NN',
'মহাদেব-কারিকা':'NNP','মহাদেব':'NN','মহাদেবের':'NNP','মহাদেশ':'NN','মহাদেশীয়':'JJ','মহাদেশে':'NN','মহাদৈত্য':'NN',
'মহাদ্বীপ':'NN','মহাদ্রক':'NN','মহাধমনী':'NN','মহাধিবক্তা':'NN','মহাধিবেশন':'NN','মহাধ্বনি':'NN','মহান':'NN',
'মহানগর':'NN','মহানগরপালিকা':'NN','মহানগরীয়':'JJ','মহানগরের':'NN','মহানদানী':'NN','মহানন্দ':'NNP','মহানন্দা':'NN',
'মহানব':'NN','মহানাভ':'NN','মহানারায়ণ':'NN','মহানায়ক':'NN','মহানিম':'NN','মহানিরীক্ষক':'NN','মহানির্দেশালয়':'NN',
'মহানির্বাণ':'NN','মহানীচ':'JJ','মহানুভব':'NN','মহানুভবতাই':'NN','মহানোভা':'NN','মহান্দষ্ট্র':'NN','মহাপঞ্চায়':'NN',
'মহাপথ':'NN','মহাপদ্ম':'NN','মহাপনস':'NN','মহাপরিচালক':'NN','মহাপরিনির্বাণ':'NN','মহাপাতক':'NN','মহাপাপ':'NN',
'মহাপাপী':'JJ','মহাপালিকা':'NN','মহাপাশ':'NN','মহাপুরুষ':'NN','মহাপূজার':'NN','মহাপ্রতারণা':'NN','মহাপ্রভু':'NN',
'মহাপ্রসংশনীয়':'JJ','মহাপ্রসাদ':'NN','মহাপ্রাণ':'NN','মহাফেজখানা':'NN','মহাবক':'NN','মহাবল':'NN','মহাবস্ত্র':'NN',
'মহাবাক্য':'NN','মহাবালেশ্বর':'NN','মহাবাহু':'NN','মহাবিক্রম':'NN','মহাবিদ্যা':'NN','মহাবিদ্যালয়':'NN','মহাবিদ্যালয়ীয়':'JJ',
'মহাবিনাশ':'NN','মহাবিশ্ব':'NN','মহাবিশ্বের':'NN','মহাবিষুব':'NN','মহাবীজ':'NN','মহাবৃক্ষ':'NN','মহাবৈঠক':'NN',
'মহাবোধি':'NN','মহাব্রাহ্মণ':'NN','মহাভদ্রা':'NN','মহাভার':'NN','মহাভারতের':'NNP','মহাভাষ্য':'NN','মহামতি':'JJ',
'মহামহিম':'NN','মহামান্য':'JJ','মহামারি':'NN','মহামারী':'JJ','মহামালিকা':'NN','মহামায়নগর':'NN','মহামায়ানগর':'NN',
'মহামিলন':'NN','মহামুণ্ড':'NN','মহামুল্যবান':'NN','মহামূর্খ':'JJ','মহামেডান':'NNP','মহামেদা':'NN','মহাযজ্ঞ':'NN',
'মহাযান':'NN','মহাযুদ্ধ':'NN','মহাযোদ্ধা':'NN','মহারণ্য':'NN','মহারথ':'NN','মহারথিরা':'NNS','মহারস':'NN',
'মহারাজকে':'NN','মহারাজগঞ্জ':'NN','মহারাজের':'NN','মহারাণা':'NN','মহারানী':'NN','মহারাষ্ট্র':'NN','মহারাষ্ট্রের':'NNP',
'মহারুখ':'NN','মহারৌদ্রী':'NN','মহার্ঘ':'JJ','মহার্ঘ্য':'NN','মহার্ণব':'NN','মহালক্ষী':'NN','মহালত':'NN',
'মহালেখা':'NN','মহাশক্তি':'NN','মহাশঙ্খ':'NN','মহাশিবরাত্রি':'NN','মহাশীর্ষ':'NN','মহাশূন্যযান':'NN','মহাশ্বেতা':'NN',
'মহাশয়':'NN','মহাশয়ের':'NNP','মহাষ্ঠমী':'NN','মহাসংখ্যা':'NN','মহাসচিব':'NN','মহাসচিবের':'JJ','মহাসভার':'NN',
'মহাসমাবেশ':'NN','মহাসমুদ্রে':'NN','মহাসম্মেলন':'NN','মহাসাগর':'NN','মহাসাগরীয়':'JJ','মহাসাগরের':'NNP','মহাসান্তপন':'NN',
'মহাসুর':'NN','মহাসূত':'NN','মহাসেন':'NN','মহাস্বন':'NN','মহাসড়ক':'NN','মহাসড়কে':'RB','মহিউদ্দিনের':'NN',
'মহিপাল':'NN','মহিপুর':'NN','মহিমা':'NN','মহিমান্বিত':'NN','মহিমাময়':'NNP','মহির':'NN','মহিলা':'NN',
'মহিলাদের':'NNS','মহিলাযাত্রী':'NN','মহিলারা':'NNS','মহিলারোপ্য':'NNP','মহিশাসুর':'NN','মহিষ':'NN','মহিষী':'NN',
'মহিসুর':'NN','মহী':'NN','মহীপাল':'NN','মহীলতা':'NN','মহীশূর':'NN','মহুলরঙা':'JJ','মহুয়া':'NN',
'মহেঞ্জো-দাড়ো':'NN','মহেট':'NNP','মহেন্দ্র':'NN','মহেন্দ্রবারুণী':'NN','মহেন্দ্রাল':'NN','মহেশ':'NNP','মহেশ্বর':'NNP',
'মহোখ':'NN','মহোত্সব':'NN','মহোদ':'NNP','মহোদর':'NN','মহোদয়রা':'NN','মহোদয়ের':'NN','মহোবা':'NN',
'মহোৎসবের':'NN','মহৌষধ':'NN','মহৎ':'NN','মহড়া':'NN','ম়ঞ্জীর':'NN','মা-কে':'NN','মা':'NN',
'মাঁকড়-হাজারের':'NNP','মাঁঝা':'NN','মাংশ':'NN','মাংস-পেশী':'NN','মাংস-ফাংস':'NN','মাংস':'NN','মাংসখোর':'JJ',
'মাংসপিণ্ড':'NN','মাংসপেশী':'NN','মাংসভক্ষী':'JJ','মাংসভোজী':'NN','মাংসরহিত':'JJ','মাংসরুহা':'NN','মাংসরোহিণী':'NN',
'মাংসল':'JJ','মাংসসম্বাত':'NN','মাংসহীন':'NN','মাংসার্বুদ':'NN','মাংসাশী':'NN','মাংসাহার':'NN','মাংসের':'NN',
'মাআমরা':'NNS','মাই':'NN','মাইওমা':'NN','মাইক':'NN','মাইকের':'NN','মাইক্রনেশিয়া':'NN','মাইক্রো':'NN',
'মাইক্রোনেশিয়া':'NN','মাইক্রোফাইন্যান্সের':'NN','মাইক্রোফোন':'NN','মাইক্রোসফট':'NNP','মাইক্রোসফটের':'NN','মাইক্রোস্কোপ':'NN','মাইগ্রেট':'NN',
'মাইট':'NN','মাইতির':'NN','মাইন':'NN','মাইনরিটিদের':'NN','মাইনাস':'NN','মাইনেতে':'NN','মাইন্ড':'NN',
'মাইন্ডদেরকে':'NNS','মাইর':'NN','মাইরা':'VB','মাইরালা':'NN','মাইরের':'NN','মাইল':'NN','মাইলফলক':'NN',
'মাইলস্টোন':'NNS','মাইলেজ':'NN','মাইসোর':'NN','মাউণ্ট':'NN','মাউল্লম':'NN','মাউস':'NN','মাএ':'NN',
'মাএায়':'NN','মাও-তাই':'NNP','মাও':'NN','মাওকর্ডিয়াল':'NNP','মাওবাদ':'NN','মাওয়া':'NN','মাকড়শা':'NN',
'মাকড়সা':'NN','মাকন্দ.অলিপ্রিয়':'NN','মাকরীসপ্তমী':'NN','মাকল':'NN','মাকে':'NN','মাকড়ের':'NN','মাখন':'NN',
'মাখনভরা':'JJ','মাখনমিশ্রিত':'JJ','মাখনা':'NN','মাখানো':'VB','মাখামাখি':'NN','মাখি':'NN','মাখিয়ে':'VB',
'মাগত':'JJ','মাগধ':'NN','মাগনা':'JJ','মাগফেরাত':'NN','মাগীবাজ':'JJ','মাগুর':'NN','মাগুরার':'NN',
'মাগো':'NN','মাগোতোমাকে':'NN','মাঘ':'NN','মাঘমাসের':'NN','মাঘী':'NN','মাঘের':'NNP','মাঙ্কি':'NN',
'মাঙ্গন':'NN','মাঙ্গলিক':'JJ','মাচা':'NN','মাচিয়া':'NN','মাচু':'NNP','মাচ্চু':'NN','মাছ':'NN',
'মাছটি':'NN','মাছরাঙা':'NN','মাছি':'NN','মাছিমারা':'NN','মাছে':'NN','মাজদার':'NN','মাজন':'NN',
'মাজা-ঘষা':'JJ','মাজা':'NN','মাজানো':'VB','মাজার':'NN','মাজিদ':'NN','মাজে':'NN','মাঝ':'NN',
'মাঝখান':'NN','মাঝখানের':'NN','মাঝঘর':'NN','মাঝধারা':'NN','মাঝবয়সি':'NN','মাঝরাতে':'NN','মাঝামাঝি':'NN',
'মাঝি':'NN','মাঝিদের':'PR','মাঝিমাল্লা':'NN','মাঝির':'NNP','মাঝে-মাঝে':'RB','মাঝে':'NN','মাঝেও':'RB',
'মাঝেমধ্যে':'NN','মাঝেমাঝে':'RB','মাঝের':'NN','মাঝোলি':'NN','মাঞ্জা':'NN','মাঞ্জিনি':'NNP','মাটা':'NN',
'মাটি.মৃত্তিকা':'NN','মাটি':'NN','মাটিতেই':'NN','মাটির':'NN','মাঠ':'NN','মাঠগুলো':'NN','মাঠপর্যায়':'NN',
'মাঠময়দানের':'NN','মাঠা':'NN','মাঠিতে':'NN','মাঠেই':'NN','মাঠেময়দানে':'NN','মাঠের':'NN','মাড়':'NN',
'মাড়খাদক':'JJ','মাড়াই':'NN','মাড়াইনো':'VB','মাড়ান':'NN','মাড়ির':'NN','মাড়ুয়া':'NN','মাণও':'NN',
'মাণবক':'NN','মাণবক্রীড়া':'NN','মাণিক':'NN','মাণিবন্ধ':'NN','মাণু':'NN','মাণ্ডব্য':'NN','মাণ্ডুক্য':'NN',
'মাণ্ডয়া':'NN','মাত':'VBN','মাতঙ্গ':'NN','মাতব্বরী':'NN','মাতম':'NN','মাতলি':'NN','মাতা-পিতা':'NN',
'মাতা':'NN','মাতামহ':'NN','মাতামাতির':'NN','মাতাল':'NN','মাতি':'NN','মাতিয়াছিলেন':'VB','মাতুল':'NN',
'মাতৃ':'NN','মাতৃকা':'NN','মাতৃকোষিকা':'NN','মাতৃগর্ভে':'NN','মাতৃতান্ত্রিক':'JJ','মাতৃতীর্থ':'NN','মাতৃত্বেই':'NN',
'মাতৃদেবীর':'NN','মাতৃপালিত':'NN','মাতৃভাষা':'NN','মাতৃভুমিকে':'NN','মাতৃভূমির':'NN','মাতৃষ্বসা':'NN','মাতৃস্থান':'NN',
'মাতৃহীন':'JJ','মাতে':'NN','মাতেশ্বরী':'NN','মাতোয়ারা':'NN','মাত্':'RP','মাত্র':'RB','মাত্রই':'NN',
'মাত্রতো':'RB','মাত্রদেশের':'NN','মাত্রা':'NN','মাত্রাতিরিক্ত':'NN','মাত্রাবদ্ধ':'JJ','মাত্রাযুক্ত':'JJ','মাত্রাসমক':'NN',
'মাত্রাসম্বন্ধীয়':'JJ','মাত্রায়':'NNS','মাত্রি':'NN','মাত্রিক':'NN','মাত্রেই':'RB','মাথা-ঘোরা':'NN','মাথা':'NN',
'মাথাটা':'NN','মাথাতে':'NN','মাথানস্ট':'NN','মাথানিচু':'NN','মাথাব্যাথা':'NN','মাথাভারী':'NNP','মাথায়':'NN',
'মাথায়':'NN','মাথেরান':'NN','মাদক':'NN','মাদকবিরোধী':'JJ','মাদকাসক্ত':'NN','মাদকের':'NN','মাদন':'NN',
'মাদা':'NN','মাদাগাস্কার':'NN','মাদাগাস্কারি':'NN','মাদাগাস্কারীয়':'JJ','মাদার':'NN','মাদারবোর্ড':'NN','মাদারি':'NN',
'মাদারীপুর':'NN','মাদাড়ি':'NN','মাদিকেরি':'NN','মাদী':'NN','মাদুর':'NN','মাদুরাই':'NNP','মাদেরই':'NN',
'মাদ্ধমে':'NN','মাদ্রবতী':'NN','মাদ্রাজ':'NNP','মাদ্রাজের':'NNP','মাদ্রাস':'NN','মাদ্রাসায়':'NN','মাদ্রিদ':'NN',
'মাদ্রিদে':'NN','মাদ্রিদেরই':'NN','মাদ্রী':'NN','মাধব':'NN','মাধবিকা':'NN','মাধবী':'NN','মাধবীলতা':'NN',
'মাধা':'NN','মাধু':'NNP','মাধুরি':'NN','মাধুর্য্য':'NN','মাধোপুর':'NN','মাধ্যকার':'NN','মাধ্যমকে':'NN',
'মাধ্যমগুলো':'NN','মাধ্যমিক':'NN','মাধ্যমেই':'NN','মাধ্যাকর্ষণ':'NN','মাধ‍্যমে':'NN','মান-সম্মান':'NN','মান-সর':'NN',
'মান':'NN','মানকে':'NN','মানগত':'NN','মানচিত্র':'NN','মানচিত্রের':'NN','মানছি':'NN','মানছিল':'VB',
'মানছে':'NN','মানছেন':'VBG','মানটা':'NN','মানটি':'NN','মানত':'NN','মানতামপ্লাস্টিক':'NN','মানতে':'NN',
'মানতেন':'NN','মানদণ্ড':'NN','মানদন্ড':'NN','মানদাতা':'NN','মাননীয়':'NN','মাননীয়':'JJ','মানব':'NN',
'মানবকৃত':'JJ','মানবকৃতি':'NN','মানবচরিত্র':'NN','মানবজাতি':'NN','মানবতা':'NN','মানবতাজনমত':'NN','মানবতাবাদী':'JJ',
'মানবতাবিরোধী':'NN','মানবত্বের':'NN','মানববন্ধন':'NN','মানববিজ্ঞান':'NN','মানবভুক':'JJ','মানবমনের':'NN','মানবরচিত':'JJ',
'মানবশাস্ত্রী':'NN','মানবসদৃশ':'NN','মানবসমাজ':'NN','মানবসম্পদ':'NN','মানবসুলভ':'NN','মানবসেবা':'NN','মানবাধিকার.':'NN',
'মানবাধিকারের':'NN','মানবিক':'JJ','মানবিকতা':'NN','মানবী':'NN','মানবীকৃত':'JJ','মানবীয়':'NN','মানবীয়':'JJ',
'মানবীয়তা':'NN','মানবে':'VB','মানবেতর':'NN','মানবের':'NN','মানভঞ্জন':'VB','মানম':'NN','মানমন্দির':'NN',
'মানলাম':'VB','মানলেই':'VB','মানষিকতা':'NN','মানস-বিজ্ঞান':'NN','মানস-সর':'NN','মানস':'NN','মানসপুত্র':'NN',
'মানসম্পন্ন':'NN','মানসম্মত':'NN','মানসম্মানহীন':'JJ','মানসরোবর':'NN','মানসশাস্ত্র':'NN','মানসা':'NN','মানসিকতা':'NN',
'মানসিকতার':'NN','মানসে':'NN','মানহানি':'NN','মানা':'NNP','মানাগুয়া':'NN','মানাচ্ছে':'NN','মানাত':'NN',
'মানানসই':'NN','মানানো':'VB','মানানোর':'NNV','মানাপমান':'NN','মানাবে':'NN','মানারতো':'NN','মানাল':'NN',
'মানায়':'NN','মানায়সমাজ':'NN','মানি':'NN','মানিঅর্ডার':'NN','মানিআবগারী':'NN','মানিক-জোর':'NN','মানিক':'JJ',
'মানিকগঞ্জ':'NN','মানিটার':'NN','মানিনী':'JJ','মানিয়ে':'VB','মানিয়ে':'NN','মানিয়েও':'VB','মানী':'JJ',
'মানুবিক':'NN','মানুয':'NN','মানুশের':'NN','মানুষ':'NN','মানুষও':'NN','মানুষকে':'NN','মানুষখুব':'NN',
'মানুষখেকো':'JJ','মানুষগুলির':'NN','মানুষগুলোকেই':'NN','মানুষজন':'NN','মানুষটা':'NN','মানুষটার':'NN','মানুষটিও':'NN',
'মানুষতার':'NN','মানুষদের':'NN','মানুষভর্তি':'NN','মানুষরাও':'NN','মানুষসহ':'NN','মানুষে':'NN','মানুষের':'NN',
'মানুষেরও':'NN','মানুষেরসবাইকে':'NN','মানুষেরাই':'NN','মানুষ্ও':'NN','মানুসিকতার':'NN','মানূষ':'NN','মানে':'NN',
'মানেতাদের':'NN','মানেতো':'NN','মানেপেট্রোল':'NN','মানের':'NN','মানো':'NNV','মানোন্নয়ন':'NN','মান্ড':'NN',
'মান্ত্রিক':'NN','মান্থলি':'NN','মান্দা':'NN','মান্দে':'NN','মান্ধাতা':'NN','মান্না':'NN','মান্নান':'NN',
'মান্নারবের':'NN','মান্য':'NN','মান্যবর':'JJ','মাপ':'NN','মাপকরূপে':'NN','মাপকাঠি':'NN','মাপজোক':'NN',
'মাপতে':'NN','মাপনি':'NN','মাপা':'NN','মাপানো':'VB','মাপার':'NN','মাপুটো':'NN','মাপে':'NN',
'মাপের':'NN','মাফ':'NN','মাফনো':'VB','মাফলার':'NN','মাফিক':'RB','মাফিদার':'NN','মাফিয়াচক্রদের':'NN',
'মাবাবা':'NN','মাবুদ':'NN','মাবে':'VB','মাবোন':'NN','মাভো':'NNP','মামরী':'NN','মামলা':'NN',
'মামলাগুলোতে':'NN','মামলাটি':'NN','মামলাবাজ':'NN','মামলার':'NN','মামলা৩':'NN','মামাত':'NN','মামার':'NN',
'মামারবাড়ি':'NN','মামী':'NN','মামুন':'NN','মামুনরা':'NN','মামুলি':'NN','মামুষের':'NN','মামোলা':'NN',
'মাময়':'NN','মাযযেন':'NN','মায়':'NN','মার-কাট':'NN','মার':'NN','মারক':'JJ','মারকাটুরে':'NN',
'মারকিন':'NN','মারকেট':'NN','মারকেনটাইল':'NNP','মারক্যুরি':'NN','মারখাওয়া':'JJ','মারগাঁও':'NN','মারচেনট-হাজারের':'NNP',
'মারছে':'VB','মারটা':'NN','মারণ':'NN','মারতাছে':'VB','মারতেছে':'VB','মারদাংগা':'NN','মারধর':'NN',
'মারনাস্ত্র':'NN','মারনের':'NN','মারপিট':'NN','মারপ্যাঁচ':'NN','মারফত':'NN','মারফত্':'RB','মারবার':'NNV',
'মারবে':'VB','মারবো':'VB','মারমার':'NN','মারমুখী':'NN','মারল':'VB','মারলে':'NN','মারলেও':'NN',
'মারলেন':'VB','মারসা':'NN','মারহাবা':'NN','মারা-মারি':'NN','মারা':'NN','মারাঠি':'NN','মারাত্মক':'NN',
'মারাদোনা':'NN','মারাদোনাই':'NNP','মারানো':'VB','মারামারি':'NN','মারামারিতে':'NN','মারামারী':'VB','মারামারীতে':'NN',
'মারার':'NN','মারি':'VB','মারিচ':'NN','মারিজুয়ানা':'NN','মারিনো':'NN','মারিয়ার':'NN','মারিয়ামনিকা':'FW',
'মারিয়ার':'NNS','মারী':'JJ','মারীনা':'NN','মারুক':'NN','মারুতাত্মজ':'NN','মারুফ':'NN','মারে':'VB',
'মারেপ্যাচে':'NN','মারের':'NN','মারো':'VB','মারোয়াড়':'NN','মারোয়াড়ি':'JJ','মারোয়াড়ী':'NN','মার্':'NN',
'মার্কআপ':'NN','মার্কণ্ডেয়':'NN','মার্কন্ডেয়পুরাণ':'NN','মার্কশীট':'NN','মার্কসবাদ':'NN','মার্কা':'JJ','মার্কার':'NN',
'মার্কিং':'NN','মার্কিন':'JJ','মার্কিনযুক্তরাষ্ট্র':'NNP','মার্কিনযুক্তরাষ্ট্রের':'NNS','মার্কেট':'NN','মার্কেটিংএ':'NN','মার্কেটের':'NN',
'মার্কোপোলো':'NN','মার্ক্কা':'NN','মার্গ-দর্শক':'NN','মার্গ':'NN','মার্গচ্যূত':'JJ','মার্গদর্শক':'NN','মার্গারেট':'NNP',
'মার্চ':'NNP','মার্চনো':'VB','মার্চে':'NN','মার্চের':'NNP','মার্জন':'NN','মার্জার':'NN','মার্জারীটোড়ী':'NN',
'মার্জালীয়':'NN','মার্জিন':'NN','মার্ডার':'NN','মার্তিকাবত':'NN','মার্না':'NNP','মার্ফত':'NN','মার্বেল':'NN',
'মার্শই':'NN','মার্শাল':'NN','মার্ষ্টাস':'NN','মার্সি':'NN','মার্সিডিজ':'NNS','মাল-পত্র':'NN','মাল':'NN',
'মালকরা':'NNS','মালকানগিরি':'NN','মালকিন':'NN','মালকোষ':'NN','মালগাড়ি':'NN','মালগাসী':'NN','মালগুর্জরী':'NN',
'মালডোবা':'NN','মালতী':'NN','মালতীটোড়ী':'NN','মালদহ':'NN','মালদার':'NN','মালদিভ':'NN','মালদ্বীপ':'NNS',
'মালদ্বীপের':'NN','মালপত্তর':'NN','মালপোয়া':'NN','মালপ্পুরম':'NN','মালব':'NN','মালবগৌড়া':'NN','মালবাহী':'NN',
'মালভূমি':'NN','মালমশলা':'NN','মালয়েশিয়া':'NN','মালশ্রী':'NN','মালসা':'NN','মালহায়ন':'NN','মালাই':'NN',
'মালাকার':'NN','মালাটা':'NN','মালাধর':'NN','মালাফল':'NN','মালাবতী':'NN','মালাবার':'NN','মালাবো':'NN',
'মালামাল':'NN','মালালিকা':'NN','মালায়াম':'NN','মালি':'NN','মালিকই':'NN','মালিককে':'NN','মালিকদেরকে':'NNS',
'মালিকপক্ষ':'NN','মালিকরা':'NN','মালিকশ্রমিকরা':'NNS','মালিকা':'NN','মালিকানতে':'NN','মালিকানাধীন':'VBN','মালিকানার':'NN',
'মালিকের':'NN','মালিকেরা':'NNS','মালিনী':'NN','মালিশ':'NN','মালিশনো':'VB','মালিেকের':'NN','মালিয়া':'NN',
'মালী':'NN','মালীদবডেনাম':'NN','মালুক':'NN','মালুমকাঠ':'NN','মালে':'NN','মালেশিয়া':'NN','মালেশিয়ান':'JJ',
'মালোয়ালি':'NN','মাল্টা':'NN','মাল্টার':'JJ','মাল্টিন্যাশনাল':'JJ','মাল্টিমিডিয়া':'NNP','মাল্যবতী':'NN','মাল্যভূষিত':'JJ',
'মাল্লা':'NN','মাল্লু':'NNP','মালয়':'NN','মালয়শিয়া':'NN','মালয়েশিয়ান':'NN','মালয়েশিয়ায়':'NN','মালয়েশীয়':'JJ',
'মাশআল্লাহ':'NN','মাশফরাফির':'NN','মাশরাফ':'NNP','মাশরাফি':'NN','মাশরাফিই':'NNP','মাশরাফিইবা':'NN','মাশরাফিও':'NNP',
'মাশরাফিকে':'NN','মাশরাফির':'NNP','মাশরাফিসাকিবদের':'NN','মাশরুম':'NN','মাশাআল্লাহ':'VBG','মাশাল্লা':'NN','মাশী':'NN',
'মাশুল':'NN','মাশ্রাফির':'NN','মাশয়':'NNP','মাষক':'NN','মাষপর্ণী':'NN','মাষা':'NN','মাষ্টারমশাই':'NNP',
'মাষ্টারি':'NN','মাস':'NN','মাসকে':'NN','মাসচেরানো':'NN','মাসজাত':'JJ','মাসটাঙ্গ':'NN','মাসতুতো':'NN',
'মাসব্যাপী':'NN','মাসরাফি':'NN','মাসরাফিতুমিই':'NN','মাসরাফির':'NN','মাসশরাফি':'NN','মাসাই':'NN','মাসাষ্টকা':'NN',
'মাসি':'NN','মাসিকভিত্তিক':'VBN','মাসী':'JJ','মাসীর':'NN','মাসুদ':'NN','মাসুল':'NN','মাসে':'NN',
'মাসেও':'NN','মাসেরই':'NN','মাস্ক':'NN','মাস্টার-কি':'NN','মাস্টারমাইণ্ড':'NN','মাস্তি':'NN','মাস্তুল':'NN',
'মাস্তুলের':'NN','মাহত':'JJ','মাহফিল':'NN','মাহফুজে':'NN','মাহবুব':'NN','মাহমুদ':'NN','মাহমুদউল্লাহ':'NN',
'মাহমুদকে':'NN','মাহমুদা':'NN','মাহমুদুর':'NN','মাহমুদুল্লাহ':'NN','মাহমুদুল্লাহের':'NN','মাহাত্ম্য':'NN','মাহাবুব':'NN',
'মাহামুদুল্লাহকে':'NN','মাহারা':'JJ','মাহিত্য':'NN','মাহিনা':'NN','মাহী':'NN','মাহুঁ':'NN','মাহুমুদ':'NNP',
'মাহে':'NN','মাহেন্দ্রক্ষন':'NN','মাহেন্দ্রবাণী':'NN','মাহেলা':'NN','মাহোগনি':'NN','মাহোবিয়া':'JJ','মাহ্মুদ্দুল্লাহকে':'NN',
'মাড়':'NN','মাড়বংশের':'NN','মাড়ির':'NN','মায়ণ':'NNP','মায়া-জাল':'NN','মায়া':'NN','মায়ানমার':'NN',
'মায়ানমারের':'NN','মায়াবতী':'NN','মায়াবাদী':'NN','মায়াবি':'NN','মায়াবিষ্ট':'VB','মায়াবী':'JJ','মায়ার':'NN',
'মায়াস্ত্র':'NN','মায়ায়':'NN','মায়িক':'JJ','মায়ু':'NN','মায়ূরিক':'NN','মায়েদের':'NN','মায়েরা':'NNS',
'মায়েলো':'NN','মায়োসিস্':'NN','মা‌নি‌য়ে‌ছে':'NN','মি-র':'NNP','মি':'NN','মিঁউ':'NN','মিঃ':'NNP',
'মিইয়ে':'VB','মিউ':'NN','মিউকোসা':'NN','মিউঙ্গ':'NN','মিউচুয়াল':'NN','মিউজিক':'NN','মিউজিক্যাল':'JJ',
'মিউজিশিয়ান':'NNP','মিউজিয়াম':'NN','মিউট':'NN','মিউনিসিপালিটি':'NN','মিকং':'NN','মিকশ্চার':'NN','মিকা':'NN',
'মিকিও':'NNP','মিকির':'NN','মিকে':'NN','মিক্স':'NN','মিক্সি':'NN','মিখ্যা':'NN','মিগ':'NN',
'মিচকা':'NN','মিচির':'NN','মিছরি':'NN','মিছা':'JJ','মিছিল':'NN','মিছিলমিটিং':'VBG','মিছিলে':'NN',
'মিছে':'JJ','মিজান':'NN','মিজো':'NN','মিট':'NN','মিটমাট':'VB','মিটাতে':'NN','মিটানো':'VB',
'মিটাবার':'NN','মিটাবেন':'VB','মিটার':'NN','মিটি':'NN','মিটিং':'VBG','মিটিংমিছিল':'NN','মিটিঙ':'NN',
'মিটিয়ে':'NN','মিটে':'NN','মিঠাই':'NN','মিঠাপুকুর':'NN','মিঠুন':'NNP','মিঠুনের':'NN','মিড':'NN',
'মিডফিল্ডকে':'NN','মিডল':'NN','মিডিয়ার':'NNP','মিডিল':'NNP','মিডিয়া':'NN','মিডিয়াকর্মী':'NN','মিডিয়াগুলো':'NN',
'মিডিয়াতে':'NNP','মিডিয়াম':'NN','মিডিয়ার':'NNP','মিডয়ার':'NN','মিতব্যয়ী':'JJ','মিতভাষিতা':'NN','মিতভাষী':'JJ',
'মিতা':'NNP','মিতাচারী':'NN','মিতাহারী':'JJ','মিতি':'NNP','মিতু':'NN','মিতে':'NNP','মিত্র':'NN',
'মিত্রজ্ঞ':'NN','মিত্রতা':'NN','মিত্রপ্রাপ্তি':'NNP','মিত্রবতী':'NN','মিত্রবান':'NN','মিত্রবাহু':'NN','মিত্রবিন্দ':'NN',
'মিত্রভেদ':'NNP','মিত্রযুক্ত':'JJ','মিত্ররহিত':'JJ','মিত্রসপ্তমী':'NN','মিত্রসেন':'NN','মিত্রহন্তা':'NN','মিত্রহীন':'JJ',
'মিত্রা':'NN','মিত্রী':'NN','মিথ':'NN','মিথষ্ক্রিয়াবাদ':'NN','মিথিল':'NN','মিথুন':'NN','মিথেন':'NN',
'মিথ্যা':'NN','মিথ্যাও':'JJ','মিথ্যাকে':'NNS','মিথ্যাচারের':'NNS','মিথ্যাত্ব':'NN','মিথ্যাবর্ণনের':'NN','মিথ্যাবাদ':'NN',
'মিথ্যাবাদী':'NN','মিথ্যাভাষী':'JJ','মিথ্যুক':'JJ','মিথ্যেবাদী':'JJ','মিথ্যের':'NN','মিথ্রিভেট':'NNP','মিথ‍্যা':'JJ',
'মিদ্বান':'NN','মিনতি':'NN','মিনস্ক':'NN','মিনহাজুল':'NN','মিনা':'NN','মিনাকারি':'NN','মিনামিসোমা':'NN',
'মিনার':'NN','মিনিট':'NN','মিনিটে':'NNS','মিনিটের':'NNS','মিনিবাসের':'NN','মিনিমাম':'NN','মিনিস্টার':'NN',
'মিনী':'NNP','মিনে':'NN','মিনের':'NN','মিন্টুকে':'NN','মিফইরুজআহমেদ':'VBN','মিফখরুল':'NN','মিবাংলাদেশ':'NN',
'মিমি':'NN','মিম্বর':'NN','মিরকি':'NN','মিরজই':'NN','মিরপুর':'NN','মিরপুরবাসী':'NNS','মিরপুরে':'NN',
'মিরর':'NN','মিরাকল':'NN','মিরাজকে':'NN','মিরাজনাঈমের':'NN','মিরায':'NN','মিরোস্লাভ':'NN','মির্জা':'NN',
'মিল':'NN','মিলছে':'VBG','মিলন':'NN','মিলনান্ত':'NN','মিলনী':'NN','মিলনের':'NN','মিলবেনাএই':'NN',
'মিলবো':'NN','মিলল':'VB','মিললে':'NN','মিলস':'NNS','মিলা':'NNP','মিলাতে':'RP','মিলানের':'NN',
'মিলার':'NNP','মিলিগ্রাম':'NN','মিলিজুলি':'JJ','মিলিটারি':'NN','মিলিটারির':'JJ','মিলিটারী':'NN','মিলিত':'NN',
'মিলিতভাবে':'RB','মিলিমিটার':'NN','মিলিয়ন':'RP','মিলিলিটার':'NN','মিলিয়ন':'NN','মিলিয়েই':'VB','মিলে':'NN',
'মিলেমিশে':'VBG','মিলের':'NNS','মিল্ক':'NN','মিল্টন':'NNP','মিল্লার':'NNP','মিশতে':'VB','মিশন':'NN',
'মিশনকেও':'NNP','মিশনারিরা':'NN','মিশনে':'NN','মিশর':'NN','মিশরকে':'NNP','মিশরবাসীরা':'NNP','মিশরীয়':'NN',
'মিশরে':'NNP','মিশরের':'NN','মিশাইলে':'RP','মিশানোকে':'NN','মিশিউর':'NN','মিশিগান':'NN','মিশিয়ে':'JJ',
'মিশুকে':'NN','মিশে':'NN','মিশ্র':'NN','মিশ্রই':'NNP','মিশ্রকেশী':'NN','মিশ্রণ-যন্ত্র':'NN','মিশ্রণ':'NN',
'মিশ্রণের':'NN','মিশ্রিত':'NN','মিশ্রীকরণ':'NN','মিশ্রের':'NNP','মিষ্ট':'NN','মিষ্টভাব':'NN','মিষ্টভাষী':'JJ',
'মিষ্টান্ন':'NN','মিষ্টার':'NNP','মিষ্টি':'NN','মিষ্টিখোর':'NN','মিস':'NNP','মিসকিন':'NNP','মিসকিন্দের':'NN',
'মিসটেক':'NN','মিসরাতা':'NN','মিসাইল':'NN','মিসিসিপি':'NN','মিসের':'NNP','মিস্কিন':'NN','মিস্টার':'NNP',
'মিস্ত্রি':'NN','মিস্ত্রীগিরি':'NN','মিস্সী':'NN','মিহি':'RB','মিহিকা':'NN','মিয়ম':'NNP','মিয়া':'NN',
'মিয়াঁদাদের':'NNP','মিয়াকে':'NN','মিয়াকোর':'NNP','মিয়ানমার':'NN','মিয়ানমারে':'NN','মিয়ান্মার':'NN','মিয়ে':'VB',
'মি‌ডিয়া':'NNP','মীকে':'NN','মীজী':'NNP','মীথ':'NNP','মীন':'NN','মীনগন্ধা':'NN','মীননাথ':'NN',
'মীনরাশি':'NN','মীনাক':'NN','মীনাক্ষী':'NN','মীপে':'NNP','মীমাংসক':'NN','মীমাংসাশাস্ত্র':'NN','মীমাংসিত':'JJ',
'মীয়':'JJ','মীরণের':'NNP','মীরভূচড়ী':'NN','মীরহাজ':'NN','মীরাবাই':'NN','মীরুত':'NN','মীরে':'NNP',
'মীলা':'NNP','মীসহ':'NN','মীড়':'NN','মুকটহীন':'JJ','মুকরি':'NN','মুকাবা':'NN','মুকুট':'NN',
'মুকুটের':'NN','মুকুন্দ':'NN','মুকুন্দপুরের':'NNP','মুকুব':'NN','মুকুবনো':'VB','মুকুর':'NN','মুকুরকে':'NNP',
'মুকুল':'NN','মুকেশ':'NN','মুক্ত':'NN','মুক্তকণ্ঠ':'JJ','মুক্তকেশী':'NN','মুক্তচন্দা':'NN','মুক্তবাজার':'NN',
'মুক্তবেণী':'NN','মুক্তরঙা':'JJ','মুক্তসর':'NN','মুক্তহস্ত':'JJ','মুক্তহস্তে':'NN','মুক্তা':'NN','মুক্তাতাভা':'NN',
'মুক্তাবলী':'NN','মুক্তালতা':'NN','মুক্তাহার':'NN','মুক্তি':'NN','মুক্তিক':'NN','মুক্তিকোপনিষদ':'NN','মুক্তিক্ষেত্র':'NN',
'মুক্তিদিন':'NN','মুক্তিমতী':'NN','মুক্তিযুদ্ধ':'NN','মুক্তিযুদ্ধাদের':'NNS','মুক্তিযুদ্ধে':'VB','মুক্তিযুদ্ধের':'NN','মুক্তিযোদ্ধা':'NN',
'মুক্তিযোদ্ধাদের':'NNS','মুক্তিযোদ্ধারা':'NNS','মুক্তির':'NN','মুক্তিলগ্নে':'NN','মুক্তিসাধন':'NN','মুক্তো':'NN','মুখ':'NN',
'মুখচোরা':'JJ','মুখঝামটা':'NN','মুখটি':'NN','মুখড়া':'NN','মুখপাক':'NN','মুখবন্দ':'NN','মুখভঙ্গীর':'NN',
'মুখমণ্ডল':'NN','মুখমাধুর্য':'NN','মুখমুখি':'NN','মুখযাচিত':'JJ','মুখর':'NN','মুখরা':'JJ','মুখরিত':'NN',
'মুখরোগ':'NN','মুখরোচক':'JJ','মুখর্শ্রেণির':'NN','মুখশুদ্ধি':'NN','মুখস্ত':'NN','মুখাকৃতি':'NN','মুখাগ্নি':'NN',
'মুখাপেক্ষী':'JJ','মুখামুখি':'NN','মুখার্জির':'NNP','মুখি':'NN','মুখিশপুরে':'NNP','মুখিয়ে':'NN','মুখী':'JJ',
'মুখুটহিন':'NN','মুখে':'NN','মুখেও':'NN','মুখেভাত':'NN','মুখের':'NN','মুখোপাধ্যায়':'NNP','মুখোমুখি':'NN',
'মুখোশ':'NN','মুখোশধারী':'VBN','মুখোস':'NN','মুখ্য':'NN','মুখ্যনির্দেশক':'NN','মুখ্যপ্রবন্ধক':'NN','মুখ্যমন্ত্রী':'NN',
'মুগ':'NN','মুগবড়ি':'NN','মুগলী':'NN','মুগুর':'NN','মুগ্দ্ধ':'NN','মুগ্ধকারী':'JJ','মুঘল':'NN',
'মুঘলদেশে':'NN','মুঘলী':'JJ','মুঘোল':'NN','মুঙ্গের':'NN','মুচকি':'NN','মুচকুন্দ':'NN','মুচড়ানো':'JJ',
'মুচমুচে':'NN','মুচি':'NN','মুচিশাহির':'NNP','মুচুকুন্দ':'NN','মুছন':'NNP','মুছাইয়া':'NN','মুছাকে':'NN',
'মুছে':'NNP','মুজফ্ফরনগর':'NN','মুজরি':'NNS','মুজরো':'NN','মুজিব':'NN','মুটি':'NN','মুটে':'NN',
'মুটেগিরি':'NN','মুঠা':'NN','মুঠিগঞ্জ':'NNP','মুঠো':'NN','মুঠোফোনইন্টারনেট':'NN','মুঠোয়':'NN','মুড':'NN',
'মুড়ানো':'VB','মুড়ি':'NN','মুড়িবন্ধ':'NN','মুড়িয়ে':'VB','মুড়ে':'VBN','মুড়োনো':'NN','মুণি':'NN',
'মুণ্ড':'NN','মুণ্ডকোপনিষদ':'NN','মুণ্ডন':'NN','মুণ্ডমালা':'NN','মুণ্ডী':'NN','মুতেহরা':'NN','মুত্রাশয়':'NN',
'মুদগল':'NN','মুদগলোপনিষদ':'NN','মুদরা':'NN','মুদি':'NN','মুদিখানা':'NN','মুদির':'NN','মুদী':'JJ',
'মুদ্রক':'NN','মুদ্রণমূল্য':'NN','মুদ্রণযন্ত্র':'NN','মুদ্রণালয়':'NN','মুদ্রল':'NN','মুদ্রা-কান্হাড়া':'NN','মুদ্রা-বিনিময়':'NN',
'মুদ্রা':'NN','মুদ্রাকর':'NN','মুদ্রাকান্হাড়া':'NN','মুদ্রাকে':'NN','মুদ্রাক্ষরযন্ত্র':'NN','মুদ্রাটোরী':'NN','মুদ্রানীতি':'NN',
'মুদ্রাবসু':'NN','মুদ্রার':'NNS','মুদ্রাস্ফীতি':'NN','মুদ্রায়':'NN','মুন':'NN','মুনকির':'NN','মুনবরা':'NN',
'মুনমুনকে':'NNP','মুনসি':'NN','মুনা':'NN','মুনাফাই':'NN','মুনাফাকারী':'NN','মুনাফাখোরি':'NN','মুনাফাভিত্তিক':'JJ',
'মুনাফার':'NN','মুনি':'NN','মুনিঋষির':'NN','মুনিপুত্র':'NN','মুনিয়া':'NN','মুনিয়ের':'JJR','মুনী':'NN',
'মুনুষদেরকে':'NNS','মুন্ডক':'NN','মুন্দরা':'NN','মুন্দ্রা':'NNP','মুন্না':'NN','মুন্সিফ':'NN','মুফত':'JJ',
'মুভ':'NN','মুভমেন্ট':'NN','মুভি':'NN','মুমতাজ':'NN','মুমিনুল':'NN','মুমিনুলমুশফিক':'NN','মুমুক্ষু':'JJ',
'মুমূর্ষ':'NN','মুমূর্ষু':'JJ','মুম্বইএর':'JJ','মুম্বাই':'NN','মুম্বাইবাসী':'NN','মুম্বাইয়ের':'NN','মুম্বাদেবী':'NN',
'মুর':'NN','মুরগাবী':'NN','মুরগি':'NN','মুরগির':'NN','মুরগী':'NN','মুরণ্ডা':'NN','মুরতা':'NN',
'মুরল':'NN','মুরলী':'NN','মুরা':'NN','মুরাদাবাদ':'NN','মুরারবাজী':'NN','মুরালি':'NN','মুরিগর':'NN',
'মুরুব্বি':'NN','মুরুব্বিদের':'NNS','মুরুব্বী':'NN','মুরৈনা':'NN','মুরোদ':'NN','মুর্খ':'NN','মুর্গকেশ':'NN',
'মুর্গির':'NN','মুর্ঘ':'NN','মুর্চ্ছিত':'JJ','মুর্শিদাবাদ':'NN','মুল':'NN','মুলত':'RB','মুলতবিনো':'VB',
'মুলতানি':'NN','মুলতুবি':'VB','মুলধন':'NN','মুলধনগুলো':'NNS','মুলা':'NN','মুলাকাত্':'NN','মুলার':'NN',
'মুলুক':'NN','মুলূকহাসবো':'IN','মুলে':'NN','মুলো':'NN','মুল্য':'NN','মুল্যহীন':'NN','মুল্যে':'NN',
'মুল্যের':'JJ','মুল্লহ':'NN','মুল্লুকে':'NN','মুশকিল':'NN','মুশফিক':'NN','মুশফিককেই':'NN','মুশফিকের':'NN',
'মুশাজ্জার':'NN','মুশি':'NN','মুশির্দাবাদ':'NN','মুশ্কদানা':'NN','মুশ্কমেহেন্দী':'NN','মুষল':'NN','মুষলধার':'JJ',
'মুষলধারে':'NN','মুষিক':'NN','মুষ্ক':'NN','মুষ্টি':'NN','মুষ্টিকা':'NN','মুষ্টিমাত্র':'JJ','মুষ্টিমেয়':'NN',
'মুষ্টিযুদ্ধ':'NN','মুসকিল':'NN','মুসফিকের':'NN','মুসমার':'NN','মুসলমান':'NN','মুসলমানবংশের':'NN','মুসলমানরাই':'NNS',
'মুসলিম':'NN','মুসলিমদের':'NNS','মুসলিমপ্রধান':'NN','মুসলী':'NN','মুসা':'NN','মুসাদ্দেক':'NN','মুসাফিরখানা':'NN',
'মুসাম্বি':'NN','মুসিং':'NNP','মুসী':'NN','মুসুর':'NN','মুসোম্বি':'NN','মুসৌরী':'NN','মুস্তফা':'NN',
'মুস্তাফিজ':'NN','মুস্ফিক':'NN','মুহর্তগুলো':'NN','মুহাম্মদ':'NN','মুহালা':'NN','মুহিত':'NN','মুহুরি':'NN',
'মুহুর্তটির':'NN','মুহুর্তের':'NN','মুহূরিবৃত্তি':'NN','মুহূর্তও':'NN','মুহূর্তটিতে':'NN','মুহূর্তেই':'NN','মুড়কির':'NN',
'মুড়ির':'NN','মুড়িয়ে':'VBD','মু‌খে':'NN','মূক':'NN','মূখর':'NN','মূখ্য':'NN','মূখ্যদ্বার':'NN',
'মূখ্যমন্ত্রীকে':'NN','মূঞ্ছী':'NN','মূঢ়তা':'NN','মূতরী':'NN','মূত্রকৃচ্ছ্র':'NN','মূত্রক্ষয়':'NN','মূত্রগ্রহ':'NN',
'মূত্রত্যাগ':'NN','মূত্রথলির':'NN','মূত্রদোষ':'NN','মূত্রনালিকা':'NN','মূত্রনিরোধ':'NN','মূত্রপতন':'NN','মূত্রবাহিকা':'NN',
'মূত্রবিজ্ঞান':'NN','মূত্রমালি':'NN','মূত্ররোধ':'NN','মূত্রলা':'NN','মূত্রস্থলীতে':'NN','মূত্রাঘাত':'NN','মূত্রাসাদ':'NN',
'মূদ্রা-স্ফীতি':'NN','মূদ্রা':'NN','মূদ্রাস্ফীতি':'NN','মূনা':'NN','মূরিদরা':'NNS','মূর্খ':'NN','মূর্খই':'JJ',
'মূর্খরা':'NN','মূর্চ্ছনা':'NN','মূর্চ্ছিত':'NN','মূর্ছার':'NN','মূর্তি':'NN','মূর্তিকার':'NN','মূর্তিত':'JJ',
'মূর্তিতে':'NN','মূর্তিপূজা':'NN','মূর্তিবিহীন':'NN','মূর্তিমান':'JJ','মূর্তির':'NN','মূর্ত্তি':'NN','মূর্দ্ধন্য':'NN',
'মূর্ধন্য':'JJ','মূল-নিবাসী':'NN','মূল':'NN','মূলকথা':'NN','মূলগত':'JJ','মূলজ':'NN','মূলতঃ':'RB',
'মূলতান':'NN','মূলধণ':'NN','মূলধনের':'NN','মূলভাষা':'NN','মূলমন্ত্র':'NN','মূলশোধন':'NN','মূলহীন':'JJ',
'মূলা':'NN','মূলাকলা':'NNP','মূলাধার':'NN','মূলী':'NN','মূলেসকল':'NNS','মূল্য':'NN','মূল্যটা':'NN',
'মূল্যফেরত':'NN','মূল্যবান':'JJ','মূল্যবৃদ্ধি':'NN','মূল্যবোধ':'NN','মূল্যবোধসম্পন্ন':'NN','মূল্যবোধের':'NN','মূল্যস্ফীতি':'NN',
'মূল্যহীন':'NN','মূল্যাঙ্কন':'NN','মূল্যাতীত':'JJ','মূল্যায়ন':'NN','মূল্যারোপণে':'NN','মূল্যায়ক':'NN','মূল্যায়ণকারী':'NN',
'মূল্যায়ন':'NN','মূল্যে':'NN','মূষককর্ণী':'NN','মূষিক':'NN','মূসক':'NN','মূসলী':'NN','মূহুর্ত':'NN',
'মূহূর্তেই':'VB','মৃকণ্ড':'NN','মৃগ-মরীচিকা':'NN','মৃগ':'NN','মৃগচর্ম':'NN','মৃগছানা':'NN','মৃগতৃষ্ণা':'NN',
'মৃগত্তোম':'NN','মৃগদাও':'NN','মৃগনাভি':'NN','মৃগনয়নী':'NN','মৃগভক্ষা':'NN','মৃগমদ':'NN','মৃগমৃগীদের':'NN',
'মৃগরাটিকা':'NN','মৃগরোগ':'NN','মৃগলোচনা':'NN','মৃগশাবক':'NN','মৃগশির':'NN','মৃগহারায়':'NNP','মৃগারতি':'NN',
'মৃগী':'NN','মৃগীরোগী':'NN','মৃগেন্দ্র':'NN','মৃগয়া':'NN','মৃণাল':'NN','মৃত':'NN','মৃতজন্মা':'NN',
'মৃতজাত':'JJ','মৃতদের':'NN','মৃতদেহটা':'NN','মৃতপ্রায়':'NN','মৃতবত্সা':'JJ','মৃতর':'JJ','মৃতসঞ্জীবনী':'NN',
'মৃতসত্কার':'NN','মৃতা':'NN','মৃতে':'NN','মৃত্তিকা':'NN','মৃত্পাণ্ডু':'NN','মৃত্যু-প্রমাণপত্র':'NN','মৃত্যু':'NN',
'মৃত্যুকর':'NN','মৃত্যুচিন্তা':'NN','মৃত্যুঞ্জয়':'NN','মৃত্যুঞ্জয়ী':'JJ','মৃত্যুটা':'NN','মৃত্যুদণ্ড':'NN','মৃত্যুদিবস':'NN',
'মৃত্যুপরান্ত':'RB','মৃত্যুবরণ':'NN','মৃত্যুভয়হীন':'JJ','মৃত্যুমুখি':'NN','মৃত্যুলোক':'NN','মৃত্যুসংবাদ':'NN','মৃত্যুহার':'NN',
'মৃত‌্যুদন্ডই':'NN','মৃদঙ্গ':'NN','মৃদঙ্গবাদক':'NN','মৃদপঘাত':'NN','মৃদু':'NN','মৃদুনাদী':'JJ','মে':'NN',
'মেইটরা':'NN','মেইডেন':'NNP','মেইন':'NN','মেইনটেইন':'NN','মেইনস্ট্রিম':'NN','মেইল':'NN','মেওয়া':'NN',
'মেওয়াড়':'NN','মেক':'NN','মেকাক':'NN','মেকি':'NN','মেকুর':'NN','মেক্সিকান':'NN','মেক্সিকীয়':'JJ',
'মেক্সিকো':'NN','মেক্সিকোর':'NN','মেক্সিমিলানো':'NN','মেক্সীকানদের':'NN','মেখলা':'NNP','মেখে':'VB','মেগ':'NN',
'মেগাওয়াট':'NN','মেগাটেরা':'NN','মেগাপিক্সেল':'NN','মেগাবাইট':'NN','মেগাসিটি':'NN','মেগাহার্ত্জ':'NN','মেগ্রীব':'NN',
'মেঘ':'NN','মেঘজ্যোতি':'NN','মেঘনাট':'NN','মেঘনাদ-রস':'NN','মেঘনাদরস':'NN','মেঘবান':'NN','মেঘবিস্ফূর্জিতা':'NN',
'মেঘবিহীন':'JJ','মেঘমল্লার':'NN','মেঘমুক্ত':'JJ','মেঘরাগ':'NN','মেঘলা':'NN','মেঘহীন':'JJ','মেঘাচ্ছন্ন':'JJ',
'মেঘাচ্ছাদিত':'JJ','মেঘালয়':'NN','মেঘে':'NN','মেঘের':'NNS','মেচক':'NN','মেছুনি':'NN','মেছে':'VB',
'মেজ':'NN','মেজনিলো-নুনেজ':'NN','মেজর':'NN','মেজরকে':'NNP','মেজরিটি':'NN','মেজাকে':'JJ','মেজাজ':'NN',
'মেজাজি':'NN','মেজিস্ট্রিসি':'NN','মেজে':'VB','মেজো':'JJ','মেঝে':'NN','মেটা':'NN','মেটাচ্ছে':'NN',
'মেটানো':'NN','মেটাবার':'NNV','মেটার':'NN','মেটাল':'NNP','মেটে':'NN','মেট্রো':'NN','মেট্রোরেলই':'NN',
'মেঠাই':'NN','মেঠো':'NN','মেড':'NN','মেডাম':'NN','মেডিকেল':'NN','মেডিটেশনের':'NN','মেডিসিন':'NN',
'মেডেল':'NN','মেঢ়াসিঙ্গি':'NN','মেণ্টাম':'NNP','মেতরানী':'NN','মেতে':'NN','মেথর':'NN','মেথি':'NN',
'মেথৌরী':'NN','মেদ':'NN','মেদিনী':'NN','মেধা':'NN','মেধাকে':'NN','মেধাজিত':'NN','মেধাতিথি':'NN',
'মেধাবি':'JJ','মেধাবী':'NN','মেধাবীদের':'JJ','মেধাবীদেরই':'NN','মেধাবীরাই':'NN','মেধাসম্পন্ন':'NN','মেধাহীন':'NN',
'মেধি':'NN','মেধ্য':'JJ','মেন':'NN','মেনকাউরে':'NNP','মেনট':'NN','মেননের':'NN','মেনাবলী':'NN',
'মেনু':'NN','মেনেকা':'NN','মেনেছিলেন':'NN','মেনেতবে':'NN','মেনোফি':'NN','মেন্':'NN','মেন্টেন':'NN',
'মেন্ড্রিল':'NN','মেন্তালিটির':'NN','মেপে':'NN','মেবার':'NN','মেম':'NN','মেমব্রেন':'NN','মেমরিও':'NN',
'মেমসাহেব':'NN','মেমোরি':'NN','মেম্বর':'NNP','মেম্বার':'NN','মেয়রের':'NN','মেয়াদ':'NN','মেরও':'NN',
'মেরঠ':'NN','মেরামত':'NN','মেরামতি':'NN','মেরামতির':'JJ','মেরামতের':'NN','মেরি':'NN','মেরির':'NNP',
'মেরিল্যান্ড':'NN','মেরী':'NN','মেরুকরণ':'NN','মেরুতে':'NN','মেরুদণ্ড':'NN','মেরুদণ্ডী':'NN','মেরুদন্ডহীন':'NN',
'মেরুন':'NN','মেরুপর্বত':'NN','মেরুপ্রদেশীয়':'JJ','মেরুরজ্জু':'NN','মেরুরেখা':'NN','মেরে':'NN','মেরেছিল':'NN',
'মেরেছিলেন':'NN','মেরেছেন':'NN','মেল':'NN','মেলবন্ধনে':'NN','মেলবর্ণ':'NN','মেলা':'NN','মেলাও':'VB',
'মেলাতে':'NN','মেলানো':'NN','মেলামাইন':'NN','মেলামেলি':'NN','মেলার':'NN','মেলে':'VB','মেলেনি':'NN',
'মেলো':'VB','মেল্হনা':'NN','মেশন':'NN','মেশানো':'NN','মেশিনগান':'NN','মেশীন':'NN','মেশে':'NN',
'মেষ':'NN','মেষপাল':'NN','মেষপুচ্ছ':'NN','মেষরাশি':'NN','মেষরাশিবিশিষ্ট':'NN','মেষশাবক':'NN','মেষহৃত':'NN',
'মেষের':'NN','মেস':'NN','মেসিক':'NN','মেসিডনের':'NNP','মেসিডোনিয়ান':'NN','মেসিডোনিয়ার':'NNP','মেসিডোনিয়া':'NN',
'মেসিডোনিয়ার':'JJ','মেসিদের':'NN','মেসিন':'NN','মেসিরই':'NN','মেসিরোনালদোর':'NN','মেসিহীন':'NN','মেসু':'NN',
'মেসেঞ্জার':'NN','মেসের':'NN','মেসো':'NN','মেসোপটেমিয়া':'NNP','মেসোপটেমিয়া':'NN','মেসোর':'NN','মেস্কল':'NN',
'মেহতা':'NN','মেহনতি':'NN','মেহরাবদার':'JJ','মেহল':'NN','মেহসানার':'NN','মেহিনী':'NN','মেহেদি':'NN',
'মেহেন্দি':'NN','মেহেবুবনগর':'NN','মেহেরের':'NNP','মোটাত্ব':'NN','মোটামুটি':'NN','মোটেও':'NN','মোবাইল':'NN',
'মোবাইলের':'NN','মোশাররফ':'NN','মোড়ল':'NN','মৌলিক':'NN','মেয়দের':'NN','মেয়রের':'NN','মেয়াদ':'NN',
'মেয়াদযুক্ত':'JJ','মেয়াদি':'NN','মেয়াদে':'NN','মেয়ানমারের':'NN','মেয়ে':'NN','মেয়েকে':'NN','মেয়েগুলি':'NN',
'মেয়েটা':'NN','মেয়েটার':'NN','মেয়েটির':'NN','মেয়ের':'NN','মেয়েরাও':'NN','মেয়েলি':'JJ','মেয়েলোকের':'NN',
'মেয়োনিজ':'NN','মৈত্রাবরুণ':'NN','মৈত্রায়ণী':'NN','মৈত্রীপূর্ণ':'JJ','মৈত্রেয়':'NN','মৈথিল':'NN','মৈথিলি':'JJ',
'মৈথিলী':'NN','মৈথুন':'NN','মৈনপুরি':'NN','মৈনাক':'NN','মৈনী':'NN','মৈন্দ':'NN','মৈমনসিংহ':'NNP',
'মৈরনী':'NN','মৈসুর':'NN','মো':'NN','মোকদ্দমা':'NN','মোকা':'NN','মোকাবিলা':'NN','মোকাবেলার':'NN',
'মোকাব্বির':'NN','মোকোকচুঙ্গ':'NN','মোক্তার':'NN','মোক্তারী':'NN','মোক্ষ':'NN','মোক্ষদানন্দ':'NNP','মোক্ষদায়ক':'JJ',
'মোক্ষপ্রাপ্ত.বন্ধনমুক্ত':'JJ','মোক্ষম':'NN','মোখা':'NN','মোগল':'NN','মোগলি':'NN','মোগা':'NN','মোগাদিশু':'NN',
'মোঘল':'NN','মোঘলীয়':'JJ','মোঙ্গলা':'NN','মোঙ্গোলিয়ান':'JJ','মোচড়':'NN','মোচড়ানো':'NNV','মোচন':'NN',
'মোচড়ানো':'NNV','মোছা':'NN','মোছার':'NN','মোজা':'NN','মোজাম্বিক':'NN','মোজায়':'NN','মোট.':'JJ',
'মোট':'NN','মোটনক':'NN','মোটর':'NN','মোটরগাড়ি':'NN','মোটরগাড়ী':'JJ','মোটরচালিত':'NN','মোটরবোট':'NN',
'মোটরসাইকেল':'NN','মোটর্স':'NN','মোটা':'NN','মোটাতাজা':'NN','মোটামুটি':'NN','মোটামুটিভাবে':'RB','মোটাসোটা':'JJ',
'মোটে':'NN','মোটেও':'NN','মোটেল':'NN','মোড':'NN','মোড়ওলা':'JJ','মোড়যুক্ত':'JJ','মোড়হীন':'JJ',
'মোড়া':'NN','মোডি':'NN','মোডেম':'NN','মোতানো':'VB','মোতাবেক':'NN','মোতি':'NN','মোতিলাল':'NN',
'মোতিহারি':'NN','মোতিয়াদাম':'NN','মোতে':'NNP','মোদ':'NN','মোদন':'NNP','মোদি':'NN','মোদিজী':'NN',
'মোদিরই':'NN','মোদী':'NN','মোদীজির':'NN','মোদীর':'NN','মোদীসর্বস্ব':'NN','মোনরোবিয়া':'NN','মোনস':'NN',
'মোনাকো-বিলে':'NN','মোনাজাইট':'NNP','মোনেকো':'NN','মোনোফসফেট':'NN','মোপম':'NNP','মোপেড':'NN','মোফাজ্জালসাঈদ':'NN',
'মোবাইক':'NN','মোবাইলে':'NN','মোবিলিটি':'NN','মোবুতু':'NNP','মোম':'NN','মোমদানি':'NN','মোমিন':'NN',
'মোমের':'NN','মোয়':'NN','মোর':'NN','মোরক্কো':'NN','মোরগ':'NN','মোরজুটনা':'NN','মোরধ্বজ':'NN',
'মোরসবী':'NN','মোরা':'NN','মোরাদাবাদ':'NN','মোরামতের':'NN','মোরারজী':'NN','মোরাস্মানী':'NN','মোরিটানিয়া':'NN',
'মোরোব্বা':'NN','মোর্তজা':'NN','মোর্মোসেট':'NN','মোর্শেদা':'NN','মোর্শেদার':'NN','মোল':'JJ','মোলায়েম':'NN',
'মোল্ডভিয়া':'NN','মোল্ডোভান':'JJ','মোল্ডোভীয়':'JJ','মোল্ডোয়া-বাসী':'NN','মোল্লা':'NN','মোশতাকের':'NN','মোশারফই':'NN',
'মোশাররফসে':'NN','মোশায়েব':'NN','মোষ':'NN','মোষপালক':'NN','মোষের':'NN','মোসাদ':'NN','মোসাদ্দেক':'NN',
'মোসাদ্দেকুর':'NN','মোসাম্বি':'NN','মোসাহেব':'NN','মোসুল':'NN','মোসোমশাই':'NN','মোস্ট':'NN','মোস্তফা':'NN',
'মোস্তাফিজ':'NN','মোহ':'NN','মোহন':'NN','মোহনবাগান':'NNP','মোহনমালা':'NN','মোহনাকে':'NNP','মোহনী':'NN',
'মোহন্ত':'NNP','মোহভঙ্গ':'NN','মোহমুক্ত':'JJ','মোহর':'NN','মোহরম':'NNP','মোহরযুক্ত':'JJ','মোহরা':'NN',
'মোহরী':'NN','মোহান্ত':'NN','মোহাবিষ্ট':'VB','মোহামেডান':'NN','মোহাম্মদ':'NN','মোহাম্মদপুরে':'NN','মোহাম্মাদ':'NN',
'মোহিত':'NN','মোহে':'NN','মোড়':'NN','মোড়া':'NNV','মোয়া':'NN','মোয়ামি':'NNP','মৌ':'NN',
'মৌখিক':'NN','মৌচাক':'NN','মৌজ':'NN','মৌন':'NN','মৌনব্রতধারী':'JJ','মৌনী':'NN','মৌন্যব্রত':'NN',
'মৌমাছি':'NN','মৌরসি':'NN','মৌরিজাতীয়':'NN','মৌরিটানিয়ার':'JJ','মৌরীর':'NN','মৌরুসি':'NN','মৌর্য':'NN',
'মৌল':'NN','মৌলদ্বয়':'NN','মৌলনা':'NNP','মৌলবাদি':'NN','মৌলবী':'NN','মৌলশ্রী':'NN','মৌলিক':'NN',
'মৌলিমণ্ডন':'NN','মৌসুম':'NN','মৌসুমে':'NN','ম্নে':'NN','ম্পদ':'NN','ম্পু':'NNP','ম্পে':'NN',
'ম্বই':'NN','ম্বক':'JJ','ম্বন':'NN','ম্বর':'NNP','ম্বল':'JJ','ম্বা':'NNP','ম্বাবানে':'NNP',
'ম্বী':'JJ','ম্বে':'NN','ম্বো':'NNP','ম্ভক':'NNP','ম্ভব':'JJ','ম্ভর':'NNP','ম্ভে':'NN',
'ম্মত':'JJ','ম্মদ':'NN','ম্যও':'NN','ম্যক':'JJ','ম্যকগ্রা':'NN','ম্যচ':'NN','ম্যনিফেস্টো':'NN',
'ম্যরাডোনাও':'NN','ম্যশ':'NN','ম্যাঁ':'NN','ম্যাঁম্যাঁ':'NN','ম্যাক':'NN','ম্যাকগ্রাই':'NN','ম্যাকব্রাইড':'NN',
'ম্যাক্স':'NN','ম্যাগনেটাইট':'NN','ম্যাগনেশিয়াম':'NN','ম্যাগমা':'NN','ম্যাঙ্গানিজ':'NN','ম্যাঙ্গো':'NN','ম্যাচ':'NN',
'ম্যাচটা':'NN','ম্যাচসংখ্যাকে':'NN','ম্যাচিং':'NNV','ম্যাচিঙ্গ':'JJ','ম্যাচে':'NN','ম্যাচেও':'NN','ম্যাজিক':'JJ',
'ম্যাজিকাল':'NN','ম্যাজিকের':'NN','ম্যাজিস্ট্রেট':'NN','ম্যাজিস্ট্রেটি':'NN','ম্যাট':'NN','ম্যাটেরিয়্যালস':'NN','ম্যাডাম':'NN',
'ম্যাধমটা':'NN','ম্যান':'NN','ম্যানচেস্টার':'NN','ম্যানতো':'NN','ম্যানসনে':'NN','ম্যানার':'NN','ম্যানিটল':'NN',
'ম্যানেজ':'NN','ম্যানেজমেন্টে':'NN','ম্যানেজার':'NN','ম্যানেজারবাবুর':'NNP','ম্যানেজারীর':'NN','ম্যানেজিং':'NN','ম্যানোফেষ্ট':'NN',
'ম্যান্ডেট':'NN','ম্যামথ':'NN','ম্যালওয়ার':'NN','ম্যালেরিয়া':'NN','ম্যালেরিয়ায়':'NN','ম্যাশ':'NN','ম্যাশকে':'NN',
'ম্যাশের':'NN','ম্যাসমেরিজম':'NN','ম্যাসরাফিকে':'NN','ম্যাসেঞ্জার':'NN','ম্যাস্টাইটিস':'NN','ম্যাড়ম্যাড়ে':'NN','ম্যা‌চে':'NN',
'ম্যুনিখ':'NN','ম্যেচ':'NN','ম্রিয়মাণ':'VB','ম্লান':'NN','ম্লেচ্ছ':'NN','ম্লেচ্ছজাতির':'NN','মৎস্য':'NN',
'মড়ন':'NN','মড়ায়':'NN','মড়িটার':'NN','ময়':'NN','ময়কর':'JJ','ময়তনয়া':'NN','ময়দা':'NN',
'ময়দানব':'NN','ময়না':'NN','ময়ন্দ':'NN','ময়মত':'JJ','ময়মনসিংহ':'NN','ময়রা':'NN','ময়লা-প্রতিরোধক':'NN',
'ময়লা':'NN','ময়িক':'JJ','ময়ীর':'NN','ময়ু':'NN','ময়ুরভঞ্জ':'NN','ময়ূখ':'NN','ময়ূরগতি':'NN',
'ময়ূরধ্বজ':'NN','ময়ূরপুচ্ছ':'NN','ময়ূরশিখা':'NN','ময়ূরসারিণী':'NN','ময়ূরী':'NN','ময়েই':'NN','ময়েন':'NN',
'ম‌তোও':'NN','ম‌ধ্যে':'NN','ম‌নে':'NN','ম‍্যাচে':'NN','য':'NN','যওয়াশ':'NN','যকরী':'JJ',
'যকলা':'NN','যকাল':'RB','যকৃত':'NN','যকৃপ্রদাহ':'NN','যকের':'NN','যক্ত':'JJ','যক্ষ':'NN',
'যক্ষতরু':'NN','যক্ষরুচি':'NN','যক্ষারোগী':'NN','যক্ষি':'NN','যক্ষী':'NN','যক্ষ্মনাশন':'NN','যখ':'NN',
'যখনই':'NN','যখনি':'WRB','যখানে':'NN','যগণ':'NN','যগুর':'NN','যগৃহ':'NN','যঙ্গ':'NN',
'যজন-যাজন':'NN','যজনক':'JJ','যজমান':'NN','যজমানী':'NN','যজু':'NN','যজুরবেদী':'NN','যজুশ্রুতি':'NN',
'যজ্ঞ':'NN','যজ্ঞকুণ্ড':'NN','যজ্ঞকোপ':'NN','যজ্ঞগার':'NN','যজ্ঞপশু':'NN','যজ্ঞপাত্র':'NN','যজ্ঞবেদী':'NN',
'যজ্ঞশত্রু':'NN','যজ্ঞশালা':'NN','যজ্ঞসেন':'NN','যজ্ঞস্থল':'NN','যজ্ঞীয়':'JJ','যজ্ঞৃ-কুণ্ড':'NN','যটনায়':'NN',
'যটির':'NN','যণীয়':'JJ','যত...তত':'RB','যত':'NN','যতক্ষণ':'NN','যতখানি':'CD','যতগুলি':'CD',
'যতগুলো':'DT','যতজন':'CD','যতটা':'NN','যতটুকু':'NN','যতদিন':'NN','যতদুর':'NN','যতবার':'NNS',
'যতসব':'NN','যতাপ':'NN','যতায়':'NN','যতি':'NN','যতীত':'JJ','যতীন্দ্রনাথ':'NNP','যতে':'NN',
'যতো':'NN','যতোক্ষণ':'RB','যত্তসব':'NN','যত্ন':'NN','যত্নআত্তি':'NN','যত্ননিন':'NN','যত্নপূর্বক':'RB',
'যত্নশীল':'VBG','যত্নশীলভাবে':'RB','যত্নে':'RB','যথা':'NN','যথাকর্ম':'RB','যথাকিঞ্চিত':'JJ','যথাক্রমে':'NN',
'যথানিয়মে':'RB','যথাপূর্বক':'RB','যথাবাঞ্ছিত':'RB','যথাবিহিত':'JJ','যথাযত':'JJ','যথাযথ':'RB','যথাযথভাবে':'NN',
'যথার':'NN','যথার্থ':'NN','যথার্থই':'RB','যথার্থতা':'NN','যথার্থবাদী':'NN','যথাশক্তি':'RB','যথাসম্ভব':'RB',
'যথাসময়ে':'RB','যথাসাধ্য':'RB','যথাস্থানে':'RB','যথেচ্ছ':'RB','যথেচ্ছাচার':'NN','যথেচ্ছাচারী':'JJ','যথেষ্ট':'RB',
'যথেষ্টআল্লাহর':'NN','যথেষ্টতা':'NN','যথোচিত':'JJ','যদার':'NNP','যদি':'NN','যদিও':'CC','যদু':'NN',
'যদুবংশ':'NN','যদুর':'NNP','যদেব':'NNP','যদের':'NN','যদোয়':'NN','যধিক':'JJ','যন':'JJ',
'যনলে':'NN','যনাথ':'NNP','যন্ত':'JJ','যন্ত্র-মানব':'NN','যন্ত্রকুশলী':'NN','যন্ত্রকৌশল':'NN','যন্ত্রগুলিতে':'NN',
'যন্ত্রগুলো':'NNS','যন্ত্রগৃহ':'NN','যন্ত্রচালিত':'NN','যন্ত্রটির':'NN','যন্ত্রণাই':'NN','যন্ত্রনা':'NN','যন্ত্রনাকর':'JJ',
'যন্ত্রপাতি':'NN','যন্ত্রবিদ্':'NN','যন্ত্রবিন্যাস':'NN','যন্ত্রশালা':'NN','যন্ত্রাপীড়':'NN','যন্ত্রে':'NN','যন্ত্রোপকরণ':'NN',
'যন্রাংশ':'NN','যপান':'NN','যব':'NN','যবক্রীত':'NN','যবক্ষা':'NN','যবতমাল':'NN','যবতিক্তা':'NN',
'যবতী':'JJ','যবন':'NN','যবনদের':'NN','যবনরাজার':'NN','যবনিকা':'NN','যবনের':'NN','যবনেষ্ট':'NN',
'যবফল':'NN','যবসা':'NN','যবাদ':'NN','যবাপমরুত':'NN','যবীনর':'NN','যবে':'RB','যবের':'NN',
'যবোধ':'NN','যম':'NN','যমতে':'VB','যমদূত':'NN','যমদেব':'NN','যমদ্বিতীয়া':'NN','যমন':'NN',
'যমপুরী':'NN','যমরাজ':'NN','যমলোক':'NN','যমস্তোম':'NN','যমাতিরাত্র':'NN','যমান':'JJ','যমানুজা':'NN',
'যমিক':'JJ','যমুন':'NN','যমুনানগর':'NN','যমুনাবতী':'NNP','যমুনার':'NN','যমুনোত্রী':'NN','যমেই':'RB',
'যমের':'NNP','যমেশ':'NN','যযাতি':'NN','যযান':'NN','যযু':'NN','যরকম':'NN','যরাজ':'NN',
'যর্জুবেদ':'NN','যর্থ':'JJ','যলাভ':'NN','যশ':'NN','যশস্বী':'JJ','যশহীন':'JJ','যশোদা':'NN',
'যশোধর':'NN','যশোবন্ত':'NNP','যশোবর':'NN','যশোমতি':'NN','যশোর':'NN','যশোহর':'NNP','যষ্টি':'NN',
'যষ্টীকণ':'NN','যষ্ঠিমধু':'NN','যস্ক':'NN','যস্ত':'JJ','যহীন':'JJ','য়গা':'NN','য়ত':'RB',
'য়তা':'NN','য়নি':'VB','য়নে':'NN','য়শই':'RB','য়সী':'JJ','য়াচ':'NN','য়াড':'NNP',
'য়ান':'NN','য়ার':'NN','য়ুথ':'NNP','য়েক':'CD','য়েড':'NNP','য়েত':'JJ','য়ের':'NN',
'য়োগ':'NN','যা':'PR','যাঁও':'PR','যাঁকে':'NN','যাঁচ':'PR','যাঁতা':'NN','যাঁদের':'DT',
'যাঁর':'PR','যাঁরা':'NN','যাঁহারা':'PR','যাই':'NN','যাইতে':'VB','যাইতেছে':'VBG','যাইতেছেন':'VB',
'যাইতো':'NN','যাইনাই':'NN','যাইব':'NN','যাইযেই':'NN','যাএীর':'VB','যাও':'VB','যাওয়া':'NN',
'যাওয়ায়':'VB','যাওয়ার':'NN','যাওসময়োচিত':'NN','যাওয়া-আসা':'NNV','যাওয়া':'NN','যাওয়াই':'NN','যাওয়াকে':'NNV',
'যাওয়ার':'NN','যাক':'NN','যাকাতের':'NN','যাখো':'VB','যাগ':'NN','যাগযজ্ঞ':'NN','যাগসন্তান':'NN',
'যাগী':'JJ','যাঙ্গনু':'NN','যাচক':'NN','যাচছ':'VBG','যাচছে':'VBG','যাচনা':'NN','যাচাই':'NN',
'যাচাইনো':'VB','যাচাইবাছাই':'NN','যাচিত':'JJ','যাচেছ':'VBG','যাচ্ছ':'NN','যাচ্ছিল':'VBG','যাচ্ছিলেন':'NN',
'যাচ্ছিলো':'VBG','যাচ্ছে':'VBG','যাচ্ছেকথায়':'NN','যাচ্ছেতত্বা‌বধায়ক':'NN','যাচ্ছেতাই':'RB','যাচ্ছেদয়া':'VB','যাচ্ছেন':'NN',
'যাচ্ছেনএতে':'RB','যাচ্ছেনা':'NN','যাচ্ছেযেখান':'VBG','যাচ্ছেশ্রদ্ধা':'NN','যাছি':'NN','যাজ':'NN','যাজকদের':'NN',
'যাজন':'NN','যাজুষ':'JJ','যাজুষি-অনুষ্টুপ':'NN','যাজুষি-উষ্ণিক':'NN','যাজুষি-গায়ত্রী':'NN','যাজুষি-ত্রিষ্টুপ':'NN','যাজুষি-পংক্তি':'NN',
'যাজুষি-বৃহতী':'NN','যাজুষিগায়ত্রী':'NN','যাজুষিত্রিষ্টুপ':'NN','যাজুষিপংক্তি':'NN','যাজুষিবৃহতী':'NN','যাজ্ঞবল্ক্য':'NN','যাজ্ঞসেনী':'NN',
'যাজ্ঞিক':'NN','যাজ্ঞীয়':'JJ','যাটল':'VB','যাটা':'PR','যাঠা':'PR','যাডন':'PR','যাতন':'NN',
'যাতা':'NN','যাতাযাত':'NN','যাতায়াত':'NN','যাতি':'NN','যাতীয়':'NN','যাতে':'WP','যাত্':'NN',
'যাত্রাকে':'NN','যাত্রাপথেই':'NN','যাত্রাবাড়ি':'NN','যাত্রায়':'IN','যাত্রি':'NNS','যাত্রী':'NN','যাত্রীগণ':'NNS',
'যাত্রীবাহী':'NN','যাত্রীরা':'NNS','যাথাযথভাবে':'RB','যাথার্থ':'NN','যাথি':'PR','যাদঃপতি':'NN','যাদব':'NN',
'যাদবপুর':'NNP','যাদর':'NN','যাদা':'PR','যাদু':'NN','যাদুকরদের':'NN','যাদুঘর':'NN','যাদুবিদ্যা':'NN',
'যাদুশহর':'NN','যাদের':'PR','যাদেরকে':'NN','যাধি':'PR','যান':'NN','যানএগিয়ে':'NN','যানকিছু':'NN',
'যানক্ষমতা':'NN','যানজট':'NN','যানজটের':'NNS','যানঝট':'NN','যাননি':'NN','যানবাহন':'NN','যানবাহনের':'NNS',
'যানযট':'NN','যানস':'PR','যানহীন':'JJ','যানারূঢ়':'JJ','যানে':'NN','যানের':'VB','যানো':'NNV',
'যান্ত্রিক':'NN','যাপক':'JJ','যাপন':'NN','যাপনের':'VBG','যাপি':'PR','যাপী':'JJ','যাব':'NN',
'যাবজ্জীবন':'NN','যাবটা':'NN','যাবত':'IN','যাবতই':'NN','যাবতজিবন':'NN','যাবতীয়':'DT','যাবনাল':'NN',
'যাবি':'NN','যাবেআর':'NN','যাবেই':'UH','যাবেএ':'VB','যাবেএকদিকে':'NN','যাবেএটা':'NN','যাবেকিন্তু':'JJ',
'যাবেদুর্নীতি':'NN','যাবেন':'VB','যাবেনই':'NN','যাবেনাদেশের':'NN','যাবেভালো':'NN','যাবেমান':'NN','যাবেয':'NN',
'যাবেশুভ':'NN','যাবো':'NN','যাবৎ':'IN','যাবৎই':'NN','যাভাবেই':'NN','যামল':'VB','যামানার':'NN',
'যামোস্সুক্রো':'NN','যাম্য':'NN','যায়':'NNS','যায়কাদের':'NN','যায়নি':'VB','যাযাবর':'NN','যার':'NN',
'যারাই':'DT','যারাও':'NN','যারি':'PR','যারে':'NN','যালা':'PR','যালয়':'NN','যাশা':'NN',
'যাসী':'JJ','যাসে':'VB','যাস্ক':'NN','যাস্টিফাই':'VB','যাহত':'PR','যাহা':'NN','যাহাতে':'IN',
'যাহাদের':'VB','যাহার':'PR','যাহারা':'NN','যাহোক':'RB','যা্ছে':'VBG','যা্বেআমি':'NN','যাড়ে':'VB',
'যায়':'NNS','যায়অবশ্য':'NN','যায়এই':'NN','যায়একটা':'NN','যায়এখানে':'NN','যায়ক্লাস':'NN','যায়গা':'NN',
'যায়তাহলে':'NN','যায়ন':'VB','যায়না':'NN','যায়নাগুলিস্থানে':'NNS','যায়নি':'NN','যায়প্রয়াত':'NN','যায়বাংলাদেশ':'NN',
'যায়সরকারের':'NN','যায়ার':'NN','যায়ি':'NN','যায়ী':'JJ','যায়ে':'NN','যা‌চ্ছে':'NN','যিকির':'NN',
'যিঙ্গকিওঙ্গ':'NN','যিনি':'PR','যীশু':'NN','যুঁই':'NNP','যুক্ত':'NN','যুক্তনো':'VB','যুক্তরাজ্য':'NN',
'যুক্তরাজ্যের':'NN','যুক্তরাষ্ট':'NNS','যুক্তরাষ্টের্র':'NNP','যুক্তরাষ্ট্র':'NN','যুক্তরাষ্ট্রকে':'NNS','যুক্তরাষ্ট্রে':'NNS','যুক্তরাস্ট্রের':'NN',
'যুক্তহচ্ছে':'VBG','যুক্তা':'NN','যুক্তায়স':'NN','যুক্তিও':'NN','যুক্তিগ্রাহ্য':'JJ','যুক্তিটা':'NN','যুক্তিতর্ক':'NN',
'যুক্তিপূর্ণ':'JJ','যুক্তিপূর্ণতা':'NN','যুক্তিপূর্ণভাবে':'RB','যুক্তিবাক্য':'NN','যুক্তিবাদী':'NN','যুক্তিযুক্ত':'JJ','যুক্তির':'VBG',
'যুক্তিসংগত':'JJ','যুক্তিহীন':'JJ','যুগ':'NN','যুগধর্ম':'NN','যুগন্ধর':'NN','যুগপুরুষ':'NN','যুগযন্ধি':'NN',
'যুগযুগান্ত':'NN','যুগল':'NN','যুগলক্ষণ':'NN','যুগলের':'NN','যুগান্ত':'NN','যুগান্তর':'NN','যুগে':'NN',
'যুগের':'NN','যুগোত্তীর্ণ':'JJ','যুগোশ্লাভিয়া':'NN','যুগোশ্লাভিয়াবাসী':'NN','যুগোস্লোভিয়ান':'NN','যুগ্ম':'NN','যুগ্মপত্র':'NN',
'যুঝা':'VB','যুতক':'NN','যুতসই':'NN','যুতে':'NN','যুথিকা':'NN','যুদ্ধ':'NN','যুদ্ধক্ষেত্র':'NN',
'যুদ্ধগ্রস্ত':'JJ','যুদ্ধজাহাজ':'NN','যুদ্ধজয়ী':'NN','যুদ্ধটা':'NN','যুদ্ধনীতি':'NN','যুদ্ধপরাধী':'JJ','যুদ্ধপলায়ন':'NN',
'যুদ্ধপোত':'NN','যুদ্ধপ্রতিযোগীতা':'VB','যুদ্ধবন্দী':'NN','যুদ্ধবাজদের':'NN','যুদ্ধবিরতি':'NN','যুদ্ধভূমি':'NN','যুদ্ধভেরী':'NN',
'যুদ্ধমুষ্টি':'NN','যুদ্ধযাত্রায়':'NN','যুদ্ধযান':'NN','যুদ্ধশিশুদের':'NNS','যুদ্ধসামগ্রী':'NN','যুদ্ধাজি':'NN','যুদ্ধাপরাধিদের':'NNS',
'যুদ্ধাপরাধী':'JJ','যুদ্ধাপরাধীদের':'NNS','যুদ্ধাপরাধীর':'NN','যুদ্ধাভ্যাস':'NN','যুদ্ধে':'NN','যুদ্ব':'NNP','যুধধ':'NNP',
'যুধাজিত্':'NN','যুধাজিত্্':'NNP','যুধামন্যু':'NN','যুধিষ্ঠির':'NN','যুপাক্ষ':'NN','যুব':'NN','যুবকদের':'NN',
'যুবকরা':'NNS','যুবতী':'NN','যুবতীরা':'NN','যুবদল':'NN','যুবনাশ্ব':'NN','যুবপলিত':'JJ','যুবরাজ':'NN',
'যুবরাজের':'NN','যুবরাণী':'NN','যুবলীগ':'NN','যুবসমাজ':'NN','যুবসমাজের':'NN','যুবা':'NN','যুবানাশ্ব':'NN',
'যুবাবস্থা':'NN','যুবোলীগের':'NN','যুযুত্সা':'NN','যুযুধান':'NN','যুল-কারনাইন':'NNP','যু‌ক্তিই':'NN','যূথি':'NN',
'যূথী':'NN','যূবরাজ':'NN','যূস্কুভ':'NN','যে-কমপ্লেক্সে':'NN','যে-গান':'NN','যে-দিন':'NN','যে-পথেই':'NN',
'যে-সব':'NN','যে-সে':'JJ','যে':'NN','যেইদিনবাংলাদেশ':'NN','যেইভাবে':'NN','যেইসব':'DT','যেও':'VB',
'যেকথা':'NN','যেকেউ':'NN','যেকোন':'NN','যেকোনো':'RP','যেকোনোভাবেই':'RB','যেখবর':'NN','যেখান':'NN',
'যেখানে-সেখানে':'RB','যেখানে':'NN','যেখা‌নে':'WRB','যেগত':'NN','যেগুলি':'PR','যেগুলো':'WDT','যেগুলোর':'NN',
'যেচে':'RB','যেজাই':'NN','যেটা':'WDT','যেটাকে':'PR','যেটাতে':'NNP','যেটার':'NN','যেটায়':'WRB',
'যেটি':'PR','যেটুকু':'NN','যেটে':'VB','যেত':'MD','যেততেন':'NN','যেতশুধু':'NN','যেতা':'VB',
'যেতাম':'NN','যেতুম':'VB','যেতে-আসতে':'VB','যেতে':'NN','যেতেন':'NN','যেতো':'NN','যেথানে':'WRB',
'যেদিকে':'RB','যেদিন':'NN','যেদেশে':'NN','যেধরনের':'NN','যেন':'NN','যেনতেন':'NN','যেনমধুর':'NN',
'যেনিয়ে':'NN','যেনো':'IN','যেভাবে':'NN','যেভাবেই':'RB','যেম':'PR','যেমন-তেমন':'JJ','যেমন':'NN',
'যেমনই':'JJ','যেমনকে':'RB','যেমনটা':'NN','যেমনি':'NN','যেযা':'NN','যেরই':'PR','যেরকম':'NN',
'যেরা':'PR','যেসকল':'NNP','যেসব':'DT','যেসমস্ত':'NN','যেহুত':'IN','যেহেতু':'CC','যেহেতুতাদের':'NN',
'যোগ্য':'NN','যোগ্যতা':'NNS','যোগ‍্য':'JJ','যেয়ে':'NN','যেয়েও':'RB','যোগ-কুণ্ডলিনি':'NN','যোগ-নিয়ম':'NN',
'যোগ':'NN','যোগএর':'JJ','যোগচূড়ামণি':'NN','যোগজ':'NN','যোগতত্ত্ব':'NN','যোগত্য':'NN','যোগদর্শন':'NN',
'যোগদা':'NN','যোগধারা':'NN','যোগনিয়ম':'NN','যোগন্ধর':'NN','যোগফল':'NN','যোগমুদ্রা':'NN','যোগযোগ':'NN',
'যোগশাস্ত্র':'NN','যোগশিক্ষা':'NN','যোগসূত্র':'NN','যোগাড়':'NN','যোগানদার':'NN','যোগাভ্যাস':'NN','যোগাযোগ':'NN',
'যোগাযোগমন্ত্রী':'NNS','যোগাযোগের':'NN','যোগাসন':'NN','যোগাড়ের':'NN','যোগায়':'NN','যোগিনী':'NN','যোগিয়া':'NN',
'যোগী':'NN','যোগীন্দ্র':'NN','যোগীপাড়ার':'NN','যোগীরাজ':'NN','যোগীশ':'NN','যোগীয়া':'NN','যোগে':'NN',
'যোগেশ্বর':'NN','যোগোশ':'NN','যোগ্য':'NN','যোগ্যতা':'NN','যোগ্যতার':'NNS','যোগ্যতাসম্পন্ন':'VBN','যোগ্যতাহীন':'VBN',
'যোগ্যতায়':'NN','যোগ্যদের':'NN','যোজক':'NN','যোজকচিহ্ন':'NN','যোজন':'NN','যোজনগন্ধা':'NN','যোজনযোগ্য':'NN',
'যোজনা':'NN','যোজ্ঞ':'NN','যোঝা':'VB','যোতি':'NN','যোদ্ধা':'NN','যোদ্ধারা':'NN','যোধপুর':'NN',
'যোনি':'NN','যোনিপ্রান্ত':'NN','যোনিভ্রংশ':'NN','যোনিলিঙ্গ':'NN','যোন্যব্যাধিবিশেষ':'NN','যোল':'NN','যৌক্তিক':'NN',
'যৌক্তিকতা':'NN','যৌগ':'NN','যৌগগুলির':'NN','যৌগিক':'NN','যৌগের':'NN','যৌতুক':'NN','যৌথ':'NN',
'যৌথভাবে':'RB','যৌধেয়':'NN','যৌন':'NN','যৌনজীবন':'NN','যৌনসন্ত্রাসের':'NN','যৌবন':'NN','যৌবনপ্রাপ্তা':'NN',
'যৌবনে':'NN','যৌবরাজ্যাভিষেক':'NN','য্খন':'NN','য্যও':'NN','য্যে':'NN','য্য়':'NN','যয়িত':'JJ',
'যয়ের':'NN','য‌দিও':'NN','র':'NN','রং':'NN','রংগো':'NN','রংতুলির':'NN','রংপুর':'VB',
'রংপুরে':'NN','রংবোধহীন':'JJ','রংয়ে':'NN','রইব':'NN','রইল':'NN','রইলাম':'VBN','রইলুম':'VB',
'রইলে':'RP','রইলেন':'VB','রইলো':'VBN','রইল—':'NN','রউফ':'NNP','রএসএ':'NN','রওনা':'NN',
'রক':'NN','রককে':'NN','রকম':'JJ','রকমই':'NN','রকমভাবে':'NN','রকমারির':'NN','রকমে':'NN',
'রকর':'NN','রকার':'NN','রকাশ':'NN','রকি':'NN','রকিবউদ্দিনকে':'NN','রকুট':'NN','রকৃত':'JJ',
'রকে':'NN','রকেও':'NN','রকেটের':'NN','রকেল':'NN','রকোপ':'NN','রক্ত-পুষ্পিকা':'NN','রক্ত':'NN',
'রক্তঅস্থিমজ্জা':'NN','রক্তআমাশয়':'NN','রক্তআর':'NN','রক্তকণিকা':'NN','রক্তকদম্ব':'NN','রক্তকন্দ':'NN','রক্তকরবী':'NN',
'রক্তকাশি':'NN','রক্তক্ষরণ':'NN','রক্তখরনেই':'NN','রক্তগঙ্গা':'NN','রক্তগতজ্বর':'NN','রক্তগুল্ম':'NN','রক্তগ্রন্থি':'NN',
'রক্তচক্ষু':'NN','রক্তচন্দন':'NN','রক্তচাপ':'NN','রক্তজকৃমি':'NN','রক্তদান':'NN','রক্তধাতু':'NN','রক্তনাড়ি':'NN',
'রক্তনীল':'NN','রক্তপত্র':'NN','রক্তপাতের':'VBG','রক্তপায়ী':'JJ','রক্তপিত্ত':'NN','রক্তপুষ্পা':'NN','রক্তপ্রদর':'NN',
'রক্তপ্রবৃত্তি':'NN','রক্তপ্রমেহ':'NN','রক্তফলা':'NN','রক্তবর্গ':'NN','রক্তবিস্ফোটক':'NN','রক্তবীজ':'NN','রক্তবৃন্তক':'NN',
'রক্তব্রণ':'NN','রক্তমঞ্জরী':'NN','রক্তমাংসের':'NN','রক্তরঞ্জিত':'JJ','রক্তরস':'NN','রক্তলতা':'NN','রক্তশূণ্য':'NN',
'রক্তষ্ঠীবি':'NN','রক্তসার':'NN','রক্তহংসা':'NN','রক্তহীন':'JJ','রক্তা':'NN','রক্তাক্ত':'JJ','রক্তাঙ্গী':'NN',
'রক্তাধান':'NN','রক্তাভ':'JJ','রক্তাম্লান':'NN','রক্তারক্তি':'NN','রক্তার্বুদ':'NN','রক্তাল্পতা':'NN','রক্তাল্পতাযুক্ত':'JJ',
'রক্তিম':'JJ','রক্তিমতা':'NN','রক্তে':'NN','রক্ষঃপুরী':'NN','রক্ষক':'NN','রক্ষকবিহীন':'JJ','রক্ষকারী':'JJ',
'রক্ষকের':'NN','রক্ষণশীল':'JJ','রক্ষণশীলতা':'NN','রক্ষণা-বেক্ষণ':'NN','রক্ষণাবেক্ষণ':'VB','রক্ষণাবেক্ষণের':'NN','রক্ষনাবেক্ষন':'NN',
'রক্ষা-মন্ত্রালয়':'NN','রক্ষা':'NN','রক্ষাকবজযুক্ত':'NN','রক্ষাকর্তা':'JJ','রক্ষাকারিরা':'NN','রক্ষাবন্ধন':'NN','রক্ষামন্ত্রালয়ে':'NN',
'রক্ষার':'NN','রক্ষায়':'NN','রক্ষিত':'NN','রক্ষী':'NN','রক্ষে':'NN','রক্ষোধাম':'NN','রক্ষোরাজ':'NN',
'রখশী':'NN','রগ':'NN','রগকাটা':'NN','রগড়':'NN','রগড়ানোর':'NN','রগণ':'NN','রগতি':'NN',
'রগম্':'NN','রগার':'NNP','রগির':'NN','রঘটক':'NNP','রঘু':'NN','রঘুনন্দন':'NN','রঘুবংশের':'NN',
'রঙ-পরিবর্তনশীল':'JJ','রঙ-বেরঙের':'JJ','রঙ-ভেদ':'NN','রঙ-রূপ':'NN','রঙ':'NN','রঙগৃহ':'NN','রঙঢঙ':'NN',
'রঙদানি':'NN','রঙনো':'VB','রঙপঞ্চমী':'NN','রঙফলক':'NN','রঙবেরঙের':'NN','রঙভেদ':'NN','রঙমহল':'NN',
'রঙমেজাজি':'NN','রঙর':'NN','রঙরেনী':'NN','রঙশিল্পী':'NN','রঙহীন':'JJ','রঙা':'NN','রঙিন':'JJ',
'রঙীন':'NN','রঙে':'NN','রঙের':'NN','রঙোত্সব':'NN','রঙ্কিণী':'NN','রঙ্কু':'NN','রঙ্গ':'NN',
'রঙ্গকৌতুকের':'NN','রঙ্গন':'NN','রঙ্গবল্লিকা':'NN','রঙ্গবিদ্যাধর':'NN','রঙ্গমঞ্চ':'NN','রঙ্গমঞ্চের':'NN','রঙ্গমাতা':'NN',
'রঙ্গমিলান্তি':'NN','রঙ্গরস':'NN','রঙ্গরুট':'NN','রঙ্গলতা':'NN','রঙ্গাবয়':'NN','রঙ্গাভরণ':'NN','রঙ্গারেড্ডী':'NN',
'রঙ্গালয়':'NN','রঙ্গিণী':'NNP','রঙ্গিত':'NN','রঙ্গীন':'NN','রঙ্গীরেটা':'NN','রঙ্গীলা-টোড়ী':'NN','রঙ্গোলী':'NN',
'রচণা':'NN','রচনা.কল্পনাশ্রিত':'NN','রচনা':'NN','রচনাগুলির':'NN','রচনাত্মক':'NN','রচনায়':'NN','রচনাশৈলীর':'NN',
'রচনায়':'NN','রচনীয়':'JJ','রচবে':'NN','রচয়িতা':'NN','রচলন':'NN','রচার':'NN','রচিত':'NN',
'রচীন':'JJ','রচুর':'NNP','রচয়িতা':'NN','রচয়ীতা':'JJ','রছিল':'VB','রছেন':'VB','রজঃধর্ম':'NN',
'রজঃনিবৃত্তি':'NN','রজঃস্বলা':'NN','রজক':'NN','রজত':'NN','রজতপ্রস্থ':'NN','রজতাচল':'NN','রজতাদ্রি':'NN',
'রজনবিশেষ':'NN','রজনীগন্ধা':'NN','রজনীশ':'NN','রজস্বলা':'JJ','রজস্রাব':'NN','রজার':'NN','রজীর':'NNP',
'রজো':'NN','রজোগুণ':'NN','রজোগোত্র':'NN','রজোনিবৃত্তি':'NN','রজৌরি':'NN','রজ্জু':'NN','রজ্জুখণ্ডকে':'NN',
'রজ্জুপথ':'NN','রঞ্জক':'NN','রঞ্জনের':'NN','রঞ্জিত':'NN','রট':'NN','রটনা':'NN','রটন্তী':'NN',
'রটাক':'VB','রটার':'NN','রটায়':'VB','রটির':'NN','রটিয়ে':'VB','রড':'NN','রডা':'NNP',
'রডের':'NN','রঢ়িয়া':'NN','রণ':'NNP','রণকে':'NN','রণক্ষেত্র':'NN','রণগত':'JJ','রণজী':'NN',
'রণজয়ের':'NNP','রণটা':'NN','রণত':'JJ','রণতঃ':'RB','রণথম্ভৌর':'NN','রণনীতি':'NN','রণনৈতিক':'JJ',
'রণপলায়ন':'NN','রণবীর':'NN','রণভেরী':'NN','রণর':'NNP','রণসঙ্গীত':'NN','রণহংস':'NN','রণাই':'NNP',
'রণাঙ্গণের':'NN','রণাম':'NN','রণাশ':'NNP','রণায়':'NN','রণির':'NN','রণীয়':'JJ','রণেই':'NN',
'রণোত্কট':'NN','রণ্ট':'NNP','রণয়ন':'NNP','রত':'NN','রতনচূড়':'NN','রতনপ্রিয়া':'NNP','রতনিয়া':'NN',
'রতনে':'NN','রতলা':'NNP','রতলাম':'NN','রতাপ':'NNP','রতার':'NN','রতালু':'NN','রতায়':'NN',
'রতি':'NN','রতিই':'NNP','রতিক':'JJ','রতিকর্ম':'NN','রতিকলহ':'NN','রতিক্রিয়া':'NN','রতিবন্ধ':'NN',
'রতিবাহী':'NN','রতিভ':'JJ','রতিভর':'RB','রতিম':'NNP','রতিলাল':'NN','রতিসংহতি':'NN','রতিসত্বরা':'NN',
'রতিসাধন':'NN','রতিসুন্দর':'NN','রতী':'NN','রতীপ':'NNP','রতীয়':'JJ','রতুন':'NN','রতুল':'NNP',
'রতুয়া':'NN','রতেই':'NN','রতেন':'VB','রতের':'NNP','রতোয়া':'NN','রত্':'NNP','রত্তক':'NN',
'রত্তী':'NN','রত্ন':'NN','রত্নকর':'NN','রত্নগর্ভ':'NN','রত্নধেনু':'NN','রত্নপরীক্ষা':'NN','রত্নপাথর':'NN',
'রত্নপুরার':'NNP','রত্নমালা':'NN','রত্নহার':'NN','রত্নাগিরি':'NN','রত্নাবলী':'NN','রত্নালঙ্কারে':'NN','রত্নাসুর':'NN',
'রত্নায়েককে':'NNP','রত্নের':'NN','রত্ব':'NN','রথ-সৈন্য':'NN','রথ':'NN','রথগুপ্তি':'NN','রথচালনা':'NN',
'রথদ্রু':'NN','রথবাহ':'NN','রথমত':'RB','রথমে':'NN','রথযাত্রা':'NN','রথসেনা':'NN','রথহীন':'JJ',
'রথার':'NN','রথারূঢ়':'JJ','রথারোহী':'JJ','রথাশ্ব':'NN','রথি':'NN','রথিত':'JJ','রথী':'NN',
'রথের':'NNP','রথোদ্ধতা':'NN','রদ':'NN','রদগণ':'NN','রদন':'NN','রদবদল':'NN','রদাই':'NNP',
'রদাও':'NN','রদার':'NNP','রদায়':'NN','রদিক':'JJ','রদিন':'NN','রদীপ':'NNP','রদীয়':'JJ',
'রদের':'NN','রদেহ':'NN','রদ্দা':'NN','রদ্দিওয়ালা':'NN','রধান':'JJ','রন':'NN','রনতঃ':'RB',
'রনদের':'NN','রনপণ':'NN','রনমি':'NN','রনাথ':'NNP','রনি':'NN','রনে':'NN','রনের':'NN',
'রন্ত':'JJ','রন্তিদেব':'NN','রন্থ':'NN','রন্দ্রে':'NN','রন্ধন':'NN','রন্ধ্রযুক্ত':'JJ','রন্ধ্রে':'NN',
'রপতি':'NN','রপরও':'NN','রপাত':'NN','রপের':'NN','রপ্ত':'NN','রপ্তানি-কর':'NN','রপ্তানিকারকরা':'NN',
'রপ্তানিতে':'NN','রপ্তানিযোগ্য':'NN','রপ্তানির':'NN','রপ্তানীকারী':'NN','রপ্তানীমুখি':'NN','রফতানি':'NN','রফাদফা':'NN',
'রফি-মুকেশ-কিশোর':'NNP','রফিউ':'NN','রফিকুল':'NN','রব':'NN','রবত্':'JJ','রবধি':'NN','রবধু':'NNP',
'রবময়':'JJ','রবরা':'NN','রবান্ডা':'NN','রবান্ডার':'JJ','রবাব-বাদক':'NN','রবাব':'NN','রবার':'NN',
'রবার্ট':'NN','রবার্টসন':'NNP','রবার্টসনগনঞ্জ':'NN','রবাহ':'NN','রবি':'NN','রবিও':'NNP','রবিকান্ত':'NN',
'রবিগুরু':'NN','রবিজকেতু':'NN','রবিতেও':'NN','রবিদাস':'NN','রবিদাসী':'JJ','রবিন':'NN','রবিনন্দন':'NN',
'রবিপ্রিয়':'NN','রবিবার':'NN','রবিমণি':'NN','রবির':'NN','রবিশস্য':'NN','রবিসঞ্জক':'NN','রবীণ':'NNP',
'রবীন্দ্র-ব্যক্তিত্বের':'NN','রবীন্দ্র':'NN','রবীন্দ্রনাথ':'NN','রবীন্দ্রনাথকে':'NNP','রবীন্দ্রসঙ্গীত':'NN','রবীন্দ্রসঙ্গীতের':'NNP','রবীন্দ্রোত্তর':'JJ',
'রবীর':'NNP','রবীল':'NN','রবে':'NN','রবেন':'VB','রবের':'NNP','রবেশ':'NN','রবোন':'NNP',
'রব্বানীর':'NN','রব্য':'NN','রভাব':'NN','রভূত':'JJ','রভূম':'NNP','রভেণক':'NN','রভেদ':'NN',
'রমজান':'NN','রমজানের':'NN','রমণ':'NN','রমণকারী':'JJ','রমণী':'NN','রমণীদের':'NN','রমণীয়':'JJ',
'রমণে':'NN','রমন':'NN','রমযান':'NN','রমরমা':'NN','রমশঃ':'NNP','রমা':'NN','রমাই':'NNP',
'রমাকান্ত':'NN','রমাণ':'NN','রমানাথন':'NNP','রমাপতি':'NN','রমার':'NNP','রমিক':'JJ','রমিজ':'NN',
'রমিস':'NNP','রমুখ':'NN','রমেই':'NNP','রমেশ':'NN','রমেশচন্দ্র':'NNP','রমৈণী':'NN','রমোন':'NN',
'রম্বা':'NN','রম্ভ':'NN','রম্ভাতৃতীয়া':'NN','রম্ভাপতি':'NN','রম্ভাসুর':'NN','রম্ভিনী':'NN','রম্ভোরূ':'JJ',
'রম্য-চিত্র':'NN','রম্য':'NN','রয়ে':'NN','রয়েছে':'VB','রয়েছেনএটা':'NN','ররাই':'NN','ররিব':'NN',
'ররূপ':'NN','রলতম':'JJ','রলতা':'NN','রলাম':'VB','রলেই':'NN','রলেও':'RP','রলেন':'VB',
'রলেপ':'NN','রলোক':'NN','রশাহ':'NN','রশি':'NN','রশিদ':'NN','রশীদ':'NN','রশীল':'JJ',
'রশ্ন':'NN','রশ্মি':'NN','রশ্মিক্রীড়া':'NN','রশ্মির':'NN','রস-আবেশে':'NN','রস':'NN','রসংঘ':'NNP',
'রসইহা':'NN','রসওট':'NN','রসখান':'NN','রসগোল্লা':'NN','রসদ':'NN','রসনা':'NN','রসনারোচক':'JJ',
'রসপর্পটী':'NN','রসপূর্ণ':'JJ','রসবতী':'NN','রসমণ্ডুর':'NN','রসমালাই':'NN','রসমুন্ডী':'NN','রসমূর্তিটি':'NN',
'রসময়ীর':'NNP','রসরাজ':'NN','রসশেখর':'NN','রসসাম্য':'NN','রসসিঁদুর':'NN','রসস্বাদন':'NN','রসহীন':'JJ',
'রসা':'NN','রসাগ্য':'NN','রসাঞ্জন':'NN','রসাতল':'NN','রসাত্মক':'JJ','রসাদ':'NN','রসাপায়ী':'NN',
'রসাম্ল':'NN','রসার':'NN','রসাল.আম্র':'NN','রসালো':'JJ','রসাস্বাদন':'NN','রসায়ন-উপাচার':'NN','রসায়ন-চিকিত্সা':'NN',
'রসায়ন':'NN','রসায়নবিদ্':'NN','রসায়নশাস্ত্র':'NN','রসায়নের':'NN','রসি':'NN','রসিআউর':'NN','রসিক':'NN',
'রসিকতাপূর্ণ':'NN','রসিদ':'NN','রসু':'NN','রসুইতে':'VB','রসুন':'NN','রসুলপুরের':'NNP','রসূল':'NN',
'রসে':'NN','রসের':'NN','রস্ত':'JJ','রস্ব':'NN','রহণে':'NN','রহম':'NN','রহমান':'NN',
'রহমানদের':'NN','রহমানের':'NN','রহরে':'NN','রহশ্য':'NN','রহস্যগোপন':'NN','রহস্যজনক':'JJ','রহস্যটা':'NN',
'রহস্যময়':'JJ','রহস্যহীন':'JJ','রহস্যাবৃত':'JJ','রহস্যে':'NN','রহস্যোদ্ঘাটক':'JJ','রহস্যোদ্ঘাটন':'VB','রহাট':'NNP',
'রহিত':'NN','রহিয়া':'NN','রহিয়াছে':'VB','রহীন':'JJ','রহু':'NN','রহের':'NN','রহ্ম':'NN',
'রা':'NN','রাঁচী':'NN','রাঁড়':'NN','রাঁদ':'NNP','রাঁধা':'VB','রাংতা':'NN','রাই':'NN',
'রাইখা':'VB','রাইট':'NN','রাইটারে':'NN','রাইটার্স':'NNP','রাইড':'NN','রাইফেল':'NN','রাইবোনিউক্লিক':'NN',
'রাইম':'NNP','রাইস':'NN','রাইসেন':'NNP','রাউজ':'NNP','রাউণ্ড':'NN','রাউন':'NNP','রাউন্ড':'NN',
'রাউন্ডে':'VB','রাউরকেলায়':'NNP','রাউলিং':'NNP','রাও':'NN','রাওয়ালপিন্ডি':'NNP','রাওরখা':'NN','রাওয়ালপিণ্ডি':'NN',
'রাকা':'NN','রাকী':'JJ','রাকে':'NN','রাক্ষস':'NN','রাক্ষসী':'NN','রাক্ষুসে':'VB','রাখ':'RB',
'রাখছি':'VB','রাখছেন':'VB','রাখটী':'NN','রাখঢাক':'VB','রাখত':'VB','রাখতে':'VB','রাখতেছি':'VB',
'রাখতো':'VB','রাখব':'VB','রাখবে':'VB','রাখবেশুভ':'VB','রাখবো':'VB','রাখলাম':'VB','রাখলেই':'VB',
'রাখলেওতো':'VB','রাখলো':'VB','রাখা':'NN','রাখাইন':'VB','রাখাইনের':'NN','রাখানো':'VB','রাখাব্রডকাস্ট':'NN',
'রাখাযাতে':'NN','রাখার':'NN','রাখালকে':'NNP','রাখালদের':'NN','রাখালের':'NNP','রাখায়':'NNV','রাখি':'NN',
'রাখিতে':'VB','রাখিনা':'NN','রাখিনি':'VB','রাখিবার':'NN','রাখিবে':'VB','রাখী':'NN','রাখুন':'VB',
'রাখে':'NNS','রাখেকিন্তু':'VB','রাখেতারা':'NN','রাখেন':'VB','রাখেনবিসিএস':'NN','রাখেনা':'NN','রাখেসেই':'NN',
'রাগ.':'NN','রাগত':'JJ','রাগতে':'VB','রাগপুষ্প':'NN','রাগপ্রসব':'NN','রাগবি':'NN','রাগলতা':'NN',
'রাগানো':'VB','রাগান্বিত':'NN','রাগি':'NN','রাগিণী':'NN','রাগিয়ে':'VB','রাগী':'NN','রাগের':'NN',
'রাগ্বি':'NN','রাঘব':'NN','রাঘববোয়ালদের':'NN','রাঘবেন্দ্র':'NN','রাঘর':'NN','রাঙ':'NN','রাঙাইয়া':'NN',
'রাঙান':'NNP','রাঙানো':'NN','রাঙাবে':'NN','রাঙামাটিতে':'NNP','রাঙিয়ে':'NN','রাঙ্কিং':'NN','রাঙ্গা':'NN',
'রাঙ্গানো':'VB','রাচর':'NN','রাজ-কাজ':'NN','রাজ-দরবার':'NN','রাজ-পুষ্পী':'NN','রাজ-প্রিয়':'NN','রাজ-সভা':'NN',
'রাজ':'NN','রাজউকে':'NN','রাজকন্যা':'NN','রাজকমলবাবুর':'NNP','রাজকীয়':'NN','রাজকুমার':'NN','রাজকুমারের':'NN',
'রাজকুল':'NN','রাজকোট':'NN','রাজকোষীয়':'JJ','রাজগড়':'NN','রাজগুরু':'NN','রাজঘরানা':'NN','রাজঘাট':'RB',
'রাজচন্দ্র':'NNP','রাজজ':'NN','রাজজ্যোতিষীও':'NN','রাজঝুমকা':'NN','রাজতন্ত্র':'NN','রাজত্ত':'NN','রাজত্বকালের':'NN',
'রাজত্বের':'NN','রাজদ':'NN','রাজদন্ড':'NN','রাজদরবার':'NN','রাজদূতাবাস':'NN','রাজদ্রোহ':'NN','রাজধর্মা':'NN',
'রাজধানিতে':'NN','রাজধানীকেন্দ্রিক':'NN','রাজধানীতে':'NN','রাজধানীর':'NN','রাজন':'NN','রাজনইতিক':'NN','রাজনন্দ':'NN',
'রাজনান্দগাঁও':'NN','রাজনিতি':'NNS','রাজনিতিবিদ':'NN','রাজনিতিবিদনা':'NN','রাজনিতির':'NN','রাজনীতি':'NN','রাজনীতিও':'NNS',
'রাজনীতিক':'NN','রাজনীতিকদের':'NNS','রাজনীতিকরাই':'NN','রাজনীতিকেরা':'NN','রাজনীতিজ্ঞ':'NN','রাজনীতিটা':'NNS','রাজনীতিতে':'NN',
'রাজনীতিবিদদের':'NN','রাজনীতিবিদরাই':'NN','রাজনীতিময়':'NN','রাজনীতিশাস্ত্র':'NN','রাজনীনিতিতে':'NN','রাজনৈতিক':'NN','রাজনৈতিভাবে':'NN',
'রাজনৈতীক':'JJ','রাজনৈ‌তিক':'NN','রাজপণ্ডিত':'JJ','রাজপণ্ডিতের':'NN','রাজপত্রী':'NN','রাজপথ':'NN','রাজপথে':'NN',
'রাজপরিবার':'NN','রাজপরিবারের':'RB','রাজপিপলা':'NN','রাজপুত':'NN','রাজপুত্রের':'NN','রাজপুষ্প':'NN','রাজপ্রতিনিধি':'NN',
'রাজপ্রাসাদ':'NN','রাজপ্রিয়':'NN','রাজফল্গু':'NN','রাজবংশ':'NN','রাজবংশের':'NN','রাজবন্দি':'NN','রাজবাড়ি':'NN',
'রাজভবন':'NN','রাজভোগ':'NN','রাজমহল':'NN','রাজমা':'NN','রাজমিস্ত্রী':'NN','রাজযোগ':'NN','রাজরাজেশ্বরী':'NN',
'রাজর্ষি':'NN','রাজশকুন':'NN','রাজশক্তি':'NN','রাজশাহী':'NN','রাজশাহীর':'NN','রাজশুক':'NN','রাজসভা':'NN',
'রাজসমন্দ':'NN','রাজসিংহাসন':'NN','রাজসুয়ী':'NN','রাজসূয়-যজ্ঞ':'NN','রাজসূয়ের':'JJ','রাজস্থান':'NN','রাজস্থানী':'NN',
'রাজস্ব':'NN','রাজস্য':'NN','রাজহংস':'NN','রাজা':'NN','রাজাকার':'NN','রাজাকারআলবদরদের':'NN','রাজাকারতোষন':'NN',
'রাজাকারদের':'NN','রাজাকারবান্ধব':'RB','রাজাকাররা':'NN','রাজাকারের':'NN','রাজাজ্ঞা':'NN','রাজাদের':'NN','রাজাধিদেবী':'NN',
'রাজাপুরী':'NN','রাজাবর্ত':'NN','রাজাবাদশা':'NN','রাজাম্ল':'NN','রাজায়':'NN','রাজারা':'NNS','রাজার্ক':'NN',
'রাজালাবু':'NN','রাজাসমন্দ':'NN','রাজাসুলভ':'JJ','রাজি':'NN','রাজিকাচিত্র':'NN','রাজিন্দর':'NNP','রাজিব':'NN',
'রাজিবপুলিশের':'NN','রাজিববাংলাদেশের':'NN','রাজিবের':'NN','রাজিল':'NN','রাজী':'NN','রাজীনো':'VB','রাজীব':'NN',
'রাজীবগণ':'NN','রাজীবের':'NNP','রাজে':'NN','রাজেশ্বরী':'NNP','রাজ্ঞী':'NN','রাজ্য-তন্ত্র':'NN','রাজ্য-সভা':'NN',
'রাজ্যকাল':'NN','রাজ্যতন্ত্র':'NN','রাজ্যপাঠ':'NN','রাজ্যভাষা':'NN','রাজ্যমন্ত্রী':'NN','রাজ্যলাভ':'NN','রাজ্যশাসনের':'NN',
'রাজ্যসভা':'NN','রাজ্যসরকারের':'NN','রাজ্যে':'NN','রাজয়':'NN','রাজ‍্যে':'NN','রাট':'NN','রাটন':'NNP',
'রাটি':'NN','রাটে':'NNP','রাডার':'NN','রাডারযন্ত্র':'NN','রাডারের':'NN','রাণও':'NN','রাণি':'NNP',
'রাণী':'NN','রাণীক্ষেত':'NN','রাণে':'NN','রাত':'NN','রাতওয়াহী':'NN','রাতকানা':'NN','রাতদিন':'RB',
'রাতদুপুর':'NN','রাতন':'NN','রাতবিরেত':'NN','রাতহব্য':'NN','রাতা':'NN','রাতারাতি':'RB','রাতি':'NN',
'রাতেই':'NN','রাতেভয়ে':'NN','রাতের':'NN','রাতৈল':'NN','রাত্':'NN','রাত্তিরে':'NN','রাত্রিক':'NN',
'রাত্রিকালীন':'JJ','রাত্রিবেদ':'NN','রাত্রে':'NN','রাত্রের':'NN','রাথে':'NN','রাদি':'NNP','রাধা-গোবিন্দের':'NNP',
'রাধা':'NN','রাধাকৃষ্ণের':'NNP','রাধাঙ্গ':'NN','রাধাপ্রসঙ্গে':'NNP','রাধারাণী':'NN','রাধাষ্টমী':'NN','রাধিকা':'NN',
'রাধী':'JJ','রাধুনি':'NN','রাধেয়':'NN','রান':'NN','রানআউট':'NN','রানও':'NN','রানওয়ারিয়া':'NN',
'রানওয়ে':'NN','রানটা':'NN','রানতারপর':'NN','রানমেশিন':'NN','রানা':'NN','রানাডের':'NNP','রানার':'NN',
'রানার্স':'NNS','রানার্সআপ':'NN','রানি':'NN','রানে':'NN','রানো':'NNV','রান্নবান্নার':'NN','রান্না':'NN',
'রান্নাঘরে':'NN','রান্নানো':'VB','রান্নার':'NN','রাপথ':'NNP','রাপি':'NN','রাপ্তী':'NN','রাফটিং':'NN',
'রাফা':'NN','রাফী':'NNP','রাফ্লেশিয়া':'NN','রাব':'NN','রাবড়ি':'NN','রাবণ':'NN','রাবদ':'NNP',
'রাবাট':'NN','রাবার':'NNV','রাবিশ':'JJ','রাবিশবাংলাদেশে':'NN','রাবিশের':'NN','রাব্বি':'NN','রাভব':'NNP',
'রাভি':'NN','রাম-উপাসক':'NN','রাম-তিলক':'NN','রাম-বাণ':'JJ','রাম-লীলা':'NN','রাম':'NN','রামক':'NNP',
'রামকথক':'NN','রামকার্পাস':'NN','রামকিরি':'NN','রামকুমার':'NNP','রামকৃষ্ণ':'NN','রামকৃষ্ণকে':'NNP','রামকেলী':'NN',
'রামগঙ্গরা':'NN','রামগুপ্ত':'NNP','রামচকরা':'NN','রামচন্দ্র':'NNP','রামচন্দ্রের':'NNP','রামচরিত':'NN','রামচরিতমানস':'NNS',
'রামচাঙ্গী':'NN','রামজাম':'NN','রামঝোল':'NN','রামত':'NNP','রামতাপণি':'NN','রামতুলসী':'NN','রামদানা':'NN',
'রামদ্বাদশী':'NN','রামধনু':'NN','রামধুন':'NN','রামনন্দ':'NN','রামনবমী':'NN','রামনাথপুরম':'NN','রামনিধি':'NNP',
'রামপাখি':'NN','রামপালের':'JJ','রামপুর':'NN','রামফোর্ড':'NNP','রামবাণ':'NN','রামবাবু':'NNP','রামবীণা':'NN',
'রামমোহনের':'NNP','রামরজ':'NN','রামরহস্য':'NN','রামরাজাতলা':'NNP','রামরাজ্য':'NN','রামলাল':'NNP','রামলীলা':'NN',
'রামলোক':'NN','রামলোচন':'NNP','রামশ্রী':'NN','রামহরির':'NNP','রামা':'NN','রামানন্দ':'NN','রামানুজম':'NN',
'রামাবত':'NN','রামায়ণ':'NN','রামায়ণে':'NNP','রামী':'NN','রামে':'NNP','রামেশ্বর':'NN','রামোস':'NN',
'রামোসকে':'NN','রাময়':'NNP','রায়':'NN','রারি':'NNP','রাল':'NN','রালে':'NN','রালেই':'JJ',
'রালো':'JJ','রাশ':'NN','রাশটাতে':'NN','রাশব্দ':'NN','রাশি-চক্র':'NN','রাশি':'NN','রাশিচক্র':'NN',
'রাশিতে':'NN','রাশিবিজ্ঞানী':'NN','রাশিবিশিষ্ট':'NN','রাশিমণ্ডল':'NN','রাশিয়া':'NN','রাশিযুক্ত':'NN','রাশির':'NN',
'রাশিয়াই':'NN','রাশিয়াতে':'NN','রাশিয়ার':'NN','রাশেদ':'NN','রাশেদনুরুদের':'NN','রাষট্র':'NN','রাষ্ট্র':'NN',
'রাষ্ট্রকে':'NN','রাষ্ট্রক্ষমতার':'NN','রাষ্ট্রগুলোকে':'NN','রাষ্ট্রটা':'NN','রাষ্ট্রদ্রোহী':'NN','রাষ্ট্রনায়ক':'NN','রাষ্ট্রনেতাদের':'NN',
'রাষ্ট্রপতি':'NN','রাষ্ট্রপতির':'NNP','রাষ্ট্রপ্রধান':'NN','রাষ্ট্রবাদ':'NN','রাষ্ট্রবিজ্ঞান':'NNP','রাষ্ট্রবিজ্ঞানীও':'NN','রাষ্ট্রবিজ্ঞানের':'NNP',
'রাষ্ট্রব্যবস্থার':'NN','রাষ্ট্রভক্ত':'NN','রাষ্ট্রভাষা':'NN','রাষ্ট্রমণ্ডল':'NN','রাষ্ট্রমন্ত্রী':'NN','রাষ্ট্রর':'NN','রাষ্ট্রসংঘের':'NNP',
'রাষ্ট্রহিত':'NN','রাষ্ট্রায়ত্ত':'JJ','রাষ্ট্রীয়সহ':'NN','রাষ্ট্রীয়করণ':'NN','রাষ্ট্রে':'NN','রাস':'NN','রাসতাল':'NN',
'রাসনালুফ':'NN','রাসপূর্ণিমা':'NN','রাসবিহারী':'NNP','রাসমণি':'NNP','রাসলীলা':'NN','রাসাল্ভক':'NN','রাসায়ণিক':'NN',
'রাসায়ানিক':'NN','রাসি':'NNP','রাসিয়া':'NN','রাসী':'JJ','রাসে':'NN','রাসৌল':'NN','রাস্কিনের':'NNP',
'রাস্ট্র':'NN','রাস্ট্রপতি':'NNP','রাস্ট্রায়ত্ব':'NN','রাস্তা':'NN','রাস্তাঘাট':'NN','রাস্তাটা':'NN','রাস্তায়':'NN',
'রাস্তায়':'NN','রাস্না':'NN','রাস্পবেরী':'NN','রাসয়নিকের':'NNS','রাহজানি':'NN','রাহমানকে':'NN','রাহা':'NN',
'রাহিতুল':'NN','রাহী':'NN','রাহুগ্রাশ':'NNS','রাহুরত্ন':'NN','রাহুল':'NN','রায়':'NN','রায়ই':'NNP',
'রায়কে':'NNP','রায়গঞ্জ':'NN','রায়গড়':'NN','রায়চাঁদ':'NNP','রায়চুর':'NN','রায়চৌধুরীদের':'NNP','রায়টা':'NN',
'রায়ণ':'NNP','রায়তা':'NN','রায়তি':'NNP','রায়তো':'NN','রায়পুর':'NN','রায়পুরা':'VB','রায়বাহাদুর':'JJ',
'রায়বেরিলী':'NN','রায়সেন':'NN','রায়াণ্ডীয়':'JJ','রায়ান্স':'NNS','রায়ে':'NN','রা‌নের':'NN','রা‌ষ্ট্রে':'NN',
'রি':'NN','রিংগিট':'NN','রিংশ':'NN','রিঅ্যাক্টর':'NN','রিওদয়ান':'NNP','রিকওয়াঁছ':'NN','রিকগনিশন':'NN',
'রিকন্ডিশন':'NN','রিকর':'JJ','রিকশা':'NN','রিকা':'NN','রিকি':'JJ','রিকুয়েস্ট':'NN','রিকে':'NN',
'রিকোভার':'VB','রিকোয়ারমেন্টের':'NN','রিক্টার':'NN','রিক্ত':'NN','রিক্তিকা':'NN','রিক্রুটমেন্ট':'NN','রিক্রুটিং':'VBG',
'রিক্শয়':'NN','রিক্সা':'NN','রিক্সাওয়ালার':'NN','রিখে':'VB','রিগর':'NN','রিগিং':'VBG','রিঙ্গাল':'NN',
'রিচা':'NN','রিচার্জকারী':'NN','রিচার্জের':'NN','রিচার্ডস':'NNS','রিচয়':'NN','রিজন':'NN','রিজবির':'NN',
'রিজভিকেও':'NN','রিজভিফখরুলরা':'NN','রিজভির':'NN','রিজভীকে':'NN','রিজম':'NN','রিজারব':'NNP','রিজার্ভ':'NN',
'রিজার্ভের':'NNP','রিজার্ভেশন':'NN','রিজি':'NN','রিজেক্ট':'NN','রিজেন্সি':'NN','রিজ্':'NNP','রিট':'NN',
'রিটাইয়ার':'NN','রিটার্ণ':'NN','রিটার্নিং':'NN','রিটায়ারমেন্ট':'NN','রিটায়ার্ড':'JJ','রিটের':'NN','রিঠা':'NN',
'রিড':'NN','রিডার':'NN','রিণত':'JJ','রিতা':'NN','রিতুশালা':'NN','রিতে':'NN','রিদওয়ান':'NNP',
'রিদওয়ান':'NN','রিদোয়ান':'NNP','রিদয়ে':'NN','রিনত':'JJ','রিনা':'NN','রিনি':'VB','রিনিউ':'NN',
'রিনিয়েবল':'NN','রিনী':'NN','রিপন':'NNP','রিপাবলিক':'NN','রিপাবলিকান':'JJ','রিপাব্লিক':'NN','রিপিট':'NN',
'রিপু':'NN','রিপুঞ্জয়':'NN','রিপুর':'NN','রিপোটের':'NN','রিপোট':'NN','রিপোরটার':'NN','রিপোর্টই':'NN',
'রিপোর্টকার্ড':'NN','রিপোর্টগুলো':'NNS','রিপোর্টটা':'NN','রিপোর্টার':'NN','রিপোর্টে':'NN','রিপোর্টের':'NN','রিপ্রেজেন্ট':'JJ',
'রিপ্লে':'NN','রিপ্লেস':'NN','রিপ্লেসের':'NN','রিফ':'NN','রিফর্মের':'NN','রিফর্মেশন':'NNP','রিফাইনারী':'NN',
'রিফাত':'NN','রিফান্ড':'NN','রিফিউজি':'NN','রিফু':'NN','রিফ্যাক্টরি':'NN','রিবন':'NN','রিবে':'VB',
'রিবোফ্লেবিন':'NN','রিভ':'NNP','রিভলবার':'NN','রিভার':'NN','রিভিউ':'NN','রিম':'NN','রিমঝিম':'NN',
'রিমল':'NNP','রিমা':'NN','রিমাইন্ডার':'NN','রিমান্ডে':'NN','রিমোট':'NN','রিমোসাদ্দেক':'NN','রিয়':'JJ',
'রিয়া':'NN','রিয়াল':'JJ','রিয়েল':'JJ','রিরা':'NN','রির্টানিং':'VBG','রিল':'NN','রিলি':'NNP',
'রিলিস':'NN','রিলে':'NN','রিশ':'NN','রিষদ':'NNP','রিষভ':'NN','রিসম':'NNP','রিসা':'NN',
'রিসার্ভ':'NNP','রিসালদার':'NN','রিসিভ':'VB','রিসিভার':'NN','রিসেপশন':'NN','রিসেশন':'NN','রিসোর্ট':'NN',
'রিসোর্স':'NNS','রিস্ক':'NN','রিস৷':'NNP','রিহাব':'NN','রিহার্সাল':'NN','রিহ্যাবের':'NN','রিয়া':'VB',
'রিয়াজ':'NN','রিয়াদকে':'NN','রিয়াধ':'NN','রিয়ালকে':'JJ','রিয়ালবার্সা':'NN','রিয়ালে':'NN','রিয়ালের':'JJ',
'রিয়ে':'VB','রিয়েক্ট':'NN','রিয়েল':'JJ','রিয়েলের':'NN','রিয়্যাক্ট':'NNP','রিয়্যাল':'JJ','রিয়্যালিটি':'NN',
'রীকে':'NN','রীগণ':'NN','রীজনাল':'NN','রীজভীর':'NN','রীটি':'NN','রীটে':'VB','রীঠা':'NN',
'রীডার':'NNP','রীণে':'NN','রীতি-নীতি':'NN','রীতি':'NN','রীতিমত':'NN','রীতিমতো':'JJ','রীতির':'NN',
'রীতে':'NN','রীদি':'NNP','রীপট':'NNP','রীবা':'NN','রীরও':'NN','রীরে':'NN','রীসা':'NN',
'রীড়া':'NNP','রুই':'NN','রুইকাতলাদের':'NN','রুইতন':'NN','রুইদাসী':'NN','রুকমঞ্জনী':'NN','রুকস্যাক':'NN',
'রুকে':'NNP','রুক্মমালী':'NN','রুক্মরথ':'NN','রুক্মসেন':'NN','রুক্মী':'NN','রুক্ষতা':'NN','রুখতেই':'NN',
'রুগি':'NN','রুগী':'NN','রুগ্ণ':'JJ','রুগ্নতা':'NN','রুচি':'NN','রুচিকারক':'JJ','রুচিতে':'NN',
'রুচিপ্রভ':'NN','রুচিমতী':'NN','রুচির':'NN','রুচিশীল':'JJ','রুজ':'NN','রুজভেল্ট':'NNP','রুঞ্জ':'NN',
'রুট':'NN','রুটিখোর':'JJ','রুটিন':'NN','রুটিহালুয়ার':'VBG','রুটে':'NN','রুডবোরস্টজে':'NN','রুণা':'NN',
'রুণী':'JJ','রুতর':'JJ','রুতি':'NN','রুথিনিয়াম':'NN','রুদল':'NN','রুদ্ধ':'JJ','রুদ্ধদ্বার':'NN',
'রুদ্ধবাক':'JJ','রুদ্ধশ্বাস':'NN','রুদ্র-জটা':'NN','রুদ্র-হৃদয়':'NN','রুদ্র':'NN','রুদ্রপ্রয়াগ':'NN','রুদ্রবীণা':'NN',
'রুদ্রাক্ষ':'NN','রুদ্রাক্ষোপনিষ':'NN','রুদ্রাণী':'NN','রুধির':'NN','রুধিরগুল্ম':'NN','রুধিরবৃদ্ধিদাহ':'NN','রুধিরস্রাব':'NN',
'রুধিরহীন':'JJ','রুনির':'NN','রুনী':'NN','রুনুল':'NN','রুপ-লাবণ্য':'NN','রুপ':'NN','রুপই':'NNS',
'রুপকথা':'NNS','রুপকথার':'NN','রুপদ':'NN','রুপবান':'JJ','রুপবিজ্ঞান':'NN','রুপম':'NN','রুপমরা':'NN',
'রুপমান':'JJ','রুপমূল':'NN','রুপরেখা':'NN','রুপশ্রী':'NN','রুপান্তর':'NN','রুপান্তরিত':'VBN','রুপান্তারিত':'JJ',
'রুপালী':'NN','রুপি':'NN','রুপির':'NNS','রুপিয়া':'NN','রুপী':'NNS','রুপে':'RB','রুপেয়া':'NN',
'রুপোর':'NN','রুফিয়া':'NN','রুবা':'NN','রুবাইএমন':'NN','রুবি':'NN','রুবিডিয়াম':'NN','রুবেল':'NN',
'রুবেলকে':'NNS','রুম':'NN','রুমন্বান':'NN','রুমমেট':'NN','রুমা':'NN','রুমানিয়া':'NN','রুমানী':'NN',
'রুমাল':'NN','রুমে':'NN','রুয়েট':'NN','রুরি':'NN','রুরী':'JJ','রুরু':'NN','রুরুদ্রহ':'NNP',
'রুরুয়া':'NN','রুল':'NN','রুলিং':'VBG','রুল্লা':'NN','রুশ':'JJ','রুশঙ্গু':'NN','রুশমার্কিন':'NN',
'রুশা-বাসী':'NN','রুশি':'JJ','রুষ্ট':'NN','রুষ্টা':'JJ','রুসে':'VB','রুস্তম':'NN','রুহের':'NN',
'রুয়া':'NNP','রুয়েট':'NN','রূচি':'NN','রূডবোরস্টজে':'NN','রূড়ি':'NN','রূড়িলক্ষণা':'NN','রূঢ়':'NN',
'রূতি':'NN','রূদ্রাক্ষ':'NN','রূপ-লাবণ্য':'NN','রূপ':'NN','রূপকথা':'NN','রূপকবিহীন':'JJ','রূপকালঙ্কার':'NN',
'রূপক্রান্তা':'NN','রূপগরবিনী':'JJ','রূপঘনাক্ষরী':'NN','রূপচতুর্দশী':'NN','রূপটি':'NN','রূপণ':'NN','রূপধারী':'NN',
'রূপনগর':'NN','রূপনারায়ণে':'NN','রূপবতী':'JJ','রূপবান':'NN','রূপম':'NN','রূপমরা':'NN','রূপমসেই':'NN',
'রূপরেখা':'NN','রূপল':'NN','রূপশূণ্যতা':'NN','রূপসী':'NN','রূপহীনতা':'NN','রূপা':'NN','রূপান্তর':'NN',
'রূপান্তরমূলক':'JJ','রূপান্তরিত':'VBN','রূপান্তরে':'NN','রূপায়ণ':'NN','রূপায়িত':'VB','রূপে':'NN','রূপের':'NN',
'রূপো':'NN','রূপোলী':'JJ','রূমালী':'NN','রূসী':'NN','রূঢ়':'NN','রে':'NN','রেঁদা':'NN',
'রেইট':'NN','রেইল':'NN','রেওয়াচিনি':'NN','রেওয়াজ':'NN','রেক':'NN','রেকডিং':'VBG','রেকর্ড':'NN',
'রেকর্ডগুলো':'NNS','রেকর্ডটা':'NN','রেকর্ডমেসি':'NN','রেকর্ডহাটট্রিক':'NN','রেকর্ডিং':'NN','রেকর্ডের':'NN','রেকাঙ্গ':'NN',
'রেকাব':'NN','রেকাবে':'NN','রেক্জাবিক':'NN','রেক্টম':'NN','রেকড়':'NN','রেখা-চিত্র':'NN','রেখা':'NN',
'রেখাকে':'NN','রেখাগাণিতিক':'JJ','রেখাঙ্কন':'NN','রেখাচিত্র':'NN','রেখাটি':'NN','রেখীয়':'NN','রেখে':'VBG',
'রেখেই':'NN','রেখেছি':'VB','রেখেছিলসুযোগটা':'NN','রেখেছিলাম':'VB','রেখেছিলেন':'NN','রেখেছে':'VBN','রেখেছেতাই':'NN',
'রেখেছেন':'VBN','রেখো':'VB','রেগধ':'NN','রেগুলার':'NN','রেগুলেটার':'NN','রেগে':'NN','রেঙ্কিং':'NN',
'রেঙ্গুন':'NN','রেচক':'NN','রেচকসহ':'NNP','রেচন':'NN','রেছি':'VB','রেছো':'VB','রেজওয়ানুলের':'NN',
'রেজা':'NN','রেজাউল':'NN','রেজাল্টটা':'NN','রেজাল্টের':'NN','রেজি':'NN','রেজিষ্ট্রেশন':'NN','রেজিস্টরী':'NN',
'রেজিস্ট্রার':'NN','রেজিস্ট্রি':'NN','রেজিস্ট্রিনো':'VB','রেজিস্ট্রীকৃত':'JJ','রেজিস্ট্রেশন':'NN','রেজী':'JJ','রেঞ্চ':'NN',
'রেট':'NN','রেটও':'NN','রেটরিক':'NN','রেটিং':'VBG','রেটিনা':'NN','রেটিনোপ্যাথি':'NN','রেটে':'NN',
'রেট্':'NN','রেট্রোস্পেকটিভে':'NN','রেড':'NN','রেডক্রস':'NN','রেডক্লিফ':'NN','রেডটেপ':'NN','রেড়ি':'NN',
'রেডান':'NN','রেডি':'NN','রেডিওকে':'NN','রেডিওথেরাপি':'NN','রেডিওসক্রিয়':'JJ','রেডিমেড':'JJ','রেডিসনে':'NN',
'রেডিয়াম':'NN','রেডিয়েশন':'NN','রেণী':'NN','রেণুকা':'NN','রেণুমত্':'NN','রেণুসার':'NN','রেণ্ডম':'NN',
'রেত':'NN','রেতকুণ্ড':'NN','রেতন':'NN','রেতা':'NN','রেনকোট':'NN','রেনডিয়ার':'NN','রেনল':'NN',
'রেনি':'VB','রেনিয়াম':'NN','রেনে':'NN','রেনেসাঁকে':'NN','রেনেসাঁসের':'NN','রেন্ট':'NN','রেন্টাল':'JJ',
'রেন্ডিবাজী':'NN','রেপিড':'JJ','রেপিষ্ট':'NN','রেফ':'NN','রেফারি':'NN','রেফারিং':'VBG','রেফারির':'VB',
'রেফারী':'NN','রেফারেন্স':'NNS','রেফ্রিজারেটর':'NN','রেবত':'NN','রেবতীরমণ':'NN','রেবন্দ':'NN','রেবা':'NN',
'রেভ':'NN','রেভরেণ্ড':'NNP','রেভাঃ':'NNP','রেভিনিউ':'NN','রেম':'NN','রেমিট':'NN','রেমিটেন্স':'NNS',
'রেমিটেন্সের':'NNS','রেমিট্যান্সে':'NN','রেমিট্যান্সের':'NNS','রেমী':'JJ','রেমে':'NN','রেরই':'NN','রের্কড':'NN',
'রেল-গাড়ি':'NN','রেল':'NN','রেলওয়ে':'NN','রেলওয়ের':'NNS','রেলগাড়ি':'NN','রেলতন্ত্র':'NN','রেলপথ':'NN',
'রেলবিভাগ':'NN','রেলমন্ত্রী':'NN','রেলমার্গীয়':'NN','রেললাইন':'NN','রেলা':'NN','রেলি':'NNP','রেলিং':'NN',
'রেলে':'NN','রেশ':'NN','রেশটুকুও':'NN','রেশন':'NN','রেশনকার্ড':'NN','রেশনিং':'NN','রেশনের':'JJ',
'রেশম':'NN','রেশমী':'JJ','রেশমের':'NN','রেশারেশির':'NN','রেশিডেন্সিয়াল':'NN','রেষারেষি':'NN','রেষ্টুরেন্টে':'NN',
'রেস':'NN','রেসট':'NN','রেসপেক্ট':'NN','রেসর':'NN','রেসা':'NN','রেসারেসি':'NN','রেসি':'NN',
'রেসিপ্রোকাল':'NN','রেসিরাজের':'NN','রেসী':'JJ','রেসে':'NN','রেস্ট':'NN','রেস্টুরেন্ট':'NN','রেস্ট্রিকশন':'NN',
'রেস্তোরাঁ':'NN','রেস্পেক্ট':'NN','রেহন':'NN','রেহাই':'NN','রেহানা':'NNP','রেহায়':'NN','রোগে':'NN',
'রোনালদো':'NN','রোবটকে':'NN','রোহিঙ্গা':'NN','রেয়াল':'NN','রে‌খে':'NN','রৈদাস':'NN','রৈবত':'NN',
'রোঁদ':'NN','রোঁয়া':'NN','রোইঙ্গ':'NN','রোকন':'VB','রোগ':'NN','রোগগ্রস্ত':'NN','রোগগ্রস্থতা':'NN',
'রোগনিদান':'NN','রোগনির্ণয়':'NN','রোগবালাই':'NNS','রোগবিজ্ঞানী':'NN','রোগমুরারী':'NN','রোগরহিত':'JJ','রোগা-পাতলা':'JJ',
'রোগা':'NN','রোগীকে':'NN','রোগীরা':'NN','রোগে':'NN','রোগোপচার':'NN','রোচক':'JJ','রোচিসা':'NN',
'রোজ':'RB','রোজউড':'NN','রোজকার':'JJ','রোজগার':'NN','রোজগারনো':'VB','রোজগারহীন':'JJ','রোজগারী':'NN',
'রোজনামচা':'NN','রোজভ্যালি':'NN','রোজা':'NN','রোজাদার':'NN','রোজাদারদের':'NNS','রোজার':'NN','রোজি':'NN',
'রোট':'NN','রোটা':'NN','রোটিহান':'NN','রোড':'NN','রোডট্যাক্স':'NN','রোডস':'NNS','রোডিয়াম':'NN',
'রোডে':'NN','রোণালদোর':'NN','রোতই':'NN','রোতে':'VB','রোথি':'NNP','রোদ-স্নান':'NN','রোদ':'NN',
'রোদঘড়ি':'NN','রোদন':'VB','রোদনঅথবা':'NN','রোদস্নান':'NN','রোদে':'NN','রোদ্দুর':'NN','রোধ':'NN',
'রোধক':'JJ','রোধাত্মক':'JJ','রোধী':'JJ','রোধে':'NN','রোধ্য':'JJ','রোনালদরে':'NN','রোনালদিনহো':'NN',
'রোনালদোই':'NN','রোনালদোও':'NN','রোনালদোবিহীন':'NN','রোনালদোর':'NN','রোনালদোরা':'NN','রোনালদোরেই':'NN','রোনাল্ডো':'NN',
'রোনাল্ডোর':'NN','রোনো':'NNP','রোপ':'NN','রোপণ':'VBG','রোপণকারী':'NN','রোপণের':'JJ','রোপনক্ষেত্র':'NN',
'রোপা':'JJ','রোপিত':'JJ','রোপে':'NN','রোফি':'NN','রোবট':'NN','রোবটে':'NN','রোবটেরা':'NN',
'রোববার':'NNP','রোবোটিকস':'NN','রোভমান':'NN','রোম':'NN','রোমকূপ':'NN','রোমন্থক':'NN','রোমরন্ধ্র':'NN',
'রোমশ':'JJ','রোমহর্ষক':'JJ','রোমা':'NN','রোমাঞ্চক':'NN','রোমাঞ্চকর':'JJ','রোমাঞ্চিত':'NN','রোমাণ্টিক':'JJ',
'রোমান':'NN','রোমানিয়া':'NN','রোমানিয়ার':'JJ','রোমান্স':'NN','রোমার':'NN','রোমিও':'NN','রোমীয়':'JJ',
'রোমে':'NNP','রোমেশ':'NN','রোযা':'VBG','রোযার':'NN','রোরা':'NN','রোল':'NN','রোলা':'NNP',
'রোলান্ডো':'NN','রোলার':'NN','রোলী':'NN','রোশনচৌকি':'NN','রোশো':'NNP','রোষ':'NN','রোষপ্রবণতা':'NN',
'রোষাভাব':'NN','রোসলী':'NN','রোসো':'NN','রোহণ':'NN','রোহতক':'NN','রোহতাস':'NNS','রোহন':'NN',
'রোহাইপনাল':'NN','রোহিঙ্গা':'NN','রোহিঙ্গাকে':'NN','রোহিঙ্গাদের':'NN','রোহিণী':'NN','রোহিতক':'NN','রোহিনী':'NN',
'রোহিপ্নাল':'NN','রোহিশ':'NN','রোহী':'JJ','রোয়া':'NNP','রোয়াবী':'JJ','রৌচ্য':'NN','রৌদ্র':'NN',
'রৌদ্রকর্মা':'NN','রৌদ্রজনিত':'JJ','রৌদ্রশুষ্ক':'JJ','রৌদ্রাভ':'NN','রৌদ্রে':'NN','রৌদ্রোজ্জ্বল':'NN','রৌপো':'NN',
'রৌপ্য':'NN','রৌপ্যপাত্র':'NN','রৌরব':'NN','রৌহিষ':'NN','র্কণ':'NN','র্কীতি':'NN','র্নিবাচন':'NN',
'র্পূবাবস্থায়':'NN','র্পৌঁছানো':'VB','র্সবোচ্চ':'NN','রয়':'NN','রয়ছে':'VB','রয়ান':'NNP','রয়ে':'VBG',
'রয়েই':'NN','রয়েছি':'NN','রয়েছেকত':'NN','রয়েছেন':'VB','রয়েড':'NNP','রয়ের':'NN','রয়েে':'NN',
'রয়োগ':'NN','র‌্যবের':'NN','র‌্যাগিং':'NN','র‍্যাগিংয়ের':'NN','র‍্যাডিসন':'NN','র‍্যাব':'NN','ল-এর':'NNP',
'ল':'NN','লংকা':'NN','লংকার':'NN','লংঘন':'NN','লংটার্ম':'NN','লইতে':'VB','লইনা':'NN',
'লইয়াই':'NN','লকলক':'NN','লকার':'NN','লকারান্ত':'JJ','লকিন':'NN','লকীর':'NN','লকুট':'NNP',
'লকেট':'NN','লক্কর':'NN','লক্তক':'NN','লক্ষ':'NN','লক্ষকোটি':'NN','লক্ষণ':'NN','লক্ষণবিহীন':'JJ',
'লক্ষণরহিত':'JJ','লক্ষণরেখা':'NN','লক্ষণশূণ্য':'JJ','লক্ষণা':'NN','লক্ষণের':'NN','লক্ষতম':'JJ','লক্ষন':'NN',
'লক্ষনগুলি':'NN','লক্ষনীয়':'NN','লক্ষপতি':'NN','লক্ষভেদ':'NN','লক্ষলক্ষ':'NN','লক্ষসরকার':'NN','লক্ষাধিক':'NN',
'লক্ষী':'NN','লক্ষে':'NN','লক্ষেলক্ষে':'NN','লক্ষ্ণণ':'NN','লক্ষ্মীও':'NNP','লক্ষ্মীকান্ত':'NN','লক্ষ্মীকে':'NNP',
'লক্ষ্মীটোড়ী':'NN','লক্ষ্মীদিদি':'NNP','লক্ষ্মীদেবী':'NNP','লক্ষ্মীপুর২':'NN','লক্ষ্মীবাই':'NNP','লক্ষ্মীমণি':'NNP','লক্ষ্মীর':'NNP',
'লক্ষ্য':'NN','লক্ষ্যচ্যূত':'NN','লক্ষ্যণীয়':'NN','লক্ষ্যবস্তু':'NN','লক্ষ্যভেদী':'JJ','লক্ষ্যভ্রষ্ট':'JJ','লক্ষ্যমাত্রা':'NN',
'লক্ষ্যসংক্রান্ত':'NNP','লক্ষ্যস্থান':'NN','লক্ষ্যে':'NN','লখনউ':'NN','লখিমপুর':'NN','লখিল':'VB','লখিসরায়':'NN',
'লগ':'NN','লগলগ':'NN','লগা':'NN','লগি':'NN','লগিবৈঠা':'NN','লগুড়':'NN','লগে':'NN',
'লগ্ন-দন্ড':'NN','লগ্ন':'NN','লগ্নীকৃত':'NN','লগ্নে':'NN','লঘরে':'NN','লঘিত্র':'NN','লঘিমা':'NN',
'লঘু':'NN','লঘুকরণমিতি':'NN','লঘুকায়':'JJ','লঘুকিন্নরী':'NN','লঘুচন্দন':'NN','লঘুচিন্তক':'JJ','লঘুজল':'NN',
'লঘুত্ব':'NN','লঙ':'NN','লঙ্ক-টঙ্কটা':'NN','লঙ্ক':'NN','লঙ্কটঙ্কটা':'NN','লঙ্কলাট':'NN','লঙ্কাকাণ্ড':'NN',
'লঙ্কাগুড়ো':'NN','লঙ্কাধিপতি':'NN','লঙ্কান':'NN','লঙ্কাপতি':'NN','লঙ্কায়িত':'NN','লঙ্কিনী':'NN','লঙ্কেশ':'NN',
'লঙ্কোদক':'NN','লঙ্গ':'NN','লঙ্গরী':'NN','লঙ্গা-মঙ্গনোয়ার':'NN','লঙ্গা':'NN','লঙ্গুর':'NN','লঙ্ঘন':'NN',
'লঙ্ঘনকারী':'JJ','লঙ্ঘনীয়তা':'NN','লচলন':'NN','লচার':'NN','লচ্ছাশাখ':'NN','লছিল':'VB','লছিস':'NNP',
'লছেন':'VB','লজজা':'NN','লজাত':'JJ','লজান':'NN','লজিক':'NN','লজিস্টীক':'NN','লজ্জ':'NNP',
'লজ্জা':'NN','লজ্জাকর':'JJ','লজ্জাবতী':'NN','লজ্জাবোধ':'VB','লজ্জার':'NN','লজ্জাশীল':'JJ','লজ্জাশীলতা':'NN',
'লজ্জাহীন':'JJ','লজ্জাহীনতা':'NN','লজ্জায়':'NN','লজ্জিত':'NN','লজ্জ্বা':'NN','লঞ্চ':'NN','লট':'NN',
'লটলটে':'JJ','লটাক':'NN','লটারি':'NN','লটির':'NN','লট্ঠা':'NN','লড়া':'NN','লড়াই':'VBG',
'লড়াকু':'NN','লড়িয়া':'NN','লড়িয়ে':'VB','লড্ডু':'NN','লণ্ঠন':'NN','লণ্ডন':'NNP','লণ্ডনে':'NN',
'লণ্ডনের':'NNP','লণ্ড্রি':'NN','লতলা':'NNP','লতা':'NN','লতাকসুতিকা':'NN','লতাগুল্ম':'NN','লতাতরু':'NN',
'লতান':'NN','লতার':'NN','লতাশাল':'NN','লতাসাধনা':'NN','লতায়':'NN','লতি':'NN','লতিফ':'JJ',
'লতির':'NN','লতেই':'NN','লতেন':'VB','লতের':'NN','লথের':'NNP','লদের':'NN','লন':'NN',
'লনকে':'NN','লনডনে':'NNP','লনার':'NN','লনের':'NN','লন্ঠন':'NN','লন্ড':'NN','লন্ডনে':'NN',
'লন্ডভন্ড':'NN','লন্ডলী':'NN','লন্ডারিং':'NN','লন্ত':'JJ','লপতি':'NN','লপান':'NN','লপেতেগি':'NN',
'লফিন':'NN','লফুল':'NN','লফেট':'NNP','লব-কুশ':'NN','লব':'NN','লবঙ্গ-লতা':'NN','লবঙ্গলতা':'NN',
'লবণ':'NN','লবণক্ষেত্র':'NN','লবণতৃণ':'NN','লবণহীন':'JJ','লবণাক্ত':'NN','লবণাসুর':'NN','লবতী':'NNP',
'লবত্':'JJ','লবন':'NN','লবা':'NN','লবাম':'NN','লবার':'NNV','লবিং':'NN','লবিংবাজির':'NN',
'লবিক':'JJ','লবির':'NN','লবিষ্ট':'NN','লবীজ':'NN','লবেন':'VB','লবের':'NN','লব্দ্ধ':'JJ',
'লব্ধপ্রণাশ':'NNP','লব্বা':'NN','লভার':'NN','লভিন':'NNP','লভেট':'NN','লভ্যতা':'NN','লভ্যাংশতো':'NN',
'লমগজা':'NN','লমলে':'NN','লমান':'JJ','লমাল':'NN','লম্পজম্প':'NN','লম্পট':'JJ','লম্পটতা':'NN',
'লম্ফ-ঝম্প':'NN','লম্ফ':'NN','লম্বকর্ণ':'NN','লম্বভাবে':'RB','লম্বা':'NN','লম্বাই':'NN','লম্বাটে':'JJ',
'লম্বিত':'JJ','লম্বোদর':'NN','লরজ':'NN','লরাও':'NN','লরাম':'NNP','লরি':'NN','লর্ড':'NN',
'ললন':'NN','ললনাবৃত্ত':'NN','ললন্তিকা':'NN','ললাট':'NN','ললাম':'VB','ললামী':'NN','ললিউড':'NN',
'ললিত':'NN','ললিতপুর':'VB','ললিতলোচন':'JJ','ললিতা-পঞ্চমী':'NN','ললিতা-ষষ্ঠী':'NN','ললিতা-সপ্তমী':'NN','ললিতা':'NN',
'ললিতাপঞ্চমী':'NN','ললিতাষষ্ঠী':'NN','ললিতাসপ্তমী':'NN','ললিপপে':'NN','ললুম':'VB','ললেই':'NN','ললেও':'RP',
'ললেন':'VB','ললেম':'NN','লল্লরী':'NN','লশকর':'NN','লস':'NN','লসনের':'NNP','লসলে':'NN',
'লসাস':'NNP','লসিকা':'NN','লসিকাতন্ত্র':'NN','লসিকার':'JJ','লসিত':'JJ','লসেচ':'NN','লস্কর':'NN',
'লস্সি':'NN','লহতোরা':'NN','লহর':'NN','লহরপটোর':'NN','লহরিত':'JJ','লহেঙ্গা':'NN','লহের':'NN',
'লা':'NN','লাইক':'NN','লাইকগুলো':'NN','লাইট':'NN','লাইটিং':'NN','লাইন':'NN','লাইনগুলো':'NN',
'লাইনটা':'NN','লাইনশেয়ারের':'NN','লাইনিন':'NN','লাইনের':'NN','লাইনেরমারিয়া':'NN','লাইন্স':'NN','লাইন্সম্যানের':'NN',
'লাইফ':'NN','লাইফের':'NN','লাইবনিত্স':'NNP','লাইবেরিয়া':'NN','লাইব্রেরীকে':'NN','লাইব্রেরীতে':'NN','লাইভ':'NN',
'লাইলী':'NNP','লাইসেন্স':'NN','লাইসেন্সবিহীন':'NN','লাইসেন্সের':'NN','লাউ':'NN','লাউকার':'NN','লাউজ':'NN',
'লাউডস্পিকার':'NN','লাউহে':'NN','লাও':'NN','লাওস':'NN','লাওসীয়':'JJ','লাওয়েশিয়ান':'NN','লাক':'NN',
'লাকে':'NN','লাক্ষা':'NNS','লাক্ষাগৃহ':'NN','লাক্ষাজাত':'NN','লাক্ষাদ্বীপ':'NN','লাক্ষারস':'NN','লাক্সেমবার্গ-বাসী':'NN',
'লাক্সেমবার্গের':'NN','লাখ':'NN','লাখটাকার':'JJ','লাখড়া':'NN','লাখপতি':'NN','লাখা':'NN','লাখুয়া':'NN',
'লাখের':'NN','লাখো':'NN','লাগ-ডাঁট':'NN','লাগছে':'NN','লাগত':'NN','লাগতে':'NN','লাগতেও':'VB',
'লাগতো':'NN','লাগব':'NN','লাগবা':'NN','লাগবেআর':'NN','লাগবেতারা':'NN','লাগর':'NN','লাগল':'VB',
'লাগলে':'NN','লাগলেন':'VB','লাগলো':'NN','লাগসে':'NN','লাগা':'NN','লাগাইসো':'NN','লাগাচ্ছি':'NN',
'লাগাচ্ছে':'VB','লাগাতার':'NN','লাগান':'NN','লাগানি':'VB','লাগানো':'NN','লাগানো-ভাঙ্গানো':'NN','লাগানো':'VBN',
'লাগানোতে':'NN','লাগাবেন':'VB','লাগাম':'NNS','লাগামহীন':'NN','লাগার':'NN','লাগালে':'RP','লাগায়':'NN',
'লাগিয়ে':'NN','লাগিল':'VB','লাগিয়ে':'NN','লাগিয়েছিলেন':'NN','লাগু':'JJ','লাগুক':'NN','লাগে':'NNS',
'লাগেউৎপল':'JJ','লাগেগতি':'NN','লাগেজ':'NN','লাগেনা':'NN','লাগেনাআমাদের':'NN','লাগেনাই':'NN','লাগোয়া':'JJ',
'লাঘব':'NN','লাঙল':'NN','লাঙ্গুল':'NN','লাচি':'NN','লাচুই':'NN','লাছি':'NN','লাজ':'NN',
'লাজপাছে':'NN','লাজলজ্জা':'NN','লাজুক':'NN','লাজ্জা':'NN','লাঞ্চ':'NN','লাঞ্ছনা':'NN','লাঞ্ছিত':'JJ',
'লাঞ্ছিতা':'NN','লাট':'NN','লাটকান':'NN','লাটঙ্গ':'NN','লাটসাহেব':'NN','লাটা':'NN','লাটানুপ্রাশ':'NN',
'লাটি':'NN','লাটুক':'NN','লাটোরা':'NN','লাট্টু':'NN','লাঠি':'NN','লাঠিপেটা':'NN','লাঠিয়াল':'NN',
'লাড্ডু':'NN','লাতখোর':'JJ','লাতভিয়া':'NN','লাতভিয়াবাসী':'NN','লাতল':'JJ','লাতিন':'NN','লাতিনীয়':'JJ',
'লাতুর':'NN','লাতে':'VB','লাথখোর':'NN','লাথবাজ':'JJ','লাথি':'NNP','লাদ':'NN','লাদা':'JJ',
'লাদাখ':'NN','লাদেন':'NN','লাদেনের':'NN','লাদ্দিম':'NN','লানো':'NNV','লাপিকা':'NN','লাফ':'NN',
'লাফদড়ি':'NN','লাফল':'NN','লাফাই':'NN','লাফাচ্ছিলে':'VB','লাফাচ্ছে':'VBG','লাফাচ্ছেন':'NN','লাফানো':'NN',
'লাফাবে':'NN','লাফালাফি':'NN','লাফায়':'NN','লাফিং':'NN','লাফিয়ে':'VBG','লাফের':'NN','লাফোঁ':'NNP',
'লাব':'NN','লাবজ':'NN','লাবণী':'NN','লাবণ্যময়':'NN','লাবণ্যময়ী':'JJ','লাবণ্যে':'NN','লাবলাবলাবলাব':'NN',
'লাবা':'NN','লাবে':'VB','লাভ':'NN','লাভও':'NN','লাভজনক':'NN','লাভটা':'NN','লাভতো':'NN',
'লাভদায়ক':'NN','লাভদায়ী':'JJ','লাভবান':'NN','লাভলোকসানচাঁদার':'NN','লাভহীন':'JJ','লাভা':'NN','লাভার্থী':'NN',
'লাভে':'NN','লাভেও':'NN','লাভেরে':'VB','লাম':'NN','লামজ':'NN','লামজ্জক':'NN','লামফেলপট':'NN',
'লামা':'NN','লামি':'NN','লাম্বা':'NN','লাময়':'NN','লায়':'NN','লারা':'NN','লার্জ':'NN',
'লাল-কালো':'NN','লাল-ঘাস':'NN','লাল':'JJ','লালঅম্বারীর':'NN','লালঝান্ডায়':'NN','লালড়ী':'NN','লালডানা':'NN',
'লালদীঘি':'NNP','লালন-পালন':'NN','লালন':'NN','লালনকারি':'NN','লালনপালনের':'NN','লালনীল':'NN','লালপেট':'NN',
'লালপ্রমেহ':'NN','লালফিতে':'NN','লালফিতেতন্ত্র':'NN','লালবাতি':'NN','লালভরেঁড়া':'NN','লালমধুমেহ':'NN','লালমনিরহাট':'NNP',
'লালমনিরহাটে':'NN','লালমাটি':'NN','লালমির্চ':'NN','লালমুনিয়া':'NN','লালরঙের':'NN','লালসা':'NN','লালসাদা':'JJ',
'লালসাপূর্ণ':'JJ','লালসামুক্ত':'JJ','লালসারহিত':'JJ','লালসির':'NN','লালা':'NN','লালাবাজারে':'NN','লালাভ':'JJ',
'লালাভক্ষ':'NN','লালাসা':'NN','লালায়িত':'JJ','লালি':'NN','লালিত':'VB','লালিতপালিত':'JJ','লালিমা':'NN',
'লালিমাযুক্ত':'JJ','লালী':'NN','লালুকা':'NN','লালে':'NN','লাল্হারা':'NN','লাশ-কাটা':'NN','লাশ':'NN',
'লাশের':'NNS','লাষ্ট':'JJ','লাস':'NN','লাসভেগাস':'NN','লাসা':'NN','লাসী':'JJ','লাসে':'NN',
'লাসোড়া':'NN','লাসৌটা':'NN','লাস্ভেগাস':'NN','লাস্য':'NN','লাহকৌর':'NN','লাহল':'NN','লাহোর':'NN',
'লায়লা':'NN','লা‌গে':'NN','লি':'NN','লিংক':'NN','লিংকনের':'NN','লিউকোমিয়া':'VB','লিওন':'NN',
'লিওনটায়ন':'NN','লিওনের':'JJ','লিওপোল্ডবিল':'NN','লিক':'NNS','লিকটেন্সটাইন':'NN','লিকা':'NN','লিকুইডিটি':'NN',
'লিকে':'NN','লিখছে':'NN','লিখছেন':'VB','লিখতে':'NN','লিখন':'NN','লিখনে':'VBG','লিখনের':'NN',
'লিখবেন':'NN','লিখলেন':'NN','লিখা':'VBG','লিখাটি':'NN','লিখি':'VB','লিখিত':'NN','লিখিতে':'VB',
'লিখিবার':'NNV','লিখিয়ে':'NN','লিখুন':'VB','লিখে':'VBG','লিখেও':'VBG','লিখেছি':'NN','লিখেছে':'NN',
'লিখেন':'NN','লিগ':'NN','লিগনাইট':'NN','লিগাই':'NN','লিগাওয়ানে':'NNP','লিগাতে':'NN','লিগামেণ্ট':'NN',
'লিগার':'NN','লিগাল':'NNP','লিগে':'NN','লিগের':'NN','লিগ্যাল':'NN','লিগ—কোনো':'NN','লিঙ্ক':'NN',
'লিঙ্গচর্ম':'NN','লিঙ্গপুরাণ':'NN','লিঙ্গশূণ্য':'NN','লিঙ্গের':'NN','লিচু':'NN','লিজ':'NN','লিজা':'NNP',
'লিজার্ড':'NN','লিজে':'NNP','লিজেন':'NN','লিজেন্ড':'VB','লিট.':'NNP','লিটনকে':'NNP','লিটনতো':'NNP',
'লিটনের':'NNP','লিটমাস':'NN','লিটল':'NN','লিটার':'NN','লিটারের':'NN','লিটাস':'NN','লিটি':'NNP',
'লিট্টি':'NN','লিট্্ল':'JJ','লিড':'NN','লিডৌরী':'NN','লিড্ডার':'NN','লিতা':'NN','লিথিয়াম':'NN',
'লিথুনিয়া-বাসী':'NN','লিথুয়ানিয়া':'NN','লিথুয়ানিয়ান':'JJ','লিনও':'NNP','লিনি':'VB','লিনী':'NNP','লিনে':'NN',
'লিপ':'NN','লিপস্টিক':'NN','লিপি':'NN','লিপিবদ্ধ':'NN','লিপিবদ্ধকরণ':'VBG','লিপিবদ্ধন':'NN','লিপির':'NN',
'লিপিশৈলী':'NN','লিপিসজ্জা':'NN','লিপেন্স':'NN','লিপ্ত':'NN','লিপ্ততা':'NN','লিপ্সা':'NN','লিপ্সু':'JJ',
'লিফটিং':'NN','লিফলেট':'NN','লিবআপনি':'NN','লিবারাল':'NN','লিবারেশন':'NN','লিবিয়া':'NN','লিবিয়াবাসী':'NN',
'লিবীয়':'JJ','লিবে':'VB','লিবেরিয়া':'NN','লিবেরিয়াবাসী':'NN','লিব্রেভিলে':'NN','লিভ':'NN','লিভারপুল':'NN',
'লিভারপুলে':'NN','লিভে':'NN','লিভেরপুলেরই':'NN','লিমা':'NN','লিমিট':'NN','লিমিটেড':'NNP','লিম্ফোসাইট':'NN',
'লিম্বাস':'NN','লিরা':'NN','লির্বাতে':'NNP','লিলগিনী':'NN','লিলা':'NN','লিলাঙ্গওয়ে':'NN','লিলার':'NN',
'লিলি':'NN','লিল্লাহ':'NN','লিশন':'NNP','লিষ্ট':'NN','লিস':'NNP','লিসবন':'NN','লিসি':'NN',
'লিস্ট':'NN','লিস্টেই':'NN','লিস্টেড':'VBN','লিয়ন':'NN','লিয়ম':'NNP','লিয়া':'NNP','লিয়ে':'VB',
'লীকে':'NN','লীগ':'NN','লীগও':'NN','লীগকে':'NN','লীগগে':'NN','লীগধারীরা':'NNS','লীগবিএনপি':'NN',
'লীগরাজ':'NN','লীগারদের':'NNS','লীগাররা':'NN','লীগাররাই':'NNS','লীগায়':'NN','লীগে':'NN','লীগেও':'NN',
'লীগেরই':'NN','লীতে':'NN','লীন':'NN','লীনা':'NNP','লীরা':'NN','লীলগহী':'NN','লীলা':'NN',
'লীলাকথাই':'NN','লীলাবতী':'NN','লীলাবসান':'NN','লীলার':'NN','লীলাসহচরী':'NN','লীলায়':'NN','লু':'NN',
'লুই':'NNP','লুইস':'NN','লুকনো':'JJ','লুকসাজ':'NN','লুকাঠ':'NN','লুকাতে':'NN','লুকানো':'NNP',
'লুকাসফিল্ম':'NN','লুকায়':'NN','লুকিকায়':'JJ','লুকিয়ে':'VBG','লুকুচুরি':'NN','লুকোচুরিটা':'NN','লুকোতে':'VB',
'লুকোনো':'VB','লুক্কায়ন':'NN','লুক্কায়িত':'NNP','লুক্সিমবর্গীয়':'JJ','লুক্সেমবার্গ':'NN','লুক্সেমবুর্গিস':'JJ','লুক্সেমবুর্গের':'JJ',
'লুখ':'NN','লুঙ্গলেই':'NN','লুঙ্গী':'NN','লুচি':'NN','লুচুই':'NN','লুচ্চা':'NN','লুজ':'NN',
'লুট':'NN','লুটতে':'NN','লুটপাট':'NN','লুটপাটও':'VBG','লুটপাটকারিদের':'NNS','লুটপাটকারীদের':'NNS','লুটপাটতন্ত্র':'NN',
'লুটপাটে':'NN','লুটবাজ':'NNS','লুটবেন':'NN','লুটানো':'JJ','লুটি':'NN','লুটিয়ে':'VB','লুটেপুটে':'VBN',
'লুটের':'NN','লুটেরা':'NNS','লুটেরাতে':'NNS','লুটেরারা':'NNS','লুটেশিয়াম':'NN','লুটোপুটি':'NN','লুট্':'NN',
'লুঠ':'NN','লুঠতরাজ':'NN','লুঠতরাজে':'NNP','লুঠপাট':'VBG','লুঠেরা':'NN','লুণ্ঠন':'VBG','লুণ্ঠনের':'NN',
'লুণ্ঠিত':'VB','লুতপাট':'VBG','লুথার':'NN','লুধিয়ানা':'NNP','লুনা-9':'NNP','লুনি':'NN','লুন্ঠন':'NN',
'লুপ্ত':'NN','লুবাক':'NN','লুব্ধ':'VBN','লুম':'NN','লুমুম্বা':'NNP','লুমুম্বাদের':'NNP','লুলা':'NN',
'লুশাই':'NN','লুসাকা':'NN','লুসিয়া':'NN','লু্টপাটের':'VBG','লুয়াণ্ডা':'NN','লূটের':'NN','লৃঙ্':'NN',
'লে':'NN','লেংটি':'NN','লেংথই':'NN','লেংরা':'NN','লেঃ':'NN','লেই':'NN','লেইন':'NNP',
'লেইম':'NN','লেউ':'NN','লেওয়াক':'NN','লেক':'NN','লেকচার':'NN','লেকারের':'NN','লেখ':'NN',
'লেখকদের':'NN','লেখকের':'NN','লেখন-ভঙ্গী':'NN','লেখন-শৈলী':'NN','লেখন-সামগ্রী':'NN','লেখন':'NN','লেখনশৈলী':'NN',
'লেখনি':'NN','লেখপাল':'NN','লেখা':'VBG','লেখাকর্মী':'NN','লেখাগুলির':'NN','লেখাঙ্কিত':'JJ','লেখাজোখা':'NN',
'লেখাটা':'VBG','লেখাটি':'NN','লেখাতাম':'NN','লেখাদাগ':'VBG','লেখান':'VB','লেখানো':'VBG','লেখাপড়া':'NN',
'লেখাপড়াও':'NN','লেখাপড়ায়':'NN','লেখাযুক্ত':'NN','লেখার':'NN','লেখালিখি':'NN','লেখালেখি':'VBG','লেখায়':'VBG',
'লেখি':'NN','লেখিয়েছে':'NN','লেখুন':'VB','লেখে':'NNS','লেখেছিলেন':'VB','লেখেন':'NNS','লেখ্য':'JJ',
'লেগস্পিনার':'NN','লেগু':'NNP','লেগুনা':'NN','লেগে':'NN','লেগেই':'RB','লেগেছিল':'NN','লেগেছিলো':'VB',
'লেগেছে':'NN','লেগেছেন':'IN','লেগেছেসেতুমন্ত্রীর':'NN','লেঙ্গড়ি':'NN','লেচি':'NN','লেছি':'VB','লেজ':'NN',
'লেজওয়ালা':'VBN','লেজকাটা':'JJ','লেজবিশিষ্ট':'JJ','লেজবিহীন':'JJ','লেজযুক্ত':'JJ','লেজহীন':'JJ','লেজ়র':'NN',
'লেজার':'NN','লেজিম':'NN','লেজুরবৃত্তিই':'VBG','লেজুড়বৃত্তিটা':'VBG','লেজে':'NN','লেট':'NN','লেটারের':'NN',
'লেটুস':'NN','লেট্':'NN','লেঠা':'NN','লেঠেল':'JJ','লেড':'NN','লেড়কি':'NN','লেডিস':'NNS',
'লেডীকে':'NN','লেণ্ডেলের':'NN','লেত্তি':'NN','লেথা':'NN','লেদ':'NN','লেন-দেন':'NN','লেন':'NN',
'লেনদার':'JJ','লেনদেন':'NN','লেনদেনে':'NN','লেনদেনেও':'NNS','লেনস':'NN','লেনিন':'NN','লেনিনের':'NN',
'লেন্':'NN','লেন্ডী':'NN','লেন্সকে':'NN','লেন্সে':'NN','লেপ':'NN','লেপটপে':'NN','লেপটে':'VB',
'লেপন':'VBG','লেপনকর্মী':'NN','লেপা':'VBN','লেপানো':'VB','লেপার':'NN','লেপ্টে':'VB','লেফাফা':'NN',
'লেফ্টেন্যান্ট':'NN','লেব':'NN','লেবানন':'NN','লেবানীস':'JJ','লেবাস':'NN','লেবাসে':'NNS','লেবিয়াগাটা':'NN',
'লেবু':'NN','লেবুমামার':'NN','লেবেল':'NN','লেভি':'NN','লেভেল':'NN','লেভেলপ্লেয়িংফিল্ড':'NN','লেভেলে':'NN',
'লেমর':'NN','লেমিনেটিং':'VBG','লেম্পীরা':'NN','লেরই':'NN','লেরী':'NN','লেলিয়ে':'VB','লেশ':'NN',
'লেশমাত্র':'RB','লেষণ':'NN','লেস':'NN','লেসু':'NNP','লেসোটো':'NN','লেসোথি':'NN','লেসোথোবাসী':'NN',
'লেসোথোর-সম্পর্কিত':'JJ','লেসোথোর':'JJ','লেহ':'NN','লেহনকারী':'VBG','লেহনীয়':'JJ','লেহনের':'NN','লোক':'NN',
'লোকজনের':'NN','লোকটা':'NN','লোকদের':'NNS','লোকসান':'NNS','লোকসানে':'NN','লোকেদের':'NNS','লোভ':'NN',
'লো':'NN','লোক-নৃত্য':'NN','লোক':'NNS','লোকই':'NN','লোককথা':'NN','লোককে':'NNS','লোকগাঁথা':'NN',
'লোকগীতি':'NN','লোকগুলির':'NN','লোকগুলোই':'NN','লোকচিত্রকলা':'NN','লোকজন':'NNS','লোকজনএর':'NN','লোকজনদের':'NN',
'লোকজনরাই':'NNS','লোকজনের':'NN','লোকটা':'NN','লোকটাকে':'NN','লোকটারে':'NN','লোকটি':'NN','লোকঠকানো':'NN',
'লোকতন্ত্র':'NN','লোকতান্ত্রিক':'JJ','লোকতো':'NNS','লোকদেখানো':'NN','লোকদের':'NN','লোকদেরকে':'NNS','লোকনায়ক':'NN',
'লোকনৃত্য':'NN','লোকপাল':'NN','লোকপ্রিয়':'JJ','লোকবল':'NN','লোকমত':'NN','লোকমান্য':'NN','লোকমুখে':'NN',
'লোকযত':'NN','লোকলস্কর':'NN','লোকশান':'NNS','লোকশিক্ষক':'NN','লোকশিল্পের':'NN','লোকশূণ্য':'NN','লোকসংখ্যা':'NN',
'লোকসংস্কৃতির':'NN','লোকসঙ্গীত':'NN','লোকসত্তা':'NN','লোকসভায়':'NN','লোকসমাগমে':'JJ','লোকসান':'NNS','লোকসানে':'NNS',
'লোকসাহিত্য':'NN','লোকসেবা':'NN','লোকহিত':'NN','লোকহিতৈষী':'JJ','লোকাচার':'NN','লোকাট':'NN','লোকাধিপতি':'NN',
'লোকামী':'NN','লোকিয়ে':'VBG','লোকে':'NNS','লোকেদের':'NN','লোকেরা':'NNS','লোকোই':'NNS','লোকোপোযোগী':'JJ',
'লোগো':'NN','লোঙ্গতলাই':'NN','লোচক':'NN','লোচনদাসের':'NN','লোচনপ্রান্ত':'NN','লোজপা':'NN','লোজহোম':'NN',
'লোট':'NN','লোটাসজ্জি':'NN','লোটি':'NN','লোড':'NN','লোডংলে':'NN','লোডশেডিং':'VBG','লোডসেডিং':'NN',
'লোডিং':'VBG','লোতে':'NN','লোধ':'NN','লোধবৃক্ষ':'NN','লোন':'NN','লোনগ্রহিতা':'NN','লোনা':'NN',
'লোনের':'NN','লোপ':'NN','লোপকারী':'JJ','লোপাট':'NN','লোপামুদ্রা':'NN','লোপ্পা':'NN','লোবা':'NN',
'লোবিংবাজি':'NNP','লোবিয়া':'NN','লোভ':'VB','লোভকে':'NN','লোভন':'NN','লোভনীয়':'VBG','লোভশূণ্য':'JJ',
'লোভহীন':'JJ','লোভাতুর':'NN','লোভী':'NN','লোভে':'NN','লোম':'NN','লোমওয়ালা':'JJ','লোমকূপ':'NN',
'লোমফোঁড়া':'NN','লোমযুক্ত':'NN','লোমরন্ধ্র':'NN','লোমশ':'NN','লোমশপর্ণী':'NN','লোমশা':'NN','লোমহর্ষক':'JJ',
'লোমা':'NN','লোরেন':'NNP','লোল':'NN','লোলুকাস':'NN','লোলুপ':'NN','লোল৩জি':'NN','লোশন':'NN',
'লোহগড়':'NNP','লোহড়ী':'NN','লোহরদগ্গা':'NN','লোহা':'NN','লোহানীকে':'NN','লোহাবাঁধানো':'NN','লোহাযুক্ত':'NN',
'লোহার':'NN','লোহালক্কর':'JJ','লোহালক্করের':'NN','লোহিত':'JJ','লোহিতসাগর':'NN','লোহিত্যা':'NN','লোয়ার':'NN',
'লৌকিক':'NN','লৌকিকাগ্নি':'NN','লৌরি':'NN','লৌহ-আকরিক':'JJ','লৌহ-পুরুষ':'NN','লৌহ':'NN','লৌহআকর':'NN',
'লৌহখণ্ড':'NN','লৌহচোলিকা':'NN','লৌহতত্ত্ব':'NN','লৌহপথগামিনী':'NN','লৌহপুরুষ':'NN','লৌহসার':'NN','লৌহাসব':'NN',
'লৌহ্য':'NN','ল্কা':'NN','ল্গু':'NNP','ল্টন':'NNP','ল্টে':'NN','ল্টো':'NNP','ল্ডে':'NN',
'ল্পী':'NN','ল্যংড়া':'NN','ল্যাংগুয়েজ':'NN','ল্যাংটো':'NN','ল্যাংড়া':'NN','ল্যাংড়ানো':'NN','ল্যাকটোজ':'NN',
'ল্যাক্টোফ্লেবিন':'NN','ল্যাঙওয়েজ':'NN','ল্যাঙট':'NN','ল্যাঙোট':'NN','ল্যাঙ্গরা':'JJ','ল্যাঙ্গারকে':'NN','ল্যাঙ্গুয়েজে':'NN',
'ল্যাঙ্গোট':'NN','ল্যাজ':'NN','ল্যাটা':'JJ','ল্যাটিন':'NN','ল্যাঠা':'NN','ল্যাণ্ডস্কেপ':'NN','ল্যাতিন':'JJ',
'ল্যান্ড':'NN','ল্যান্থানাম':'NN','ল্যান্সাররা':'NN','ল্যাপটপ':'NN','ল্যাব':'NN','ল্যাবরেটরি':'NN','ল্যাভিয়সিয়েরই':'NNP',
'ল্যাম্প':'NN','ল্যাস্কির':'NNP','ল্যুভল্যানা':'NN','ল্যে':'NN','ল্লব':'NNP','ল্লভ':'NN','ল্লা':'NN',
'ল্লি':'NNP','ল্লী':'JJ','ল্লু':'NNP','ল্লে':'NN','লড়ছেসুতরাং':'VBG','লড়তে':'NN','লড়াই':'VBG',
'লড়াইটাও':'NN','লড়াইরত':'NN','লড়াইয়ে':'NN','লড়ুন':'NN','লড়েছিলাম':'NN','লয়':'NN','লয়কারিতেও':'NN',
'লয়কে':'NN','ল‌োভ‌ে':'VB','শ':'NN','শংকর':'NN','শংকিতএকটা':'NN','শংখ্যদ্রাব':'NN','শংসা':'NN',
'শংয়ু':'NN','শওকত':'NN','শক':'NN','শকটাসুর':'NN','শকদ্রুম':'NN','শকর':'NN','শকরকন্দ':'NN',
'শকরখোরা':'NN','শকরি':'NN','শকরিমুনিয়া':'NN','শকলেন্দু':'NN','শকাব্দের':'NN','শকারি':'NN','শকুন':'NN',
'শকুনের':'NNS','শকুন্ত':'NN','শকুন্তলা':'NN','শকে':'NN','শকেও':'NN','শক্ত':'IN','শক্তপোক্ত':'IN',
'শক্তভাবে':'RB','শক্তি':'NN','শক্তিকে':'NN','শক্তিগুলির':'NN','শক্তিতে':'NN','শক্তিপাণি':'NN','শক্তিপূর্ণতা':'NN',
'শক্তিবন':'NN','শক্তিবৈকল্য':'NN','শক্তিমন্ত্রী':'NN','শক্তিমান':'JJ','শক্তির':'NN','শক্তিরাজাকার':'NN','শক্তিরূপে':'NN',
'শক্তিশাবী':'JJ','শক্তিশালী':'NN','শক্তিসাহস':'NN','শক্তিহীনতা':'NN','শক্তুক':'NN','শক্তের':'IN','শক্রজানু':'NN',
'শক্রপুরি':'NN','শক্রবাপী':'NN','শখ':'NN','শখানেক':'NN','শখে':'RB','শখের':'NN','শগুল':'NNP',
'শঙ্কচুর':'NN','শঙ্কপুষ্পী':'NN','শঙ্কর':'NN','শঙ্করতাল':'NN','শঙ্করাচার্য':'NN','শঙ্করি':'NN','শঙ্কা':'NN',
'শঙ্কাপ্রবণ':'JJ','শঙ্কারবাস':'NN','শঙ্কাহীন':'JJ','শঙ্কু':'NN','শঙ্কুর':'NNP','শঙ্কুশির':'NN','শঙ্খ':'NN',
'শঙ্খচুড়':'NN','শঙ্খণ':'NN','শঙ্খদ্রাবক':'JJ','শঙ্খনারী':'NN','শঙ্খপলীতা':'NN','শঙ্খপুষ্পিকা':'NN','শঙ্খবাদক':'NN',
'শঙ্খানাম্বী':'NN','শঙ্খাসুর':'NN','শঙ্খাহুলী':'NN','শঙ্খিনী':'NN','শঙ্খোদরী':'NN','শচি':'NN','শচিনকে':'NN',
'শচী':'NN','শচীদি':'NNP','শচীদেবী':'NNP','শচীদেবীর':'NNP','শচীন':'NN','শচীনদেব':'NNP','শচীনের':'NN',
'শচীমাতা':'NN','শচীর':'NNP','শজাত':'JJ','শজারু':'NN','শট':'NN','শটাই':'NN','শটির':'NN',
'শটী':'NN','শটে':'NN','শঠ':'NN','শঠতা':'NN','শণ':'NN','শণগাছ':'NN','শণঘণ্টা':'NN',
'শণপুষ্পী':'NN','শণসমা':'NN','শণিকা':'NN','শণের':'NN','শত':'NN','শতককে':'NN','শতকরা':'NN',
'শতকুন্ডী':'NN','শতকুম্ভ':'NN','শতকে':'NN','শতকোটি':'NNS','শতকোটিপতি':'NN','শতগাভীসম্পন্ন':'JJ','শতগুম্বুজ':'NNS',
'শতগ্রন্থি':'NN','শততম':'JJ','শতদল':'NN','শতদ্রু':'NN','শতধন্বা':'NN','শতপত্র-নিবাস':'NN','শতপত্রক':'NN',
'শতপথ-ব্রাহ্মণ':'NN','শতপথিক':'JJ','শতপর্ণিকা':'NN','শতপর্বিকা':'NN','শতপুত্রী':'NN','শতপোদ':'NN','শতপ্রভেদন':'NN',
'শতবতী':'NN','শতবর্ষে':'NN','শতবলা':'NN','শতবাহু':'NN','শতভাগ':'NN','শতমূলী':'NN','শতরঞ্জী':'NN',
'শতরান':'NN','শতরানের':'JJ','শতরূপা':'NN','শতশত':'NN','শতসহস্র':'CD','শতাংশ':'NN','শতাংশঅর্থাৎ':'NN',
'শতাংশই':'NN','শতাংশও':'NN','শতাংশের':'NN','শতাক্ষ':'NN','শতাধিক':'JJ','শতানন্দ':'NN','শতানিক':'NN',
'শতাব্দী':'NN','শতাব্দীর':'NN','শতায়ু':'JJ','শতের':'NN','শত্রবো':'VB','শত্রু':'NN','শত্রুইসাময়িক':'JJ',
'শত্রুঘ্ন':'NN','শত্রুজিত্':'JJ','শত্রুজয়':'NN','শত্রুতা':'NN','শত্রুতাপূর্ণ':'JJ','শত্রুদের':'NN','শত্রুদেরঅতীতে':'NNS',
'শত্রুনাশক':'JJ','শত্রুপূর্ণ':'JJ','শত্রুবিহীন':'JJ','শত্রুর':'NN','শত্রুরহিত':'JJ','শত্রুরা':'NN','শত্রুসংহার':'NN',
'শত্রুহীন':'JJ','শদের':'NN','শন':'NN','শনকে':'NNP','শনটি':'NN','শনপাপড়ি':'NN','শনাক্ত':'VB',
'শনার':'NN','শনাল':'NNP','শনি':'NN','শনিক':'JJ','শনিদেব':'NN','শনিবার':'NNP','শনির':'NN',
'শনেই':'NN','শনৈশ্চর':'NN','শন্দীল':'NN','শপথ':'NN','শপারদের':'NN','শপিং':'NN','শপ্ত':'JJ',
'শফতালু':'NN','শফি':'NN','শফিকুর':'NN','শব-কক্ষ':'NN','শব-গৃহ':'NN','শব-চুল্লী':'NN','শব':'NN',
'শবকক্ষ':'NN','শবগৃহ':'NN','শবতী':'JJ','শবদাহ':'NN','শবদেহ':'NN','শবপরীক্ষণ':'NN','শবযাত্রা':'NN',
'শবযান':'NN','শবর':'NN','শবরিমালা':'NN','শবরী':'NN','শবরীমালা':'NN','শবরীর':'NN','শবরীরায়নের':'NNP',
'শবল':'NN','শবলেপন':'NN','শবসত্কার':'NN','শবাধার':'NN','শবালী':'JJ','শবাসন':'NN','শব্দ':'NNS',
'শব্দই':'NN','শব্দকার':'NN','শব্দকোশ':'NN','শব্দগুলো':'NN','শব্দজাল':'NN','শব্দটাকে':'NN','শব্দটি':'NN',
'শব্দটির':'NN','শব্দতালিকা':'NN','শব্দপ্রয়োগের':'NN','শব্দব্যয়':'NN','শব্দভেদী':'JJ','শব্দরূপ':'NN','শব্দরূপের':'NN',
'শব্দহীন':'NN','শব্দাংশ':'NN','শব্দাড়ম্বর':'NN','শব্দাড়ম্বরপূর্ণ':'JJ','শব্দানুবাদ':'NN','শব্দাবলী':'NN','শব্দালঙ্কার':'NN',
'শব্দায়মান':'JJ','শব্দে':'NN','শব্দের':'NNS','শমণ':'NN','শমন':'NN','শমশেরবাজি':'NN','শমি':'NN',
'শমিক':'JJ','শমিয়ের':'NNP','শমীক':'NN','শম্ঙুকান্তা':'NN','শম্পা':'NN','শম্বর':'NN','শম্বসাদন':'NN',
'শম্বুক':'NN','শম্ভু':'NN','শম্ভুনাথ':'NNP','শম্ভুলোক':'NN','শয্য':'NN','শয্যায়':'NN','শর':'NN',
'শরকে':'NNP','শরণ':'NN','শরণস্থল':'NN','শরণাগত':'JJ','শরণার্থী':'NN','শরণ্য':'JJ','শরতকালীন':'JJ',
'শরত্':'NN','শরত্চন্দ্র':'NNP','শরদন্ত':'NN','শরদবান':'NN','শরদিন্দুর':'NNP','শরনার্থিদের':'NNS','শরপক্ষ':'NN',
'শরবত':'NN','শরবতগড়ী':'NN','শরবতি':'NN','শরবতের':'NN','শরভ':'NN','শরভঙ্গ':'NN','শরভোপনিষদ':'NN',
'শরম':'NN','শরমিন্দা':'NN','শরমে':'NN','শরাটি':'NN','শরাবণ':'NN','শরারি':'NN','শরায়ু':'NN',
'শরিক':'NN','শরিকভাগাভাগির':'NN','শরিফ':'NN','শরিফপাবলিক':'JJ','শরিরএই':'NN','শরিয়ত্':'NN','শরীক':'NN',
'শরীফ':'NN','শরীর-বিজ্ঞান':'NN','শরীর':'NN','শরীরটা':'NN','শরীরধারী':'JJ','শরীরবিজ্ঞান':'NN','শরীরহীন':'JJ',
'শরীরী':'NN','শরীরেও':'NN','শরীয়':'JJ','শরীয়া':'NN','শরু':'NN','শরুতেই':'NN','শরের':'NN',
'শর্করা':'NN','শর্ট':'NN','শর্টহ্যাণ্ডে':'NN','শর্ণচাপিলি':'NN','শর্ত':'NN','শর্তগুলিই':'NN','শর্তনামা':'NN',
'শর্তযুক্ত':'NN','শর্তহীন':'NN','শর্তাধীন':'NN','শর্তে':'NN','শর্তের':'NN','শর্বক':'NN','শর্ম-অল-শেখ':'NN',
'শর্মা':'NN','শর্মিলা':'NNP','শর্মিষ্ঠা':'NN','শর্যাতি':'NN','শর্ষে':'NN','শরৎকালটা':'NNP','শল':'NN',
'শলঙ্কু':'NN','শলণ্টক':'NN','শলভ':'NN','শলা':'NN','শলাকা':'NN','শলাথল':'NN','শলার':'NN',
'শলুকা':'NN','শলের':'NN','শল্ক':'NN','শল্য-চিকিত্সা':'NN','শল্য-শাস্ত্র':'NN','শল্য':'NN','শল্যকর্ম':'NN',
'শল্যক্রিয়া':'NN','শল্যচিকিতসক':'NN','শল্যচিকিত্সক':'JJ','শল্যচিকিত্সা':'NN','শল্যদা':'NN','শল্যশাস্ত্র':'NN','শল্যা':'NN',
'শশক':'NN','শশকর্ণ':'NN','শশধর':'NN','শশবিন্দু':'NN','শশভৃত':'NN','শশমৌলি':'NN','শশলক্ষণ':'NN',
'শশলাঞ্ছন':'NN','শশা':'NN','শশাঙ্ক':'NN','শশাঙ্কের':'NNP','শশাদ':'NN','শশি':'NN','শশিকলা':'NN',
'শশিদেব':'NN','শশিধ্বজ':'NN','শশিবদনা':'NN','শশিবাটিকা':'NN','শশিভূষণ':'NN','শশী':'NN','শশীখণ্ড':'NN',
'শশীভাগা':'NN','শশুরসহ':'NN','শস্ত':'JJ','শস্ত্র':'NN','শস্য':'NN','শস্যদানা':'NN','শস্যরাশি':'NN',
'শস্যশ্যামল':'NN','শস্যহীন':'JJ','শস্যাগাড়':'NN','শস্যের':'NN','শহমির':'NNP','শহর':'NN','শহরগুলো':'NN',
'শহরগুলোতে':'NNS','শহরগুলোতেও':'NN','শহরটিকে':'NN','শহরবাসী':'NN','শহরীকৃত':'JJ','শহরে':'NN','শহরের':'NN',
'শহিদ':'NN','শহিদুল':'NN','শহীদ':'NN','শহীদুল্লাহ':'NNP','শহীদের':'NN','শহুরে':'NN','শ়ৃঙ্খলা':'NN',
'শা-রুদ':'NNP','শা':'NNP','শাঁক':'NN','শাঁখটা':'NN','শাঁখারি':'NN','শাঁখের':'JJ','শাঁড়াষী':'NN',
'শাঁস':'NN','শাঁসালো':'JJ','শাংঘাই':'NN','শাওনের':'NN','শাওমি':'NN','শাক':'NN','শাকজীবি':'JJ',
'শাকদের':'NNP','শাকদ্বীপ':'NN','শাকবালেয়':'NN','শাকবীর':'NN','শাকভাত':'NN','শাকশ্রেষ্ঠা':'NN','শাকসবজির':'NN',
'শাকাষ্টমী':'NN','শাকাহার':'NN','শাকিনী':'NN','শাকিবকে':'NN','শাকীদা':'NNP','শাকে':'NN','শাক্ত':'NN',
'শাখা-প্রশাখা':'NN','শাখা-প্রশাখাযুক্ত':'JJ','শাখা':'NN','শাখাকন্ট':'NN','শাখাপিত্ত':'NN','শাখাপ্রশাখা':'NN','শাখামৃগ':'NN',
'শাখাযুক্ত':'JJ','শাখার':'NN','শাখাহীন':'JJ','শাখায়':'NN','শাগত':'JJ','শাঙ্কবাকার':'NN','শাঙ্খায়ন':'NN',
'শাঙ্খিক':'JJ','শাজাপুর':'NN','শাজাহান':'NN','শাটার':'NN','শাটিন':'NN','শাড়ি':'NN','শাণ-পাথর':'NN',
'শাণ':'NN','শাণিত':'JJ','শাণ্ডদূর্বা':'NN','শাণ্ডিলী':'NN','শাতিল-আরবের':'NNP','শাতে':'NN','শাত্যাযনি':'NN',
'শাদা':'JJ','শাদ্বল':'JJ','শাধিনতা':'NN','শান':'NN','শানানো':'VB','শানে':'NN','শানো':'NNV',
'শান্ডিল্য':'NN','শান্ত':'NN','শান্তকণ্ঠে':'RB','শান্তকে':'NN','শান্তনু':'NN','শান্তভাবে':'RB','শান্তর':'NN',
'শান্তশিষ্ট':'NN','শান্তা':'NN','শান্তি-প্রেমী':'JJ','শান্তি':'NN','শান্তিকামি':'NN','শান্তিকারী':'JJ','শান্তিতে':'NN',
'শান্তিদায়ক':'JJ','শান্তিদেব':'NNP','শান্তিদেবা':'NN','শান্তিনিকেতনে':'NNP','শান্তিপুরে':'NNP','শান্তিপূর্ণ':'NN','শান্তিপূর্ন':'NN',
'শান্তিপূর্বক':'RB','শান্তিপ্রদ':'JJ','শান্তিবাহিনী':'NN','শান্তিমত':'NN','শান্তিময়':'JJ','শান্তির':'NN','শান্তিশৃঙ্খলা':'NN',
'শাপ':'NN','শাপগ্রস্ত':'JJ','শাপভঙ্গ':'NN','শাপমুক্তি':'NN','শাপমোচন':'NN','শাপলা':'NN','শাপাম্বু':'NN',
'শাপেনাপিট':'NNP','শাফিন':'NN','শাবক':'NN','শাবনব':'NN','শাবর':'NN','শাবাশ':'NN','শাবিনার':'NNP',
'শাবিপ্রবি':'NN','শাবী':'JJ','শাব্দিক':'JJ','শামক':'NN','শামসুর':'NN','শামসের':'NNP','শামিম':'NN',
'শামিল':'VB','শামিয়ানা':'NN','শামীম':'NN','শামুক':'NN','শাম্ভবী':'NN','শায়':'NN','শায়েস্তা':'NN',
'শার':'NN','শারঙ্গপাণি':'NN','শারণী':'NN','শারথপর':'NN','শারদ':'NN','শারদপূর্ণিমা':'NN','শারদা':'NN',
'শারদীয়':'JJ','শারিরিক':'NN','শারীরকোপনিষদ':'NN','শারীরবৃত্তীয়':'JJ','শারীরিক':'JJ','শারীরিকধর্ম':'NN','শারীরিকভাবে':'RB',
'শারীরির':'JJ','শারে':'NN','শার্ট':'NN','শার্টল':'NNP','শার্টিং':'NN','শার্দুল-ললিত':'NN','শার্দুলকর্ণ':'NN',
'শার্দূল':'NN','শার্সির':'NN','শাল':'NN','শালকঙ্টকট':'NN','শালকরাগ':'NN','শালগম':'NN','শালঙ্কটাঙ্কট':'NN',
'শালঙ্কাযনজা':'NN','শালদোজ':'NN','শালপর্ণ':'NN','শালবদন':'NN','শালবাফ':'NN','শালবাহন':'NN','শালমজুরী':'NN',
'শালরস':'NN','শালশিল্পী':'NN','শালা':'NN','শালাক্যশাস্ত্র':'NN','শালাজ':'NN','শালাবতী':'NN','শালার':'NN',
'শালি':'NN','শালিগ্রাম':'NN','শালিধান':'NN','শালিপর্ণী':'NN','শালিবাহন':'NN','শালী':'JJ','শালীনতা':'NN',
'শালীনতাপূর্বক':'RB','শালু':'NN','শালুকিনী':'NN','শালের':'NN','শাল্ব':'NN','শাল্ম':'NN','শাল্মদ্বীপ':'NN',
'শাল্মলি':'NN','শাশন':'NN','শাশুড়ি':'NN','শাশুড়ির':'NN','শাশ্বত':'NN','শাশ্বতবাদী':'NN','শাশ্রূনয়নে':'NN',
'শাসক':'NN','শাসকগুলোও':'NN','শাসকগোষ্ঠীর':'NN','শাসকদলের':'NN','শাসকরা':'NN','শাসকীয়':'JJ','শাসকের':'NN',
'শাসন-তন্ত্র':'NN','শাসন':'NN','শাসনকর্তা':'NN','শাসনতন্ত্র':'NN','শাসননীতি':'NN','শাসনব্যবস্থার':'NN','শাসনভার':'NN',
'শাসনহীনতা':'NN','শাসনাধিকার':'NN','শাসনাধীনে':'NN','শাসনামলের':'NN','শাসানি':'NN','শাসালে':'NN','শাসিকা':'NN',
'শাসে':'NN','শাস্ত':'NN','শাস্তিই':'NN','শাস্তিযোগ্য':'NN','শাস্তির':'NN','শাস্ত্র-বিরুদ্ধ':'JJ','শাস্ত্র':'NN',
'শাস্ত্রগ্রন্থ':'NN','শাস্ত্রজ্ঞ':'NN','শাস্ত্রজ্ঞানহীন':'JJ','শাস্ত্রবিরুদ্ধ':'JJ','শাস্ত্রসমূহ':'NN','শাস্ত্রানুসারে':'JJ','শাস্ত্রার্থ':'NN',
'শাস্ত্রীর':'NN','শাস্ত্রীয়-নৃত্য':'NN','শাস্ত্রে':'NN','শাহ':'NN','শাহও':'NNP','শাহজাদা':'NN','শাহজানপুর':'NN',
'শাহজালাল':'NN','শাহজাহান':'NN','শাহজীরাজে':'NN','শাহদাত':'NN','শাহনশাহ':'NN','শাহনাজের':'NN','শাহনামা':'NNP',
'শাহবলুত':'NN','শাহবাগ':'NN','শাহবাজ':'NN','শাহবুলবুল':'NN','শাহমীর':'NNP','শাহরিয়ার':'NN','শাহাজান':'NN',
'শাহানা':'NN','শাহানাকান্হড়া':'NN','শাহারিয়ার':'NN','শাহী':'NN','শাহীন':'NN','শাহুতেলা':'NN','শাহের':'NNP',
'শাড়ি':'NN','শাড়ির':'NN','শাড়ী':'NN','শায়খ':'NN','শায়রী':'NN','শায়িত':'JJ','শায়ী':'JJ',
'শায়েস্তা':'NN','শিং':'NN','শিংবিহীন':'JJ','শিংযুক্ত':'JJ','শিউরে':'NN','শিওর':'NN','শিকঞ্জবীন':'NN',
'শিকরা':'NN','শিকল':'NN','শিকাকাই':'NN','শিকাগো':'NN','শিকাগোতে':'NNP','শিকার':'NN','শিকারও':'NN',
'শিকারি':'NN','শিকারে':'NN','শিক্কক':'NN','শিক্কা':'NN','শিক্কার্থীদের':'NN','শিক্রা':'NN','শিক্ষক-শিক্ষিকাগণের':'NN',
'শিক্ষক':'NN','শিক্ষকও':'NN','শিক্ষকগণের':'NN','শিক্ষকছাত্রদের':'NN','শিক্ষকট্রেনিং':'NN','শিক্ষকতটা':'NN','শিক্ষকতার':'NN',
'শিক্ষকরা':'NN','শিক্ষকেরা':'NN','শিক্ষণ':'NN','শিক্ষণের':'NN','শিক্ষা-দিক্ষা':'NN','শিক্ষা-ব্যবস্থা':'NN','শিক্ষা-শুল্ক':'NN',
'শিক্ষা':'NN','শিক্ষাও':'NN','শিক্ষাখাতকে':'NN','শিক্ষাখাতের':'NN','শিক্ষাগতা':'NN','শিক্ষাগুলো':'NN','শিক্ষাগ্রহণ':'NN',
'শিক্ষাঙ্গণগুলোকে':'NN','শিক্ষাটা':'NN','শিক্ষাদান':'NN','শিক্ষানবিশ':'NN','শিক্ষানুরাগী':'NN','শিক্ষাপ্রতিষ্ঠানগুলোতে':'NN','শিক্ষাপ্রতিষ্ঠানের':'NN',
'শিক্ষাবর্ষ':'NN','শিক্ষাব্যবস্থা':'NN','শিক্ষাব্যবস্থায়':'NN','শিক্ষামণ্ত্রীই':'NN','শিক্ষামন্ত্রীকে':'NN','শিক্ষামন্রীর':'NN','শিক্ষামূলক':'JJ',
'শিক্ষার':'NN','শিক্ষার্থিদের':'NN','শিক্ষার্থী':'NN','শিক্ষার্থীদের':'NN','শিক্ষার্থীর':'NN','শিক্ষার্ধীদেরও':'NN','শিক্ষালয়':'NN',
'শিক্ষায়':'NN','শিক্ষায়তনের':'NN','শিক্ষিকা':'NN','শিক্ষিতদের':'NN','শিকড়':'NN','শিখ':'NN','শিখছে':'VB',
'শিখছেভালো':'NN','শিখণ্ডিনী':'NN','শিখতে':'NN','শিখধর্ম':'NN','শিখধর্মাবলম্বী':'NN','শিখন্ডি':'NN','শিখন্ডী':'NN',
'শিখবে':'NN','শিখবো':'NN','শিখর':'NN','শিখরা':'NNS','শিখরিণী':'NN','শিখরে':'NN','শিখলো':'NN',
'শিখা-সুত্র':'NN','শিখা':'NN','শিখাধর্মাবলম্বী':'NN','শিখান':'NN','শিখাপিত্ত':'NN','শিখাবল':'NN','শিখার':'NN',
'শিখায়':'NN','শিখি':'NN','শিখিয়ে':'NN','শিখিয়েছিলেন':'VB','শিখী':'NN','শিখুন':'NN','শিখুনতাহলে':'NN',
'শিখে':'NNS','শিখেছি':'NN','শিখেছিআমি':'VBN','শিখেছিলাম':'NN','শিখেছে':'VBN','শিখেন':'NN','শিগগিরই':'NN',
'শিগ্রি':'NN','শিঘ্রই':'RB','শিঙ':'NN','শিঙবিহীন':'NN','শিঙ্গ':'JJ','শিজওয়া':'NN','শিটা':'NN',
'শিতা':'NN','শিতে':'NN','শিতোদ্রিকার্ণী':'NN','শিথিল':'NN','শিথিলীকরণ':'NN','শিদান্ত':'NN','শিন':'NN',
'শিপন':'NN','শিপ্র':'NN','শিফাতরু':'NN','শিব-কিঙ্কর':'NN','শিব-ডিয়োনিসাসের':'NNP','শিব-প্রতিমা':'NN','শিব-বিগ্রহ':'NN',
'শিব-মূর্তি':'NN','শিব':'NN','শিবকিঙ্কর':'NN','শিবগঙ্গা':'NN','শিবগণ':'NN','শিবগিরি':'NN','শিবজা':'NN',
'শিবধনু':'NN','শিবধাম':'NN','শিবনেত্র':'NN','শিবপুর':'NN','শিবপুরি':'NN','শিবপুরের':'NNP','শিবপূজা':'NN',
'শিবপ্রতিমা':'NN','শিববল্লিকা':'NN','শিববিগ্রহ':'NN','শিবভক্ত':'NN','শিবমূর্তি':'NN','শিবরাত্রি':'NN','শিবরাম':'NN',
'শিবলাল':'NNP','শিবলিংঙ্গ':'NN','শিবলিঙ্গটি':'NN','শিবলোক':'NN','শিবশৈল':'NN','শিবসাগর':'NN','শিবহর':'NN',
'শিবা':'NN','শিবানী':'NN','শিবালিক':'NN','শিবি':'NN','শিবির':'NN','শিবিরছাত্রদল':'NN','শিবিরে':'NN',
'শিবীরথ':'NN','শিবের':'NNP','শিবেষ্টা':'NN','শিম':'NN','শিমূল':'NN','শিম্পাঞ্জী':'NN','শিম্ব':'NN',
'শিয়াল':'NN','শিরওড়কর':'NN','শিরডী':'NN','শিরণাস্ত্র':'NN','শিরদাঁড়া':'NN','শিরনাম':'NN','শিরমোর':'NN',
'শিরশিরানি':'NN','শিরস্ত্রাণ':'NN','শিরা':'NN','শিরাউপশিরায়':'NN','শিরাপত্র':'NN','শিরাশিরা':'NN','শিরিগ্রহ':'NN',
'শিরিডী':'NN','শিরী':'NNP','শিরীষ':'NN','শিরুয়া':'NN','শিরোগ্রহ':'NN','শিরোণাস্ত্র':'NN','শিরোনাম':'NN',
'শিরোনামে':'NN','শিরোনামের':'NN','শিরোপা':'NN','শিরোপাবন্ধ্যাত্ব':'NN','শিরোমণি':'NN','শিরোরুজা':'NN','শিরোস্ত্র':'NN',
'শির্ডী':'NN','শির্ষভুষণ':'NN','শিল':'NN','শিলখড়ি':'NN','শিলচর':'NN','শিলন্ধর':'NN','শিলমোহর':'NN',
'শিলমোহরযুক্ত':'JJ','শিলা':'NN','শিলাখণ্ড':'NN','শিলাজতু':'NN','শিলাদিত্যের':'NN','শিলান্যাস':'NN','শিলাবতী':'NNP',
'শিলাভূমি':'NN','শিলার':'NN','শিলালেখ':'NN','শিলায়ুপ':'NN','শিলি':'NN','শিলিগুড়ি':'NN','শিলিঙ':'NN',
'শিলিন্দ':'NN','শিলীন্ধ্র':'NN','শিলু':'NN','শিলের':'NN','শিল্প-অর্থ-কর্পোরেশন':'NN','শিল্প-ব্যবসা':'NN','শিল্প':'NN',
'শিল্পউদ্যোক্তা':'NN','শিল্পকর্ম':'NN','শিল্পকলায়':'NN','শিল্পকার্য':'NN','শিল্পকৃতি':'NN','শিল্পকেও':'NN','শিল্পখাতের':'NN',
'শিল্পগুলি':'NN','শিল্পটিকেবিদেশী':'NN','শিল্পনগরীতে':'NN','শিল্পপতি':'NN','শিল্পপার্ক':'NN','শিল্পপোযোগিতা':'NN','শিল্পপ্রদর্শনী':'NN',
'শিল্পবাণিজ্যের':'NN','শিল্পবিজ্ঞান':'NN','শিল্পমন্ত্রীসহ':'NN','শিল্পমালিকেরা':'NN','শিল্পশাস্ত্র':'NN','শিল্পসংক্রান্ত':'NN','শিল্পসচেতন':'NN',
'শিল্পহীনতা':'NN','শিল্পাঞ্চল':'NN','শিল্পায়ন':'NN','শিল্পী-রূপে':'NN','শিল্পী-সত্তা':'NN','শিল্পী':'NN','শিল্পীগণ':'NN',
'শিল্পীদের':'NNS','শিল্পীবর্গ':'NN','শিল্পীর':'NN','শিল্পে':'NN','শিল্পের':'NN','শিল্পোদ্যোগ':'JJ','শিল্পোদ্যোগী':'NN',
'শিল্পোন্নত':'VBN','শিল্পোন্নয়ন':'NN','শিশা':'NN','শিশির':'NN','শিশিরা':'NN','শিশু':'NN','শিশুকে':'NN',
'শিশুগদি':'NN','শিশুটা':'NN','শিশুটির':'NN','শিশুতুল্য':'JJ','শিশুতোষ':'NN','শিশুথলিকা':'NN','শিশুদের':'NN',
'শিশুদেরকেও':'NNS','শিশুনাগ':'NN','শিশুপোযোগী':'JJ','শিশুভুলানো':'NNS','শিশুমন':'NN','শিশুর':'NN','শিশুরাও':'NNS',
'শিশুসুলভ':'JJ','শিশূরা':'NNS','শিশ্ন':'NN','শিষ্ট':'JJ','শিষ্টতা':'NN','শিষ্টতাপূর্বক':'RB','শিষ্টভাবে':'RB',
'শিষ্টমণ্ডল':'NN','শিষ্টাচার':'NN','শিষ্টাচারহীন':'JJ','শিষ্য-প্রশিষ্য':'NN','শিষ্য':'NN','শিষ্যদের':'NN','শিহরণ':'NN',
'শিহরিত':'VBN','শিহালা':'NN','শিয়রে':'NN','শিয়া':'NN','শিয়ালকোট':'NN','শিয়ে':'VB','শীকর':'NN',
'শীঘুগন্ধ':'NN','শীঘ্র':'RB','শীঘ্রই':'NN','শীঘ্রতঃ':'RB','শীঘ্রতা':'NN','শীত':'NN','শীতঋতু':'NN',
'শীতকালীন':'JJ','শীতজ্বর':'NN','শীততাপ':'VBG','শীতদূর্বা':'NN','শীতপকড়':'NN','শীতপিত্ত':'NN','শীতপুতনা':'NN',
'শীতপুষ্প':'NN','শীতবস্ত্র':'NN','শীতল':'NN','শীতলচিনি':'NN','শীতলতা':'NN','শীতলপাটি':'NN','শীতলা':'NN',
'শীতলার':'NNP','শীতলাষষ্ঠী':'NN','শীতলী':'NNP','শীতলীকরণ':'NN','শীতলীভবন':'NN','শীতাতপ':'JJ','শীতাতপনিয়ন্ত্রণের':'NN',
'শীতার্থদের':'NNS','শীতে':'NN','শীমা':'NN','শীরা':'NN','শীর্ণপত্র':'NN','শীর্ষ-বিন্দু':'NN','শীর্ষ':'NN',
'শীর্ষদেশের':'NN','শীর্ষবিন্দু':'NN','শীর্ষভাগ':'NN','শীর্ষস্থান':'NN','শীর্ষস্থানে':'NN','শীর্ষাংশ':'NN','শীল':'NN',
'শীলধন্যবাদ':'JJ','শীলন':'NN','শীলমোহর':'NN','শীলা':'NN','শীলী':'JJ','শীল্ড':'NNP','শীশম':'NN',
'শীষ':'NN','শীষের':'NN','শুঁকানো':'VB','শুঁকে':'NN','শুঁট':'NN','শুঁটি':'NN','শুঁড়':'NN',
'শুঁয়োপোকা':'NN','শুই':'VB','শুইয়ে':'JJ','শুক-রহস্য':'NN','শুক':'NN','শুককীট':'NN','শুকদেব':'NN',
'শুকদ্রুম':'NN','শুকনা':'NN','শুকনাশন':'NN','শুকনো':'NN','শুকবৃক্ষ':'NN','শুকরিয়া':'NN','শুকরী':'NN',
'শুকানো':'VBG','শুকায়ে':'NN','শুকে':'NNP','শুকোতে':'VB','শুক্তিপর্ণ':'NN','শুক্তিবীজ':'NN','শুক্র':'NN',
'শুক্রগ্রন্থি':'NN','শুক্রপুষ্প':'NN','শুক্রবার':'NN','শুক্রহীন':'JJ','শুক্রাচার্য':'NN','শুক্রাণু':'NN','শুক্রাশয়':'NN',
'শুক্রের':'NN','শুক্ল':'NN','শুক্লকন্দা':'NN','শুক্লকুষ্ঠ':'NN','শুক্লধ্বজ':'NNP','শুক্লপক্ষ':'NN','শুক্লমেহ':'NN',
'শুক্লাভিসারিকা':'NN','শুখদানি':'NN','শুখনো':'NN','শুঙ্গ':'NNP','শুচিকা':'NN','শুটার':'NN','শুটিং':'NN',
'শুণ্ড':'NN','শুণ্য':'NN','শুতে':'VB','শুদু':'RB','শুদ্ধ':'NN','শুদ্ধার্থে':'NN','শুদ্ধি':'NN',
'শুদ্ধিঅভিযান':'NN','শুদ্ধিকন্দ':'NN','শুদ্ধির':'NN','শুদ্ধোদন':'NN','শুধরাতে':'NN','শুধরে':'NNS','শুধিতে':'RB',
'শুধু':'RB','শুধুই':'NN','শুধুমাএ':'RB','শুধুহত্যাকারীদের':'NNS','শুধুৃ':'RB','শুধের':'NN','শুনক':'NN',
'শুনছ':'VB','শুনছি':'VBG','শুনছিলামএখন':'NNP','শুনছে':'VBG','শুনতাছি':'NN','শুনতাম':'NNS','শুনতে':'VB',
'শুনব':'VB','শুনবো':'NNS','শুনলাম':'NN','শুনলেই':'NN','শুনলেন':'VB','শুনা':'VB','শুনাইয়েন':'VB',
'শুনাচ্ছে':'NN','শুনানি':'NN','শুনানো':'VB','শুনার':'NN','শুনালেও':'NNS','শুনি':'VB','শুনিনি':'NN',
'শুনিসত্যি':'RB','শুনিয়া':'VB','শুনিয়ে':'VBG','শুনুন':'VB','শুনে':'VB','শুনেছি':'VB','শুনেছিলাম':'NN',
'শুনেছেন':'NNP','শুনেন':'VB','শুনেনএদেশকে':'NN','শুন্ঠি':'NN','শুন্ডল':'NN','শুন্যও':'NN','শুফল':'NN',
'শুবিধা':'NN','শুভ':'JJ','শুভংকরের':'NN','শুভকানমা':'NN','শুভকামনায়':'NN','শুভক্ষণ':'NN','শুভগ্রহ':'NN',
'শুভঙ্করী':'NN','শুভচিন্তক':'NN','শুভচিন্তাকারী':'JJ','শুভজন্ম':'NN','শুভদিন':'NN','শুভফল':'NN','শুভবুদ্ধির':'NN',
'শুভবোধের':'NN','শুভব্রত':'NN','শুভলক্ষ্মীর':'NNP','শুভসূচক':'JJ','শুভাকাঙ্খী':'NN','শুভেচছা':'NNS','শুভেচ্ছা':'NN',
'শুভেচ্ছেক':'JJ','শুভ্র':'NN','শুভ্রধারী':'JJ','শুমন':'NN','শুম্ভ':'NN','শুম্ভঘাতিনী':'NN','শুম্ভমর্দিনী':'NN',
'শুয়ে':'JJ','শুরভু':'NN','শুরভূমি':'NN','শুরসেন':'NN','শুরা':'NN','শুরু':'VBG','শুরুটা':'VBG',
'শুরুতে':'RB','শুরুতেআপনাদের':'VBG','শুরুতেই':'VBG','শুরুবোমা':'NN','শুরুর':'NN','শুল':'NN','শুলফা':'NN',
'শুল্ক':'NN','শুল্কমুক্ত':'JJ','শুল্কে':'NN','শুশ্রুষা':'NN','শুষ্ক':'NN','শুষ্কতা':'NN','শুষ্কস্তনবিশিষ্টা':'NN',
'শুষ্কার্দ্র':'NN','শুড়ি':'NN','শুয়ে':'JJ','শুয়োড়':'NN','শুয়োর':'NN','শুয়োরের':'NN','শূককীট':'NN',
'শূকনাস':'JJ','শূকফল':'NN','শূকর':'NN','শূকশিম্বিকা':'NN','শূণ্য':'NN','শূণ্যবাদ':'NN','শূণ্যমনস্কতা':'NN',
'শূণ্যে':'RB','শূণ‍্য':'NN','শূদ্র':'NN','শূদ্রপত্নী':'NN','শূদ্রা':'NN','শূদ্রী':'NN','শূনশান':'NN',
'শূন্য':'NN','শূন্যে':'NN','শূর':'NN','শূরবীর':'NN','শূরা':'NN','শূল':'NN','শূলহীন':'JJ',
'শূলে':'NN','শূশ্রূষার':'JJ','শৃংখলা':'NN','শৃংখলার':'NN','শৃগাল':'NN','শৃগালী':'NN','শৃঙ্ক':'NN',
'শৃঙ্খলযুক্ত':'JJ','শৃঙ্খলা':'NN','শৃঙ্খলাবদ্ধ':'JJ','শৃঙ্খলার':'NN','শৃঙ্খলাহীনতা':'NN','শৃঙ্খলিত':'VBN','শৃঙ্গ':'NN',
'শৃঙ্গযুক্ত':'JJ','শৃঙ্গহীন':'JJ','শৃঙ্গাটক':'NN','শৃঙ্গার':'NNP','শৃঙ্গারদান':'NN','শৃঙ্গী':'NN','শে':'PRP',
'শেওলা':'NN','শেকড়':'NN','শেকর':'NN','শেকলে':'NN','শেকসপিয়ার':'NN','শেকেল':'NN','শেক্সপীয়র':'NNP',
'শেক্সপীয়ার':'NN','শেকড়':'NN','শেখ':'NN','শেখদের':'NN','শেখপুরা':'NN','শেখা':'VB','শেখাও':'NN',
'শেখাচ্ছেন':'VBG','শেখাতে':'NN','শেখান':'VB','শেখানো':'NN','শেখানোর':'NNV','শেখার':'VBG','শেখায়':'NNS',
'শেখে':'NNS','শেখেন':'VB','শেঠ.':'NN','শেডিং':'VBG','শেণ্য':'NN','শেতে':'VB','শেন':'NN',
'শেফালি':'NN','শেফিল্ড':'NNP','শেবাগ':'NN','শের':'NN','শেরওয়ানি':'NN','শেরপুর':'NN','শেরশাহ':'NN',
'শেরাটন':'NN','শেরানিরাপত্তার':'NN','শেরে':'NN','শেলফের':'NN','শেষ':'NN','শেষকাজ':'NN','শেষকৃত্য':'NN',
'শেষঘোড়ার':'NN','শেষটায়':'NN','শেষণ':'NN','শেষত':'RB','শেষতক্‌':'NN','শেষদিন':'NN','শেষনাগ':'NN',
'শেষপাতের':'NN','শেষমেষ':'RB','শেষাংশে':'NN','শেষাচল':'NN','শেষার্ধ':'NN','শেষে':'VB','শেষের':'NN',
'শেষোক্ত':'JJ','শেস':'NN','শেহালা':'NN','শোডাউন':'NN','শোভনীয়':'NN','শোষনের':'NN','শেয়ার':'NN',
'শেয়ারগুলোর':'NNS','শেয়ারবাজার':'NN','শেয়ারবাজারেও':'NN','শেয়ারহোল্ডারদের':'NNS','শেয়ারে':'NN','শেয়ারের':'NNS','শেয়াল':'NN',
'শেয়ালটা':'NN','শৈক্ষিক':'JJ','শৈথিল্য':'NN','শৈব':'NN','শৈব্য':'NN','শৈলগঙ্গা':'NN','শৈলজা':'NN',
'শৈলপ্রাচীর':'NN','শৈলশিখা':'NN','শৈলসূতা':'NN','শৈলাদি':'NN','শৈলাধীপ':'NN','শৈলীতে':'NN','শৈলুষ':'NN',
'শৈলেন্দ্র':'NN','শৈল্পিক':'JJ','শৈল্য':'NN','শৈশব':'NN','শৈশির':'NN','শো':'NN','শোঁ-শোঁ':'NN',
'শোঁ':'IN','শোঁকা':'NN','শোও':'VB','শোওয়ানো':'JJ','শোক':'VBG','শোকগ্রস্ত':'JJ','শোকজ':'NN',
'শোকপূর্ণ':'JJ','শোকমিছিলের':'NN','শোকরানা':'VBG','শোকহর':'NN','শোকহীনতা':'NN','শোকাকুল':'JJ','শোকান্তক':'JJ',
'শোকাহত':'NN','শোকে':'VBG','শোকেসএ':'NN','শোচনীয়':'JJ','শোট':'NN','শোণিত':'NN','শোণিতধৌত':'JJ',
'শোণিতপল':'NN','শোতে':'NN','শোথ':'NN','শোথরোগী':'JJ','শোধ':'NN','শোধক':'JJ','শোধণ':'NN',
'শোধরাতে':'NN','শোধরানোর':'NN','শোধিত':'NN','শোন':'VB','শোনানো':'NN','শোনালেন':'VB','শোনায়':'VB',
'শোনে':'VB','শোনেতার':'NN','শোনেন':'VB','শোন্':'VB','শোপিস':'NN','শোভন':'NN','শোভনীয়':'JJ',
'শোভা':'NN','শোভাযাত্রা':'NN','শোভিত':'VB','শোয়া':'NNV','শোরগোল':'NN','শোরুম':'NN','শোরে':'VB',
'শোলা':'NNP','শোলাপুর':'NN','শোষক':'NN','শোষণ-বঞ্চনা':'NN','শোষণ':'NN','শোষণমুক্ত':'JJ','শোষণের':'NN',
'শোষন':'NN','শোষিত':'NN','শোয়':'VB','শোয়া':'NN','শোয়ান':'NNV','শোয়ানো':'JJ','শোয়ার':'NN',
'শৌকি':'NN','শৌখিন':'NN','শৌচ':'NN','শৌচকর্ম':'NN','শৌচস্থান':'NN','শৌচাগার':'NN','শৌচালয়':'NN',
'শৌনক':'NN','শৌনেয়':'NN','শৌন্ড':'NN','শৌভিক':'NN','শৌর্য':'NN','শৌর্যবিহীন':'JJ','শৌর্যহীন':'NN',
'শৌলফা':'NN','শৌল্কায়নি':'NN','শ্বভ্র':'NN','শ্বশুড়':'NN','শ্বশুর':'NN','শ্বশুরবাড়ির':'NN','শ্বশুর্য':'NN',
'শ্বসন-তন্ত্র':'NN','শ্বসন':'NN','শ্বসনতন্ত্র':'NN','শ্বসনাঙ্গ':'NN','শ্বাপদ':'NN','শ্বাশুরি':'NN','শ্বাস-প্রশ্বাস':'NN',
'শ্বাস':'VBG','শ্বাসকষ্ট':'NN','শ্বাসনালী':'NN','শ্বাসপ্রশ্বাস':'NN','শ্বাসবিশিষ্ট':'JJ','শ্বাসরুদ্ধ':'NN','শ্বেত':'NN',
'শ্বেতকন্দা':'NN','শ্বেতকমল':'NN','শ্বেতকেতু':'NN','শ্বেতকোণিকা':'NN','শ্বেতগজ':'NN','শ্বেতচ্ছদ':'NN','শ্বেতদ্রীপ':'NN',
'শ্বেতধামা':'NN','শ্বেতনেত্র':'NN','শ্বেতপদ্ম':'NN','শ্বেতপাথর':'NN','শ্বেতপুষ্প':'NN','শ্বেতবাজী':'NN','শ্বেতলোধ্র':'NN',
'শ্বেতসার':'NN','শ্বেতসারযুক্ত':'JJ','শ্বেতহস্তি':'NN','শ্বেতা':'NN','শ্বেতাম্বর':'NNP','শ্বেতাশ্বতর':'NN','শ্বেতী':'NN',
'শ্বেতোত্পল':'NN','শ্মশান':'NN','শ্মশানঘাট':'NN','শ্মশ্রূ':'NN','শ্যাওলা':'NN','শ্যাওস্ব':'NN','শ্যাকসটন':'NNP',
'শ্যাম':'NN','শ্যামদেশ':'NNP','শ্যামনগর':'NN','শ্যামপুকুর':'NNP','শ্যামপূরবী':'NN','শ্যামবত্র্ম':'NN','শ্যামবর্ণা':'NNP',
'শ্যামবর্ত্ম':'NN','শ্যামমঞ্জরী':'NN','শ্যামল':'JJ','শ্যামলিমা':'NN','শ্যামা':'NN','শ্যামাসুন্দরী':'NNP','শ্যাম্পু':'NN',
'শ্যালক':'NN','শ্যেন':'NN','শ্যোনাক':'NN','শ্রদ্ধা':'NN','শ্রদ্ধাবান':'NN','শ্রদ্ধাবোদস্নেহশীল':'NN','শ্রদ্ধাভক্তি':'NN',
'শ্রদ্ধার':'NN','শ্রদ্ধেয়':'JJ','শ্রফল্ক':'NN','শ্রবণ':'VBG','শ্রবণদ্বাদশী':'NN','শ্রবণা':'NN','শ্রবণীয়':'JJ',
'শ্রবণেন্দ্রিয়':'NN','শ্রব্য':'JJ','শ্রম-বিভাগ':'NN','শ্রম':'NN','শ্রমজল':'NN','শ্রমজীবির':'NN','শ্রমণা':'NN',
'শ্রমবাজার':'NN','শ্রমবারি':'NN','শ্রমভিত্তিক':'JJ','শ্রমমন্ত্রী':'NN','শ্রমমান':'NN','শ্রমশক্তির':'NN','শ্রমসংগীতের':'NN',
'শ্রমিক':'NN','শ্রমিকই':'NNS','শ্রমিককে':'NN','শ্রমিকদের':'NNS','শ্রমিকপক্ষ':'NN','শ্রমিকভাইদের':'NNS','শ্রমিকরা':'NNS',
'শ্রমিকেদের':'NNS','শ্রমিকেরা':'NNS','শ্রমীক':'NNS','শ্রমীকের':'NNS','শ্রমে':'NN','শ্রমের':'NN','শ্রাদ্ধ.':'NN',
'শ্রাদ্ধকর্ম':'NN','শ্রান্ত':'JJ','শ্রান্তি':'NN','শ্রাবণ':'NN','শ্রাবণের':'VBG','শ্রাবস্তী':'NN','শ্রাব্য':'JJ',
'শ্রারামকৃষ্ণ':'NNP','শ্রী':'NN','শ্রীকাকুলম':'NN','শ্রীকৃষ্ণ':'NNP','শ্রীখন্ড':'NN','শ্রীগীতগোবিন্দম্':'NNP','শ্রীচক্র':'NN',
'শ্রীচূড়াকরণ':'NNP','শ্রীচৈতন্য':'NNP','শ্রীত্রিপুরসুন্দরীর':'NNP','শ্রীনগর':'NN','শ্রীনিবাস':'NN','শ্রীপঞ্চমীতেই':'NNP','শ্রীপুষ্প':'NN',
'শ্রীপ্রতাপ':'NNP','শ্রীফল':'NN','শ্রীবত্স':'NN','শ্রীবর্দ্ধন':'NN','শ্রীবল্লী':'NN','শ্রীবাস':'NN','শ্রীবিদ্যা':'NNP',
'শ্রীভান':'NN','শ্রীম':'NNP','শ্রীমঞ্জরী':'NN','শ্রীমতি':'NN','শ্রীমদভাগবত্পুরাণ':'NN','শ্রীমদ্ভগবদগীতা':'NN','শ্রীমান':'NN',
'শ্রীমুখ':'NNP','শ্রীময়ী':'JJ','শ্রীরমণ':'NN','শ্রীরমাকৃষ্ণ':'NNP','শ্রীরাগ':'NN','শ্রীরামকৃষ্ণ':'NNP','শ্রীরামকৃষ্ণলোকে':'NNP',
'শ্রীলংকা':'NN','শ্রীলংকাতে':'NN','শ্রীলংকার':'NN','শ্রীলঙ্কা':'NN','শ্রীলঙ্কাতে':'NNP','শ্রীলঙ্কান':'NN','শ্রীলঙ্কানরাও':'NNS',
'শ্রীলঙ্কাবাসী':'NN','শ্রীলঙ্কায়':'NN','শ্রীশ্রীজগদম্বাকে':'NNP','শ্রীশ্রীমায়ের':'NNP','শ্রীশ্রীরামকৃষ্ণ':'NNP','শ্রীসনাতন':'NNP','শ্রীসমাধ':'NN',
'শ্রীহরিকে':'NNP','শ্রীহরিকোটা':'NN','শ্রীহীন':'NN','শ্রুত':'JJ','শ্রুতকর্মা':'NN','শ্রুতবর্মা':'NN','শ্রুতবিদ':'NN',
'শ্রুতসেন':'NN','শ্রুতায়ু':'NN','শ্রুতিপ্রতিপাদ্য':'NN','শ্রুতিমধুর':'JJ','শ্রুতিরম্য':'JJ','শ্রুতিলিপি':'NN','শ্রুতিস্বরূপ':'NN',
'শ্রেণি':'NN','শ্রেণির':'NN','শ্রেণী-বিপ্লবের':'NN','শ্রেণী':'NN','শ্রেণীকে':'NN','শ্রেণীদের':'NN','শ্রেণীপ্রধান':'NN',
'শ্রেণীবিভাগ':'NN','শ্রেণীভুক্ত':'JJ','শ্রেণীর':'NN','শ্রেণীরকর্মকর্তা':'NN','শ্রেণীহীন':'JJ','শ্রেনিদের':'NN','শ্রেনী':'NN',
'শ্রেয়া':'NN','শ্রেষ্ঠ':'NN','শ্রেষ্ঠতম':'JJS','শ্রেষ্ঠতা':'NN','শ্রেষ্ঠত্য':'NN','শ্রেষ্ঠ্য':'JJS','শ্রেয়':'NN',
'শ্রেয়স্কর':'JJ','শ্রেয়াংসনাথ':'NN','শ্রোণি':'NN','শ্রোতব্য':'JJ','শ্রোতমূল':'NN','শ্রোতাদের':'NN','শ্রয়':'NN',
'শ্লথ':'NN','শ্লাঘনীয়':'JJ','শ্লাঘ্য':'JJ','শ্লিষ্ট':'NN','শ্লীপদ':'NN','শ্লীল':'JJ','শ্লেষ':'NN',
'শ্লেষযুক্ত':'JJ','শ্লেষা':'NN','শ্লেষাত্মক':'JJ','শ্লেষালঙ্কার':'NN','শ্লেষ্মা':'NN','শ্লেষ্মাগ্রন্থি':'NN','শ্লেষ্মাতক':'NN',
'শ্লেষ্মী':'NN','শ্লোক':'NNP','শ্লোগান':'NN','শয়':'NNP','শয়তান':'NN','শয়তানী':'JJ','শয়ন-কক্ষ':'NN',
'শয়ন':'NN','শয়নকক্ষ':'NN','শয়নকক্ষের':'NN','শয়ে':'JJ','ষ':'NN','ষটকর্ম':'NN','ষটকোণ':'JJ',
'ষটতিলা':'NN','ষটপদী':'JJ','ষট্রাগ':'NN','ষডযন্ত্রকারীদের':'NNS','ষডযন্ত্রমূলক':'JJ','ষড়জ':'NN','ষড়দর্শন':'NN',
'ষড়ভুজ':'NN','ষড়যন্ত্র':'NN','ষড়রস':'NN','ষড়ানন':'JJ','ষণ্ড':'NN','ষণ্ডা':'JJ','ষণ্ডামর্ক':'NN',
'ষতিগ্রস্ত':'VBN','ষরযন্ত্রকারী':'NN','ষষ্টকর্ণ':'NN','ষষ্টি':'NN','ষষ্ঠ':'NN','ষষ্ঠদশ':'JJ','ষষ্ঠবার':'NN',
'ষষ্ঠবাহী':'JJ','ষষ্ঠান':'NN','ষষ্ঠানকালে':'NN','ষষ্ঠী':'NN','ষাঁড়':'NN','ষাট':'NN','ষাটেক':'JJ',
'ষাটের':'NN','ষাড়ব':'NN','ষাণ্মাসিক':'JJ','ষুরকে':'NN','ষেপে':'NN','ষেরই':'NN','ষোলকলা':'NN',
'ষোড়শ':'JJ','ষোড়শী':'NN','ষোড়ষোপচার':'NN','ষোল':'NN','ষোলআনাই':'NN','ষোলকলা':'NNS','ষোলো':'NN',
'ষোলোতম':'JJ','ষোড়শ':'CD','ষোড়শী':'JJ','ষ্টিককে':'NN','ষ্টেটে':'NN','ষ্টেশন':'NN','ষড়দর্শনের':'NN',
'ষড়বর্গ':'NN','ষড়যন্ত্র':'NN','ষড়যন্ত্রকারীদের':'NN','ষড়যন্ত্রে':'NN','স':'NN','সঁপে':'VB','সং':'NN',
'সংকট':'NN','সংকটগ্রস্ত':'JJ','সংকটজনক':'JJ','সংকটপূর্ণ':'JJ','সংকটময়':'NN','সংকটাপন্ন':'NN','সংকটে':'NN',
'সংকটের':'NN','সংকরিত':'JJ','সংকরীকরণ':'NN','সংকর্ষণ':'NN','সংকলক':'NN','সংকলনের':'NN','সংকলিত':'NN',
'সংকল্প':'NN','সংকল্পা':'NN','সংকল্পিত':'JJ','সংকীর্ণ':'NN','সংকীর্তন':'NN','সংকুচিত':'VBN','সংকেত':'NN',
'সংকেতায়ন':'NN','সংকোচ':'VB','সংকোচক':'NN','সংকোচের':'NN','সংক্রন্ত':'NN','সংক্রমণ':'NN','সংক্রান্ত':'NN',
'সংক্রান্তির':'NN','সংক্রামক':'NN','সংক্রাম্যতন্ত্র':'NN','সংক্ষিপ্ত':'NN','সংক্ষিপ্ততা':'NN','সংক্ষেপ':'NN','সংখ্যক':'NNP',
'সংখ্যা':'NNS','সংখ্যাকে':'NN','সংখ্যাগরিষ্ঠ':'JJ','সংখ্যাগরিষ্ঠতার':'NN','সংখ্যাটা':'NNP','সংখ্যাটির':'NN','সংখ্যাতত্তবিদ':'NN',
'সংখ্যাত্মক':'JJ','সংখ্যার':'NNS','সংখ্যালঘিষ্ঠ':'JJ','সংখ্যালঘু':'NN','সংখ্যালঘুদের':'NNS','সংখ্যাশাস্ত্র':'NN','সংখ্যাসহ':'NNS',
'সংগঠক':'NN','সংগঠন':'NN','সংগঠনগুলোর':'NNS','সংগঠনটি':'NN','সংগঠনটির':'NN','সংগঠনবাদের':'NN','সংগঠনহীন':'JJ',
'সংগঠনে':'NN','সংগঠিত':'NN','সংগণক':'NN','সংগণকীকৃত':'JJ','সংগণন':'NN','সংগতিপূর্ণ':'JJ','সংগম':'NN',
'সংগরেড্ডী':'NN','সংগাটাও':'NN','সংগী':'NN','সংগীত-সাধক':'NN','সংগীত':'NN','সংগীতপ্রেমী':'JJ','সংগীতের':'NN',
'সংগে':'IN','সংগ্রহ':'NN','সংগ্রহণ':'NN','সংগ্রহণীয়':'JJ','সংগ্রহশালা':'NN','সংগ্রহী':'NN','সংগ্রহে':'VB',
'সংগ্রহের':'NN','সংগ্রাম':'NN','সংগ্রামিক':'JJ','সংগ্রামী':'NN','সংগ্রামের':'NN','সংঘ':'NN','সংঘটনকারী':'NN',
'সংঘটিত':'VBD','সংঘবদ্ধ':'VBN','সংঘমিত্রা':'NN','সংঘর্ষ':'NN','সংঘর্ষকারী':'JJ','সংঘর্ষণ':'NN','সংঘর্ষপূর্ণ':'JJ',
'সংঘর্ষময়':'JJ','সংঘর্ষে':'NN','সংঘষরএর':'NN','সংঘাত':'NN','সংঘীয়':'NN','সংঘের':'NN','সংঙ্গা':'NN',
'সংজ্ঞা':'NN','সংজ্ঞাযুক্ত':'JJ','সংজ্ঞার':'NN','সংজ্ঞাশূণ্য':'JJ','সংজ্ঞাশূণ্যতা':'NN','সংজ্ঞাহীন':'JJ','সংঞ্চালন':'NN',
'সংপৃক্ত':'VBN','সংবত':'NN','সংবদ্ধ':'VBN','সংবরণ':'NN','সংবর্ত্তক':'NN','সংবর্ধনা':'NN','সংবর্ধনার':'NN',
'সংবর্ধনীয়':'JJ','সংবলিত':'NN','সংবহন':'NN','সংবহনতন্ত্র':'NN','সংবাদ':'NN','সংবাদগুলো':'NNS','সংবাদটা':'NNS',
'সংবাদদাতা':'NN','সংবাদপত্র':'NN','সংবাদপত্রের':'JJ','সংবাদবাহক':'NN','সংবাদী':'JJ','সংবাদে':'NN','সংবাহিনী':'NN',
'সংবিধাণ':'NN','সংবিধানকে':'NN','সংবিধানতারা':'NNS','সংবিধানপরিপন্থী':'NN','সংবিধানসংবিধানে':'NN','সংবিধানসম্মত':'NN','সংবিধানে':'NN',
'সংবিধাম':'NN','সংবিধিবদ্ধ':'NN','সংবৃত':'NN','সংবৃদ্ধি':'NN','সংবেদন':'NN','সংবেদনশীলতা':'NN','সংবেদনহর':'JJ',
'সংবেদনা':'NN','সংমিশ্রণ':'NN','সংযত':'NN','সংযমশীল':'JJ','সংযমিত':'JJ','সংযমী':'NN','সংযুক্ত':'VBN',
'সংযুক্তি':'NN','সংযোগ':'NN','সংযোগকারী':'JJ','সংযোগস্থল':'NN','সংযোগের':'NN','সংযোজক':'NN','সংযোজনের':'NN',
'সংযোজিত':'NN','সংরক্ষক':'NN','সংরক্ষণাগার':'NN','সংরক্ষন':'VB','সংরক্ষননির্দিষ্ট':'NN','সংরক্ষিত':'NN','সংরচনা':'VB',
'সংরচিত':'JJ','সংরিক্ষত':'NN','সংর্বধনা':'NN','সংলগ্ন-পত্র':'NN','সংলগ্ন':'JJ','সংলগ্নক':'NN','সংলাপ':'NN',
'সংলাপের':'NN','সংশোধক':'NN','সংশোধন':'NN','সংশোধনের':'NN','সংশোধিত':'JJ','সংশ্রয়':'NN','সংশ্লিষ্ট':'NN',
'সংশ্লিষ্টদের':'JJ','সংশ্লিষ্টরা':'NN','সংশ্লিস্ট':'JJ','সংশ্লেষ':'NN','সংশয়':'NN','সংশয়জনক':'JJ','সংশয়শীল':'JJ',
'সংশয়হীন':'NN','সংশয়াত্মক':'JJ','সংশয়ী':'JJ','সংশয়ে':'NN','সংশয়োপোমা':'NN','সংষ্করনে':'NN','সংসদ':'NN',
'সংসদীয়':'NN','সংসদের':'NN','সংসর্গ':'NN','সংসারজীবন':'NN','সংসারজ্ঞানের':'NN','সংসারিক':'JJ','সংসারী':'NN',
'সংসারীরা':'NNS','সংসারে':'NN','সংসারের':'NN','সংসিদ্ধ':'JJ','সংসৃষ্ট':'NN','সংস্করণ':'NN','সংস্করণে':'NN',
'সংস্কার':'NN','সংস্কারবদ্ধ':'JJ','সংস্কারমূলক':'JJ','সংস্কারী':'NN','সংস্কারের':'NN','সংস্কৃত':'NN','সংস্কৃতি-সংক্রান্ত':'JJ',
'সংস্কৃতি':'NN','সংস্কৃতির':'NN','সংস্কৃতে':'NNP','সংস্কৃতের':'NN','সংস্ক্রিয়া':'NN','সংস্থা':'NN','সংস্থাকেও':'NN',
'সংস্থাগুলি':'NN','সংস্থাগুলো':'NNS','সংস্থাটি':'NN','সংস্থান':'NN','সংস্থানবিহীন':'JJ','সংস্থানের':'NNS','সংস্থাপক':'NN',
'সংস্থাপনায়':'NN','সংস্পর্শ':'NN','সংস্মরণ':'NN','সংস্লিষ্টদের':'JJ','সংস্হা':'NN','সংসয়':'NN','সংহতি':'NN',
'সংহনাদি':'NN','সংহার':'NN','সং্খালঘুরা':'NNS','সংয়ংসম্পূর্ণ':'JJ','সই':'NN','সইছিলনা':'NN','সইটি':'NN',
'সইতে':'NN','সইবনাভীরুর':'NN','সইবার':'NN','সইবে':'NN','সইহা':'NN','সঈ':'NN','সউদি':'NN',
'সউদীকে':'NN','সওগাতের':'NN','সওদা':'NN','সওয়া':'NN','সওয়াড়ি':'NN','সওয়ার':'NN','সওয়ারী':'NN',
'সওয়াসন':'NN','সকয়':'NN','সকরা':'PR','সকর্মক':'NN','সকল':'DT','সকলই':'NN','সকলও':'PR',
'সকলকে':'NN','সকলেই':'NN','সকলেরই':'PR','সকাম':'NN','সকাল':'VBG','সকালে':'NN','সকাল–বিকাল':'NN',
'সকেই':'PR','সক্কমতায়':'NN','সক্তু':'NN','সক্রমিত':'NN','সক্রিয়':'JJ','সক্রিয়তা':'NN','সক্রেটিসকে':'NN',
'সক্ষম':'NN','সখনও':'RB','সখপ্রদ':'JJ','সখর':'NN','সখা':'NN','সখাহীন':'JJ','সখী':'NN',
'সখীদের':'NN','সখীভাব':'NN','সখীর':'NN','সগউরবে':'NN','সগণ':'NN','সগর':'NNP','সগর্বে':'RB',
'সগুণ':'NN','সগুনৌতী':'NN','সগোত্রী':'JJ','সগোত্রীয়':'NN','সগৌরবে':'NN','সগড়িয়ান':'JJ','সঘন':'NN',
'সঙ':'NN','সঙ্কট-কাল':'NN','সঙ্কটকালে':'NN','সঙ্কটজনক':'JJ','সঙ্কটটাই':'NN','সঙ্কটনাশক':'JJ','সঙ্কটপূর্ণ':'JJ',
'সঙ্কটমোচনকারী':'JJ','সঙ্কর-সমাস':'NN','সঙ্কল্পপূর্বক':'RB','সঙ্কীর্ণ':'JJ','সঙ্কুচিত':'VB','সঙ্কেত':'NN','সঙ্কোচনের':'NN',
'সঙ্কোচহীন':'RB','সঙ্গ':'IN','সঙ্গকালে':'NN','সঙ্গকুপি':'NN','সঙ্গঠনগুলো':'NN','সঙ্গঠনটা':'NN','সঙ্গত':'NN',
'সঙ্গতি':'NN','সঙ্গদোষ':'NN','সঙ্গবসরি':'NN','সঙ্গম':'NN','সঙ্গরুর':'NN','সঙ্গসার':'NN','সঙ্গসুলেমানি':'NN',
'সঙ্গা-শব':'NN','সঙ্গি':'NN','সঙ্গিনী':'NN','সঙ্গীটির':'NN','সঙ্গীত':'JJ','সঙ্গীতকার':'NN','সঙ্গীতজীবন':'NN',
'সঙ্গীতময়':'JJ','সঙ্গীতানুষ্ঠান':'NN','সঙ্গীদের':'NN','সঙ্গীনী':'NN','সঙ্গে':'RB','সঙ্গেই':'NN','সঙ্গেও':'PSP',
'সঙ্গের':'NN','সঙ্ঘ':'NN','সঙ্ঘীয়':'NN','সঙ্ঘেরা':'NN','সচতুরভাবে':'NN','সচল':'VBG','সচারাচার':'NN',
'সচিব':'NN','সচিবদের':'NNS','সচিবরা':'NN','সচিবসংক্রান্ত':'JJ','সচিবালয়':'NN','সচিবালয়ের':'NN','সচিবের':'JJ',
'সচীনকে':'NN','সচীবালয়':'NN','সচেতন':'NN','সচেতনতার':'NN','সচেনতামূলক':'NN','সচেষ্ট':'NN','সচ্চরিত্র':'JJ',
'সচ্চরিত্রতা':'NN','সচ্চরিত্রা':'JJ','সচ্চিদানন্দ':'NN','সচ্ছ':'NN','সছিদ্র':'JJ','সছিল':'VB','সছেন':'VB',
'সজন':'NN','সজনে':'NN','সজল':'RB','সজাগ':'NN','সজাতি':'NN','সজারুর':'NN','সজীব':'NN',
'সজুতা':'NN','সজ্জন':'NN','সজ্জাকার':'NN','সজ্জিত':'NN','সজ্ঞা':'NN','সজ্ঞাহীন':'NN','সঞ্চরণ':'NN',
'সঞ্চরণশীল':'JJ','সঞ্চার':'NN','সঞ্চারিত':'JJ','সঞ্চারী':'NN','সঞ্চালক-মণ্ড':'NN','সঞ্চালন':'NN','সঞ্চালিত':'NN',
'সঞ্চয়':'NN','সঞ্চয়পত্রওয়ালাদের':'NN','সঞ্চয়পত্রের':'NN','সঞ্জয়':'NN','সঞ্জাও':'NN','সঞ্জাত':'JJ','সঞ্জাহরণ':'NN',
'সঞ্জিত':'NN','সঞ্জীব':'NN','সঞ্জীবনী':'NN','সঞ্জয়':'NN','সটকে':'VB','সটিস':'NNP','সঠিক':'NN',
'সঠিকভাবে':'RB','সঠীক':'NN','সড়ক':'NN','সড়ষে':'NN','সণ্চার':'NN','সত':'NN','সতজ্বর':'NN',
'সততা':'NN','সতবাহিনী':'NN','সতবৃত্তি':'NN','সতভেয়া':'NN','সতর্ক':'NN','সতর্কতামুলক':'NN','সতর্কবাণী':'NN',
'সতানন্দ':'NN','সতাম':'NN','সতারুক':'NN','সতিত':'NN','সতিবন':'NN','সতির':'NN','সতি্য':'NN',
'সতী':'NN','সতীত্ব':'NN','সতীদাহের':'NN','সতীন':'NN','সতীর্থ':'NN','সতীশ':'NNP','সতীশচন্দ্র':'NNP',
'সতীসাবিত্রী':'NN','সতুর':'NNP','সতেই':'NN','সতেন':'VB','সতেরো':'NN','সত্':'NN','সত্কদম্ব':'NN',
'সত্কর্ম':'NN','সত্কার্য':'NN','সত্কৃতি':'NN','সত্ক্রিয়া':'NN','সত্গুণ':'NN','সত্তর-বাহাত্তর':'JJ','সত্তর':'NN',
'সত্তরতম':'JJ','সত্তা':'NN','সত্তাশূণ্য':'JJ','সত্তাহীনপদার্থ':'NN','সত্তিকার':'NN','সত্তেও':'NN','সত্ত্ব':'NN',
'সত্ত্বা':'NN','সত্ত্বাহীনতা':'NN','সত্ত্বেও':'NN','সত্পুরুষ':'NN','সত্ব':'NN','সত্য':'NN','সত্যকাম':'NN',
'সত্যকে':'NN','সত্যগুলিকে':'NN','সত্যগ্রহী':'NN','সত্যজিত':'NN','সত্যটা':'NN','সত্যতা':'NN','সত্যতার':'NN',
'সত্যনারায়ণ':'NN','সত্যনির্ভর':'NN','সত্যনিষ্ট':'JJ','সত্যনিষ্ঠা':'NN','সত্যবক্তা':'NN','সত্যবাদিতার':'NN','সত্যবাদিনী':'JJ',
'সত্যবাদী':'NN','সত্যব্রত':'NN','সত্যভামা':'NN','সত্যভাষিণী':'JJ','সত্যভাষী':'NN','সত্যমিথ্যা':'NN','সত্যযজ্ঞ':'NN',
'সত্যযুগ':'NN','সত্যযুগাদ্ধ্য':'NN','সত্যরক্ষার':'NN','সত্যসন্ধ':'NN','সত্যা':'NN','সত্যাগ্রহী':'JJ','সত্যাগ্রহে':'NN',
'সত্যাপন':'NN','সত্যাশ্রয়ী':'JJ','সত্যাসত্য':'NN','সত্যায়ু':'NN','সত্যি':'RB','সত্যিই':'NN','সত্যিও':'JJ',
'সত্যিকারভাবে':'NN','সত্যিতে':'NN','সত্যিসত্যিই':'RB','সত্যেন্দ্রনাথ':'NNP','সত্যের':'NN','সত্রাজিত':'NN','সত্রি':'JJ',
'সত্রীসেবন':'NN','সত্সঙ্গ':'NN','সত্সমাগম':'NN','সত‍্য':'NN','সথিত':'JJ','সদগতি':'NN','সদগুরু':'NN',
'সদঞ্জন':'NN','সদন':'NN','সদব্যবহার':'NN','সদর':'NN','সদরঘাটের':'NN','সদরে':'NN','সদর্থক':'JJ',
'সদস্য.':'NN','সদস্যগণ':'NN','সদস্যদের':'NN','সদস্যবৃন্দ':'NN','সদস্যরা':'NN','সদা':'RB','সদাচরণ':'NN',
'সদাচারিণী':'JJ','সদাবর্তী':'NN','সদাশোয়':'NN','সদাশয়':'JJ','সদাশয়তা':'NN','সদাসর্বদাই':'RB','সদাহাস্যমুখর':'NN',
'সদিচ্ছা':'NN','সদীয়':'JJ','সদুপদেশ':'NN','সদৃশ':'NN','সদৃশস্তে':'NN','সদের':'NN','সদ্':'NN',
'সদ্গতি':'VB','সদ্গুণসম্পন্ন':'JJ','সদ্গুরু':'NN','সদ্বংশজাত':'JJ','সদ্ব্যবহার':'NN','সদ্ভাব':'NN','সদ্য':'NN',
'সদ্যনির্মিত':'NN','সদ্যপ্রসবা':'JJ','সদ্যপ্রসুতা':'NN','সদ্যবিবাহিতা':'JJ','সদ্যোজাত':'JJ','সদ্যোজাতের':'NN','সদয়':'NN',
'সধবা':'NN','সধর্মিতা':'NN','সধর্মী':'JJ','সন':'NN','সনকাকে':'NNP','সনকে':'NNP','সনটি':'NN',
'সনতকুমার':'NN','সনদ':'NN','সনদধারী':'NN','সনদপত্র':'NN','সনদে':'NN','সনন্দন':'NN','সনসন':'VB',
'সনসেট':'NN','সনাক্ত':'NN','সনাক্তকরণের':'NN','সনাতন':'NN','সনাতনধর্মী':'NN','সনাতনপন্থী':'NN','সনাতনপন্হী':'JJ',
'সনাতনী':'NN','সনাথ':'JJ','সনিক':'JJ','সনিসিক্স':'NN','সনে':'NN','সনের':'NN','সন্এাসী':'NN',
'সন্চয়':'NN','সন্ত':'NN','সন্ততিদেরকে':'NN','সন্ততিহোম':'NN','সন্তরণ':'NN','সন্তষ্ট':'NN','সন্তাতান':'NN',
'সন্তানকে':'NN','সন্তানদের':'NN','সন্তানরা':'NN','সন্তানসুখ':'NN','সন্তানহীন':'JJ','সন্তানের':'NN','সন্তাপ':'NN',
'সন্তু':'NN','সন্তুষ্টর':'JJ','সন্তুষ্টি':'NN','সন্তুষ্টির':'NN','সন্তোষ':'NN','সন্তোষদায়ক':'JJ','সন্তোষপ্রদ':'JJ',
'সন্ত্রসীরা':'NN','সন্ত্রস্ত':'NNP','সন্ত্রাস':'NN','সন্ত্রাসপেট্রোল':'NN','সন্ত্রাসবাদ':'NN','সন্ত্রাসমূলক':'JJ','সন্ত্রাসসর্বস্ব':'NN',
'সন্ত্রাসি':'NN','সন্ত্রাসী':'NN','সন্ত্রাসীদের':'NN','সন্ত্রাসীরা':'NN','সন্ত্রাসেরও':'NN','সন্দংশ':'NN','সন্দর্ভ':'NN',
'সন্দিগ্ধ':'JJ','সন্দিগ্ধতা':'NN','সন্দিহান':'JJ','সন্দীপ':'NN','সন্দীপনী':'NN','সন্দেরশা':'NN','সন্দেশবাহক':'NN',
'সন্দেহজনক':'NN','সন্দেহপূর্ণ':'JJ','সন্দেহপ্রবণ':'NN','সন্দেহবাতিক':'NN','সন্দেহভাজন':'NN','সন্দেহমূলক':'NN','সন্দেহহীন':'NN',
'সন্দেহাতীত':'JJ','সন্দেহে':'RB','সন্দেহের':'NN','সন্ধ':'NN','সন্ধানও':'NN','সন্ধানী':'NN','সন্ধানে':'NN',
'সন্ধায়':'NN','সন্ধিত':'JJ','সন্ধিতন্ত্র':'NN','সন্ধিপাদ':'NN','সন্ধিবন্ধনী':'NN','সন্ধিবিচ্ছেদ':'NN','সন্ধিস্হল':'NN',
'সন্ধে':'NN','সন্ধ্যা':'NN','সন্ধ্যাকালে':'NN','সন্ধ্যাবেলা':'NN','সন্ধ্যামণি':'NN','সন্ধ্যার':'NN','সন্ধ্যে':'NN',
'সন্ধ্যোপাসনা':'NN','সন্ন':'JJ','সন্নত':'NN','সন্নাদন':'NN','সন্নিকট':'JJ','সন্নিকটে':'RB','সন্নিপাত':'NN',
'সন্নিহিত':'JJ','সন্ন্যাস':'NN','সন্ন্যাসিনী':'NN','সন্ন্যাসীর':'NN','সন্মত':'NN','সন্মাননা':'NN','সন্মানীত':'NN',
'সন্মেলনে':'NN','সন্যাস':'NN','সন্যাসীদের':'NN','সন্যাসোপনিষদ':'NN','সপ':'NN','সপত্নজিত':'NN','সপত্নীক':'RB',
'সপরিবারে':'NN','সপসপে':'JJ','সপিং':'NN','সপ্ত-সত্গুণ':'NN','সপ্ত':'NN','সপ্তকের':'NN','সপ্তগুণ':'NN',
'সপ্তদশ':'JJ','সপ্তপত্র':'NN','সপ্তপদী':'NN','সপ্তপর্ণ':'NN','সপ্তপ্রকৃতি':'NN','সপ্তপ্রণী':'NN','সপ্তবিংশ-ত্রিংশ':'CD',
'সপ্তম':'NN','সপ্তমুষ্টিক':'NN','সপ্তর্ষি':'NN','সপ্তশতী':'NN','সপ্তস্পর্ধা':'NN','সপ্তাহ':'NN','সপ্তাহে':'NN',
'সপ্ন':'NN','সপ্রতিভ':'JJ','সপ্রযজ্ঞ':'NN','সফটওয়ার':'NN','সফটওয়ার':'NN','সফটওয়্যার':'NN','সফদার':'NN',
'সফরকারী':'NN','সফরটা':'NN','সফরি':'NN','সফরের':'NN','সফল':'NN','সফলকাম':'NN','সফলতার':'NN',
'সফলভাবে':'NN','সফলা-একাদশী':'NN','সফলা':'NN','সফুল':'JJ','সফেদ':'NN','সফেদপলকা':'NN','সফ্ট':'NN',
'সফ্টওয়ার':'NN','সব':'NN','সবংশ':'NN','সবই':'NN','সবক':'NN','সবকার্য':'NN','সবকিছরই':'PR',
'সবকিছু':'NN','সবকিছুকে':'PR','সবকিছুতে':'NN','সবকিছুর':'NN','সবকে':'PR','সবখানে':'NN','সবগুলি':'NN',
'সবগুলিই':'PR','সবগুলিকে':'NN','সবগুলো':'NN','সবগুলোকে':'NN','সবচাইতে':'NN','সবচেয়ে':'NN','সবচেয়ে':'JJS',
'সবজান্তা':'NN','সবজায়গাতেই':'NN','সবজি':'NN','সবজিনিসের':'NN','সবটা':'CD','সবটিকে':'NN','সবটুকু':'NN',
'সবতী':'JJ','সবতুমি':'NN','সবতো':'NN','সবথেকে':'NN','সবদেশেই':'NN','সবন':'NN','সববিষয়ে':'NN',
'সবমিলিয়ে':'NN','সবরমতী':'NN','সবল':'NN','সবলের':'NN','সবসময়':'NN','সবসময়':'RB','সবসময়ই':'NN',
'সবসময়ের':'NNS','সবা':'NN','সবাইকে':'NN','সবাইকেআমাদের':'NN','সবাইকেই':'NN','সবাইতো':'NN','সবাইভাবছো':'NN',
'সবাইরে':'NN','সবাইয়ের':'PR','সবাক':'JJ','সবাদ':'NN','সবারই':'NN','সবাস':'PR','সবাার':'NN',
'সবায়':'NN','সবিনয়':'RB','সবিশেষ':'JJ','সবিস্তারে':'RB','সবুজ':'JJ','সবুজপত্র':'NN','সবুর':'VB',
'সবে-সবে':'RB','সবে':'NN','সবেদা':'NN','সবেন':'VB','সবের':'NN','সবোধ':'NN','সব্জি':'NN',
'সব্জী':'NN','সব্বাই':'NN','সব্য':'NN','সব্যসাচী':'NN','সব‌চে‌য়ে':'NN','সভরে':'NN','সভা-মণ্ডপ':'NN',
'সভা':'NN','সভাকক্ষ':'NN','সভাগৃহ':'NN','সভাঘর':'NN','সভাতে':'VBG','সভাধ্যক্ষ':'NN','সভানিষ্কাশিত':'JJ',
'সভানেত্রীর':'NN','সভাপতি':'NN','সভাপতিত্বে':'NN','সভাপতির':'JJ','সভামণ্ডপ':'NN','সভায়':'NN','সভার':'NN',
'সভাসদ':'NN','সভাসমাবেশ':'NN','সভাসমিতির':'NN','সভাস্থল':'NN','সভায়':'NN','সভ্য':'NN','সভ্যতায়':'NN',
'সভ্যদের':'NN','সম':'NN','সমকক্ষ':'NN','সমকামী':'NN','সমকালীন':'RB','সমকালীনতা':'NN','সমকোণ':'NN',
'সমক্ষ':'RB','সমগোত্রীয়':'JJ','সমগ্রীকৃত':'JJ','সমজাতি':'NN','সমজোতার':'NN','সমঝদার':'NN','সমঝোতা':'NN',
'সমণি':'NN','সমতল':'JJ','সমতলাবতল':'JJ','সমতলীয়':'JJ','সমতলোত্তল':'JJ','সমতা':'NN','সমতাপী':'JJ',
'সমতাবাদ':'NN','সমতাল':'NN','সমতির':'NN','সমতুল্য':'NN','সমথন':'NN','সমদর্শী':'JJ','সমদৃষ্টি':'NN',
'সমদ্বিবাহু':'JJ','সমধিক':'JJ','সমন':'NN','সমনার্থক':'NN','সমন্তদুগ্ধ':'NN','সমন্ধে':'NN','সমন্বিত':'JJ',
'সমন্বয়':'NN','সমন্বয়কৃত':'NN','সমন্বয়বাদী':'NN','সমপরিমাণ':'NN','সমপর্যায়':'NN','সমপর্যায়ের':'NN','সমপ্তি':'NN',
'সমবংশীয়':'JJ','সমবন্টন':'NN','সমবর্গীয়':'JJ','সমবর্তিত':'JJ','সমবাদীর':'NN','সমবাহু':'JJ','সমবায়':'NN',
'সমবেদনা':'NN','সমব্যাথী':'JJ','সমবয়সী':'JJ','সমভাবাপন্ন':'JJ','সমভুমি':'NN','সমভূজ':'NN','সমভূমির':'NN',
'সমমনা':'NN','সমমর্যাদার':'NN','সমমান':'NN','সমমানের':'NN','সময়':'NN','সময়টা':'NN','সময়ের':'NN',
'সমর':'NN','সমরবেহিস্ত':'NN','সমরূপ':'RB','সমরূপতা':'NN','সমরূপসম্পন্ন':'VB','সমরূপী':'JJ','সমরে':'NN',
'সমর্থ':'NN','সমর্থকগোষ্ঠী':'NN','সমর্থকদের':'NN','সমর্থকপুষ্ট':'NN','সমর্থকরা':'NNS','সমর্থকেরা':'NN','সমর্থন':'NN',
'সমর্থনে':'NN','সমর্থিত':'JJ','সমর্পণ':'NN','সমর্পিত':'VBN','সমলগ্ন':'NN','সমলচনা':'NN','সমশীর্ষ':'JJ',
'সমষ্টি':'NN','সমষ্টিগত':'NN','সমসংখ্যা':'NN','সমসতো':'DT','সমসাময়িক':'JJ','সমসুযোগ–সুবিধা':'NN','সমস্ত':'NN',
'সমস্থল':'NN','সমস্থানিক':'NN','সমস্বরে':'NN','সমস্য':'NN','সমস্যাই':'NNS','সমস্যাগুগল':'NN','সমস্যাগুলো':'NNS',
'সমস্যাগ্রস্ত':'JJ','সমস্যাটা':'NN','সমস্যাটি':'NN','সমস্যাতো':'NNS','সমস্যাদি':'NN','সমস্যাবলীর':'NN','সমস্যায়':'NNS',
'সমস্যার':'NN','সমাগত':'JJ','সমাগম':'NN','সমাচার':'NN','সমাজ-নিরপেক্ষ':'NN','সমাজ':'NN','সমাজকেও':'NN',
'সমাজগত':'JJ','সমাজচেতনার':'NN','সমাজজীবনের':'NN','সমাজতন্ত্র':'NN','সমাজতন্ত্রকে':'NN','সমাজতন্ত্রী':'NN','সমাজতাত্ত্বিক':'NN',
'সমাজতান্ত্রিক':'JJ','সমাজবদ্ধ':'JJ','সমাজবাদ':'NN','সমাজবিজ্ঞান':'NNP','সমাজবিদ':'NN','সমাজব্যবস্থায়':'NN','সমাজভাষাবিজ্ঞান':'NNP',
'সমাজসংস্কারক':'NN','সমাজসেবক':'NN','সমাজসেবার':'NN','সমাজীকরণ':'NN','সমাজে':'NN','সমাডোহ':'NN','সমাদর':'NN',
'সমাদরপূর্বক':'RB','সমাদৃত':'JJ','সমাদ্দার':'NN','সমাধা':'NN','সমাধান':'NN','সমাধানগুলি':'NN','সমাধানযোগ্য':'JJ',
'সমাধানহীন':'JJ','সমাধানে':'NN','সমাধানের':'NN','সমাধি-স্থল':'NN','সমাধি':'NN','সমাধিত':'JJ','সমাধিতে':'NN',
'সমাধিবেষ্টনে':'NN','সমাধিমগ্ন':'JJ','সমাধিস্থ':'NN','সমান':'NN','সমানভাবে':'RB','সমানাধিকরণ':'NN','সমানাভিহরাত্':'JJ',
'সমানুপাত':'NN','সমানুপাতিক':'JJ','সমানে':'NN','সমান্তরাল':'RB','সমান্তরালে':'NN','সমাপন':'NN','সমাপনীয়':'JJ',
'সমাপনের':'NN','সমাপ্ত':'VBN','সমাপ্তি':'NN','সমাপ্তের':'VBN','সমাপ্য':'JJ','সমাবর্তন':'NN','সমাবিষ্ট':'NN',
'সমাবেশ':'NN','সমাবেশে':'RB','সমাবেষ্টিত':'JJ','সমারোহ':'NN','সমার্থক':'NN','সমালোচনা':'NN','সমালোচক':'NN',
'সমালোচকবৃন্দগণ':'NN','সমালোচকেরা':'NN','সমালোচনার':'NN','সমাস':'NN','সমাসীকরণ':'NN','সমাহারে':'NN','সমাহিত':'JJ',
'সমিক':'NN','সমিচী':'NN','সমিতি':'NN','সমিতির':'NN','সমিত্র':'JJ','সমিধ':'NN','সমীকরণ':'NN',
'সমীকরণে':'NN','সমীক্ষক':'NN','সমীচীন':'NN','সমীপগমন':'NN','সমীপতা':'NN','সমীপবর্তী':'JJ','সমীপস্থ':'JJ',
'সমীপাগত':'JJ','সমীপে':'NN','সমীপের':'JJ','সমীর':'NN','সমুচিত':'JJ','সমুদায়':'NN','সমুদ্র-ফল':'NN',
'সমুদ্রকাক':'NN','সমুদ্রগামী':'JJ','সমুদ্রজাত':'JJ','সমুদ্রতরঙ্গ':'NN','সমুদ্রফল':'NN','সমুদ্রসৈকত':'NN','সমুদ্রাগ্নি':'NN',
'সমুদ্রে':'NN','সমুন্দর-সোখ':'NN','সমুন্নত':'VBN','সমুন্নদ':'NN','সমুহ':'NN','সমূদয়':'NN','সমূলে':'NN',
'সমূহ':'NN','সমূহকে':'TO','সমূহের':'IN','সমৃতি':'NNS','সমৃতিতে':'NN','সমৃদ্ধ':'NN','সমৃদ্ধিদায়ক':'JJ',
'সমেত':'NN','সম্পতির':'NN','সম্পত্তিবাবদ':'NN','সম্পদ':'NN','সম্পদদেশের':'NN','সম্পদশালী':'JJ','সম্পদশালীদের':'NN',
'সম্পদে':'NN','সম্পদের':'NNS','সম্পন্ন':'NN','সম্পর্ক':'NN','সম্পর্কমূলক':'JJ','সম্পর্কযুক্ত':'NN','সম্পর্করহিত':'JJ',
'সম্পর্কস্থাপক':'JJ','সম্পর্কহীন':'JJ','সম্পর্কিত':'NN','সম্পর্কে':'RB','সম্পর্কেও':'IN','সম্পর্কের':'NNS','সম্পাতি':'NN',
'সম্পাদকমণ্ডলীর':'NN','সম্পাদকীয়':'NN','সম্পাদন':'NN','সম্পাদনর':'JJ','সম্পাদনা':'NN','সম্পাদনীয়':'JJ','সম্পাদিত':'VBN',
'সম্পুট':'NN','সম্পুর্ণ':'JJ','সম্পুর্ন':'NN','সম্পূট':'NN','সম্পূণ':'JJ','সম্পূরণ':'NN','সম্পূর্ণত':'RB',
'সম্পূর্ণতা':'NN','সম্পূর্ণভাবে':'RB','সম্পূর্ন':'JJ','সম্পূর্নরূপে':'RB','সম্পৃক্ততা':'NN','সম্প্রচার':'NN','সম্প্রতি':'RB',
'সম্প্রদান':'NN','সম্প্রদায়':'NN','সম্প্রদায়বাদী':'NN','সম্প্রদায়ে':'NNP','সম্প্রদায়ের':'NN','সম্প্রপাত':'NN','সম্প্রভুত্ব':'NN',
'সম্প্রসারণ':'NN','সম্প্রসারনের':'NN','সম্প্রসারিত':'JJ','সম্প্রাপ্তি-কাল':'NN','সম্প্রিতীর':'NN','সম্প্রেষণ':'NN','সম্প্রয়োগ':'NN',
'সম্বন্ধ':'NN','সম্বন্ধযুক্ত':'NN','সম্বন্ধা':'NN','সম্বন্ধায়':'JJ','সম্বন্ধী':'NN','সম্বন্ধে':'NN','সম্ববত':'RB',
'সম্বর':'NN','সম্বলপুর':'NN','সম্বলিত':'VBG','সম্বাদ':'NN','সম্বিত':'JJ','সম্বিৎ':'NN','সম্বোধক':'NN',
'সম্বোধনকারী':'NN','সম্বোধিত':'NN','সম্ভব':'NN','সম্ভবএছাড়া':'JJ','সম্ভবত':'RB','সম্ভবন':'NN','সম্ভবনাথ':'NN',
'সম্ভবপর':'JJ','সম্ভবের':'NN','সম্ভব্য':'JJ','সম্ভাজি':'NN','সম্ভাবত':'RB','সম্ভাবনা':'NN','সম্ভাবনাময়':'JJ',
'সম্ভাবনার':'NN','সম্ভাবনায়':'JJ','সম্ভাব্য':'RB','সম্ভাব্যতা':'NN','সম্ভার':'NN','সম্ভাষণ':'NN','সম্ভাষিত':'VB',
'সম্ভূতি':'NN','সম্ভোগ':'NN','সম্ভোগকারী':'JJ','সম্ভোগকারীদের':'NN','সম্ভোগে':'NN','সম্ভোহ':'NN','সম্ভ্যাব্য':'JJ',
'সম্ভ্রম':'NN','সম্ভ্রান্ত':'JJ','সম্ভৱ':'RB','সম্মত':'NN','সম্মতি-পত্র':'NN','সম্মতিটা':'NN','সম্মতিহীন':'JJ',
'সম্মান':'NN','সম্মানআভিজাত্য':'NN','সম্মানকে':'NN','সম্মানজনক':'JJ','সম্মানটাকে':'NN','সম্মানদক্ষিণা':'NN','সম্মানিত':'VBN',
'সম্মানী':'JJ','সম্মানীয়':'NN','সম্মানীয়া':'JJ','সম্মানে':'NN','সম্মানোত্সব':'NN','সম্মিলিত':'NN','সম্মিলীত':'JJ',
'সম্মিশ্রিত':'VB','সম্মুক্ষীন':'VBG','সম্মুখ':'RB','সম্মুখভাগে':'NN','সম্মুখস্ত':'JJ','সম্মুখাগত':'NN','সম্মুখে-পশ্চাতে':'NN',
'সম্মুখে':'RB','সম্মেলন':'NN','সম্মেলনের':'NN','সম্মোহন':'NN','সম্মোহনকারী':'JJ','সম্মোহনপূর্ণ':'JJ','সম্মোহনবিদ্যা':'NN',
'সম্মোহিত':'NN','সম্যক':'NN','সম্যগরক্ষিত':'JJ','সম্রাজ্ঞী':'NN','সম্রাজ্যবাদীরা':'NNS','সম্রাট':'NN','সময়':'NN',
'সময়ও':'NN','সময়কার':'NN','সময়কে':'NN','সময়টাতেই':'NN','সময়তালিকা':'NN','সময়তূর্য':'NN','সময়নির্ধারনকারী':'NN',
'সময়পোযগি':'NN','সময়মত':'NN','সময়লেখী':'NN','সময়সারণী':'NN','সময়সীমা':'NN','সময়সূচি':'NN','সময়াতিক্রান্ত':'JJ',
'সময়ানুকূল':'JJ','সময়ানুবর্তী':'JJ','সময়ানুসার':'NN','সময়ানুসারে':'RB','সময়াপযোগী':'RB','সময়াভাব':'NN','সময়ে-সময়ে':'RB',
'সময়ে':'NN','সময়েও':'NN','সময়োচিত':'JJ','সময়োপযোগী':'JJ','সম‌য়ের':'NN','সযত্ন':'NN','সযোগ':'NN',
'সর':'NNP','সরকর':'JJ','সরকরি':'NN','সরকারই':'NN','সরকারকে':'NN','সরকারকেও':'NN','সরকারগুলো':'NNS',
'সরকারতো':'NN','সরকারদলীয়':'NN','সরকারপন্থি':'NN','সরকারিদলকে':'NN','সরকারিভাবে':'RB','সরকারির':'NN','সরকারে':'NN',
'সরকারেরই':'NN','সরকারেরে':'NN','সরগম':'NN','সরগরম':'NN','সরগুজা':'NN','সরজুপারী':'NN','সরঞ্জাম':'NN',
'সরট':'NN','সরণ':'NN','সরদার':'NN','সরন':'NN','সরন্ধ্র':'JJ','সরফরাজ':'NN','সরব':'VB',
'সরবচ্চ':'NN','সরবত':'NN','সরবরাহ':'NN','সরবরাহের':'NN','সরবেন্দ':'NNP','সরবোচ্চ':'NN','সরবোন':'NNP',
'সরমা':'NN','সরযুক্ত':'JJ','সররুহ':'NN','সরল':'NN','সরলতম':'JJ','সরলতা':'NN','সরলতায়':'NN',
'সরলমনা':'VBN','সরলরেখার':'NN','সরলা':'NNP','সরলীকরণের':'NN','সরষে':'NN','সরস':'JJ','সরসতা':'NN',
'সরসর':'NN','সরস্বতী-রহস্য':'NN','সরস্বতী':'NN','সরা':'VB','সরাইওয়ালা':'NN','সরাইকেলা':'NN','সরাইক্ষকের':'NN',
'সরাইখানা':'NN','সরাইরক্ষকপনা':'NN','সরাইয়ের':'NN','সরাকার':'NN','সরাতে':'VB','সরান':'NN','সরানোর':'VB',
'সরাফ':'NN','সরালে':'NN','সরাসরি':'RB','সরায়ু':'NN','সরি':'NN','সরিক':'JJ','সরিত্শেখরকে':'NNP',
'সরিবন':'NN','সরিয়ে':'NN','সরিষা':'NN','সরিয়া':'VB','সরিয়ে':'VBN','সরীসৃপ':'NN','সরু':'NN',
'সরে':'NN','সরের':'NN','সরোজ':'NN','সরোজমুখী':'JJ','সরোদ':'NN','সরোদবাদক':'NN','সরোবর':'NN',
'সরোবরের':'NNP','সর্কল':'NN','সর্গ':'NN','সর্গপতালী':'NN','সর্গপুট':'NN','সর্গে':'NN','সর্তকতা':'NN',
'সর্দার':'NN','সর্দি':'NN','সর্প':'NN','সর্পগন্ধা':'NN','সর্পদংশন':'NN','সর্পদণ্ডী':'NN','সর্পদন্তা':'NN',
'সর্পভুক':'NN','সর্পরাজ':'NN','সর্পসুগন্ধা':'NN','সর্পহিংসক':'NN','সর্পাক্ষী':'NN','সর্পারি':'NN','সর্পাস্য':'NN',
'সর্পি':'NN','সর্পিল':'NN','সর্পিলা':'JJ','সর্পোন্মাদ':'NN','সর্ব-সার':'NN','সর্ব':'DT','সর্বংসহা':'JJ',
'সর্বকর্মপারদর্শী':'JJ','সর্বকালীন':'JJ','সর্বকালে':'RB','সর্বকালের':'NN','সর্বক্ষণ':'NN','সর্বগুণসম্পন্ন':'JJ','সর্বগুণান্বিত':'JJ',
'সর্বগ্রাস':'NN','সর্বচ্চো':'NN','সর্বজনগ্রাহ্য':'VBN','সর্বজনগ্রাহ্যতা':'NN','সর্বজনবিদিত':'NN','সর্বজনসম্মত':'JJ','সর্বজনীন':'NN',
'সর্বজ্ঞ':'JJ','সর্বজ্ঞতা':'NN','সর্বজ্ঞাতা':'JJ','সর্বতোমুখী':'JJ','সর্বত্যাগী':'JJ','সর্বত্র':'RB','সর্বথা':'RB',
'সর্বদক্ষিণে':'NN','সর্বদলীয়':'JJ','সর্বদা':'RB','সর্বদাই':'NNS','সর্বদার':'RB','সর্বদেশীয়':'JJ','সর্বনাম':'NN',
'সর্বনাশ':'NN','সর্বনাশটা':'NN','সর্বনাশী':'JJ','সর্বনিন্ম':'JJS','সর্বপ্রকার':'NN','সর্বপ্রথম':'RB','সর্বপ্রধান':'JJ',
'সর্বপ্রাণবাদী':'JJ','সর্বপ্রিয়':'JJ','সর্ববিত্':'JJ','সর্ববিদ্যমান':'JJ','সর্ববৃহত্':'JJ','সর্ববৃহৎ':'JJS','সর্বব্যপী':'JJ',
'সর্বব্যাপিতা':'NN','সর্বব্যাপী':'JJ','সর্বভক্ষ্য':'JJ','সর্বভারত':'NN','সর্বভারতীয়':'JJ','সর্বভুক':'JJ','সর্বমঙ্গলা':'NN',
'সর্বমত':'NN','সর্বমান্য':'JJ','সর্বমোট':'NN','সর্বশক্তি':'NN','সর্বশক্তিশালী':'JJ','সর্বশান্ত':'NNP','সর্বশাস্ত্রে':'NN',
'সর্বশেষ':'NN','সর্বশেষে':'RB','সর্বশ্রেষ্ঠ':'NN','সর্বসমতা':'NN','সর্বসম্মত':'JJ','সর্বসম্মতি':'NN','সর্বসময়ের':'NN',
'সর্বসাকুল্যে':'NN','সর্বসাধারণকে':'NN','সর্বসাধারণের':'JJ','সর্বসার':'NN','সর্বস্তরে':'NNS','সর্বস্ব':'NN','সর্বহারা':'NN',
'সর্বাঙ্গ':'NN','সর্বাঙ্গিক':'JJ','সর্বাঙ্গে':'NN','সর্বাত্মক':'JJ','সর্বাধিক':'JJS','সর্বাধিকারী':'NN','সর্বাধুনিক':'JJ',
'সর্বাপরি':'NN','সর্বাপেক্ষা':'NN','সর্বাহারী':'JJ','সর্বেশ্বর':'JJ','সর্বেসর্বা':'NN','সর্বোচ্চ':'NN','সর্বোৎকৃষ্ট':'JJS',
'সর্বৈব':'NN','সর্বোচ্চ':'NN','সর্বোত্কৃষ্ট':'NN','সর্বোত্তম':'NN','সর্বোত্রই':'RB','সর্বোদয়':'NNP','সর্বোপরি':'RB',
'সর্ব্বোচ্চ':'NN','সর্মথন':'NN','সর্ম্পন্য':'NN','সর্ষপ':'NN','সর্ষের':'NN','সলজ্জভাবে':'RB','সলতে':'NN',
'সলতেবিশিষ্ট':'NN','সলপত্র':'NN','সলভিন':'NNP','সলমা':'NN','সলরমতি':'NN','সলাম':'NNP','সলিউশন':'NN',
'সলিম':'NN','সলিলকুন্তল':'NN','সলিলা':'NN','সলীম':'NN','সলুম':'VB','সলেই':'NN','সলেন':'VB',
'সলের':'NN','সলোমন':'NN','সল্ট':'NN','সশক্ত':'JJ','সশক্তিকরণ':'NN','সশব্দে':'NN','সশরীরী':'JJ',
'সশরীরে':'RB','সশস্ত্র':'JJ','সশুল্ক':'JJ','সশ্রদ্ধ':'RB','সশ্রম':'JJ','সষের':'NN','সসংগ্রাম':'NN',
'সসখ':'JJ','সসম্মান':'RB','সসার':'NN','সসীম':'JJ','সস্তা':'NN','সস্তার':'NNP','সস্তায়':'NN',
'সস্নেহ':'JJ','সস্বম্মানের':'RB','সহ-সমীকরণ':'NN','সহ':'VBG','সহঅধ্যক্ষ':'NN','সহকর্মী':'NN','সহকার':'NN',
'সহকারী':'NN','সহগমন':'NN','সহগামী':'NN','সহচর':'NN','সহজ':'NN','সহজতর':'JJR','সহজতা':'NN',
'সহজন্মা':'NN','সহজপ্রাপ্য':'NN','সহজবোধ্য':'JJ','সহজভাবে':'RB','সহজলভ্য':'NN','সহজস্য':'JJ','সহজাত':'JJ',
'সহজাতি':'NN','সহজে':'RB','সহডোল':'NN','সহদেই':'NN','সহদেবা':'NN','সহদেবের':'NNP','সহধর্মীনিও':'NN',
'সহন':'NN','সহনশীল':'NN','সহনশীলতার':'NN','সহনায়ক':'NN','সহনীয়':'JJ','সহপাঠী':'NN','সহবাস':'NN',
'সহভাগ':'NN','সহমত':'NN','সহমতদ':'JJ','সহমরণ':'NN','সহমর্মিতা':'NN','সহযাত্রী':'NN','সহযোগ':'NN',
'সহযোগিতা':'NN','সহযোগিতায়':'NN','সহযোগী':'NN','সহযোগীতা':'NN','সহযোগীদের':'NNS','সহযোগে':'NN','সহর':'NN',
'সহরোলী':'NN','সহরোহিঙ্গাদের':'NN','সহর্ষ':'RB','সহশিক্ষা':'NN','সহসংযুক্ত':'JJ','সহসভাপতি':'NN','সহসম্পাদক':'NN',
'সহসা':'RB','সহস্ত্রবাচ':'NN','সহস্র':'JJ','সহস্রজিত্':'NN','সহস্রধারা':'NN','সহস্রাধিক':'NNS','সহস্রাব্দ':'NN',
'সহস্রার্জুন':'NN','সহানুভুতিশীল':'JJ','সহানুভূতি':'NN','সহানুভূতিশীল':'JJ','সহাবস্থান':'NN','সহায়':'NN','সহাস্য':'JJ',
'সহায়':'NN','সহায়তা':'NN','সহায়তাপ্রাপ্ত':'JJ','সহায়তার':'NN','সহি':'NN','সহিংসতা':'NN','সহিত':'RB',
'সহিলি':'NN','সহিষ্ণু':'JJ','সহিষ্ণুতা':'NN','সহিস':'NN','সহীন':'JJ','সহৃ':'NN','সহৃদয়তা':'NN',
'সহে':'IN','সহেরা':'NN','সহোদর':'NN','সহ্য':'NN','সহ্স্রার':'NN','সহয়াদ্রি':'NN','সহ‌জে':'JJ',
'সা':'NN','সাঁই':'NN','সাঁইত্রিশ':'NN','সাঁইত্রিশতম':'JJ','সাঁইবাবা':'NN','সাঁওতাল':'NNP','সাঁকড়া':'NN',
'সাঁচিস্তূপ':'NNP','সাঁচী':'NN','সাঁজানো':'VBN','সাঁজোয়া':'NN','সাঁঝ':'NN','সাঁটলিপি':'NN','সাঁটা':'NN',
'সাঁটানো':'VB','সাঁটালে':'NN','সাঁড়নি':'NN','সাঁতরানোর':'NN','সাঁতরে':'NN','সাঁতলান':'VB','সাঁতলানো':'NN',
'সাঁতারু':'NN','সাঁতারের':'NN','সাঁথি':'NN','সাঁপের':'NN','সাঁবত':'NN','সাঁস':'NN','সাং':'NNP',
'সাংকেতিক':'NN','সাংখিকী':'NN','সাংখ্য':'NN','সাংখ্যশাস্ত্র':'NN','সাংগা':'NN','সাংঘর্ষিক':'NN','সাংঘাতিক':'RB',
'সাংবাদিক':'NN','সাংবাদিকগণ':'NNS','সাংবাদিকতা':'NN','সাংবাদিকতায়':'NN','সাংবাদিকদের':'NNS','সাংবাদিকের':'NN','সাংবিধানিক':'JJ',
'সাংসদ':'NN','সাংসদীয়':'JJ','সাংসদের':'NN','সাংসরিক':'JJ','সাংসারিক':'NN','সাংস্কৃতিক':'NN','সাংহাইকে':'NN',
'সাই':'NN','সাইকাঁটা':'NN','সাইকেল':'NN','সাইকেলের':'NNS','সাইকো':'NN','সাইকোটিক':'JJ','সাইকোলজি':'NN',
'সাইক্লোন':'NN','সাইজ':'NN','সাইট':'NN','সাইটোপ্লাজম্':'NN','সাইড':'NN','সাইন':'NN','সাইনবোর্ড':'NN',
'সাইন্স':'NN','সাইপানের':'NNP','সাইপ্রাস':'NN','সাইপ্রাসের':'NN','সাইফউদ্দিন':'NN','সাইফুদ্দিনই':'NN','সাইফুর':'NN',
'সাইফুল':'JJ','সাইবর্গ':'NN','সাইবাবা':'NN','সাইবারঅপরাধ':'NN','সাইবারক্রাইম':'NN','সাইবেরিয়া':'NN','সাইবেরিয়ার':'JJ',
'সাইমং':'NN','সাইমেন্স':'NN','সাইরাকিউস':'NNP','সাইরেন':'NN','সাঈদ':'NN','সাউথ':'NN','সাউথইস্ট':'NN',
'সাউদের':'NNP','সাউন্ড':'NN','সাউহ':'NNP','সাও':'NN','সাওন্ত':'NN','সাকলাইন':'NN','সাকার':'NN',
'সাকিব':'NN','সাকিবতো':'NN','সাকিবদের':'NN','সাকিবমুস্তাফিজ':'NN','সাকিবের':'NN','সাকী':'NN','সাকেত':'NN',
'সাক্ষর':'NN','সাক্ষাতকার':'NN','সাক্ষাতের':'VBG','সাক্ষাত্':'NN','সাক্ষাত্কারী':'NN','সাক্ষাৎকারে':'NN','সাক্ষী':'NN',
'সাক্ষীর':'NN','সাক্ষ্যও':'NN','সাক্ষ্যপ্রমাণ':'NN','সাখাওয়াত':'NN','সাখি':'NN','সাগজুবান':'NN','সাগর':'NN',
'সাগররুনি':'NN','সাগরালয়':'NN','সাগরে':'NN','সাগরের':'NN','সাগু':'NN','সাগুদানা':'NN','সাগ্নিক':'NN',
'সাঙ':'NN','সাঙ্গখারা':'NN','সাঙ্গলী':'NN','সাচরী':'NN','সাচ্চা':'JJ','সাজ-গোজ':'NN','সাজ-পোশাকে':'NN',
'সাজ':'NN','সাজগোজ':'NNS','সাজতে':'NN','সাজদা':'NN','সাজসজ্জা':'NN','সাজসজ্জার':'JJ','সাজসরঞ্জাম':'NN',
'সাজা':'NN','সাজাও':'VB','সাজাগোজা':'JJ','সাজাতে':'NN','সাজানো':'VBN','সাজানো-গোছান':'NN','সাজানো':'NN',
'সাজাপ্রাপ্ত':'JJ','সাজার':'NN','সাজিবর্গাদার':'NN','সাজিয়ে':'VBN','সাজিয়েছে':'NN','সাজুনে':'NN','সাজুরী':'NN',
'সাজেন্সন':'NN','সাজেশন':'NNS','সাজো':'NN','সাঝনী':'NN','সাটল':'NN','সাটানো':'VB','সাটিন':'NN',
'সাটিনের':'JJ','সাট্টা':'NN','সাট্টাবাজী':'NN','সাঠী':'NN','সাড়':'NN','সাত-তাড়াতাড়ি':'RB','সাত':'RB',
'সাতকানিয়ায়':'NN','সাতক্ষীরার':'NN','সাতগুণ':'NN','সাতগোছা':'NN','সাতচল্লিশ':'NN','সাতজন':'RB','সাতজনে':'NN',
'সাতটা':'CD','সাতটায়':'NN','সাততলা':'NN','সাতদিন':'NN','সাতনরী':'JJ','সাতপাক':'NN','সাতপুরিয়া':'NN',
'সাতবার':'NN','সাতভাতারি':'NN','সাতমাসিয়া':'JJ','সাতরঙা':'JJ','সাতলা':'NN','সাতলাখী':'JJ','সাতশো':'JJ',
'সাতষট্টি':'NN','সাতষট্টিতম':'JJ','সাতাত্তর':'NN','সাতাত্তরতম':'JJ','সাতানব্বই':'NN','সাতানব্বইতম':'JJ','সাতান্ন':'NN',
'সাতান্নতম':'JJ','সাতার':'NN','সাতাশ':'NN','সাতাশতম':'JJ','সাতাশি':'NN','সাতাশিতম':'JJ','সাতে':'NN',
'সাতেক':'JJ','সাতের':'NN','সাত্বতী':'NN','সাত্যকী':'NN','সাথী':'NN','সাথীযুক্ত':'JJ','সাথে':'NN',
'সাথেঅথবা':'IN','সাথেআমাদের':'NN','সাথেই':'NN','সাথেযারা':'VB','সাথের':'IN','সাথেহারিজিতি':'VBG','সাথেে':'NN',
'সাদমান':'NN','সাদর':'JJ','সাদরে':'RB','সাদা':'NN','সাদাকালো':'JJ','সাদাকালোর':'NN','সাদামাটা':'JJ',
'সাদামাটাদের':'NN','সাদাশকুন':'NN','সাদাসিধে':'NN','সাদিয়া':'NN','সাদৃশ্য':'NN','সাদে':'NN','সাদোদ্বীপে':'NN',
'সাদ্দাম':'NN','সাদ্ধ্যের':'NN','সাধ':'NN','সাধকের':'NN','সাধতে':'VB','সাধন':'NN','সাধনপূর্ণ':'JJ',
'সাধনযুক্ত':'JJ','সাধনা':'NN','সাধনীয়':'JJ','সাধনের':'NN','সাধা':'NN','সাধান':'NNP','সাধারণ':'NN',
'সাধারণত':'RB','সাধারণতন্ত্র':'NN','সাধারণতা':'NN','সাধারণভাবে':'RB','সাধারণী':'NN','সাধারণীকৃত':'JJ','সাধারণের':'NN',
'সাধারণ্যে':'RB','সাধারন':'NN','সাধারনত':'RB','সাধারনতই':'NN','সাধারনভাবে':'RB','সাধারনের':'NN','সাধিকা':'NN',
'সাধিত':'JJ','সাধীনতা':'NN','সাধু-সজ্জন':'NN','সাধু-সন্ন্যাসীই':'NN','সাধু':'NN','সাধুগিরি':'VB','সাধুতা':'NN',
'সাধুনি':'NN','সাধুবাত':'NN','সাধুবাবার':'NN','সাধুবেশে':'NN','সাধুভাষা':'NN','সাধুসম':'JJ','সাধের':'NN',
'সাধ্বস':'NN','সাধ্বী':'JJ','সাধ্যের':'NN','সান':'NN','সানকুরঙ্গী':'NN','সানগ্লাস':'NNS','সানন্দ':'JJ',
'সানন্দে':'NN','সানফ্রান্সিসকো':'NN','সানসেট':'NN','সানহানা':'NN','সানাই':'NN','সানাক্সি':'NNP','সানি':'NNP',
'সানিত':'NN','সানী':'NN','সানো':'NNV','সান্ডিল্য':'NN','সান্ত':'JJ','সান্তনা':'NN','সান্ত্বনা':'VB',
'সান্দীপনি':'NN','সান্দ্র':'JJ','সান্দ্রতামাপক':'NN','সান্দ্রমণি':'NN','সান্ধ্য':'NN','সান্নিপাতিক':'NN','সাপ':'NN',
'সাপওপেল':'NN','সাপকে':'NN','সাপটির':'NN','সাপমার':'NN','সাপিনী':'NN','সাপুড়া':'NN','সাপুড়ে':'NN',
'সাপুড়েকে':'NNP','সাপুড়েদের':'NN','সাপুড়েরা':'NN','সাপেক্ষ':'JJ','সাপেক্ষে':'NN','সাপের':'NN','সাপোরটার':'NN',
'সাপোর্ট':'NN','সাপোর্টারদের':'NN','সাপোর্টার্স':'NN','সাপোর্টে':'NN','সাপ্তাহিক':'NN','সাপ্লাই':'NN','সাফ':'JJ',
'সাফনো':'VB','সাফল্য':'NN','সাফল্যকে':'NN','সাফল্যলাভ':'NN','সাফল্যের':'NN','সাফা':'NN','সাফাইগীতি':'NN',
'সাফারি':'NN','সাব-কমেটি':'NN','সাব-য়্যাকিউট':'NN','সাব':'NN','সাবজেক্টই':'NN','সাবটাইটেল':'NN','সাবটারসিয়ান':'NN',
'সাবধাণহীনতা':'NN','সাবধানতা':'NN','সাবধানতাপূর্বক':'RB','সাবধানতার':'NN','সাবধানে':'NN','সাবমারসিবল':'NN','সাবমেরিন':'NN',
'সাবরকাণ্ঠা':'NN','সাবর্ণ':'NNP','সাবর্ণি':'NN','সাবলম্বী':'JJ','সাবলের':'NN','সাবসিডি':'NN','সাবা':'NN',
'সাবাধান':'NN','সাবানদানি':'NN','সাবাশ':'NN','সাবাড়':'NN','সাবিত্র':'NN','সাবিত্রী':'NN','সাবিত্রীদি':'NNP',
'সাবিত্রীব্রত':'NN','সাবিনা':'NN','সাবুদ':'NN','সাবে':'RB','সাবেক':'NN','সাবোই':'NN','সাব্বির':'NN',
'সাব্বিরকিন্তু':'NN','সাব্বিরসৌম্যরা':'NN','সাব্বিরের':'NN','সাব্যস্ত':'NN','সাভাবিক':'NN','সাভার':'NN','সাভারকার':'NN',
'সাম':'NN','সামগ্রিক':'RB','সামগ্রিকভাবে':'NN','সামগ্রী':'NN','সামগ্রীমন্ত্রী':'NN','সামছুর':'NN','সামঞ্জস্য':'NN',
'সামঞ্জস্যপূর্ণ':'JJ','সামঞ্জস্যহীন':'JJ','সামঞ্জস্যহীনতা':'NN','সামনা-সামনি':'NN','সামনা':'NN','সামনাসামনি':'NN','সামনি':'NN',
'সামনে-পেছন':'NN','সামনে':'NN','সামনেপিছনে':'RB','সামনের':'NN','সামন্ত-ভারতী':'NN','সামন্ত':'NN','সামন্তকালীন':'JJ',
'সামন্ততন্ত্র':'NN','সামন্ততান্ত্রিক':'NN','সামন্তপ্রথা':'NN','সামন্তবাদ':'NN','সামন্তর':'NNP','সামন্তী':'NN','সামবার':'NN',
'সামবেদ':'NN','সামবেদীয়':'JJ','সামবৈদিক':'JJ','সাময়িকভাবে':'RB','সাময়িকী':'JJ','সামর্থ':'NN','সামর্থ্যবান':'NN',
'সামর্থ্যের':'NN','সামলাতে':'NN','সামলানের':'NN','সামলানোর':'NN','সামলাবে':'VB','সামলায়':'NN','সাম়ঞ্জস্য':'NN',
'সামাজিক':'NN','সামাজিকভাবে':'RB','সামাজের':'NN','সামাথ্য':'NN','সামাধানীয়':'JJ','সামান্য':'NN','সামান্যতঃ':'RB',
'সামান্যতা':'NN','সামারিয়াম':'NN','সামাল':'VB','সামি':'NN','সামিয়ানার':'NN','সামী':'JJ','সামীপ্যাত্':'RP',
'সামুদ্রিক':'NN','সামূহিক':'RB','সামোভার':'NN','সাম্পাওলি':'NN','সাম্প্রতিক':'JJ','সাম্প্রদায়িক':'NN','সাম্প্রদায়িক':'JJ',
'সাম্প্রদায়িকতা':'NN','সাম্ব':'NN','সাম্বমিত্র':'NN','সাম্ভর':'NN','সাম্মানিক':'JJ','সাম্যবাদ':'NN','সাম্যবাদে':'NN',
'সাম্যাবস্থার':'NN','সাম্যের':'NN','সাম্রাজ্য':'NN','সাম্রাজ্যবাদী':'JJ','সাম্রাজ্যবাদীদের':'NN','সাম্রাজ্যের':'NN','সাময়িক':'NN',
'সার':'NN','সারংগা':'NN','সারংনট':'NN','সারওয়ালা':'NN','সারক':'NNP','সারকথা':'NN','সারঙ্গ':'NN',
'সারঙ্গী':'NN','সারচার্জ':'NN','সারছে':'NN','সারজিক্যাল':'NN','সারট':'NN','সারণী':'NN','সারতে':'NN',
'সারথী':'NN','সারদা-জননী':'NNP','সারদা':'NN','সারদাই':'NNP','সারদাকে':'NNP','সারদাকেও':'NNP','সারদাদেবীর':'NNP',
'সারদানন্দ':'NNP','সারদার':'NNP','সারদারু':'NN','সারনাথ':'NN','সারপূর্ণ':'JJ','সারফেস':'NN','সারবিয়া':'NN',
'সারবিয়ার':'JJ','সারবীজ':'NN','সারভেন্ট':'NN','সারমেয়':'NN','সারর্কাস':'NN','সারল':'NNP','সারস':'NN',
'সারসংক্ষেপ':'NN','সারসঙ্কলন':'NN','সারস্বত':'NN','সারহাদ':'NNP','সারহীন':'NN','সারা':'NN','সারাই':'NN',
'সারাক্ষন':'NN','সারাজীবন':'NN','সারাটা':'NN','সারাদিন':'NN','সারাদিনের':'NN','সারাদেশের':'NN','সারানো':'NNV',
'সারাফ':'NN','সারাবছর':'NN','সারি':'NN','সারিকামুখ':'NN','সারিতে':'NN','সারিন্দা':'NN','সারিবদ্ধ':'NN',
'সারিবদ্ধভাবে':'RB','সারির':'NN','সারী':'JJ','সারু':'NNP','সারে':'NN','সারেঙ্গি':'NN','সারেঙ্গীবাদক':'NN',
'সারের':'NN','সারেসাতী':'NN','সারেসেই':'NN','সারোপা':'NN','সার্ক':'NN','সার্কাসে':'NN','সার্কিট':'NN',
'সার্কুলার':'NN','সার্কুলেট':'NN','সার্চ':'NN','সার্জনাক্ষি':'NN','সার্জিক্যাল':'NNP','সার্জেন':'NN','সার্টিফিকেট':'NN',
'সার্টিফিকেটের':'NN','সার্থক':'NN','সার্থকভাবে':'RB','সার্থবাহ':'NN','সার্পরাজ্ঞি':'NN','সার্পেণ্ট':'NN','সার্পোটারদের':'NN',
'সার্ফিং':'NN','সার্বক্ষনিক':'NN','সার্বজনীক':'JJ','সার্বজনীন':'NN','সার্বজনীনতার':'NN','সার্বভৌম':'JJ','সার্বভৌমত্ব':'NN',
'সার্বভৌমিক':'JJ','সার্বভৌমিকতা':'NN','সার্বস্থানে':'NN','সার্বিক':'JJ','সার্বিকভাবে':'NN','সার্বিয়':'NN','সার্ভাইকাল':'NN',
'সার্ভিং':'NN','সার্ভিসে':'NN','সার্ভে':'NN','সাল':'NN','সালঙ্ক':'NN','সালটা':'NN','সালটি':'NN',
'সালতর':'NN','সালপান':'NN','সালফাইড':'NN','সালফেট':'NN','সালভাডোরীয়':'JJ','সালভাদোর':'NN','সালমমিশ্রী':'NN',
'সালমা':'NN','সালমানদের':'NN','সালসা':'NN','সালাউদ্দিন':'NN','সালাম':'NN','সালাহ':'NN','সালাহই':'NN',
'সালাহর':'NN','সালি':'NN','সালিমি':'NN','সালিশসভা':'NN','সালিসি':'NN','সালু':'NN','সালেই':'NN',
'সালেক':'NN','সালেকের':'NN','সালেহ':'NN','সালোয়ার':'NN','সাল্ব':'NN','সাল্ভাডোর':'NN','সাল্লু':'NN',
'সাশ্রয়':'NN','সাশ্রু':'RB','সাশ্রয়':'NN','সাশ্রয়কারী':'JJ','সাশ্রয়ী':'NN','সাষ্টাঙ্গ':'NN','সাসতি':'NN',
'সাসনলেট':'NN','সাসারাম':'NN','সাহচর্য':'NN','সাহবে':'NN','সাহষিক':'NN','সাহস':'NN','সাহসও':'NN',
'সাহসভরে':'RB','সাহসহীন':'NN','সাহসি':'NN','সাহসিক':'JJ','সাহসিকতা':'NN','সাহসিকতার':'RB','সাহসিকতায়':'NN',
'সাহসী':'NN','সাহসে':'NN','সাহাবুদ্দিন':'NN','সাহায্য':'NN','সাহায্যপাশে':'NN','সাহায্যপ্রাপ্ত':'JJ','সাহায্যে':'NN',
'সাহায্যের':'NN','সাহারনপুর':'NN','সাহারা':'NN','সাহায়ক':'NN','সাহিত্য-':'NN','সাহিত্যক':'NN','সাহিত্যকার':'NN',
'সাহিত্যপ্রেমী':'JJ','সাহিত্যসেবী':'NN','সাহিত্যিক':'NN','সাহিত্যে':'NN','সাহিত্যেরই':'NN','সাহিদুল':'NN','সাহিব':'NN',
'সাহী':'JJ','সাহুকার':'NN','সাহে':'NN','সাহেব-মেমরা':'NN','সাহেব':'NN','সাহেবও':'NN','সাহেবগঞ্জ':'NN',
'সাহেবজনগণকে':'NN','সাহেবতো':'NN','সাহেবদের':'NN','সাহেবপাড়ায়':'NN','সাহেবশুনে':'NN','সাহেরা':'NN','সাড়া':'NN',
'সাড়ে':'NN','সায়':'NN','সায়গন':'NNP','সায়ণ':'NN','সায়ন':'NNP','সায়নোকোবালামিন':'NN','সায়া':'NN',
'সায়াটিকা':'NNP','সায়ী':'JJ','সায়ে':'NN','সায়েন্সের':'NNP','সায়েব':'NNP','সা‌থে':'NN','সি.':'NNP',
'সি':'NN','সিঁকিভাগও':'NN','সিঁটিয়ে':'VB','সিঁড়ি':'NN','সিঁদুর':'NN','সিঁদুরী':'NN','সিঁধ':'NN',
'সিঁর':'NNP','সিঁড়ি':'NN','সিং-এর':'NNP','সিং':'NN','সিংগাপুর':'NN','সিংগেল':'NN','সিংঙ্গা':'NN',
'সিংভুম':'NN','সিংসা':'NN','সিংহ':'NN','সিংহকে':'NNP','সিংহগ্রীবা':'NN','সিংহচিত্রা':'NN','সিংহদ্বার':'NN',
'সিংহনাদ':'NN','সিংহনী':'NN','সিংহপর্ণী':'NN','সিংহপুচ্ছ':'NN','সিংহবাহিনী':'NN','সিংহবাহিনীর':'NNP','সিংহভাগ':'NN',
'সিংহমোনাল':'NN','সিংহরাশি':'NN','সিংহল':'NN','সিংহলাস্থান':'NN','সিংহলী':'NN','সিংহলের':'NNP','সিংহাসন':'NN',
'সিংহাসনচ্যূত':'JJ','সিংহাসনে':'NN','সিংহাসনের':'NNP','সিংহিকা':'NN','সিংহী':'NN','সিংহের':'NN','সিংহোদরি':'JJ',
'সিংয়ের':'NN','সিআইএ':'NN','সিআরপিএফ':'NN','সিইও':'NN','সিইসি':'NN','সিইসিও':'NN','সিইসির':'NN',
'সিউড়িতে':'NNP','সিএ':'NN','সিএনজি':'NN','সিএমএইচ':'NN','সিএমডি':'NN','সিএল':'NN','সিএসআর':'NN',
'সিওর':'NN','সিওয়ালি':'NN','সিকড়ীপান':'NN','সিকতা':'NN','সিকতাবর্ত্ম':'NN','সিকতামেহ':'NN','সিকথ':'NN',
'সিকনি':'NN','সিকন্দরা':'NN','সিকরেট':'NN','সিকান্দার':'NN','সিকি':'NN','সিকিউরিটি':'NN','সিকিভাগ':'NN',
'সিকিম':'NN','সিকুরিটি':'NN','সিকুয়েইরাআর্মেলিন':'NN','সিকে':'NN','সিকো':'NNP','সিক্কড়':'NN','সিক্ত':'NN',
'সিক্রী':'NN','সিক্স':'NN','সিখ':'NN','সিগনাল':'NN','সিগার':'NN','সিগারেটের':'NN','সিঙাড়া':'NN',
'সিঙ্ক':'NN','সিঙ্গড়া':'NN','সিঙ্গবিহীন':'JJ','সিঙ্গরী':'NN','সিঙ্গা':'NN','সিঙ্গাপুর':'NN','সিঙ্গাপুরে':'NN',
'সিঙ্গাপুরের':'NNP','সিঙ্গার':'NN','সিঙ্গি':'NN','সিঙ্গেল':'NN','সিঙ্গোটা':'NN','সিঙ্ঘাড়া':'NN','সিজউইক':'NNP',
'সিজদা':'NN','সিজনে':'NN','সিজার':'NNP','সিজিয়াম':'NN','সিজোফ্রেনিয়ার':'NNP','সিঞ্চন':'NN','সিট':'NN',
'সিটাসমণ্ডল':'NNP','সিটি':'NN','সিটিং':'VBG','সিটিজেন':'NN','সিটির':'NNP','সিটিসেল':'NN','সিটুর':'NNP',
'সিটে':'NN','সিটের':'NNS','সিট্রিন':'NN','সিডনি':'NN','সিডন্স':'NN','সিডাডে':'NN','সিডি':'NN',
'সিডিউলের':'NN','সিডিপি':'NN','সিণ্ডিকেট':'NN','সিত':'NN','সিতপক্ষ':'NN','সিতপুষ্প':'NN','সিতাংশুকেও':'NN',
'সিতাও':'NN','সিতাকুন্ডে':'NN','সিতানন':'NN','সিতাপাঙ্গ':'NN','সিতাব্জ':'NN','সিতামারি':'NN','সিতাম্ভোজ':'NN',
'সিতারী':'NN','সিতাসিত':'NN','সিতে':'NN','সিত্কার':'NN','সিথিল':'NN','সিদ্দিক':'NN','সিদ্দিকী':'NN',
'সিদ্ধ':'NN','সিদ্ধপুরুষ':'NN','সিদ্ধমন্ত্র':'NN','সিদ্ধহস্ত':'NN','সিদ্ধান্তও':'NN','সিদ্ধান্তটা':'NN','সিদ্ধান্তপ্রথম':'NNP',
'সিদ্ধান্তে':'NN','সিদ্ধান্তের':'NN','সিদ্ধার্থ':'NN','সিদ্ধি':'NN','সিদ্ধিদাত্রী':'NN','সিদ্ধ্বান্ত':'NN','সিদ্বান্তেই':'NN',
'সিধা':'RB','সিধান্তকে':'NN','সিধাসাধা':'JJ','সিধি':'NN','সিধু':'NNP','সিধুপর্ণী':'NN','সিধুর':'NNP',
'সিধে-সাদা':'JJ','সিধে':'NN','সিধ্বান্ত':'NN','সিন':'NN','সিনহার':'NN','সিনহালা':'NNP','সিনহালাদের':'NNP',
'সিনাই':'NNP','সিনারি':'NN','সিনি':'NNP','সিনিয়র':'NN','সিনিয়ার':'JJ','সিনী':'NNP','সিনেগাগ':'NN',
'সিনেগালবাসী':'NN','সিনেগালিস':'NN','সিনেগালীয়':'JJ','সিনেটরের':'NN','সিনেমা-ঘর':'NN','সিনেমাকেও':'NNS','সিনেমাঘর':'NN',
'সিনেমাটার':'NN','সিনেমার':'NNS','সিনেমাহল':'NN','সিন্ডকেট':'NN','সিন্ডিকেটদের':'NN','সিন্ড্রোম':'NN','সিন্দাবাদ':'NN',
'সিন্দুক':'NN','সিন্দুর-কৌটো':'NN','সিন্দুরদান':'NN','সিন্দুরী':'NN','সিন্ধ':'NN','সিন্ধান্তের':'NN','সিন্ধি':'NN',
'সিন্ধী':'NN','সিন্ধুঘোটক':'NN','সিন্ধুজা':'NN','সিন্ধুদুর্গ':'NN','সিন্ধুব':'NN','সিন্ধুবাসী':'JJ','সিন্ধুবিষ':'NN',
'সিন্ধুমাতা':'NN','সিন্ধুরাজ':'NN','সিন্ধুসুত':'NN','সিপাহী':'NNP','সিপি':'NNP','সিপিআই':'NN','সিপিএমের':'NNP',
'সিপিডি':'NN','সিপিবি':'NN','সিপিয়ু':'NN','সিফিলিটিক':'JJ','সিবনি':'NN','সিবমোগা':'NN','সিবল':'NNP',
'সিবান':'NN','সিবি':'NN','সিবিএ':'NN','সিবিসি':'NN','সিবে':'VB','সিবেএ':'NN','সিম':'NN',
'সিমকার্ড':'NN','সিমটম':'NNS','সিমটি':'NN','সিমডেগা':'NN','সিমপিথি':'NN','সিমভ':'NNP','সিমরন':'NN',
'সিমলা':'NN','সিমুই':'NN','সিমেট্রিক':'JJ','সিমেন্ট':'NN','সিমের':'NN','সিমোগা':'NN','সিম্পল':'NN',
'সিম্ফনির':'NN','সিম্বল':'NNS','সিয়েরা':'JJ','সির':'NNP','সিরকা':'NN','সিরখিস্ত':'NN','সিরচন্দ্র':'NN',
'সিরবন্ধি':'NN','সিরমৌর':'NN','সিরসা':'NN','সিরসী':'NN','সিরা':'NN','সিরাজগঞ্জ':'NN','সিরাজগঞ্জে':'NN',
'সিরাম':'NN','সিরি':'NN','সিরিজটা':'NNS','সিরিজটি':'NN','সিরিজে':'NNS','সিরিমাভো':'NNP','সিরিয়া':'NNS',
'সিরিশ':'NN','সিরিয়লেই':'NN','সিরিয়াক':'NNP','সিরিয়ান':'NN','সিরিয়ার':'NNS','সিরিয়াল':'NN','সিরিয়াস':'NN',
'সিরিয়াসলি':'RB','সিরিয়ায়':'NN','সিরোহি':'NN','সির্টি':'NN','সিল':'NN','সিলবার':'NNP','সিলবাসা':'NN',
'সিলভার':'NN','সিলভিক্রিন':'NNP','সিলমারা':'NN','সিলহি':'NN','সিলা':'NN','সিলাকান্থ':'NNP','সিলিং':'NN',
'সিলিকা':'NN','সিলিঙ্গিয়া':'NN','সিলিণ্ডার':'NN','সিলিন্ডার':'NN','সিলিন্ডারের':'NN','সিলিলি':'NNP','সিলী':'NNP',
'সিলেকশন':'NN','সিলেক্টররা':'NN','সিলেট':'NN','সিলেটবাসী':'NNS','সিলেটি':'NN','সিলেটের':'NN','সিলোবাস':'NN',
'সিল্ক':'NN','সিল্কি':'JJ','সিল্লা':'NN','সিষ্টেম':'NN','সিসওয়ারিতে':'NNP','সিসমোগ্রাফ':'NN','সিসি':'NN',
'সিসিলি':'NN','সিস্':'NN','সিস্টার্সএ':'NNS','সিস্টেম':'NN','সিস্টেমের':'NN','সিহুলা':'NN','সিহোর':'NN',
'সিড়ি':'NNS','সিড়িঁগুলি':'NN','সিয়া':'NNP','সিয়াঙ্গ':'NN','সিয়ান':'NNP','সিয়ানি':'NN','সিয়াম':'VBG',
'সিয়াল':'NN','সিয়ে':'VB','সিয়েরা':'NN','সি১৩০':'NN','সীওনী':'NN','সীকম':'NN','সীকৃত':'VBN',
'সীঙ্কপার':'NN','সীজন':'NNP','সীজার':'NNP','সীট':'NN','সীড':'NN','সীতলপাটী':'NN','সীতা':'NN',
'সীতাপতি':'NN','সীতাফল':'NN','সীতারাম':'NNP','সীতাহরণ':'NN','সীতে':'NNP','সীধু':'NN','সীন':'NN',
'সীপবোর্ড':'NN','সীবীসী':'NN','সীম':'NN','সীমন্ত':'NN','সীমবদ্ধতা':'NN','সীমা':'NN','সীমাক্ষেত্র':'NN',
'সীমাঙ্কন':'NN','সীমাঙ্কিত':'JJ','সীমাদের':'NNS','সীমানা':'NN','সীমান্তকর':'NN','সীমান্তন্নয়ন':'NN','সীমান্তফলক':'NN',
'সীমান্তে':'NN','সীমাবদ্ধ':'NN','সীমাবদ্ধতা':'NNS','সীমার':'NNS','সীমারহিত':'JJ','সীমারেখা':'NN','সীমালঙ্ঘন':'NN',
'সীমাহীন':'JJ','সীমিত':'NN','সীরা':'NN','সীল':'NN','সীলমোহর':'JJ','সীলা':'NN','সীল্যাণ্ড':'NN',
'সীসা':'NN','সু':'NN','সুঁচ':'NN','সুইং':'NN','সুইজারল্যান্ড':'NN','সুইজারল্যান্ডীয়':'NN','সুইজারল্যান্ডে':'NNP',
'সুইজারল্যান্ডের':'NN','সুইট':'NN','সুইটজারল্যান্ড':'NN','সুইডিশ':'NN','সুইডিস':'NNP','সুইডেন':'NN','সুইপার':'NN',
'সুইফট':'NN','সুইমিং':'NN','সুইস':'NN','সুইসাইডাল':'NN','সুউচ্চ':'JJ','সুকক্ষ':'NN','সুকন্যা':'NN',
'সুকরীহার':'NN','সুকান্তদের':'NNP','সুকুন্তল':'NN','সুকুমার':'NN','সুকুমারবন':'NN','সুকৃতিবাবু':'NN','সুকৃতী':'NN',
'সুকেতন':'NN','সুকেশ':'JJ','সুকেশি':'NN','সুকৌশলী':'JJ','সুকৌশলে':'RB','সুক্ত':'NN','সুক্রীড়া':'NN',
'সুক্রে':'NN','সুক্ষ্ম':'NN','সুখ-সম্পত্তি':'NN','সুখ':'NN','সুখকর':'NN','সুখতলা':'NN','সুখদ':'NN',
'সুখদায়ক':'JJ','সুখদেও':'NN','সুখনিদ্রা':'NN','সুখপূর্ণ':'JJ','সুখপ্রদ':'NN','সুখবর':'NN','সুখবরই':'NNS',
'সুখবরখানা':'NNS','সুখবরের':'NN','সুখমা':'NN','সুখময়':'JJ','সুখরব':'NNS','সুখাদ্য':'NN','সুখানুভূতি':'NN',
'সুখান্তক':'JJ','সুখাসন':'NN','সুখাসীন':'JJ','সুখিপ্সু':'JJ','সুখী':'NN','সুখে':'RB','সুখেচ্ছা':'NN',
'সুখের':'NN','সুখ্যাত':'JJ','সুখ্যাতি':'NN','সুগঠিত':'NN','সুগন্ধ':'NN','সুগন্ধা':'NN','সুগন্ধী':'NN',
'সুগম':'NN','সুগার':'NN','সুগীতিকা':'NN','সুগুণ':'NN','সুগ্রাহী':'JJ','সুগ্রীব':'NN','সুগ্রীবাগ্রজ':'NN',
'সুগ্রীবী':'NN','সুঘরাই-কান্হাড়া':'NN','সুঘরাই-টোড়ী':'NN','সুঘরাই':'NN','সুঘরাইকান্হাড়া':'NN','সুঘরাইটোড়ী':'NN','সুঘোষ':'NN',
'সুচ':'NN','সুচকের':'NN','সুচতুরা':'JJ','সুচন্দ্র':'NN','সুচারা':'NN','সুচারুরূপেই':'RB','সুচালো':'NN',
'সুচি':'NN','সুচিকিৎসা':'NN','সুচিন্তা':'NN','সুচিন্তিত':'JJ','সুচ্ছায়া':'NN','সুজন':'NN','সুজনকে':'CD',
'সুজনি':'NN','সুজয়':'NN','সুজা':'NN','সুজাতত্ত্ব':'NN','সুজাতা':'NN','সুজি':'NN','সুজুগ':'NN',
'সুঝে':'RB','সুটকেস':'NN','সুটিং':'VBG','সুট্টা':'NN','সুঠাম':'JJ','সুড়কি':'NN','সুড়ঙ্গ':'NN',
'সুড়সুড়ি':'NN','সুড়ুক':'VB','সুডৌল':'NN','সুত':'NN','সুতম্ভরা':'NN','সুতরাং':'RB','সুতল':'NN',
'সুতসোম':'NN','সুতা':'NN','সুতারং':'RB','সুতারা':'NN','সুতারাং':'RB','সুতি':'NN','সুতিয়া':'NN',
'সুতী':'NN','সুতীব্র':'JJ','সুতীর্থ':'NN','সুতু':'NNP','সুতো':'NN','সুত্রধর':'NN','সুত্রীয়':'JJ',
'সুত্রে':'NN','সুথনী':'NN','সুদ':'NN','সুদংষ্ট্র':'NN','সুদকে':'NN','সুদক্ষ':'JJ','সুদক্ষিণা':'NN',
'সুদখোর':'NN','সুদতী':'NN','সুদন্তা':'NN','সুদবাজি':'NN','সুদবিহীন':'JJ','সুদমুক্ত':'NN','সুদর্শন':'NN',
'সুদহার':'NNS','সুদান':'NN','সুদানি':'NN','সুদানীয়':'JJ','সুদানীয়া':'NNP','সুদানের':'NN','সুদামা':'NN',
'সুদাসলে':'NN','সুদিন':'NN','সুদিবাতন্তি':'NN','সুদীতি':'NN','সুদীপ':'NNP','সুদীপ্ত':'JJ','সুদুরপ্রসারী':'NN',
'সুদুর্ল্লভ':'JJ','সুদূর':'NN','সুদূরপরাহততাই':'NN','সুদূরপ্রসারী':'NN','সুদৃঢ়':'NN','সুদৃশ্য':'JJ','সুদৃঢ়':'JJ',
'সুদে':'NN','সুদেআসলে':'NN','সুদেও':'NN','সুদেষ্ণা':'NN','সুধ':'NN','সুধা':'NN','সুধাপাত্র':'NN',
'সুধামা':'NN','সুধামূলী':'NN','সুধি':'NN','সুধীন্দ্রনাথ':'NNP','সুধীর':'NNP','সুধু':'RB','সুধৃতি':'NN',
'সুনকপাশি':'NN','সুনছি':'VBG','সুনজর':'JJ','সুনজরে':'VB','সুনন্দা':'NN','সুনহ':'NN','সুনহানাল্লাহ':'NN',
'সুনাগরিক':'NNP','সুনাভ':'NN','সুনামদ্বাদশী':'NN','সুনামা':'NN','সুনামীতে':'NN','সুনামের':'NN','সুনাহি':'NN',
'সুনায়ক':'NN','সুনিপুণ':'JJ','সুনিবার্য':'JJ','সুনির্দিষ্ট':'NN','সুনির্দিষ্টভাবে':'RB','সুনিলের':'NN','সুনিশ্চিত':'NN',
'সুনিয়ন্ত্রিত':'VBD','সুনীতিকুমার':'NNP','সুনীথ':'NN','সুনে':'VB','সুনেত্র':'NN','সুন্দ':'NN','সুন্দর':'NN',
'সুন্দরকাণ্ড':'NN','সুন্দরকে':'JJ','সুন্দরগড়':'NN','সুন্দরতম':'JJ','সুন্দরবন':'NN','সুন্দরভাবে':'RB','সুন্দরী':'NN',
'সুন্ধন্বা':'NN','সুন্নি':'NN','সুন্সারি':'NN','সুনয়ন':'JJ','সুপ':'NN','সুপক্ক্ব':'JJ','সুপত্র':'NN',
'সুপথ্য':'NN','সুপরিকল্পিত':'JJ','সুপরিচিত':'NN','সুপরিণাম':'NN','সুপর্ণ':'NN','সুপর্ণযাতু':'NN','সুপাচ্য':'NN',
'সুপাঠ্য':'JJ','সুপাড়ি':'NN','সুপাত্রতা':'NN','সুপারদের':'NNS','সুপারনোভা':'NN','সুপারভাইজার':'NN','সুপারশপ':'NN',
'সুপারস্টার':'NN','সুপারি':'NN','সুপারিণ্টেডেণ্টকে':'NN','সুপারিনটেন্ডেন্ট':'NN','সুপারিশ':'NN','সুপারিশকৃত':'JJ','সুপারিশের':'VBN',
'সুপার্শ্ব':'NN','সুপুত্র':'NN','সুপুরুষ':'NN','সুপৌল':'NN','সুপ্ত':'NN','সুপ্রতিষ্ঠতা':'NN','সুপ্রতিষ্ঠিত':'JJ',
'সুপ্রতিষ্ঠিতা':'NN','সুপ্রতীক':'NN','সুপ্রতীপ':'NNP','সুপ্রভ':'NN','সুপ্রভাত':'VBG','সুপ্রভাতা':'NN','সুপ্রসন্ন':'JJ',
'সুপ্রসরা':'NN','সুপ্রসিদ্ধ':'JJ','সুপ্রাপ্য':'JJ','সুপ্রিম':'NN','সুপ্রিয়া':'NN','সুফল':'NN','সুফলক':'NN',
'সুফি':'NN','সুফীবাদ':'NN','সুবক্তা':'NN','সুবচন':'NN','সুবড়া':'NN','সুবনসিরি':'NN','সুবন্ধু':'NN',
'সুবপু':'NN','সুবর্চা':'NN','সুবর্ণপুর':'NN','সুবর্ণমেখলী':'NN','সুবর্ণযুথিকা':'NN','সুবর্ণরেখা':'NN','সুবর্ণার':'NNP',
'সুবর্মা':'NN','সুবল':'NN','সুবাদে':'NNS','সুবারি':'NN','সুবালোপনিষদ':'NN','সুবাস':'NN','সুবাহু':'NN',
'সুবিকশিত':'JJ','সুবিচার':'NN','সুবিধা':'NN','সুবিধাজনক':'NN','সুবিধাটাই':'NN','সুবিধাদি':'NNS','সুবিধাদিও':'NN',
'সুবিধাপূর্ণ':'JJ','সুবিধাপ্রাপ্তীর':'JJ','সুবিধাবঞ্চিত':'VBN','সুবিধাবাদ':'NN','সুবিধাবাদী':'NN','সুবিধাভোগিরা':'NNS','সুবিধামত':'NN',
'সুবিধার্থে':'NN','সুবিধে':'NN','সুবিধেজনক':'JJ','সুবিধের':'NN','সুবিন্যস্ত':'JJ','সুবিমর্শিত':'JJ','সুবিশাল':'NN',
'সুবুকরেঁদা':'NN','সুবুদ্ধির':'NN','সুবৃত্তা':'NN','সুবৃহত্':'JJ','সুবেদ':'NN','সুবেদারনি':'NN','সুবেদারী':'NN',
'সুবোধ':'NN','সুব্যবস্থা':'NN','সুব্যবস্থিত':'JJ','সুব্যবস্হা':'VB','সুব্রত':'NN','সুভকামনা':'NN','সুভগঙ্করণ':'NNP',
'সুভগদত্ত':'NN','সুভগা':'NN','সুভদ্রা':'NN','সুভব':'NN','সুভাগত':'NN','সুভানু':'NN','সুভাষচন্দ্র':'NN',
'সুভাষণ':'NN','সুভাষিতানি':'NN','সুভাষী':'JJ','সুভীম':'NN','সুভুজা':'NN','সুভূমি':'NN','সুভূষণ':'NN',
'সুমঙ্গলা':'NN','সুমণি':'NN','সুমতিনাথ':'NN','সুমদনাত্মজা':'NN','সুমন':'NN','সুমনদের':'NNS','সুমনাস্য':'NN',
'সুমনায়ন':'NN','সুমনের':'NN','সুমনোমুখ':'NN','সুমন্ত্র':'NN','সুমসুখড়া':'NN','সুমহাকপি':'NN','সুমাত্রা':'NN',
'সুমানিকা':'NN','সুমালিনী':'NN','সুমিংপুল':'NN','সুমিত':'NN','সুমিতা':'NNP','সুমিত্র':'NN','সুমিত্রানন্দন':'NN',
'সুমিষ্ট':'JJ','সুমী':'JJ','সুমুখ':'NN','সুমূর্তি':'NN','সুমেধা':'NN','সুমেধের':'NNP','সুমেরীয়গণের':'NNP',
'সুমেরু':'NN','সুযশা':'NN','সুযোক':'NN','সুযোগ-দান':'NN','সুযোগই':'NN','সুযোগকে':'NN','সুযোগটিকে':'NN',
'সুযোগবুঝে':'NN','সুযোগসন্ধানিকে':'JJ','সুযোগসন্ধানী':'NN','সুযোগসুবিধা':'NNS','সুযোগে':'NN','সুযোগ্য':'JJ','সুযোগ্যতা':'NN',
'সুর-তাত':'NN','সুর':'NN','সুরকলী':'NN','সুরক্ষণ':'NN','সুরক্ষাবল':'NN','সুরক্ষার':'NN','সুরক্ষাহীনতা':'NN',
'সুরক্ষিত':'NN','সুরক্ষিতভাবে':'RB','সুরগণ':'NN','সুরগুরু':'NN','সুরঙ্গ':'NN','সুরজা':'NN','সুরঞ্জিত':'NN',
'সুরট-মল্লার':'NN','সুরট':'NN','সুরটমল্লার':'NN','সুরত':'NN','সুরত্ব':'NN','সুরথা':'NN','সুরথের':'NNP',
'সুরদারু':'NN','সুরদ্রু':'NN','সুরধেনু':'NN','সুরনদী':'NN','সুরনাথ':'NN','সুরনায়ক':'NN','সুরপতি':'NN',
'সুরবাহার':'NN','সুরবুলি':'NN','সুরভানু':'NN','সুরভি':'NN','সুরমই':'NN','সুরমাদানি':'NN','সুরমাল':'NN',
'সুরম্য':'JJ','সুরম্যতা':'NN','সুরল':'NN','সুরশলাকার':'NN','সুরসুরি':'NN','সুরস্কন্দ':'NN','সুরহা':'NN',
'সুরহীন':'JJ','সুরা':'NN','সুরাঙ্গনা':'NN','সুরাচার্য':'NN','সুরাট':'NN','সুরাতের':'NN','সুরাপান':'NN',
'সুরামেহ':'NN','সুরামেহী':'JJ','সুরারী':'NN','সুরাষ্ট্র':'NN','সুরাসক্ত':'NN','সুরাসন':'NN','সুরাহা':'NN',
'সুরি':'NN','সুরিনামিজ':'NN','সুরিনামীয়':'JJ','সুরিয়াগ':'NNP','সুরু':'VBG','সুরুচি':'NN','সুরুচিসম্পন্ন':'NN',
'সুরুয়া':'NN','সুরূপা':'NN','সুরে':'NN','সুরেন্দ্র':'NN','সুরের':'NN','সুরেশ':'NN','সুর্য':'NN',
'সুরয়া':'NN','সুলক্ষণ':'NN','সুলক্ষণযুক্ত':'JJ','সুলক্ষণহীন':'JJ','সুলতান':'NN','সুলতানদের':'NN','সুলতানা':'NN',
'সুলতানি':'JJ','সুলতানী':'NN','সুলবেসিবাসী':'NN','সুলভ':'NN','সুলভেসীয়':'NN','সুলার':'JJ','সুলি':'NN',
'সুলেখক':'NN','সুলেখা':'NNP','সুলেমান':'NN','সুলোচন':'NN','সুলোহক':'NN','সুল্তানী':'NN','সুশান্তি':'NN',
'সুশারীর':'NN','সুশাসন':'NN','সুশিক্ষিত':'JJ','সুশিল':'NN','সুশীল':'JJ','সুশীলতা':'NN','সুশৃংখল':'VBN',
'সুশৃঙ্খল':'NN','সুশোভিত':'NN','সুশ্রবা':'NN','সুশ্রুত-সংহিতা':'NN','সুশ্রুত':'NN','সুষম':'JJ','সুষমা':'NN',
'সুষুম':'NN','সুষুম্নাকাণ্ড':'NN','সুষেণ':'NN','সুষ্ট':'NN','সুষ্টো':'NN','সুষ্ঠ':'JJ','সুষ্ঠু':'NN',
'সুসংগঠিত':'VBN','সুসংবাদ':'NN','সুসংস্কৃত':'JJ','সুসঙ্গত':'JJ','সুসজ্জিত':'NN','সুসঠু':'NN','সুসনা':'NN',
'সুসন্ধি':'NN','সুসভ্য':'JJ','সুসম্পন্ন':'RB','সুসম্পর্ক':'NN','সুসরি':'NN','সুসাগতম':'VB','সুসিদ্ধ':'JJ',
'সুসুড়ী':'NN','সুসুপ্ত':'JJ','সুস্থ':'NN','সুস্থতায়':'NN','সুস্থিত':'JJ','সুস্পন্দ':'JJ','সুস্পষ্ট':'NN',
'সুস্পষ্টভাবে':'RB','সুস্বাদু':'JJ','সুস্মিত':'JJ','সুহস্ত':'NN','সুহা-কানাড়া':'NN','সুহা-টোড়ী':'NN','সুহা-বিলাবল':'NN',
'সুহা-শ্যাম':'NN','সুহা':'NN','সুহাকানাড়া':'NN','সুহাগ':'NN','সুহাটোড়ী':'NN','সুহাবিলাবল':'NN','সুহাশ্যাম':'NN',
'সুহৃদ':'NN','সুহৃদদের':'NNS','সুহেল':'NN','সুহোত্র':'NN','সুড়ঙ্গ':'NN','সুড়সুড়ি':'NN','সুয়জ্ঞ':'NN',
'সুয়ষ্টব্য':'NN','সুয়ারেজ':'NN','সুয়াশাকও':'NN','সুয়াসরা':'NN','সুয়েজ':'NN','সুয়োমোটো':'NN','সূঁচ':'NN',
'সূক্ষদর্শক':'NN','সূক্ষ্ম':'NN','সূক্ষ্মকোণী':'JJ','সূক্ষ্মতম':'JJ','সূক্ষ্মতা':'NN','সূক্ষ্মতাবশতঃ':'RB','সূক্ষ্মদর্শী':'JJ',
'সূক্ষ্মা':'NN','সূখে':'NN','সূচ':'NN','সূচকাঁঙ্ক':'NN','সূচকে':'NN','সূচনা':'NN','সূচনার':'NN',
'সূচনীয়':'JJ','সূচি':'NN','সূচিত':'VB','সূচিতে':'NN','সূচী':'NN','সূচীকর্ম':'NN','সূচীবদ্ধ':'JJ',
'সূচ্যগ্র':'NN','সূচ্যাকার':'JJ','সূত':'JJ','সূততনয়':'NN','সূতপুত্র':'NN','সূতলি':'NN','সূতা':'NN',
'সূতী':'NN','সূত্র':'NN','সূত্রটিকে':'NN','সূত্রধর':'NN','সূত্রপাত':'NN','সূত্রসমষ্টিকে':'NN','সূত্রী':'JJ',
'সূত্রে':'NN','সূদন':'NN','সূদুরপ্রসারী':'NN','সূদ্রশন':'NN','সূন্য':'NN','সূপ':'NN','সূপর্ণ':'NN',
'সূপ্রসন্ন':'JJ','সূর':'NN','সূরগর্ভ':'JJ','সূরজ':'NN','সূরসা':'NN','সূরেই':'NN','সূর্পনখা':'NN',
'সূর্য-উপাসক':'NN','সূর্য':'NN','সূর্যকান্ত':'NN','সূর্যকিরণ':'NN','সূর্যতাপ':'NN','সূর্যদেব':'NN','সূর্যনাড়ী':'NN',
'সূর্যপ্রিয়া':'NN','সূর্যবংশীয়':'JJ','সূর্যভানু':'NN','সূর্যমুখী':'NN','সূর্যরশ্মি':'NN','সূর্যলোক':'NN','সূর্যসুতা':'NN',
'সূর্যাস্ত':'NN','সূর্যাস্তপূর্ব':'NN','সূর্যের':'NN','সূর্যোদয়':'NN','সূর্যোপাসক':'NN','সূর্য্য':'NN','সূর্য্যকে':'NNP',
'সূর্য্যতাপের':'NN','সূর্য্যদেব':'NNP','সূর্য্যমন্দিরের':'NN','সূর্য্যালোকে':'NN','সূয়া':'NNP','সৃজক':'NN','সৃজনকর্তা':'NN',
'সৃজনমূলক':'JJ','সৃজনশীল':'NN','সৃজনশীলতার':'NN','সৃজনাত্মক':'JJ','সৃপক্কা':'NN','সৃষ্ট':'JJ','সৃষ্টি':'NN',
'সৃষ্টিকর্তা':'NN','সৃষ্টিকে':'NN','সৃষ্টিশীল':'JJ','সৃষ্টিশীলতা':'NN','সৃষ্টী':'NN','সৃস্টি':'NN','সে-কানে':'NN',
'সে-প্রশ্ন':'NN','সে-সব':'PR','সে.মি.':'NNP','সে':'NN','সেঁক':'NN','সেঁটে':'NN','সেঃ':'FW',
'সেই':'NN','সেইই':'DT','সেইখানে':'EX','সেইখানেই':'RB','সেইগুলি':'PR','সেইগুলো':'DT','সেইজন্য':'RP',
'সেইজন্যেই':'RB','সেইটা':'DT','সেইটাও':'DT','সেইটে':'PR','সেইদিকে':'NN','সেইন':'NNP','সেইভাবে':'RB',
'সেইম':'NN','সেইযুগে':'NN','সেইরকম':'JJ','সেইরাম':'NN','সেইসঙ্গে':'NN','সেইসব':'DT','সেইসাথে':'NN',
'সেইহেতু':'RP','সেও':'PRP','সেওয়াল':'NN','সেকটরে':'NN','সেকথার':'NN','সেকরম':'JJ','সেকশন':'NN',
'সেকশনে':'NN','সেকারণেই':'NN','সেকালে':'RB','সেকুলার':'JJ','সেকুলারদের':'NNS','সেকেণ্ড':'NN','সেকেণ্ডের':'NN',
'সেকেন্ডে':'NNS','সেকেন্ডের':'NN','সেকেলে':'NN','সেক্টর':'NN','সেক্টরকেই':'RB','সেক্টরটাকে':'NN','সেক্টরেই':'NN',
'সেক্টারকে':'NN','সেক্রেটারি':'NNP','সেক্ষেত্রে':'NN','সেক্স':'NN','সেক্সপিয়র':'NNP','সেক্সের':'NN','সেখবর':'NN',
'সেখান':'NN','সেখানকার':'RB','সেখানে':'NN','সেখানেও':'NN','সেখানের':'EX','সেগান':'NN','সেগুলা':'NN',
'সেগুলি':'PR','সেগুলিতে':'PR','সেগুলো':'DT','সেগুলো':'NN','সেগুলোই':'DT','সেগুলোকে':'NN','সেচ':'NN',
'সেচন':'NN','সেচনকারী':'NN','সেচনী':'NN','সেচব্যবস্থা':'NN','সেচমন্ত্রী':'NN','সেচে':'NN','সেচ্ছায়':'RB',
'সেছি':'VB','সেজ':'NN','সেজন্য':'NN','সেজন্যেও':'NN','সেজা':'NN','সেজেগুজে':'NN','সেজেছে':'VBN',
'সেজেছেন':'NN','সেজো':'JJ','সেঞ্চুরি':'NN','সেঞ্চুরী':'NN','সেঞ্চু‌রির':'NN','সেট':'NN','সেটটার':'PR',
'সেটাই':'PR','সেটাইতো':'NN','সেটাও':'NN','সেটাকে':'DT','সেটাতে':'IN','সেটাতো':'NN','সেটারই':'DT',
'সেটারের':'NN','সেটালাইট':'NN','সেটি':'DT','সেটিং':'NN','সেটিংস':'NNS','সেটিও':'VBG','সেটিকে':'NN',
'সেটিবাম':'NN','সেটির':'PR','সেটুকু':'NN','সেটে':'NN','সেডল':'NN','সেঢ়খানা':'NN','সেণ্ট':'NNP',
'সেণ্টার':'NN','সেণ্টিমেণ্ট':'NNP','সেণ্ট্রাল':'JJ','সেতার':'NN','সেতারের':'NN','সেতু':'NN','সেতুটি':'NN',
'সেতুমন্ত্রী':'NN','সেতুর':'NN','সেতু‌তে':'NN','সেতো':'NN','সেদিও':'RB','সেদিক':'NN','সেদিকেই':'NN',
'সেদিন-ই':'RB','সেদিন':'NN','সেদিনই':'RB','সেদিনটা':'RB','সেদিনের':'NN','সেদ্ধ':'NN','সেধে':'VBN',
'সেন':'NN','সেনও':'NNP','সেনজিত':'NN','সেনসিবল':'NN','সেনসেক্স':'NN','সেনসেটিফ':'JJ','সেনা':'NN',
'সেনাদল':'NN','সেনাদের':'NNS','সেনাধিপতি':'NN','সেনাধ্যক্ষ':'NN','সেনানায়ক':'NN','সেনানী':'NN','সেনানীরা':'NNS',
'সেনাপতি':'NN','সেনাপ্রধান':'NN','সেনাবাহিনির':'NN','সেনাবাহিনীকে':'NN','সেনাবাহিনীতে':'NN','সেনামুখ':'NN','সেনারহিত':'JJ',
'সেনারা':'NNS','সেনালী':'NNP','সেনি':'PR','সেনিটেশন':'NN','সেনের':'NNP','সেন্চুরি':'NN','সেন্চুরির':'NN',
'সেন্ট':'NN','সেন্টার':'NN','সেন্টিম':'NN','সেন্টিমেন্টকে':'NN','সেন্টিয়াগো':'NN','সেন্ট্রাল':'NN','সেন্স':'NN',
'সেন্সুরি':'NN','সেন্সেটিব':'JJ','সেন্সেশান':'NN','সেপটেমবর':'NNP','সেপা':'NN','সেপাইগিরি':'NN','সেপ্টেম্বর':'NN',
'সেপ্টেম্বরের':'NNP','সেফটি':'NN','সেবক':'NN','সেবড়া':'NN','সেবতী':'NN','সেবন':'NN','সেবনযোগ্য':'JJ',
'সেবনীয়':'NN','সেবা-শুশ্রুষা':'NN','সেবা':'NN','সেবাও':'NN','সেবাকার্য্যের':'NN','সেবাকেই':'PR','সেবাটা':'NN',
'সেবাতেও':'NN','সেবাদ্বাতা':'NN','সেবাপূজা':'NN','সেবাব্যবসায়':'NN','সেবামূলক':'JJ','সেবাযত্ন':'NN','সেবার':'NNP',
'সেবারও':'RB','সেবাশ্রম':'NN','সেবায়':'NN','সেবিত':'JJ','সেবী':'NN','সেবে':'RB','সেভ':'NN',
'সেভাবে':'WRB','সেভাবেই':'NN','সেভিং':'NN','সেভিংস':'NNP','সেভিয়া':'NN','সেভেন':'NN','সেমি':'NN',
'সেমিটিক':'NN','সেমিটিকদের':'PR','সেমিতে':'NN','সেমিনার':'NN','সেমিফাইনাল':'NN','সেমির':'NN','সেময়':'NN',
'সেযুগে':'NN','সের':'NN','সেরই':'PR','সেরওয়া':'NN','সেরকম':'NN','সেরকমভাবে':'RB','সেরছিপ':'NN',
'সেরডিকা':'NN','সেরপু':'NNP','সেরা':'NN','সেরাব':'NN','সেরামেসি':'NN','সেরিয়াম':'NN','সেরূপ':'DM',
'সেরে':'NN','সেরো':'NN','সেল':'NN','সেলফোনে':'NN','সেলবির':'NNP','সেলম':'NN','সেলস':'NNS',
'সেলসিয়াস':'NN','সেলাই-এর':'NN','সেলাই':'NN','সেলাইনো':'VB','সেলাইয়ের':'NN','সেলাম':'NN','সেলায়':'NN',
'সেলিব্রিটি':'NN','সেলিব্রেটিদের':'NN','সেলিম':'NN','সেলুকাছ':'NN','সেলুকাস':'NN','সেলুন':'NN','সেলে':'NN',
'সেলেনিয়াম':'NN','সেলোটেপ':'NN','সেল্টা':'NN','সেশ':'NN','সেশনেই':'NN','সেশিল্জ':'NN','সেশিল্জী':'NN',
'সেশিল্জের':'JJ','সেশোল্স':'NN','সেসকল':'NN','সেসব':'NN','সেসিল':'NN','সেসিয়াম':'NN','সেসে':'NN',
'সেসোথো':'NN','সেসোস্ট্রিস৷':'NNP','সেহুড়':'NN','সেহেতু':'NN','সেহেরা':'NN','সোনার':'NN','সোর্সিং':'NN',
'সোলায়মান':'NN','সোহাগ':'NN','সৌদি':'NN','সেয়ানা':'JJ','সেয়ার':'NN','সে‌ঞ্চু‌রি':'NN','সৈকত':'JJ',
'সৈতারী':'NN','সৈদী':'NN','সৈনিক':'NN','সৈনিকদের':'NN','সৈন্ধ':'NN','সৈন্ধবী':'NN','সৈন্য-সামন্ত':'NN',
'সৈন্য':'NN','সৈন্যবাহিনী':'NN','সৈন্যরা':'NN','সৈয়দ':'NN','সৈরন্ধ্রী':'NN','সৈাদির':'NN','সৈয়দ':'NN',
'সো':'NN','সোঁটা':'NN','সোঁঠারা':'NN','সোঁদা':'NN','সোকরেটিস':'NN','সোখরি':'NN','সোগে':'NN',
'সোচ্চার':'VB','সোজা':'NN','সোজাপথগামী':'JJ','সোজাভাবে':'RB','সোজাসাপ্টা':'NN','সোজাসুজি':'RB','সোটা':'NN',
'সোডা-ভস্ম':'NN','সোডা':'NN','সোত্সাহে':'NN','সোদের':'NN','সোন':'NN','সোনচিড়িয়া':'NN','সোনপুর':'NN',
'সোনভদ্র':'NN','সোনলী':'NN','সোনহা':'NN','সোনা':'NN','সোনাপুর':'NN','সোনাবল্লী':'NN','সোনার':'NN',
'সোনারপুরে':'NNP','সোনাল':'NN','সোনালী':'NN','সোনিপত':'NN','সোনিয়া':'NN','সোনেপুর':'NN','সোনোগ্রাফী':'NN',
'সোপর্দ':'NN','সোপান':'NN','সোপানশ্রেনী':'NN','সোফা':'NN','সোফিস্ট':'NNP','সোফিয়া':'NN','সোবোর্গিয়াম':'NN',
'সোভিয়েট':'NN','সোভিয়েতদের':'NNP','সোম':'NN','সোমগ্রহ':'NN','সোমজ':'NN','সোমদেব':'NN','সোমদেবের':'NNP',
'সোমনাথ':'NN','সোমপাত্র':'NN','সোমবংশীয়':'JJ','সোমবল্ক':'NN','সোমবার':'NN','সোমবারি':'JJ','সোমবারের':'NNP',
'সোমযজ্ঞ':'NN','সোমরস':'NN','সোমলতা':'NN','সোমহুতি':'NN','সোমা':'NN','সোমালিয়া':'NN','সোমালিয়া-বাসী':'NN',
'সোমালিয়া-সম্পর্কিত':'JJ','সোমালিয়া':'NN','সোমালিয়ার':'NN','সোমালীয়':'JJ','সোমাষ্টমী':'NN','সোমায়ন':'NN','সোমেশ':'NN',
'সোমোদ্রবা':'NN','সোম্যা':'NN','সোরঠা':'NN','সোরনি':'NN','সোরা':'NN','সোরিক':'JJ','সোর্স':'NN',
'সোল':'NN','সোলকড়ি':'NN','সোলজার':'NN','সোশ্যাল':'NN','সোসাইটি':'NNP','সোসাইটির':'NN','সোসালিস্ট':'NN',
'সোস্যালিস্ট':'NNP','সোহন':'NN','সোহনাই':'NNP','সোহর':'NN','সোহরাওয়ার্দী':'NN','সোহাগ':'NN','সোহান':'NN',
'সোহেল':'NN','সোয়া':'NN','সোয়াজিল্যাণ্ড':'NNP','সোয়াত':'NN','সোয়ানা':'JJ','সোয়াবিন':'NN','সোয়াহিলী':'JJ',
'সোয়িংকা':'NNP','সোয়েটার':'NN','সোয়েব':'NN','সৌকারয়ণ':'NN','সৌক্ষ্মাত্':'NN','সৌখীন':'JJ','সৌজন্য':'NN',
'সৌদামণী':'NN','সৌদামিনী':'NN','সৌদি':'NN','সৌদিদের':'NN','সৌদী':'NN','সৌধ':'NN','সৌন্দর্য':'NN',
'সৌন্দর্য্যকে':'NN','সৌন্দর্য্যাত্মক':'JJ','সৌন্দর্য্যে':'NN','সৌপর্ণ':'NN','সৌবলী':'NN','সৌভর':'NN','সৌভাগ্য':'NN',
'সৌভাগ্যতৃতীয়া':'NN','সৌভাগ্যবান':'NN','সৌভাগ্যব্রত':'NN','সৌভাগ্যশালী':'JJ','সৌভাগ্যে':'NN','সৌভাগ্যোপনিষদ':'NN','সৌভারি':'NN',
'সৌমিত্র':'NN','সৌম্য':'JJ','সৌম্যকে':'NN','সৌম্যদার':'NNP','সৌম্যদের':'NN','সৌম্যের':'NN','সৌর':'RB',
'সৌরজগত্':'NN','সৌরজাত':'JJ','সৌরধ্রী':'NN','সৌরনক্ত':'NN','সৌরপত':'NN','সৌরভ':'NN','সৌরমন্ডল':'NN',
'সৌরাটি':'NN','সৌরাষ্ট্র':'NN','সৌরাষ্ট্রীয়':'JJ','সৌরাষ্ট্রের':'NN','সৌরী':'NN','সৌর্হার্দ্যপূর্ণ':'JJ','সৌশাল':'NN',
'সৌষ্ঠব':'NN','সৌহার্দ্য':'NN','সৌহার্দ্যপূর্ণ':'JJ','স্কট':'NN','স্কটল্যান্ড':'NN','স্কটিশচার্চ':'NNP','স্কটের':'NN',
'স্কন্দ':'NN','স্কন্দমাতা':'NN','স্কন্দষষ্ঠী':'NN','স্কন্দাপস্মার':'NN','স্কন্দোপনিষদ':'NN','স্কন্ধ':'NN','স্কন্ধমল্লক':'NN',
'স্কন্ধাবরণ':'NN','স্কন্ধাস্থি':'NN','স্কন্ধেই':'NN','স্কাই':'NN','স্কার্ট':'NN','স্কালক্যাপ':'NN','স্কি':'NN',
'স্কিম':'NN','স্কিলও':'NN','স্কীম':'NN','স্কুইড':'NN','স্কুটার':'NN','স্কুবা':'NN','স্কুলকলেজ':'NN',
'স্কুলগুলি':'NN','স্কুলগুলোকে':'NN','স্কুলব্যাগ':'NN','স্কুলশুদ্ধ':'JJ','স্কুলে':'NN','স্কুলের':'NN','স্কেল':'NN',
'স্কেলে':'NN','স্কোপজে':'NN','স্কোয়াড':'NN','স্কোর':'NN','স্কোরকার্ড':'NN','স্কোয়াডে':'NN','স্কোয়ার':'NN',
'স্ক্যাণ্ডালে':'NN','স্ক্যান':'NN','স্ক্যান্ডিনেভিয়া':'NN','স্ক্যান্ডিনেভীয়':'NN','স্ক্যাপ':'NN','স্ক্রীন':'NN','স্ক্র্যাপ':'NN',
'স্খলন':'NN','স্খলিত':'JJ','স্টক':'NN','স্টকএক্সচেঞ্জের':'NN','স্টকহোম':'NN','স্টক্':'NN','স্টডিয়ামে':'NN',
'স্টপ':'NN','স্টল':'NN','স্টাইপ':'NN','স্টাইলে':'NN','স্টাউট':'NNP','স্টাকহোম':'NN','স্টাটাস':'NN',
'স্টাফ':'NN','স্টারিজ':'NN','স্টার্চযুক্ত':'JJ','স্টার্ট':'NN','স্টিক':'NN','স্টিভ':'NN','স্টিমরোলার':'NN',
'স্টিম্যুলেটেড':'NN','স্টিল':'NN','স্টিয়ারিং':'NN','স্টীকার':'NN','স্টীমারে':'NN','স্টু':'NN','স্টুডেন্ট':'NN',
'স্টুপিড':'NN','স্টেজ':'NN','স্টেট':'NN','স্টেটব্যাংক':'NN','স্টেটমেন্ট':'NN','স্টেটস':'NN','স্টেটের':'NN',
'স্টেডিয়াম':'NN','স্টেডিয়ামে':'NN','স্টেথোস্কোপ':'NN','স্টেনফোর্ড':'NN','স্টেনোগ্রাফার':'NN','স্টেন্সিল':'NN','স্টেবিলাইজার':'NN',
'স্টেরয়েড':'NN','স্টেলিন':'NN','স্টেশনারি':'NN','স্টেশান':'NN','স্টোকস':'NN','স্টোনচিপ':'NN','স্টোনিয়াবাসী':'NN',
'স্টোভ':'NN','স্টোরে':'NN','স্টোর্স':'NNP','স্টোল':'NN','স্ট্যাটস':'NN','স্ট্যাটাসই':'NN','স্ট্যাটাসের':'NNP',
'স্ট্যাটিসটিক্যাল':'NN','স্ট্যাটিস্টিক্স':'NN','স্ট্যানলি':'NN','স্ট্যাম্প':'NN','স্ট্রবেরী':'NN','স্ট্রাইক':'NN','স্ট্রাইকারদের':'NN',
'স্ট্রাকচারের':'NN','স্ট্রাটেজি':'NN','স্ট্রিকের':'NN','স্ট্রিটে২':'NN','স্ট্রীট':'NNP','স্ট্রীটের':'NNP','স্ট্রেংথ':'NN',
'স্ট্রেন':'NN','স্ট্রোন্টিয়াম':'NN','স্ট্রয়বার্গ':'NNP','স্তন':'NN','স্তনহার':'NN','স্তনালিঙ্গন':'NN','স্তনের':'NN',
'স্তন্যপায়ী':'NN','স্তন্যহীনা':'JJ','স্তব':'NN','স্তব্ধতা':'NN','স্তম্ভ':'NN','স্তম্ভমূল':'NN','স্তম্ভিত':'NN',
'স্তর':'NN','স্তরযুক্ত':'JJ','স্তরিত':'JJ','স্তরীয়':'JJ','স্তরে':'NN','স্তরের':'NN','স্তাবা':'NN',
'স্তিমিত':'NN','স্তুতি':'NN','স্তুপ':'NN','স্তুপাকারে':'NN','স্তূতিস্থলে':'NN','স্তূপ':'NN','স্তোতক':'NN',
'স্ত্ররে':'NN','স্ত্রী-পুরুষ':'NN','স্ত্রী-সংক্রান্ত':'JJ','স্ত্রী-সম্পর্কিত':'JJ','স্ত্রী':'NN','স্ত্রীকুসুম':'NN','স্ত্রীকেশর':'NN',
'স্ত্রীগমন':'NN','স্ত্রীজিত':'NN','স্ত্রীপ্রজাতি':'JJ','স্ত্রীভক্ত':'JJ','স্ত্রীর':'NN','স্ত্রীলিঙ্গ':'NN','স্ত্রীলোক':'NN',
'স্ত্রীসংসর্গ':'NN','স্ত্রীসমাগম':'NN','স্ত্রীসুখ':'NN','স্ত্রৈণ':'NN','স্ত্রৈনতা':'NN','স্থগিত':'NN','স্থগিতকরণ':'NN',
'স্থগিতনো':'VB','স্থপতিদের':'NN','স্থবির':'NN','স্থবিরতার':'NN','স্থল-সেনা':'NN','স্থল':'NN','স্থলবাসী':'JJ',
'স্থলবিশেষে':'NN','স্থলভাগের':'NN','স্থলযান':'NN','স্থলসেনা':'NN','স্থা':'NN','স্থাণুরোগে':'NN','স্থান-মাহাত্ম্যের':'NN',
'স্থান':'NN','স্থানচ্যুত':'JJ','স্থানচ্যূত':'NN','স্থানটি':'NN','স্থানভেদে':'NN','স্থানান্তকরণ':'NN','স্থানান্তরণ':'NN',
'স্থানান্তরের':'NN','স্থানিক':'JJ','স্থানীয়':'JJ','স্থানীয়':'NN','স্থানীয়ভাবে':'NN','স্থানুরোগ':'NN','স্থানে':'NN',
'স্থাপত্য':'NN','স্থাপত্যবিদ':'NN','স্থাপত্যশিল্প':'NN','স্থাপত্যের':'NN','স্থাপন':'NN','স্থাপনার':'NN','স্থাপনীয়':'JJ',
'স্থাপনে':'NN','স্থাপিত':'NN','স্থাপ্য':'JJ','স্থাবর-অস্থাবর':'JJ','স্থাবর':'NN','স্থাবরঅস্থাবর':'NN','স্থায়ী':'JJ',
'স্থায়ি':'NN','স্থায়িত্ব':'NN','স্থায়ী':'NN','স্থায়ীরূপ':'NN','স্থিত':'NN','স্থিতপ্রজ্ঞ':'JJ','স্থিতি':'NN',
'স্থিতিশক্তি':'NN','স্থিতিশীল':'NN','স্থিতিস্থাপক':'JJ','স্থিতিস্থাপকতা':'NN','স্থির':'NN','স্থিরকারী':'NN','স্থিরচিত্ত':'JJ',
'স্থিরচিত্ততা':'NN','স্থিরমনস্কতা':'NN','স্থুল':'NN','স্থূলকন্দ':'NN','স্থূলকায়':'JJ','স্থূলতা':'NN','স্নাত':'NN',
'স্নাতকীয়':'JJ','স্নাতকোত্তর':'NN','স্নান':'NN','স্নানঘর':'NN','স্নাননো':'NN','স্নানপাত্র':'NN','স্নানযোগ্য':'JJ',
'স্নানাগার':'NN','স্নানাভিষেক':'NN','স্নায়ু':'NN','স্নায়ুতন্ত্র':'NN','স্নায়ুবিজ্ঞান':'NN','স্নায়ুবিদ্যা':'JJ','স্নায়ুমন্ডলী':'NN',
'স্নিকোমিটার':'NN','স্নিগ্ধ':'JJ','স্নিগ্ধতা':'NN','স্নেফরু':'NNP','স্নেহ':'NN','স্নেহময়ী':'JJ','স্নেহশীল':'NN',
'স্নেহশীলা':'NNP','স্নেহসুত্র':'NN','স্নেহা':'NN','স্নো':'NN','স্পঞ্জ-এর':'NN','স্পট':'NN','স্পটলাইট':'NN',
'স্পন্দক':'NN','স্পন্দনহীনতা':'NN','স্পন্দিত':'NN','স্পন্সরশীপ':'NN','স্পর্ধী':'NN','স্পর্শকাতর':'JJ','স্পর্শজ':'NN',
'স্পর্শনো':'VB','স্পর্শবর্ণ':'NN','স্পর্শিত':'JJ','স্পর্শে':'NN','স্পর্শেন্দ্রিয়':'NN','স্পষ্ট':'NN','স্পষ্টই':'RB',
'স্পষ্টতই':'NN','স্পষ্টতা':'NN','স্পষ্টবাদী':'JJ','স্পষ্টভাবে':'RB','স্পষ্টীকরণ':'NN','স্পা':'NN','স্পার্টা':'NN',
'স্পিকার':'NN','স্পিচ':'NN','স্পিডকে':'NN','স্পিতামা':'NNP','স্পিতি':'NN','স্পিনার':'NN','স্পিনিং':'NN',
'স্পীড':'NN','স্পীডের':'NN','স্পীডোমিটার':'NN','স্পৃশ্য':'JJ','স্পৃহা':'NN','স্পেকট্রাম':'NNP','স্পেন':'NN',
'স্পেনীয়':'NN','স্পেশাল':'NN','স্পেশালাইজড':'JJ','স্পেশালিষ্ট':'NN','স্পেস':'NN','স্পেসক্রাফ্ট':'NN','স্পোর্টসম্যানশিপ':'NN',
'স্পোক':'NN','স্পোর্টস':'NN','স্প্যনিশ':'JJ','স্প্যান':'NN','স্প্যানিশভাষী':'NN','স্প্যানিসে':'NN','স্প্রিং-ফেল্স':'NN',
'স্প্রিং':'NN','স্প্রিংওলা':'JJ','স্প্রিংযুক্ত':'JJ','স্প্রীড':'NN','স্প্রেড':'NN','স্ফটিক':'NN','স্ফটিকনির্মিত':'JJ',
'স্ফটিকসুলভ':'JJ','স্ফটিকের':'JJ','স্ফীত':'NN','স্ফুটনাঙ্ক':'NN','স্ফুর্তি':'NN','স্ফুর্তিতে':'RB','স্ফুর্তিদায়ক':'JJ',
'স্ফুর্তিপূর্বক':'RB','স্ফুলিঙ্গ':'NN','স্ফুলিঙ্গের':'NNS','স্ফূর্তিবাজ':'JJ','স্বউদ্যোগে':'NN','স্বকপোল':'JJ','স্বকপোলকল্পিত':'JJ',
'স্বকীয়':'JJ','স্বকৃত':'JJ','স্বগত':'RB','স্বচালিত':'NN','স্বচ্ছ':'NN','স্বচ্ছতার':'NN','স্বচ্ছন্দে':'NN',
'স্বচ্ছপ্রায়তা':'NN','স্বচ্ছল':'NN','স্বজন':'NN','স্বজনদের':'NN','স্বজনপোষণমূলক':'JJ','স্বজনপ্রীতি':'NN','স্বজনরাই':'NNS',
'স্বজনহীন':'JJ','স্বজাতি':'JJ','স্বজাতির':'NN','স্বজাতীয়':'JJ','স্বঠিক':'NN','স্বণামধণ্য':'NN','স্বত':'JJ',
'স্বতঃ':'RB','স্বতঃই':'PR','স্বতঃপ্রমানিত':'NN','স্বতঃমূল্য':'NN','স্বতঃসিদ্ধ':'NN','স্বতঃস্ফূর্ত':'JJ','স্বতঃস্ফূর্তভাবে':'NN',
'স্বতন্ত্র':'RB','স্বতন্ত্রতার':'NN','স্বতন্ত্রভাবে':'RB','স্বতন্ত্র্য':'JJ','স্বতস্ফুর্ততা':'NN','স্বতস্ফূর্ত':'JJ','স্বতস্ফূর্তী':'NN',
'স্বত্তেও':'NN','স্বত্ত্বাধিকারী':'NN','স্বত্বত্যাগী':'NN','স্বত্বহীন':'JJ','স্বত্বাধিকার':'NN','স্বত্বেও':'NN','স্বদিচ্ছাটাই':'NN',
'স্বদেশ':'NN','স্বদেশীয়':'JJ','স্বদেশের':'NN','স্বধা':'NN','স্বধিতি':'NN','স্বনামধন্য':'JJ','স্বনামে':'NN',
'স্বনিম-এর':'JJ','স্বনির্বাচিত':'NN','স্বনির্ভর':'JJ','স্বনির্ভরতা':'NN','স্বপক্কের':'NN','স্বপক্ষী':'JJ','স্বপক্ষে':'NN',
'স্বপক্ষের':'NNS','স্বপদে':'NN','স্বপনরা':'NN','স্বপ্নও':'NN','স্বপ্নটা':'NN','স্বপ্নদ্রষ্টা':'NN','স্বপ্না':'NN',
'স্বপ্নাবস্থা':'JJ','স্বপ্নে':'NNS','স্বপ্নের':'NN','স্বপ্রচার':'NN','স্বপ্রনেদিত':'NN','স্বপ‌দে':'NN','স্ববশ':'JJ',
'স্ববিবেক':'NN','স্ববিরোধি':'JJ','স্বভাব':'NN','স্বভাবগত':'JJ','স্বভাবজাত':'JJ','স্বভাবতঃ':'RB','স্বভাবিক':'JJ',
'স্বভাবের':'NN','স্বর':'NN','স্বরকম্পের':'NN','স্বরক্ষিত':'JJ','স্বরধ্বনি':'NN','স্বরনালী':'NN','স্বরপ্রধান':'NN',
'স্বরবর্ণ':'NN','স্বরভঙ্গ':'NN','স্বরমণ্ডল':'NN','স্বরমাত্রা':'NN','স্বরযন্ত্র':'NN','স্বরযুক্ত':'JJ','স্বরলিপি':'NN',
'স্বরাজ':'NN','স্বরাষ্টক':'NN','স্বরাষ্ট্রমন্ত্রী':'NN','স্বরিত':'NN','স্বরূপ':'NN','স্বরে':'VB','স্বরোজগার':'NN',
'স্বরোজগারিত':'JJ','স্বর্গ':'NN','স্বর্গনদী':'NN','স্বর্গরাজ্য':'NN','স্বর্গসুখ':'NN','স্বর্গালোক':'NN','স্বর্গীয়':'NN',
'স্বর্গে':'RB','স্বর্গেই':'NN','স্বর্ণকার':'NN','স্বর্ণকাল':'NN','স্বর্ণখনি':'NN','স্বর্ণজীবন্তী':'NN','স্বর্ণধুনী':'NN',
'স্বর্ণপক্ষ':'NN','স্বর্ণপর্ণী':'NN','স্বর্ণবর্ণা':'NN','স্বর্ণমক্ষিকা':'NN','স্বর্ণমাতা':'NN','স্বর্ণমুখী':'NN','স্বর্ণমুদ্রাও':'NN',
'স্বর্ণযুগ':'NN','স্বর্ণলতা':'NN','স্বর্ণশেফালিকা':'NN','স্বর্ণাকর':'NN','স্বর্ন':'NN','স্বর্বাপী':'NN','স্বল্প':'NN',
'স্বল্পকরণ':'NN','স্বল্পকালীন':'JJ','স্বল্পকেশী':'NN','স্বল্পঘণ্টা':'NN','স্বল্পজ্ঞানী':'JJ','স্বল্পতা':'NN','স্বল্পদর্শী':'JJ',
'স্বল্পন্নোত':'NN','স্বল্পপঞ্চমূল':'NN','স্বল্পপত্রক':'NN','স্বল্পপুঁজি':'JJ','স্বল্পবুদ্ধিসম্পন্ন':'JJ','স্বল্পবেশী':'JJ','স্বল্পব্যয়':'NN',
'স্বল্পব্যয়ী':'JJ','স্বল্পবয়স্ক':'NN','স্বল্পভাষী':'JJ','স্বল্পমূল্য':'JJ','স্বল্পমূল্যে':'NN','স্বল্পশিক্ষিতকে':'NN','স্বল্পসংখ্যক':'NN',
'স্বল্পাহারী':'JJ','স্বল্পায়ু':'JJ','স্বল্পোন্নত':'VBN','স্বশাসন':'NN','স্বশিক্ষিত':'JJ','স্বশ্রদ্ধ':'NN','স্বস্তি':'NN',
'স্বস্তিদায়ক':'JJ','স্বস্তির':'NN','স্বস্থানচ্যূত':'JJ','স্বস্থিতে':'NN','স্বাক্ষর':'NN','স্বাক্ষরিত':'JJ','স্বাক্ষরেরর':'NN',
'স্বাক্ষ্য':'NN','স্বাগত':'NN','স্বাগতিক':'VB','স্বাচছন্দের':'NN','স্বাজী':'NN','স্বাজীল্যান্ড':'NN','স্বাত':'NN',
'স্বাতন্ত্র':'NN','স্বাতন্ত্রের':'NN','স্বাতি':'NN','স্বাদ-ও':'NN','স্বাদ-লোলুপতা':'NN','স্বাদ':'NN','স্বাদপূর্ণ':'JJ',
'স্বাদযুক্ত':'NN','স্বাদলোলুপ':'JJ','স্বাদহীন':'JJ','স্বাদের':'NN','স্বাধিকার':'NN','স্বাধিনতাকামীরা':'NN','স্বাধিষ্ঠান':'NN',
'স্বাধিীনতা':'NN','স্বাধীনতা':'NN','স্বাধীনতাকামীদের':'NN','স্বাধীনতাবিরোধী':'NN','স্বাধীনতাযুদ্ধের':'NN','স্বাধীনতাসংগ্রামী':'NN','স্বাধীনতায়':'NN',
'স্বাধীনভাবে':'RB','স্বাধেও':'NN','স্বান্তনা':'NN','স্বাবলম্বন':'NN','স্বাবলম্বি':'JJ','স্বাবাধীন':'NN','স্বাবাবিক':'NN',
'স্বাভাবিককারন':'NN','স্বাভাবিকভাবেই':'RB','স্বাভিপ্রায়':'NN','স্বামর্থ':'NN','স্বামীকে':'NN','স্বামীজী':'JJ','স্বামীজীর':'NNP',
'স্বামীর':'NN','স্বামীস্ত্রীর':'NN','স্বামীহীনা':'JJ','স্বায়ত্তশাসিত':'JJ','স্বায়ত্তীকরণ':'NN','স্বারথোপরতা':'NN','স্বারোচিষ':'NN',
'স্বার্জিত':'JJ','স্বার্থ':'NN','স্বার্থকে':'JJS','স্বার্থকেন্দ্রিক':'JJ','স্বার্থচিন্তা':'NN','স্বার্থটা':'JJS','স্বার্থপর':'NN',
'স্বার্থপরায়ণ':'JJ','স্বার্থপূর্ণতা':'NN','স্বার্থবর্জনকারী':'JJ','স্বার্থহীন':'JJ','স্বার্থহীনতা':'NN','স্বার্থান্ধ':'JJ','স্বার্থান্বেষি':'NN',
'স্বার্থান্বেষী':'JJ','স্বার্থে':'JJS','স্বার্থেও':'NN','স্বার্থের':'JJS','স্বার্ধ':'JJ','স্বাস্থ্য':'NN','স্বাস্থ্যকরই':'JJ',
'স্বাস্থ্যনিবাস':'NN','স্বাস্থ্যপ্রদ':'JJ','স্বাস্থ্যবান':'NN','স্বাস্থ্যমন্ত্রী':'NN','স্বাস্থ্যলাভ':'NN','স্বাস্থ্যসম্মত':'JJ','স্বাস্থ্যের':'NN',
'স্বাস্থ‍্য':'NNP','স্বাহা':'NN','স্বায়ত্তশাসন':'NN','স্বায়ত্তশাসিত':'JJ','স্বায়ত্ব':'NN','স্বায়ত্বশাসিত':'JJ','স্বিকার':'NN',
'স্বী':'JJ','স্বীকরণ':'NN','স্বীকারই':'RB','স্বীকারনো':'VB','স্বীকারাত্মক':'JJ','স্বীকারোক্তি':'NN','স্বীকার্য্য':'JJ',
'স্বীকৃত':'NN','স্বীকৃতিতে':'NN','স্বীকৃতিপত্র':'NN','স্বীয়':'PR','স্বেচ্ছা':'NN','স্বেচ্ছাগামী':'JJ','স্বেচ্ছাচারিতা':'NN',
'স্বেচ্ছাচারী':'NN','স্বেচ্ছাচ্ছারী':'JJ','স্বেচ্ছাপূর্বক':'RB','স্বেচ্ছাপ্রণোদিত':'JJ','স্বেচ্ছামূলক':'JJ','স্বেচ্ছায়':'RB','স্বেচ্ছাসেবক':'NN',
'স্বেচ্ছায়':'NN','স্বেদ-বিন্দু':'NN','স্বেদ':'NN','স্বেদক':'JJ','স্বেদজ':'NN','স্বৈরতান্ত্রিক':'NN','স্বৈরাচার':'NN',
'স্বৈরাচারী':'JJ','স্বৈরাতন্ত্রের':'NN','স্বৈারাচারের':'NN','স্বোপার্জিত':'JJ','স্বয়ং':'NN','স্বয়ংক্রিয়':'JJ','স্বয়ংক্রিয়ভাবে':'NN',
'স্বয়ংবর':'NN','স্বয়ংবরসভা':'NN','স্বয়ংসম্পুর্ণ':'JJ','স্বয়ংসম্পূর্ন':'NN','স্বয়ংসিদ্ধ':'JJ','স্বয়ম':'JJ','স্বয়ম্ভু':'JJ',
'স্মন':'NN','স্মর-বাণ':'NN','স্মর':'NN','স্মরণ':'VB','স্মরণর':'NN','স্মরণশক্তি':'NN','স্মরণিকা':'NN',
'স্মরণীয়':'JJ','স্মরণীয়':'NN','স্মরনীয়':'JJ','স্মাগলার':'NN','স্মাট':'NN','স্মারকলিপি':'NN','স্মারট':'NN',
'স্মার্টফোন':'NN','স্মার্ত':'NN','স্মিত':'JJ','স্মিতভাবে':'VB','স্মিথ':'NN','স্মিথকে':'NNP','স্মৃতি-তাড়িত':'JJ',
'স্মৃতি-প্রতিরূপ':'NN','স্মৃতি':'NN','স্মৃতিকে':'NN','স্মৃতিচারণ':'NNS','স্মৃতিচিহ্ন':'NN','স্মৃতিতে':'NN','স্মৃতিধর':'JJ',
'স্মৃতিবিহীনতা':'NN','স্মৃতির':'NN','স্মৃতিরত্নাকর':'JJ','স্মৃতিশক্তি':'NN','স্মৃতিশক্তিধর':'JJ','স্মৃতিশাস্ত্র':'NN','স্মৃতিসম্বন্ধীয়':'JJ',
'স্মৃতিস্তম্ভ':'NN','স্মৃতিহীন':'JJ','স্মৃতিহীনতা':'NN','স্মোকিং':'NN','স্যন্ডুইচ':'NN','স্যন্দন':'NN','স্যমন্তক':'NN',
'স্যর':'NNP','স্যলুট':'NN','স্যাঁকা':'NN','স্যাঁতসেতে':'NN','স্যাকরানি':'NN','স্যাটেলাইট':'NN','স্যাণ্ড':'NN',
'স্যানিটোরিয়াম':'NN','স্যান্ডেল':'NN','স্যামসাং':'NN','স্যাম্পু':'NNP','স্যাম্পেল':'NN','স্যার':'NN','স্যারকে':'NNP',
'স্যারগণদেরকে':'NNS','স্যারের':'NNP','স্যালাড':'NN','স্যালারি':'JJ','স্যালুট':'NN','স্যুইমিং':'NN','স্যুট-বুট':'NN',
'স্যুটিং':'NN','স্যেন':'NN','স্রমিক':'NN','স্রমিকদের':'NNS','স্রষ্টা':'NN','স্রষ্টার':'NN','স্রাব':'NN',
'স্রিঙ্কখলা':'NN','স্রুক':'NN','স্রেফ':'RB','স্রোত':'NN','স্রোতের':'NNS','স্রৌতে':'NN','স্লগ':'NN',
'স্লাইড':'NN','স্লাভ':'JJ','স্লাম':'NN','স্লিপ':'NN','স্লিভলেস':'JJ','স্লীপার':'NN','স্লেজ':'NN',
'স্লেজিংয়ের':'NN','স্লেট':'NN','স্লেভ':'NN','স্লো':'VB','স্লোগান':'NN','স্লোগানবাজিতে':'VBG','স্লোভাকিয়া':'NN',
'স্লোভাকিয়াবাসী':'NN','স্লোভাকীয়':'NN','স্লোভেনিয়া-বাসী':'NN','স্লোভেনিয়ার':'JJ','স্লোয়ার':'JJR','স্হগিত':'JJ','স্হল':'NN',
'স্হান':'NN','স্হানাধিকারী':'NN','স্হানান্তকরণ':'NN','স্হানীয়':'JJ','স্হাপত্যসংক্রান্ত':'JJ','স্হায়ী':'NN','স্হিতপ্রজ্ঞা':'NN',
'স্হিতিস্হাপক':'JJ','স্হিতিস্হাপকতা':'NN','স্হির':'VBN','সৎ':'JJS','সৎভাবে':'RB','সড়ক':'NN','সড়কপথে':'NN',
'সড়কের':'NN','সয়':'NN','সয়ংক্রিয়':'JJ','সয়ংসম্পুর্ন':'JJ','সয়ংসিদ্ধ':'NN','সয়লাব':'NN','সয়েল':'NN',
'স‌হজ':'JJ','স‌হজলভ্য':'JJ','হ':'NN','হং':'NN','হংকং':'NN','হংস-পাশা':'NN','হংস':'NN',
'হংসগতি':'NN','হংসগমন':'NN','হংসগমনা':'JJ','হংসগামিনী':'NN','হংসগামীনী':'JJ','হংসপদী':'NN','হংসবাহন':'NN',
'হংসমঙ্গলা':'NN','হংসালি':'NN','হংসিনী':'NN','হংসোপনিষদ':'NN','হআকর':'JJ','হই':'UH','হইচই':'NN',
'হইছিল':'NN','হইছে':'NN','হইড্রোজেনের':'NNP','হইত':'RB','হইতে':'IN','হইতেই':'NN','হইতেছে':'VBG',
'হইতো':'RB','হইনি':'DT','হইব':'NN','হইবার':'NNV','হইবে':'MD','হইবেন':'VB','হইবো':'VB',
'হইব্যাপক':'IN','হইয়া':'VB','হইল':'VB','হইলে':'IN','হইলেও':'RP','হইলো':'VB','হইসে':'VB',
'হইয়া':'VB','হইয়াছে':'VB','হউ':'VB','হউক':'WDT','হউকমূল':'NN','হউয়ার':'NN','হও':'VB',
'হওক':'RB','হওয়া':'VB','হওয়ায়':'VB','হওযা':'NN','হওাকে':'VB','হওার':'VB','হওয়া':'NN',
'হওয়াই':'VB','হওয়াটা':'VB','হওয়াটায়':'VB','হওয়াতে':'VB','হওয়াতো':'VB','হওয়ার':'NN','হওয়ারই':'VB',
'হওয়ায়':'VB','হক':'NN','হককে':'NN','হকচকিয়ে':'RB','হকারান্ত':'JJ','হকাল':'NN','হকি':'NN',
'হকিংকে':'NN','হকীক':'NN','হকে':'UH','হকেট':'NNP','হকের':'NN','হঘাত':'NN','হচছে':'VBG',
'হচরী':'JJ','হচেছ':'NN','হচ্চছে':'VBG','হচ্ছি':'VBG','হচ্ছিলাম':'NN','হচ্ছিলেন':'VBG','হচ্ছে':'VB',
'হচ্ছেঅতএব':'IN','হচ্ছেঅথচ':'VBG','হচ্ছেএরপরেও':'DT','হচ্ছেটা':'VBG','হচ্ছেডপ':'NN','হচ্ছেন':'VBG','হছছে':'VB',
'হছেছ':'VBG','হজ':'NN','হজমশক্তি':'NN','হজরত':'NN','হজাত':'JJ','হজেই':'VB','হজের':'NN',
'হজ্জ':'NN','হট':'NN','হটকারিতা':'NN','হটযোগ':'NN','হটলাইন':'NN','হটলে':'NN','হটাত':'RB',
'হটানো':'VB','হটাৎ':'RB','হটিয়ে':'VBN','হটিয়ে':'VB','হটে':'NN','হট্ট':'NN','হঠ':'NN',
'হঠকারিতা':'NN','হঠকারী':'JJ','হঠযোগী':'NN','হঠাত':'NN','হঠাত্':'RB','হঠাত্্':'RB','হঠানো':'VB',
'হঠাৎ':'RB','হঠিয়ে':'VB','হড়কানে':'NN','হড়গিলা':'NN','হড়তাল':'NN','হড়প':'VB','হড়পি':'NN',
'হড়প্পা':'NN','হড়বড়':'NN','হড্ডজ':'NN','হঢ':'NNP','হণের':'NN','হণ্ডুরাসীয়':'JJ','হত':'NN',
'হতচকিত':'VB','হতচ্ছাড়া':'JJ','হততাহলে':'NN','হতদরিদ্র':'NN','হতনা':'NN','হতনাসুতরাং':'NN','হতবল':'JJ',
'হতবাক':'NN','হতবুদ্ধি':'VBN','হতভম্ব':'JJ','হতভম্ভ':'VBN','হতভাগা':'NN','হতাম':'NN','হতাশা':'NN',
'হতাশাজনক':'VBG','হতাশাবাদী':'JJ','হতাশামূলক':'JJ','হতাশার':'NN','হতাহত':'JJ','হতে':'VB','হতেই':'NN',
'হতেন':'NN','হতেহয়':'RB','হতো':'VB','হতোকারণ':'NN','হতো':'VB','হতোইনা':'NN','হতোউনাদের':'NNP',
'হতোছেলের':'NN','হতোতাহলে':'NNS','হতোনা':'NN','হত্তুকি':'NN','হত্থাজড়ী':'NN','হত্ব':'NN','হত্যা':'NN',
'হত্যাকাণ্ডে':'NN','হত্যাকান্ড':'NN','হত্যাকারি':'NNP','হত্যাকারিকে':'NN','হত্যাকারিদের':'NNS','হত্যাকারির':'NN','হত্যাকারীকে':'NN',
'হত্যাকারীতে':'NNP','হত্যাকারীদের':'NN','হত্যানির্যাতন':'NN','হত্যানো':'VB','হত্যার':'VBG','হত্যাসহ':'NN','হত‌ো':'NN',
'হত�':'VB','হথ্রন':'NN','হদিশ':'NN','হদেব':'NNP','হন':'VB','হনডুরাস-বাসী':'NN','হনতী':'JJ',
'হনন':'NN','হনাই':'VB','হনীয়':'JJ','হনু':'NN','হনুমান':'NN','হনুমানজয়ন্তী':'NN','হনের':'NN',
'হনোই':'NN','হন্টেড':'VBN','হন্ডা':'NN','হন্ডিয়া':'NN','হন্ডী':'NN','হন্ত':'JJ','হপ্তা':'NN',
'হব':'NN','হবএকদিন':'NN','হবতা':'NNS','হবতে':'VB','হবধু':'NNP','হবধূ':'VB','হবন':'NN',
'হবনীয়':'JJ','হবশচীন':'NN','হবা':'NN','হবারই':'NN','হবারও':'NNV','হবি':'NN','হবিগঞ্জে':'NN',
'হবিবুর':'NNP','হবির্ভু':'NN','হবিষ্':'NN','হবিষ্যান্ন':'NN','হবু':'NN','হবে':'VB','হবেঅথচ':'NN',
'হবেঅবশ্যই':'NN','হবেআপনাকে':'NN','হবেআমরা':'NN','হবেআর':'NN','হবেআল্লাহ':'NN','হবেআসলে':'NN','হবেই':'NN',
'হবেইনশাললাহ':'VBG','হবেইসলামী':'NNP','হবেএ':'NN','হবেএইযে':'NN','হবেএকটা':'NN','হবেএটাই':'NN','হবেও':'UH',
'হবেকত':'NN','হবেকারণ':'IN','হবেক্ষমতা':'NN','হবেক্ষমতায়':'JJR','হবেচরম':'NN','হবেতারপরও':'NN','হবেতাহলে':'NN',
'হবেতো':'VB','হবেদর্শকদের':'NN','হবেন':'VB','হবেনই':'NN','হবেনএতে':'NN','হবেননা':'NN','হবেনমহিলারা':'NN',
'হবেনা':'NN','হবেনাএছাড়া':'NN','হবেনাযদি':'NN','হবেনাসেই':'NN','হবেনিউজটা':'NNS','হবেনির্বাচনকে':'NNS','হবেপাকিস্তান':'NN',
'হবেপেট্রোল':'NN','হবেপেনসন':'NN','হবেবল':'NN','হবেবাংলাদেশে':'JJ','হবেবিএনপির':'NN','হবেভাল':'NN','হবেযা':'NN',
'হবেরাহুলকে':'NN','হবেসফরে':'NN','হবেসব':'NN','হবেসরকার':'NN','হবেসাকিব':'NN','হবেস্বাধীন':'NN','হবো':'NN',
'হব্য':'NN','হব‌ে':'NN','হমমমমম':'NN','হমাজা':'NN','হমান':'JJ','হমির':'NNP','হমিরপুর':'NN',
'হমীর':'NNP','হম্বিতম্বির':'NN','হময়ী':'JJ','হয়':'VB','হয়ত':'RB','হয়না':'NN','হয়রানি':'VB',
'হয়ে':'VB','হয়েই':'NN','হয়েছিল':'VB','হয়েছে':'NN','হয়েছেতবে':'RB','হয়েছেন':'NN','হয়েছেবিএনপির':'NN',
'হযে':'UH','হর':'NN','হরগোবিন্দ':'NN','হরচন্দ্র':'NNP','হরড়া':'NN','হরণ':'NN','হরণকারী':'NN',
'হরণযোগ্য':'JJ','হরণীয়.আহরণীয়':'JJ','হরণে':'NN','হরতন':'NN','হরতাল':'NN','হরতালকারীদের':'NNS','হরতালের':'NN',
'হরতুকি':'NN','হরদন':'NN','হরদোই':'NN','হরন':'NN','হরনাথ':'NNP','হরফ':'NN','হরফারেবড়ী':'NN',
'হরবল':'NN','হরমোন':'NN','হরশঙ্করী':'NN','হরহামেশাই':'NNS','হরাজ':'NNP','হরি':'NN','হরিকিষণ':'NN',
'হরিগীতা':'NN','হরিজন':'NN','হরিড়া':'NN','হরিণ':'NN','হরিতকি':'NN','হরিতলা':'NN','হরিত্':'NN',
'হরিদাস':'NNP','হরিদাসের':'NN','হরিদ্বার':'NN','হরিদ্রাপ্রমেহ':'NN','হরিদ্রাবর্ণ':'JJ','হরিধ্বনি':'NN','হরিনামে':'NN',
'হরিনীযদি':'NN','হরিপ্রসাদ':'NNP','হরিপ্রিয়':'NN','হরিবংশ':'NN','হরিবতক':'NN','হরিবল্লভা':'NN','হরিভক্তিও':'NN',
'হরির':'NNP','হরিরলুট':'NN','হরিলুটের':'NN','হরিশঙ্কর':'NN','হরিশচন্দ্র':'NN','হরিশ্মশ্রু':'NN','হরিস':'NN',
'হরিহর':'NN','হরিহরপিতামহ':'NN','হরিহরেশ্বর':'NN','হরিয়াণার':'JJ','হরিয়ানা':'NN','হরীতকী':'NN','হরীরা':'NN',
'হরে':'NN','হরেওয়া':'NN','হরেক':'VBN','হরেকৃষ্ণ':'NNP','হরেনা':'NN','হরের':'NNP','হরেরামপুরে':'NNP',
'হর্ণ':'NN','হর্তাকর্তা':'NN','হর্ন':'NNP','হর্মোণ':'NN','হর্ম্যশোভিত':'JJ','হর্রেয়া':'NN','হর্ষ':'NN',
'হর্ষনিস্বনী':'NN','হর্স':'NN','হল':'VB','হলআর':'NN','হলই':'NN','হলকর':'JJ','হলকে':'VB',
'হলঘরে':'NN','হলচাপে':'NN','হলদন্ড':'NN','হলধর':'NN','হলন্ত':'NN','হলফ':'NN','হলফনামা':'NN',
'হলবাহক':'NN','হলবি':'VB','হলমার্ক':'NN','হলমুখী':'NN','হলশেষ':'NN','হলাম':'NN','হলামসত্যিই':'NN',
'হলাহল':'NN','হলি':'NN','হলিদা':'NN','হলুদ':'NN','হলে':'NN','হলেআরও':'NN','হলেই':'VB',
'হলেউ':'IN','হলেও':'NN','হলেতো':'RB','হলেন':'NN','হলো':'UH','হলো':'VB','হলোআবার':'NN',
'হলোগ্রাফি':'NN','হলোনা':'NN','হলোবাংলাদেশ':'NN','হলোমোদ্দা':'NN','হলোয়িন':'NN','হল্কা':'NN','হল্যাণ্ড':'NNP',
'হল্যান্ড':'NN','হল্লা':'NN','হসন্ত':'NN','হসন্তযুক্ত':'NN','হসপিটাল':'NN','হসপিটালের':'NN','হসান':'VB',
'হসাবে':'NN','হসেবে':'IN','হস্টেল':'NN','হস্ত-মৈথুন':'NN','হস্ত':'NN','হস্তক্ষেপ':'NN','হস্তনির্মিত':'JJ',
'হস্তপৃষ্ঠ':'NN','হস্তবিহীন':'JJ','হস্তমৈথুন':'NN','হস্তরেখা':'NN','হস্তরেখাবিশারদ':'NN','হস্তলিখিত':'NN','হস্তশিল্প':'NN',
'হস্তসঞ্চালন':'RB','হস্তা':'NN','হস্তাক্ষরযুক্ত':'JJ','হস্তাক্ষরসম্পন্ন':'JJ','হস্তাক্ষরিত':'JJ','হস্তান্তকরণ':'NN','হস্তান্তরকারী':'NN',
'হস্তান্তরের':'NN','হস্তাবরণ':'NN','হস্তি':'NN','হস্তিকুম্ভ':'NN','হস্তিঙ্গি':'NN','হস্তিঞ্জা':'NN','হস্তিনাপুর':'NNP',
'হস্তিপ্রমেহ':'NN','হস্তিমস্তক':'NN','হস্তিশালা':'NN','হস্তিশ্রেষ্ঠ':'NN','হস্তী':'NN','হস্তীনি':'NN','হস্তে':'NN',
'হস্তেক্ষেপ':'NN','হস্থ':'NN','হস্র':'NNP','হা':'UH','হাঁক':'NN','হাঁকা':'NN','হাঁকানো':'VB',
'হাঁকিছে':'NN','হাঁচা':'NN','হাঁটছে':'NN','হাঁটা':'NN','হাঁটানো':'VB','হাঁটার':'NN','হাঁটু':'NN',
'হাঁটুতে':'NN','হাঁড়':'NN','হাঁড়ি':'NN','হাঁপ':'VB','হাঁপাচ্ছে':'NN','হাঁপানি':'NN','হাঁপানো':'VB',
'হাঁফ':'NN','হাঁশেল':'NN','হাঁস':'NN','হাঁসফাঁস':'NN','হাঁসির':'NN','হাঁসুলী':'NN','হাঁসের':'NN',
'হাঁড়ি':'NN','হাই':'NN','হাইওয়ে':'NN','হাইকমান্ডের':'NN','হাইকিঙ্গ':'NN','হাইকোর্টে':'NN','হাইগেন্স':'NNP',
'হাইজ্যাক':'NN','হাইটেক':'NN','হাইড্রা':'NN','হাইড্রোকার্বন':'NN','হাইড্রোক্লোরাইড':'NN','হাইড্রোজিওলজিস্ট':'NN','হাইড্রোজেন':'NN',
'হাইড্রোজেনের':'NNP','হাইড্রোফাইটা':'NN','হাইড্রোসিল':'NN','হাইতি':'NN','হাইতির':'JJ','হাইতিয়ান':'NN','হাইনলেইন':'NNP',
'হাইপ':'NN','হাইপারটেক্স্ট':'NN','হাইপারস্টোন':'NNP','হাইপোটেনশন':'NN','হাইপোথ্যালামাস':'NN','হাইপোভিটামিনোসিস':'NN','হাইব্রিড':'JJ',
'হাইব্রীড':'NN','হাইরা':'NN','হাইলাইট':'NN','হাইলাইটস':'NNS','হাইলি':'NNP','হাইল্যাণ্ডবাসী':'NN','হাইস্কুলে':'NNP',
'হাইস্পীড':'NN','হাউ':'NN','হাউজিং':'NN','হাউদা':'NN','হাউস-অফ-লর্ড':'NN','হাউস':'NN','হাউসগুলির':'NN',
'হাউসফুল':'JJ','হাউসের':'NNP','হাওড়া':'NN','হাওয়াভবন':'VBG','হাওলা':'NN','হাওড়া':'NNP','হাওড়াতে':'NN',
'হাওয়া':'NN','হাওয়াইসলামী':'NN','হাওয়াকল':'NN','হাওয়াদার':'NN','হাওয়াভবন':'VBG','হাওয়ামহল':'NN','হাওয়াযুক্ত':'NN',
'হাওয়ার':'NN','হাকল':'NN','হাকলী':'NN','হাকায়':'NN','হাকিং':'NN','হাকিমকে':'NN','হাকে':'NN',
'হাগবার':'NN','হাঙর':'NN','হাঙ্গামা':'NN','হাঙ্গেরি':'NNP','হাঙ্গেরী':'NN','হাচাই':'NN','হাচিয়ার':'NNP',
'হাচ্চি':'NN','হাছা':'NN','হাজত':'NN','হাজতেশত':'NNS','হাজন':'NN','হাজার':'NNS','হাজারগুণ':'NN',
'হাজারটা':'NN','হাজারবার':'NNV','হাজারিবাগ':'NN','হাজারে':'NN','হাজারো':'NN','হাজি':'NN','হাজির':'NN',
'হাজিরজবাব':'JJ','হাজিরা':'NN','হাজী':'NN','হাট':'NN','হাটকলোচন':'NN','হাটছি':'VBG','হাটতে':'NN',
'হাটবাজার':'NN','হাটহাজারী':'NNP','হাটা':'NN','হাটি':'NN','হাটু':'NNP','হাটুভাঙ্গা':'NN','হাটুরের':'NN',
'হাটেন':'NN','হাডডন':'NNP','হাড়-পাঁজর':'NN','হাড়':'NN','হাড়জিরজিরে':'JJ','হাড়সর্বস্ব':'JJ','হাড়ি':'NN',
'হাডু':'NN','হাড্ডাহাড্ডি':'NN','হাড্ডিসার':'NN','হাণু':'NN','হাত-পা':'NN','হাত':'NN','হাতই':'NN',
'হাতকড়া':'NN','হাতছানি':'NN','হাতটা':'NN','হাতঠেলা':'NN','হাততালি':'NN','হাতধোলাই':'NN','হাতপা':'NN',
'হাতফুল':'NN','হাতবিহীন':'JJ','হাতবোমা':'NN','হাতল':'NN','হাতলওয়ালা':'JJ','হাতলযুক্ত':'JJ','হাতসাফাই':'NN',
'হাতহীন':'JJ','হাতা':'NN','হাতাবিহীন':'NN','হাতার':'NN','হাতাহাতি':'NN','হাতি-দাঁত':'NN','হাতি':'NN',
'হাতির':'NN','হাতিশাল':'NN','হাতিসেনা':'NN','হাতিয়ার':'NN','হাতিয়ারসৃদ্ধ':'JJ','হাতিয়ে':'VB','হাতুড়ি':'NN',
'হাতুড়ী':'NN','হাতুরার':'NN','হাতুরু':'NN','হাতুরুসিংহে':'NN','হাতুড়ি':'NN','হাতুড়িচাপাতি':'NN','হাতুড়ির':'NN',
'হাতে':'NN','হাতেও':'NN','হাতেকিন্তু':'NN','হাতেখড়ি':'NN','হাতেগোনা':'NN','হাতেনাতে':'NN','হাতেম':'NN',
'হাত্':'NN','হাথরকী':'NN','হাথুরুর':'NN','হাথুরুসিংহে':'NN','হাদা':'NN','হানবে':'NN','হানা':'NN',
'হানাহানি':'NN','হানি':'NN','হানিকর':'JJ','হানিকারক':'NN','হানিফ':'NN','হানিফের':'NN','হানে':'VB',
'হান্ডা':'NN','হান্নান':'NN','হাপর':'NN','হাপিয়ে':'NN','হাপুস':'NN','হাফ':'NN','হাফপ্যান্ট':'NN',
'হাফপ্লেট':'NN','হাফলাংগ':'NN','হাফসেঞ্চুরি':'NN','হাফাম':'NNP','হাফিজ':'NN','হাফ্নিয়াম':'NN','হাব-ভাব':'NN',
'হাব':'NN','হাবভাব':'NN','হাবভাবের':'NN','হাবর':'NN','হাবশী':'JJ','হাবাগোবা':'NN','হাবু':'NN',
'হাবুডুবু':'NN','হাবুলস':'NNP','হাবেরি':'NN','হাভানা':'NN','হাভেলি':'NN','হাম':'NN','হামদম':'NNP',
'হামবন্টোটা':'NN','হামবুর্গ':'NN','হামলা':'NN','হামলাকারী':'NN','হামলামানুষের':'NN','হামলায়':'NN','হামলায়':'NN',
'হামলে':'NN','হামাগুঁড়ি':'VB','হামাগুড়ি':'NN','হামানদিস্তা':'NN','হামাম':'NN','হামাসের':'NN','হামিদ':'NN',
'হামিরপুর':'NNP','হামীর-নট':'NN','হাম্বা':'VB','হাম্বির':'NN','হাযারেরও':'NN','হার-জিত':'NN','হার':'NN',
'হারঃসিটি':'NN','হারই':'NN','হারকিউলিস':'NN','হারগুলোই':'NN','হারছে':'NN','হারছেগতদিন':'NN','হারজিত':'NN',
'হারটা':'NN','হারঠিয়া':'NN','হারত':'NN','হারবে':'NN','হারবেন':'NN','হারমোনিয়া':'NN','হারল':'NN',
'হারলেই':'NN','হারলেন':'NN','হারা':'NN','হারাইসি':'NN','হারাচ্ছি':'NN','হারাত':'NN','হারাতেন':'NN',
'হারানবাবুকে':'NNP','হারানো':'VBN','হারানোর':'NN','হারাবে':'NN','হারাবেন':'NN','হারাম':'NN','হারামখোরী':'NN',
'হারামজাদা':'NN','হারামী':'NN','হারারে':'NN','হারালে':'NN','হারালেন':'NN','হারায়':'NN','হারিকেন':'NN',
'হারিজভি':'NN','হারিত':'NN','হারিয়ে':'VB','হারিল':'NN','হারিয়েই':'NN','হারিয়েছি':'NN','হারিয়েছিল':'VB',
'হারিয়েছিলেন':'NN','হারী':'NN','হারীচাহর':'NN','হারু':'NN','হারুনঅররশীদ':'NN','হারে':'NN','হারেনি':'NN',
'হারের':'NN','হার্ট':'NN','হার্টঅ্যাটাক':'NN','হার্টের':'NN','হার্ড':'NN','হার্ডওয়্যার':'NN','হার্ডডিস্কের':'NN',
'হার্দিক':'JJ','হার্নিয়া':'NN','হার্প':'NN','হার্বিয়াস':'NN','হার্ভাড':'NN','হার্সসু':'NN','হাল-':'NN',
'হালক':'NN','হালকাভাবে':'NN','হালনাগাদ':'NN','হালফিল':'NN','হালা':'NN','হালাল':'NN','হালি':'NN',
'হালিসহরের':'NNP','হালী':'NN','হালুম':'NN','হালুয়ার':'NN','হালে':'NN','হালোংজোপিডিয়াম':'NN','হাল্কা':'NN',
'হাল্কাতম':'JJ','হাল্কাভাবে':'RB','হাশরের':'NN','হাশিম':'NN','হাশয়':'NNP','হাস':'NN','হাসছিল':'NN',
'হাসতে':'IN','হাসতেছে':'NN','হাসপাতাল':'NN','হাসপাতালের':'NN','হাসব':'VB','হাসলাম':'VB','হাসলেন':'VB',
'হাসা':'VB','হাসাইলেন':'VB','হাসান':'NN','হাসানকে':'VB','হাসানের':'VB','হাসানো':'IN','হাসানোর':'VB',
'হাসালেন':'VB','হাসাহাসি':'VB','হাসি-ঠাট্টা':'NN','হাসি':'NN','হাসিঅন্ধকারে':'NN','হাসিই':'NN','হাসিখুশি':'NN',
'হাসিতে':'NN','হাসিনা':'NN','হাসিনাকে':'NN','হাসিমুখে':'NN','হাসির':'NN','হাসিল':'VB','হাসিসে':'VB',
'হাসেজনগন':'NN','হাসেহারা':'NN','হাস্পাতালগুলোরে':'NN','হাস্য':'NN','হাস্যকর':'JJ','হাস্যকরও':'NN','হাস্যপূর্ণ':'JJ',
'হাস্যপ্রিয়তা':'NN','হাস্যমুখর':'JJ','হাস্যমুখেই':'NN','হাস্যময়':'JJ','হাস্যরত্মকভাবে':'NN','হাস্যরস':'NN','হাস্যস্পদ':'JJ',
'হাস্যে':'NN','হাহা':'NN','হাহাবাংলাদেশে':'NN','হাহাহা':'NN','হাহাহাহাহ':'NN','হাহাহাহাহাহাহা':'NN','হাড়':'NN',
'হাড়ভাঙ্গা':'NN','হাড়মাংস':'NN','হাড়র':'NN','হাড়ি':'NNP','হাড়িপাতিল':'NN','হাড়ী':'JJ','হাড়ে':'NNS',
'হাড়ের':'NN','হায়':'NNS','হায়ক':'NN','হায়দরাবাদ':'NN','হায়দার':'NN','হায়দ্রাবদ':'NNP','হায়দ্রাবাদ':'NN',
'হায়না':'NN','হায়রে':'NN','হায়হুতাশ':'NN','হায়হ্যালো':'NN','হায়া':'NN','হায়ে':'NNS','হায়েনাদের':'NNS',
'হায়েনার':'NN','হায়েস্ট':'NN','হা‌শিম':'NN','হি':'NN','হিঁচড়ানো':'VB','হিঁচড়ে':'NN','হিঁদুর':'NN',
'হিঁদুয়ানি':'VB','হিং':'NN','হিংড়া':'NN','হিংস':'NNP','হিংসক':'NN','হিংসাগ্রস্ত':'JJ','হিংসাজর্জরিত':'JJ',
'হিংসাত্মক':'JJ','হিংসাপরায়ণ':'NN','হিংসাপীড়িত':'JJ','হিংসাপ্রবণ':'JJ','হিংসাবশত':'NN','হিংসারু':'NN','হিংসে':'NN',
'হিংস্রক':'NN','হিংস্রতামূলক':'JJ','হিংস্রতার':'NN','হিউগেনাট':'NN','হিউমানরাইটস':'NNS','হিউম্যান':'NNP','হিউয়েন':'NN',
'হিকা':'NNP','হিক্কা':'NN','হিক্সোস':'NNP','হিগাইবো':'NN','হিগুয়াইনরে':'NN','হিঙ্গ':'NN','হিঙ্গোট':'NNP',
'হিঙ্গোলী':'NN','হিজড়া':'NN','হিজরা':'NN','হিজরাদের':'NNS','হিজরার':'NN','হিজরী':'NN','হিজাব':'NN',
'হিজ্জল':'NN','হিজড়া':'NN','হিজড়াকে':'JJ','হিজড়াদের':'NN','হিজড়ারা':'NN','হিঞ্জৌতী':'NN','হিট':'NN',
'হিটলার':'NN','হিটার':'NN','হিটিং':'VBG','হিট্টী':'NNP','হিড়িম্বা':'NN','হিণী':'NNP','হিণ্ডীবাদাম':'NN',
'হিত':'NN','হিতা':'NN','হিতাকাঙ্খী':'JJ','হিতাধিকারী':'NN','হিতার্থ':'RB','হিতে':'NNP','হিতৈষিতা':'NN',
'হিতৈষীকে':'NN','হিথ':'NN','হিদা':'NNP','হিনা':'NN','হিন্ডোলা':'NN','হিন্তাল':'NN','হিন্দ':'NN',
'হিন্দমহাসাগর':'NN','হিন্দি':'NNP','হিন্দিভাষার':'NN','হিন্দী':'NN','হিন্দীতে':'NNP','হিন্দু':'NN','হিন্দুত্ব':'NN',
'হিন্দুদের':'NN','হিন্দুবিদ্বেষী':'JJ','হিন্দুমতে':'NN','হিন্দুর':'NNP','হিন্দুস্তান':'NN','হিন্দোল':'NN','হিপনোটিজম':'NN',
'হিপি':'NN','হিপেটোফ্লেবিন':'NN','হিপোক্রেটাস':'NNP','হিপোক্র্যাসী':'NN','হিপ্পো':'NN','হিব্রু':'NN','হিম':'NN',
'হিমঋতু':'NN','হিমকণা':'NN','হিমকর':'JJ','হিমগিরি':'NNP','হিমঘরের':'NN','হিমজ':'JJ','হিমজা':'NN',
'হিমবত্':'JJ','হিমবাহ':'NN','হিমমানব':'NN','হিমলিঙ্গ':'NN','হিমসাগর':'NN','হিমসিম':'NN','হিমা':'NN',
'হিমাঙ্ক':'NN','হিমাচল':'NN','হিমাদ্রি':'NN','হিমানী':'NN','হিমালয়':'NN','হিমালয়ী':'JJ','হিমায়িত':'NNS',
'হিমু':'NN','হিম্মত':'NN','হিম্মতদার':'JJ','হিম্মতনগর':'NN','হিরক':'NN','হিরগনা':'NN','হিরণখুরি':'NN',
'হিরণ্ময়':'NN','হিরণ্য':'NN','হিরণ্যকাশ্যপ':'NN','হিরণ্যগর্ভ':'NN','হিরণ্যধনু':'NN','হিরণ্যস্তূপ':'NN','হিরণ্যাক্ষ':'NN',
'হিরদাবল':'NN','হিরন':'NN','হিরুএই':'NN','হিরে':'NNP','হিরো':'NN','হিরোগিরি':'NN','হিরোশিমা':'NN',
'হিল':'NN','হিলারি':'NN','হিলিঙ্স্গফোর্স':'NN','হিলিয়ামে':'NNP','হিলিয়ম':'NN','হিল্লোল':'NN','হিল্স':'NN',
'হিল্সিঙ্কী':'NN','হিষও':'NN','হিস':'NN','হিসজরা':'NN','হিসপ্যানিক':'NN','হিসবে':'VB','হিসাব':'NN',
'হিসাবও':'NNS','হিসাবকিছু':'NN','হিসাবখাতা':'NN','হিসাবগুলির':'NN','হিসাবটা':'NN','হিসাবনবিশ':'NN','হিসাবপত্রের':'NN',
'হিসাবপরীক্ষক':'NN','হিসাববিজ্ঞান':'NN','হিসাবমতে':'NN','হিসাবরক্ষক':'NN','হিসাবরক্ষণের':'NN','হিসাবশাস্ত্র':'NN','হিসাবী':'NN',
'হিসাবেই':'IN','হিসাবেও':'NN','হিসার':'NN','হিসি':'NN','হিসেব':'NNS','হিসেবই':'NN','হিসেবমতে':'NN',
'হিসেবেই':'IN','হিসেবেও':'NN','হিস্ট্রি':'NN','হিস্পেনিয়োল':'NN','হিস্যা':'NN','হিহিহি':'NN','হিয়া':'NNP',
'হিয়ার':'RB','হিয়ে':'NN','হিয়েরাপোলিসের':'NNP','হীণমন্নতা':'NN','হীতে':'VB','হীন':'NN','হীনতার':'NN',
'হীনমন্যতা':'NN','হীনযান':'NN','হীর':'NN','হীরা':'NN','হীরে':'NN','হীরের':'NNS','হীরো':'NN',
'হু':'NN','হুঁশ':'NN','হুঁশিয়ার':'JJ','হুঁশিয়ারি':'VBG','হুংকার':'NN','হুইন্তাম':'NN','হুইপকে':'NN',
'হুইল':'NN','হুইস্কি':'NN','হুও':'NN','হুওয়াই':'NN','হুক':'NN','হুকুম':'NN','হুকো':'NN',
'হুক্কা':'NN','হুক্‌ড্‌':'NN','হুগলি':'NNP','হুগলী':'NN','হুগলীতে':'NNP','হুঙ্কার':'NN','হুজুগে':'NN',
'হুজুর':'NNP','হুজুররাও':'NN','হুজূর':'NN','হুজ্জতি':'NN','হুট':'NN','হুড়কা':'NN','হুড়কার':'JJ',
'হুড়োহুড়ি':'NN','হুতল':'NNP','হুতাশন':'NNP','হুতি':'NN','হুদহুদ':'NN','হুদা':'NN','হুদী':'NNP',
'হুন্ডি':'NN','হুপদ':'NNP','হুবহু':'RB','হুবিষ্ক':'NN','হুবিষ্কের':'NNP','হুম':'NN','হুমকিধমকি':'NNS',
'হুমকির':'NN','হুমরি':'VBG','হুমা':'NN','হুল':'NN','হুলযুক্ত':'JJ','হুলিয়া':'NN','হুলুথুলু':'NN',
'হুলুম':'NN','হুলেন':'NNP','হুলো':'NN','হুল্লোড়':'NN','হুল্লোড়বাজী':'NN','হুশ':'NN','হুশিয়ারি':'VBG',
'হুস':'NN','হুসেনী-কান্হড়া':'NN','হুহু':'NN','হুড়াহুড়ি':'NNP','হুয়া':'NN','হুয়ান':'NN','হূজুগে':'NN',
'হূদাই':'NN','হৃত্পিণ্ড':'NN','হৃত্স্পন্দন':'NN','হৃদধ্বনি':'NN','হৃদয়ের':'NN','হৃদরোগ':'NN','হৃদস্পন্দন':'NN',
'হৃদয়-বিদায়ক':'JJ','হৃদয়-রোগ':'NN','হৃদয়':'NN','হৃদয়গ্রাহী':'JJ','হৃদয়ঙ্গম':'JJ','হৃদয়বান':'JJ','হৃদয়স্পর্শী':'JJ',
'হৃদয়হীন':'JJ','হৃদয়হীনতা':'NN','হৃদয়ে':'NN','হৃল্লাস':'NN','হৃষীকেশ':'NNP','হৃষ্টপুষ্ট':'JJ','হৃষ্টরোমা':'NN',
'হৃসাস':'NN','হৃার্দিক':'NN','হে':'NN','হেঁকে':'VB','হেঁচকি':'NN','হেঁচেছি':'VB','হেঁটে':'NN',
'হেঁতাল':'NN','হেক্টর':'NN','হেগো':'NN','হেটার':'PRP$,','হেটাররা':'NN','হেটার্সরা':'NNS','হেটে':'NN',
'হেটেছে':'VBD','হেট্মায়ারকে':'NN','হেট্রিকের':'NN','হেড-অফিসে':'NN','হেড':'NN','হেডকোচ':'NN','হেডন':'NN',
'হেডলাইন':'NN','হেডলাইনের':'NNS','হেডামওয়ালা':'NN','হেডিং':'VBG','হেডিস':'NN','হেডে':'NN','হেতবন্তর':'NN',
'হেতি':'NN','হেতু-অন্তর':'NN','হেতু':'NN','হেতুবাক্য':'NN','হেতুহেতুমদ্':'NN','হেতেগোতো':'NN','হেদায়েত':'NNP',
'হেদায়েতুল্লাহ':'NN','হেন':'VB','হেনকালে':'RB','হেনরি':'NN','হেনরী':'NNP','হেনস্তা':'NN','হেনা':'NN',
'হেনেছে':'NN','হেন্ড':'NN','হেপাজত':'NN','হেপাটাইটিস':'NN','হেপী':'JJ','হেফাজত':'NN','হেফাজতি':'NN',
'হেফাজতের':'NN','হেব্ব‌ি':'NN','হেভিওয়েট':'NN','হেভেন':'NN','হেম':'NN','হেমঋতু':'NN','হেমকান্তি':'NN',
'হেমগন্ধিনী':'NN','হেমগিরি':'NN','হেমচন্দ্র':'NN','হেমদন্তা':'NN','হেমনাভি':'NN','হেমন্ত':'NN','হেমন্তর':'NNP',
'হেমপর্বত':'NN','হেমপুষ্প':'NN','হেমবতী':'NN','হেমমালী':'NN','হেমাঙ্গ':'NN','হেমাল':'NN','হেমেন্দ্রনাথের':'NNP',
'হেমোপম':'NNP','হেম্না':'NN','হের-ফের':'NN','হেরম্ব':'NN','হেরা':'NN','হেরাক্লিস':'NNP','হেরাত':'NN',
'হেরাফেরি':'NN','হেরে':'NN','হেরেছে':'VBN','হেরেহি':'NN','হেরোইন':'NN','হেলপার':'NN','হেলমেট':'NN',
'হেলসিঙ্কিতে':'NNP','হেলা':'NN','হেলানো':'VBG','হেলি':'NN','হেলিকপ্টার':'NN','হেলিকপ্টারের':'NN','হেলিঙ্স্গফোর্স':'NN',
'হেলুয়া':'NN','হেলে':'NN','হেলেনীয়':'JJ','হেলেনেস্টিক':'JJ','হেল্থকেয়ার':'NN','হেল্প':'NN','হেল্পার':'NN',
'হেল্পারদেরকে':'NNS','হেল্পারের':'NN','হেল্ফ':'NN','হেল্সিঙ্কী':'NN','হেষ্টি-সাহেব':'NNP','হেষ্টি':'NNP','হেসে':'VB',
'হেয়ার':'NN','হোক':'VB','হোঙ্গে':'VB','হোটেল':'NN','হোটেলে':'NN','হোত':'VB','হোদয়':'NNP',
'হোন':'VB','হোম':'NN','হোমিওপ্যাথির':'NN','হোমে':'NN','হোল':'VB','হোলটাইমারদের':'NN','হোলো':'VB',
'হোসেন':'NNP','হোস্টেলে':'NN','হ্নে':'NN','হ্মণ':'NN','হ্মা':'NNP','হ্যদয়ের':'NN','হ্যাঁ':'UH',
'হ্যাংলা':'NN','হ্যাজ':'NNP','হ্যাণ্ডনোটে':'NN','হ্যানস':'NNP','হ্যানিম্যান':'NNP','হ্যামণ্ড':'NNP','হ্যারি':'NNP',
'হ্যাসেট':'NNP','হ্যায়':'NNP','হ্রদ':'NN','হ্রস্ব':'NN','হ্রাসবৃদ্ধি':'NN','হয়ই':'VB','হয়ছে':'VB',
'হয়ত':'RB','হয়না':'VB','হয়ে':'VB','হয়েও':'VB','হয়েছিল':'VB','হয়েছে':'VB','হয়েছো':'VB'}


listSyn = [
['-আহারী', 'খাদক', 'ভক্ষক', 'যে খায়'] ,
['A', 'A অক্ষর', 'a', 'a অক্ষর', 'এ'] ,
['একশ বিলিয়ন', '১০০০০০০০০০০০'] ,
['ঁ', 'অর্ধচন্দ্র'] ,
['ং', 'অনুস্বর'] ,
['অ', 'অক্ষর অ'] ,
['অংক', 'সংখ্যা'] ,
['অংশ করে নেওয়া', 'বিভক্ত করা', 'বিভাজিত করা', 'ভাগ করা'] ,
['অংশ বণ্টন', 'অংশ বিভাজন'] ,
['অংশ', 'অঙ্গ', 'অঙ্গী', 'কাঁধ', 'ক্ষেত্র', 'খণ্ড', 'গর্দান', 'গ্রীবা', 'চরণ', 'টুকরো', 'দান', 'বাটোয়ারা', 'বিভাগ', 'ভাগ', 'শেয়ার', 'স্কন্ধ'] ,
['অংশকালিক', 'পার্ট টাইম'] ,
['অংশগ্রহণ', 'আংশিকগ্রাস'] ,
['অংশগ্রহণকারী', 'প্রতিনিধি'] ,
['অংশধারী', 'অংশীদার', 'ভাগীদার'] ,
['অংশীদার', 'ভাগীদার', 'শরিক'] ,
['অংশীদারি', 'পার্টনারশিপ', 'ভাগীদারি', 'যৌথ মালিকানা'] ,
['অংশীদারী', 'ভাগ'] ,
['অংশু', 'কর', 'কিরণ', 'গভস্থি', 'চন্দিম', 'ছটা', 'ধৃষ্ণি', 'ভাম', 'মরীচি', 'ময়ূখ', 'রশ্মি', 'শিপি'] ,
['অংশুক', 'মখমল'] ,
['অংশুমন্ত', 'সূর্যভানু'] ,
['অকপট', 'অচ্ছদ্ম', 'অচ্ছল', 'অব্যাজ', 'কপটতাশূণ্য', 'কপটতাহীন', 'কাপট্যহীন', 'ছলনাশূণ্য', 'ছলনাহীন', 'ছলরহিত', 'নির্ব্যাজ', 'ব্যাজহীন'] ,
['অকম্পন', 'স্পন্দনহীনতা'] ,
['অকরকরা', 'তীক্ষ্ণকী'] ,
['অকরণীয়', 'অকৃত্য'] ,
['অকর্তিত', 'অখণ্ডিত'] ,
['অকর্মণ্য ব্যাক্তি', 'অকর্মা', 'নিষ্কর্মা'] ,
['অকর্মণ্য', 'নিষ্কর্মা'] ,
['অকলঙ্কিত', 'অমল', 'অমলিন', 'কলঙ্কহীন', 'দোষহীন', 'নির্দোষ', 'পরিষ্কার', 'পাপমুক্ত'] ,
['অকল্পনীয়', 'অকল্পিত', 'কল্পনাতীত'] ,
['অকল্যাণকারী', 'অনিষ্টকর', 'অমঙ্গলকারী', 'অশুভ'] ,
['অকস্মাত্', 'আচমকা', 'হঠাত্'] ,
['অকাট্য', 'অখণ্ডনীয়'] ,
['অকাম কর্ম', 'আসক্তিহীন কর্ম', 'নিষ্কাম কর্ম'] ,
['অকারণ', 'অপ্রয়োজন', 'অহেতু', 'অহেতুক', 'উদ্দেশ্যবিহীন', 'এমনি এমনি', 'বৃথা', 'বেকার'] ,
['অকারণের ভীতি', 'ব্যর্থ ভয়'] ,
['অকার্য', 'কর্মহীনতা'] ,
['অকাল প্রসূত', 'অকালজাত'] ,
['অকাল মৃত্যু', 'অপমৃত্যু'] ,
['অকাল', 'ঋতুহীন', 'দুর্ভিক্ষ', 'মন্বন্তর'] ,
['অকালি', 'অকালি সিখ'] ,
['অকাল্পনিক', 'আসল', 'প্রাকৃতিক', 'বাস্তবিক', 'যথার্থ'] ,
['অকিঞ্চন', 'নগণ্য', 'যে-সে', 'যেমন-তেমন'] ,
['অকীর্তি', 'অপকীর্তি', 'অপকৃতি', 'অপনাম', 'অপযশ', 'কুখ্যাতি', 'কুপ্রসিদ্ধি', 'দুর্নাম', 'বদনাম'] ,
['অকুটিল', 'অবোধ', 'নিষ্কপট', 'ভোলা-ভালা', 'সরল', 'সিধে-সাদা'] ,
['অকুটিলতা', 'ঋজুতা', 'কপটহীনতা', 'ছলহীনতা', 'নিশ্চলতা', 'নিষ্কপটতা', 'নিষ্পাপতা', 'সততা', 'সরলতা', 'সাধুতা', 'সোজা'] ,
['অকুলিন', 'অকুলিন ব্যক্তি'] ,
['অকুশল নাট্যশিল্পী', 'খারাপ নাট্যশিল্পী'] ,
['অকুশল', 'অদক্ষ', 'অনভিজ্ঞ', 'অনিপুণ', 'অনিষ্ট', 'অপটু', 'অমঙ্গল', 'অশুভ', 'আনাড়ী', 'কল্যাণ', 'নবীন'] ,
['অকুশলতা', 'অদক্ষতা', 'অনাড়ি', 'অনিপূণতা', 'অপটুতা', 'অপ্রবীণতা'] ,
['অকৃত', 'অনির্মিত', 'অরচিত', 'না-করা'] ,
['অকৃতজ্ঞ', 'কৃতঘ্ন'] ,
['অকৃতজ্ঞতা', 'কৃতঘ্নতা'] ,
['অকৃত্যকারী', 'খল', 'দুষ্কর্মকারী'] ,
['অকৃত্রিম', 'দৈব', 'নৈসর্গিক', 'প্রাকৃতিক', 'সহজ', 'স্বাভাবিক'] ,
['অকৃত্রিমতা', 'স্বাভাবিকতা'] ,
['অকৃপা', 'অবগ্রহ', 'কৃপাহীনতা', 'দয়াহীনতা'] ,
['অকৃষ্ট', 'অকৃষ্য'] ,
['অকোলা', 'অকোলা জেলা', 'অকোলা শহর'] ,
['অক্টোবর', 'অক্টোবর মাস'] ,
['অক্মোলা', 'আস্তানা'] ,
['অক্রোধ', 'অরোষ', 'রোষাভাব'] ,
['অক্রোধী', 'ক্রোধহীন'] ,
['অক্লান্ত', 'অপরিশ্রান্ত'] ,
['অক্লেশ', 'অনায়াস', 'প্রযত্নহীন', 'বিনা পরিশ্রম', 'সহজ'] ,
['অক্ষ রেখা', 'অক্ষাংশ', 'অক্ষাংশ রেখা', 'অনুভূমিক রেখা'] ,
['অক্ষ', 'মেরু দন্ড'] ,
['অক্ষত', 'অখণ্ডিত', 'অভঞ্জিত', 'আনাহত'] ,
['অক্ষদণ্ড', 'অক্ষধুর', 'অক্ষাগ্র'] ,
['অক্ষম', 'ক্ষমতাহীন'] ,
['অক্ষমতা', 'অযোগ্যতা', 'অসামর্থ্যতা', 'ক্ষমতাহীনতা', 'শক্তিহীনতা', 'সামর্থ্যহীনতা'] ,
['অক্ষমালা', 'রুদ্রাক্ষের মালা'] ,
['অক্ষমালিক', 'অক্ষমালিক উপনিষদ', 'অক্ষমালিকোপনিষদ'] ,
['অক্ষম্য', 'ক্ষমার অযোগ্য'] ,
['অক্ষর আ', 'আ'] ,
['অক্ষর মালা', 'অক্ষরমালা', 'বর্ণমালা'] ,
['অক্ষর', 'বর্ণ', 'শব্দ', 'হরফ', 'হাতের লেখা'] ,
['অক্ষর-বিন্যাস', 'বর্ণ-বিন্যাস'] ,
['অক্ষরজীবি', 'কলমকার', 'কলমজীবি', 'লেখক', 'শব্দকার'] ,
['অক্ষরে অক্ষরে', 'হুবহু'] ,
['অক্ষি পটল', 'নেত্র পটল', 'রেটিনা'] ,
['অক্ষি', 'অক্ষি উপনিষদ', 'আঁখি', 'চক্ষু', 'চোখ', 'নেত্র', 'নয়ন', 'লোচন'] ,
['অক্ষিকোণ', 'অপাঙ্গ', 'চোখের কোণ', 'নয়নপ্রান্ত', 'নয়নোপান্ত', 'লোচনপ্রান্ত'] ,
['অক্ষিতারা', 'চোখের তারা', 'তারা', 'নেত্রগোলক'] ,
['অক্ষিপক্ষ', 'চোখের পাতার লোম'] ,
['অক্ষয়', 'অবিনশ্বর', 'অমর'] ,
['অক্ষয়-তৃতীয়া', 'অক্ষয়তৃতীয়া'] ,
['অক্সফর্ড', 'অক্সফোর্ড'] ,
['অক্সিজেন', 'প্রাণবায়ু'] ,
['অখণ্ডনীয়', 'অখণ্ড্য', 'অবিভাজ্য'] ,
['অখণ্ডিত', 'অটুট', 'অবিভক্ত', 'অভিন্ন'] ,
['অখন্ডিত', 'গোটা', 'পুরো', 'সম্পূর্ণ'] ,
['অখাত', 'উপসাগর', 'খাড়ী', 'জলাধার', 'জলাশয়', 'ট্যাঙ্ক', 'মীনগোধিকা', 'হ্রদ'] ,
['অখাদ্য পদার্থ', 'অখাদ্য বস্তু'] ,
['অখাদ্য', 'অনাহার্য', 'অভক্ষণীয়', 'অভোজ্য'] ,
['অখিল বিশ্ব', 'বিশ্ব', 'বিশ্বব্রহ্মাণ্ড', 'ব্রহ্মাণ্ড', 'মহাবিশ্ব'] ,
['অখুশী হয়ে', 'অপ্রসন্নতাপূর্বক'] ,
['অখ্যাত', 'অপ্রসিদ্ধ'] ,
['অখ্যাতি', 'অপ্রসিদ্ধি', 'অসিদ্ধি'] ,
['অগঠিত', 'অনিরুপিত', 'অসংগঠিত'] ,
['অগণিত', 'অগণ্য', 'অগুনতি', 'অনন্ত', 'অসংখ্য'] ,
['অগম্য', 'অপ্রবেশ্য', 'কঠিন', 'দুরূহ', 'দুর্গম'] ,
['অগম্যতা', 'গতিহীনতা'] ,
['অগর্বিত', 'অহংকারশূণ্য', 'গর্বশূণ্য', 'গর্বহীন'] ,
['অগস্ত্য', 'মৈত্রাবরুণ', 'যাম্য'] ,
['অগাধ', 'অতল', 'অতি', 'অতিশয়', 'অধিক', 'অপার', 'খুব', 'বহুত', 'বেশি'] ,
['অগাবে', 'অগাবে গাছ'] ,
['অগিয়া', 'বিন্ডুল'] ,
['অগুঢ়', 'রহস্যহীন', 'রহস্যাবৃত নয় এমন'] ,
['অগুপ্ত', 'অগোপনীয়', 'কথ্য', 'প্রকাশ্য'] ,
['অগোচর', 'অতীন্দ্রিয়', 'অপ্রত্যক্ষ', 'অভৌতিক', 'ইন্দ্রিয়াতীত', 'পরোক্ষ'] ,
['অগোছালো করা', 'তছনছ করা'] ,
['অগোছালো', 'অব্যবস্থিত', 'বিশৃঙ্খল'] ,
['অগোপন', 'অনিভৃত'] ,
['অগৌরবজনক অবস্থা', 'গৌরবহীনতা'] ,
['অগ্নায়ী', 'দহন প্রিয়া', 'বৃষাকপায়ী', 'স্বাহা'] ,
['অগ্নি কোণ', 'দক্ষিণ পূর্ব', 'দক্ষিণ-পূর্ব', 'দক্ষিণপূর্ব'] ,
['অগ্নি পরীক্ষা', 'কঠিন পরীক্ষা'] ,
['অগ্নি পুরাণ', 'অগ্নিপুরাণ'] ,
['অগ্নি মন্দির', 'পারসী মন্দির'] ,
['অগ্নি', 'অগ্নিদেব', 'অনিলসখা', 'চিত্রভানু', 'পরিজন্মা', 'পিঙ্গেশ', 'বসুনীথ', 'বসুপ্রাণ', 'বসুবিদ', 'মিত্রবিন্দ', 'শাণ্ডিল্য', 'শিখি'] ,
['অগ্নি-কুণ্ড', 'অগ্নিকুণ্ড', 'যজ্ঞকুণ্ড', 'যজ্ঞৃ-কুণ্ড'] ,
['অগ্নি-পরীক্ষা', 'অগ্নিপরীক্ষা'] ,
['অগ্নিকর্ম', 'অগ্নিকার্য', 'অগ্নিক্রিয়া', 'অন্ত্যেষ্টি', 'অন্ত্যেষ্টিক্রিয়া', 'মৃতসত্কার', 'শবসত্কার', 'শেষকাজ', 'শেষকৃত্য', 'শ্মশানকৃত্য', 'সংস্ক্রিয়া', 'সত্কার', 'সত্কৃতি', 'সত্ক্রিয়া'] ,
['অগ্নিকাণ্ড', 'দহন', 'দাহ'] ,
['অগ্নিকুণ্ড', 'আগুন'] ,
['অগ্নিনাশক-যন্ত্র', 'দমকল'] ,
['অগ্নিনির্বাপক-যন্ত্র', 'প্রশমক'] ,
['অগ্নিপাবক', 'অগ্নিপাবক ঋষি'] ,
['অগ্নিশিখা', 'আঁচ', 'কুসুম', 'শিখা'] ,
['অগ্নিষ্টোম', 'অগ্নিষ্টোম যজ্ঞ'] ,
['অগ্নিসংস্কার', 'অধ্বর', 'আহব', 'আহুতি', 'যজ্ঞ', 'যাগ', 'যাগযজ্ঞ', 'হব', 'হবন', 'হুতি', 'হোত্র', 'হোম'] ,
['অগ্নুত্পাত', 'আগ্নেয়গিরি বিস্ফোরণ', 'লাভা উদ্গীরণ'] ,
['অগ্যস্ত ফুল', 'পাশুপত', 'বক', 'বকুল', 'বক্রপুষ্প'] ,
['অগ্র ভাগ', 'অগ্রভাগ', 'আগা', 'প্রথমাংশ', 'শীর্ষ ভাগ', 'শীর্ষাংশ'] ,
['অগ্র', 'অগ্রবর্তী', 'পূর্ব', 'সম্মুখ'] ,
['অগ্রগণ্য', 'ইজ্জতদার', 'গণমান্য', 'গণ্যমান্য', 'প্রতিষ্ঠিত', 'প্রধান', 'বরিষ্ঠ', 'বিশিষ্ট', 'বিশেষ', 'মাননীয়', 'মান্য', 'মূখ্য', 'শ্রেষ্ঠ', 'সম্মানিত'] ,
['অগ্রগতি', 'প্রগতি'] ,
['অগ্রগন্ধা', 'অগ্রা', 'ক্ষবক', 'ছিকনী', 'নাকছিকনী'] ,
['অগ্রগামী', 'অগ্রণী', 'অগ্রদূত', 'পুরোগামী', 'প্রগতি কর্তা'] ,
['অগ্রজ', 'জেষ্ঠ্য ভাই', 'দাদা', 'পূর্বজ', 'পূর্বপুরুষ', 'বড় ভাই'] ,
['অগ্রজা', 'দিদি', 'বড় বোন'] ,
['অগ্রদূত', 'অগ্রে সন্দেশ বাহক'] ,
['অগ্রভাগ', 'কোণ', 'সামনে', 'সামনের অংশ', 'সামনের দিক', 'সূচ্যগ্র'] ,
['অগ্রসারিত', 'সুপারিশ করা'] ,
['অগ্রহণীয়', 'অগ্রাহ্য'] ,
['অগ্রিম প্রতিলিপি', 'এডভান্স কপি'] ,
['অগ্রু', 'আগর', 'লঘুচন্দন'] ,
['অঘটন', 'অসম্ভব'] ,
['অঘমর্ষণ', 'অঘমর্ষণ ঋষি'] ,
['অঘোর', 'অঘোরী'] ,
['অঘোরপন্থী', 'অঘোরী'] ,
['অঘোষ', 'নিঃশব্দ', 'নীরব', 'শব্দহীন'] ,
['অঘ্রায়ণ', 'মৃগ'] ,
['অঙ্ক', 'অঙ্কদেশ', 'কোল', 'ক্রোড়', 'নম্বর', 'নাটক অঙ্ক', 'প্রাপ্ত অঙ্ক', 'প্রাপ্তাঙ্ক', 'সংখ্যা'] ,
['অঙ্কক', 'মূল্যাঙ্কন কর্তা', 'মূল্যাঙ্কন কারী'] ,
['অঙ্কন শিক্ষা', 'চিত্রকলা'] ,
['অঙ্কশাস্ত্রে', 'গণিতশাস্ত্র'] ,
['অঙ্কিত', 'চিত্রিত', 'চিহ্নিত', 'লিখিত', 'লিপিবদ্ধ', 'লেখা'] ,
['অঙ্কুর নির্গত হওয়া', 'অঙ্কুরিত হওয়া', 'অঙ্কুরোদ্গম'] ,
['অঙ্কুর', 'আঁকুর', 'মুকুল'] ,
['অঙ্কুরোদ্গম বিন্দু', 'চোখ'] ,
['অঙ্কুশ', 'বৈণুক'] ,
['অঙ্গ মর্দন', 'অঙ্গ মলাই', 'মালিশ'] ,
['অঙ্গ সমূহ', 'তন্ত্র'] ,
['অঙ্গ', 'অঙ্গ-প্রত্যঙ্গ', 'কলেবর', 'কায়া', 'দেহ', 'বপু.তনু', 'শরীর', 'শারীরিক অঙ্গ'] ,
['অঙ্গ-ভঙ্গী', 'ঈঙ্গিত', 'ঈশারা', 'সংকেত'] ,
['অঙ্গচ্ছেদ', 'ব্যবচ্ছেদ'] ,
['অঙ্গজ', 'আত্মজ', 'আত্মভূ', 'কিশোর', 'কুমার', 'চিরঞ্জীব', 'ছেলে', 'তনুজ', 'তনয়', 'নন্দন', 'পুত্র', 'বালক', 'সুত'] ,
['অঙ্গদ দেব', 'গুরু অঙ্গদ দেব'] ,
['অঙ্গদ', 'তারা কুমার', 'বালীসূত'] ,
['অঙ্গনা', 'নারী', 'বনিতা', 'ভামিনী', 'মহিলা', 'মহিলা', 'মানবী', 'স্ত্রী'] ,
['অঙ্গবাচক', 'অঙ্গবাচক শব্দ'] ,
['অঙ্গবিকার', 'অঙ্গবিকৃতি'] ,
['অঙ্গভঙ্গী', 'ছলাকলা', 'হাব-ভাব', 'হাবভাব'] ,
['অঙ্গরক্ষক', 'অঙ্গরক্ষী', 'দেহরক্ষী', 'বডিগার্ড'] ,
['অঙ্গরাজ্য', 'প্রদেশ', 'রাজ্য'] ,
['অঙ্গরোম', 'গাত্ররুহ', 'রোম', 'লোম'] ,
['অঙ্গহীন', 'পঙ্গু', 'প্রতিবন্ধী', 'বিকলাঙ্গ'] ,
['অঙ্গহীনতা', 'বিকলাঙ্গতা'] ,
['অঙ্গারক', 'কার্বন', 'শুক্রপুষ্প', 'সহচর'] ,
['অঙ্গারপর্ণ', 'চিত্ররথ', 'দগ্ধরথ'] ,
['অঙ্গিকার', 'কথা', 'গৃহিত দায়িত্ব', 'প্রতিজ্ঞা', 'প্রতিশ্রুতি', 'প্রতিশ্রুতিবদ্ধতা'] ,
['অঙ্গিরস', 'অঙ্গিরস ঋষি', 'সংবর্ত'] ,
['অঙ্গিরা', 'অঙ্গিরা ঋষি'] ,
['অঙ্গীকরণ', 'অঙ্গীকার', 'ম়ঞ্জুরী', 'স্বীকৃতি'] ,
['অঙ্গীকার করা', 'গ্রহণ করা', 'নেওয়া', 'স্বীকার করা'] ,
['অঙ্গীকারপত্র', 'অনুবন্ধ-পত্র', 'বন্ড', 'শর্তনামা'] ,
['অঙ্গীকৃত', 'গৃহীত', 'স্বীকৃত'] ,
['অঙ্গীবাচক শব্দ', 'সর্বাঙ্গবাচক শব্দ'] ,
['অঙ্গীভূত', 'সমন্বিত', 'সমাবেষ্টিত', 'সমাহিত'] ,
['অঙ্গুলী', 'আঙুল'] ,
['অচঞ্চল', 'অচপল', 'অনুদ্ধত', 'গম্ভীর', 'ঠাণ্ডা', 'শান্ত', 'সৌম্য', 'স্থির'] ,
['অচপলতা', 'উদ্বেগহীনতা', 'গাম্ভীর্য', 'স্থিরচিত্ততা', 'স্থিরমনস্কতা'] ,
['অচর', 'অচল', 'গতিরোধ', 'স্থাবর'] ,
['অচল সম্পত্তি', 'স্থাবর সম্পত্তি'] ,
['অচল', 'অদ্রি', 'গতিরোধ', 'পাহাড়', 'ভূধর', 'স্থাবর'] ,
['অচলকন্যা', 'অপর্ণা', 'অম্বা', 'অম্বিকা', 'আর্যা', 'ইলা', 'উমা', 'গিরিজা', 'গৌরি', 'জগজ্জননী', 'জগদীশ্বরী', 'জয়ন্তী', 'জয়া', 'ত্রিভুবনসুন্দরী', 'দেবেশী', 'নন্দিনী', 'পার্বতী', 'ভগবতি', 'ভবানী', 'মঙ্গলা', 'মহাগৈরী', 'মহাদেবী', 'রুদ্রাণী', 'শঙ্করী', 'শম্ঙুকান্তা', 'শিবা', 'শৈলজা', 'শৈলসূতা', 'সুনন্দা', 'হৈমবতী', 'হৈমসুতা'] ,
['অচলা একাদশী', 'অপরা একাদশী', 'জৈষ্ঠ-কৃষ্ণ একাশী'] ,
['অচলা', 'অবনী', 'ক্ষিতি', 'পৃথিবী', 'বসুধা', 'বসুন্ধরা'] ,
['অচিত্রিত', 'অনিরূপিত', 'অবর্ণিত'] ,
['অচিন্তনীয়', 'অবিবেচ্য', 'অভাবনীয়'] ,
['অচিরপ্রভা', 'অচিরাংশু', 'অণুপ্রভা', 'অণুভা', 'ক্ষণদ্যুতি', 'ক্ষণপ্রভা', 'চপলা', 'চিকুর', 'তড়িত্', 'দামিনী', 'নীলাঞ্জনা', 'বিজলী', 'বিজুরি', 'বিদ্যুত্', 'মেঘজ্যোতি', 'শম্পা', 'সৌদামিনী'] ,
['অচিহ্নিত', 'চিহ্নবিহীন'] ,
['অচেতন প্রক্রিয়া', 'অজৈব্য প্রক্রিয়া'] ,
['অচেতন', 'অর্ধচেতন'] ,
['অচেনা জায়গা', 'অপরিচিত জায়গা', 'যেখান থেকে হোক'] ,
['অচেনা লোক', 'পর', 'বহিরাগত লোক', 'বাইরের লোক'] ,
['অচেনা', 'অজানা', 'অজ্ঞাত', 'অপরিচিত'] ,
['অচৈতন্য জগত', 'জড় জগত'] ,
['অচৈতন্য', 'অজৈব', 'জড়'] ,
['অচ্ছুত', 'অন্তেবাসী', 'অন্ত্যজ', 'অস্পৃশ্য', 'শূদ্র'] ,
['অচ্ছুত্', 'অন্তজ', 'অস্পৃশ্য', 'শূদ্র'] ,
['অচ্যুতাগ্রজ', 'কূটহন্তা', 'বজ্রদেহ.বকবৈরী', 'বলভদ্র', 'বলরাম', 'বালভৃত', 'মধুপ্রিয়', 'রেবতীরমণ', 'সংকর্ষণ', 'সীতাধর', 'হলধর'] ,
['অচয়নিত', 'অনির্বাচিত'] ,
['অছি', 'ট্রাস্টি', 'ন্যাসরক্ষক'] ,
['অছিলা', 'অজুহাত', 'বাহানা', 'ভান'] ,
['অছেদ্য', 'অভেদনীয়', 'অভেদ্য', 'দুর্ভেদ্য'] ,
['অজ', 'অজাত', 'অজাসুর', 'অনাগত', 'অনুত্পন্ন', 'অনুদ্ভূত', 'ছাগল', 'লম্বকর্ণ'] ,
['অজদন্তী', 'কটুপত্রফলা'] ,
['অজনন কোষিকা', 'জড় কোষিকা'] ,
['অজপাদ', 'ইন্দুপর্ণী', 'পঞ্জীরী'] ,
['অজর', 'চিরযুবা', 'চিরযৌবনসম্পন্ন', 'জরারহিত'] ,
['অজাত', 'অজাতি', 'জাতহীন'] ,
['অজাতরজস্কা', 'অনাগতার্তবা'] ,
['অজাতশত্রু', 'শত্রুবিহীন', 'শত্রুহীন'] ,
['অজান্তে করা অপরাধ', 'অবোধগম্য অপরাধ'] ,
['অজিজ্ঞাসু', 'অনুত্সুক', 'জিজ্ঞাসাহীন', 'নিরুত্সুক'] ,
['অজিত', 'অজেয়', 'অপরাজেয়', 'অপরাজেয়', 'দুর্জয়'] ,
['অজির', 'অনিল', 'ধূলিধ্বজ', 'পবন', 'বায়ু', 'মরুত্', 'সমীর', 'হাওয়া'] ,
['অজীর্ণ', 'অজীর্ণ রোগ', 'বদহজম'] ,
['অজীর্ণরোগগ্রস্ত', 'অজীর্ণরোগী', 'অজীর্ণী'] ,
['অজুত', 'দশ হাজার', 'দশ হাজার', '১০০০০,'] ,
['অজুহাতবাজ', 'বাহানাবাজ'] ,
['অজেয়', 'অযোধ্য', 'অশক্য'] ,
['অজ্ঞ', 'যারা খবর রাখে না'] ,
['অজ্ঞতা', 'অজ্ঞানতা', 'অনভিজ্ঞতা', 'অবিদ্যা', 'অশিক্ষা', 'জ্ঞানহীনতা'] ,
['অজ্ঞান অন্ধকার', 'অন্ধ তিমির'] ,
['অজ্ঞান', 'অজ্ঞানতা', 'অবচেতনা', 'চেতনাহীন', 'জ্ঞানশূণ্যতা', 'জ্ঞানহীন', 'বেহুঁশ', 'মুর্চ্ছিত', 'মূর্চ্ছা', 'শূণ্যমনস্কতা', 'সংজ্ঞাশূণ্যতা'] ,
['অজ্ঞানতা', 'ছেলেমানুষি', 'জ্ঞানহীনতা', 'মূঢ়তা', 'মোহ', 'সলরমতি'] ,
['অজ্ঞানতাপূর্ণ', 'জ্ঞানহীন'] ,
['অজ্ঞেয়', 'জ্ঞানাতীত'] ,
['অঞ্চল', 'আঁচল'] ,
['অঞ্জন', 'ধামন'] ,
['অঞ্জনযুক্ত', 'অঞ্জনিত'] ,
['অঞ্জনরহিত', 'নিরঞ্জন'] ,
['অঞ্জনা', 'অঞ্জনী'] ,
['অঞ্জলি', 'করপাত্র', 'করপুট', 'করপূট', 'কোষ', 'মুঠো', 'সম্পুট', 'সম্পূট'] ,
['অঞ্জলিবদ্ধ', 'করবদ্ধ'] ,
['অটবী', 'অরণ্য', 'জঙ্গল', 'বন', 'বিপিন'] ,
['অটল বিহারী', 'অটল বিহারী বাজপেয়ী'] ,
['অটল সংকল্প', 'দৃঢ় প্রতিজ্ঞা', 'ভীষ্মের প্রতিজ্ঞা'] ,
['অটল', 'অনিবার্য', 'অবশ্যম্ভাবী', 'অবিচল', 'অবিচলিত', 'গতিহীন', 'দৃঢ়', 'নিশ্চল', 'স্থির'] ,
['অটোমেটেড টেলার মেশিন', 'এটিএম', 'স্বচালিত গণক মেশিন'] ,
['অটোমোবাইল', 'অটোমোবিল', 'মোটর গাড়ি', 'মোটরগাড়ি'] ,
['অট্টালিকা', 'গগনচুম্বী ইমারত', 'গগনচুম্বী ভবন', 'গগনস্পর্শী', 'বহুতল বাড়ি'] ,
['অট্টালিকাময়', 'হর্ম্যশোভিত'] ,
['অড়হর ডালের বড়ি', 'ডালের বড়ি'] ,
['অডানা', 'অডানা রাগ'] ,
['অণু সম্বন্ধীয়', 'আণবিক'] ,
['অণু', 'কণা', 'মলিকিউল', 'লেশ'] ,
['অণ্ডগ্রন্থি', 'শুক্রাশয়'] ,
['অণ্ডজ', 'ডিম্বজ'] ,
['অণ্ডবৃদ্ধি', 'জল বৃষণ', 'হাইড্রোসিল'] ,
['অতটা', 'ততটা'] ,
['অতল', 'গভীর'] ,
['অতসী', 'ক্ষৌম', 'তিসি', 'নীলপুষ্পিকা', 'মসিনা', 'মালিকা', 'শণ', 'হেমবতী'] ,
['অতি অভাবগ্রস্ততা', 'কাঙালপনা'] ,
['অতি আবশ্যক', 'অত্যাবশ্যক', 'অপরিহার্য'] ,
['অতি উচ্চ পদ', 'অত্যুচ্চ পদ'] ,
['অতি উত্সাহী', 'অত্যোত্সাহী'] ,
['অতি কটূ', 'খুব কড়া', 'খুব কষা', 'তেতো'] ,
['অতি ক্রুদ্ধ', 'রাগে আগুন'] ,
['অতি ক্ষীণকায়', 'হাড় সর্বস্ব'] ,
['অতি গুঢ়', 'দুর্বোধ্য', 'দূরুহ', 'প্যাঁচানো'] ,
['অতি বলিষ্ঠ', 'মহাবলী'] ,
['অতি বিশাল', 'বিশালতম', 'বৃহত্তম'] ,
['অতি শীঘ্র', 'ঝটপট', 'তাড়াতাড়ি'] ,
['অতি শ্যাম', 'কালো', 'কুচকুচে কালো'] ,
['অতি সুন্দর স্থান', 'অদ্ভুত সুন্দর স্থান', 'অদ্ভুত স্থান', 'অপার্থিব স্থান'] ,
['অতি সূক্ষ্ম', 'সূক্ষ্মতম'] ,
['অতিকায় হাতি', 'বড় হাতি'] ,
['অতিকায়', 'বিশালকায়', 'বৃহত্কায়', 'মহাকায়', 'লম্বা চওড়া'] ,
['অতিকৃচ্ছ', 'অতিকৃচ্ছ ব্রত'] ,
['অতিক্রম করা', 'পার করা', 'যাওয়া'] ,
['অতিক্রম', 'অবদান'] ,
['অতিক্রমকারী', 'অতিক্রমী', 'অতিক্রামক', 'ক্রমোলঙ্ঘনকারী', 'লঙ্ঘনকারী'] ,
['অতিক্রমণ', 'উল্লঙ্ঘন', 'লঙ্ঘন'] ,
['অতিক্রমযোগ্য', 'পারগম্য'] ,
['অতিক্রম্য', 'উল্লঙ্ঘনীয়'] ,
['অতিথি কক্ষ', 'গেস্টরুম'] ,
['অতিথি সেবা', 'অতিথি-সত্কার', 'আথিতেয়ত'] ,
['অতিথি', 'অভ্যাগত', 'আগন্তুক'] ,
['অতিথি-গৃহ', 'অতিথি-ভবন', 'অতিথি-শালা', 'অতিথিগৃহ'] ,
['অতিথ্যকর্তা হওয়া', 'আমন্ত্রয়িতা করা', 'নিমন্ত্রাতা হওয়া'] ,
['অতিথ্যকর্তা', 'আমন্ত্রয়িতা', 'নিমন্ত্রাতা'] ,
['অতিনম্র', 'অবনত', 'অবনম্র'] ,
['অতিপক্ক', 'বেশী পাকা'] ,
['অতিপ্রিয়', 'পরমপ্রিয়'] ,
['অতিবাহিত করা', 'কাটা', 'কাটানো', 'নির্বাহ করা'] ,
['অতিবীর', 'পরমবীর'] ,
['অতিব্যয়ী', 'অপব্যয়ী', 'অমিতব্যয়ী', 'খরুচে', 'ব্যয়শীল', 'ব্যয়ী'] ,
['অতিভোজী', 'খাপুসে', 'পেটুকপনা'] ,
['অতিমানব', 'অতিমানুষ', 'মহান'] ,
['অতিরঞ্জন', 'অতিশয়োক্তি', 'অত্যুক্তি'] ,
['অতিরিক্ত ন্যায়াধীশ', 'অবর ন্যায়াধীশ'] ,
['অতিরিক্ত সময়', 'অবকাশ'] ,
['অতিরিক্ত', 'ছাড়া', 'বিনা'] ,
['অতিশয় দাতা', 'দানবীর', 'দানশীল'] ,
['অতীত কালীন', 'পূর্বকালীন', 'ভূতকালীন'] ,
['অতীত', 'অতীত কাল', 'অতীতকাল', 'কাল', 'গত', 'গত কাল', 'বিগত', 'বিগত কাল', 'বিগত দিন', 'ভূত'] ,
['অতীন্দ্রিয় বাদ', 'অতীন্দ্রিয়বাদ'] ,
['অতুঙ্গ', 'অনুচ্চ', 'নিম্ন', 'নীচু'] ,
['অতুল', 'অতুলনীয়', 'অপরিমেয়', 'জুড়িহীন'] ,
['অতুলনীয়', 'অপ্রতীম সৌন্দর্য্য'] ,
['অতুষ্টি', 'অতৃপ্তি', 'অসন্তুষ্টি', 'অসন্তোষ'] ,
['অতৃপ্ত', 'অসন্তুষ্ট', 'বন্দী'] ,
['অতেশয়োক্তি', 'অতেশয়োক্তি অলঙ্কার'] ,
['অত্যধিক খারাপ অবস্থা হওয়া', 'খারাপ থেকে আরও খারাপ হওয়া'] ,
['অত্যধিক পরিমাণে', 'ভয়ঙ্কর ভাবে'] ,
['অত্যধিক পরিশ্রম করা', 'কঠোর পরিশ্রম করা'] ,
['অত্যধিক যত্নপূর্বক', 'অত্যন্ত যত্ন সহকারে', 'প্রাণপণে'] ,
['অত্যধিক', 'অত্যন্ত', 'অধিক', 'অনেক বেশী', 'অপরিমিত', 'খুব', 'ঘোর', 'প্রচুর', 'বিপুল', 'ভয়ঙ্কর', 'ভয়ানক'] ,
['অত্যন্ত পরাক্রমী', 'অপ্রতিবীর্য'] ,
['অত্যন্ত মজবুত', 'সুদৃঢ়'] ,
['অত্যল্প', 'একটু', 'স্বল্প'] ,
['অত্যাচার করা', 'উত্পীড়ণ করা', 'কষ্ট দেওয়া'] ,
['অত্যাচার সহ্য করা', 'উত্পীড়ন সহ্য করা'] ,
['অত্যাচার', 'অনাচার', 'অন্যায়', 'অভাবগ্রস্ততা', 'উত্পীড়ন', 'জুলুম', 'দুর্নীতি', 'যাতনা'] ,
['অত্যাচারী', 'অনাচারী', 'উত্পীড়ক'] ,
['অত্যাবশ্যক', 'অনিবার্য', 'আবশ্যক', 'জরুরী', 'দরকারী', 'প্রয়োজন', 'প্রয়োজনীয়'] ,
['অত্যুহ', 'উপক', 'কপক', 'তঞ্জল', 'ধনাখ', 'ধারাত', 'পাপিয়া'] ,
['অত্যোক্তি', 'অন্যাপদেশ'] ,
['অত্রি', 'অত্রি নদী'] ,
['অত্রিপ্রিয়া', 'অনুসূয়া'] ,
['অথর্ব', 'অথর্ব বেদ', 'অথর্বন', 'অর্থবেদ'] ,
['অথর্ব-শির', 'অথর্ব-শির উপনিষদ', 'অথর্ব-শিরোপনিষদ'] ,
['অথার্থ', 'অনুচিত', 'অসঙ্গত', 'ভুল'] ,
['অথ্যলেটিক্স', 'খেলাধুলা প্রতিযোগিতা'] ,
['অদক্ষ', 'অপটু', 'আনাড়ি'] ,
['অদণ্ডনীয়', 'অদণ্ড্য'] ,
['অদত্তা', 'অবিবাহিত মহিলা', 'অবিবাহিতা', 'কুমারী মহিলা'] ,
['অদমিত', 'অদলিত', 'অনুত্পীড়িত', 'অমর্দিত'] ,
['অদরকারি জিনিস', 'ফালতু জিনিস', 'বেকার বস্তু'] ,
['অদর্শন', 'অদৃশ্যতা'] ,
['অদর্শনীয়', 'অদ্রষ্টব্য'] ,
['অদল বদল', 'আদান-প্রদান', 'বিনিময়'] ,
['অদল-বদল', 'অদলবদল', 'পরিবর্তণ', 'পালটানো', 'ফেরবদল', 'বদল', 'হের-ফের'] ,
['অদিতি', 'অবনি', 'ক্ষিতি', 'ধরণী', 'ধরা', 'ধরিত্রী', 'নিষ্টিগ্রী', 'পৃথিবী', 'বসুধা', 'বসুন্ধরা', 'ভূ', 'ভূমণ্ডল', 'মহী', 'মেদিনী'] ,
['অদূরদর্শী', 'স্বল্পদর্শী'] ,
['অদূরে', 'কাছে', 'নিকটে', 'পাশে', 'সন্নিকটে'] ,
['অদৃঢ়', 'কমজোর', 'কাঁচা', 'ক্ষণভঙ্গুর', 'মোলায়েম'] ,
['অদৃশতা', 'বিলুপ্ততা', 'লুপ্ততা'] ,
['অদৃশ্য হওয়া', 'বিলুপ্ত হওয়া', 'লুকিয়ে পরা'] ,
['অদৃশ্য', 'অদৃষ্টিগোচর', 'অন্তর্হিত', 'অন্ত্রধান', 'গায়েব', 'তিরোধান', 'বিলীন', 'বিলুপ্ত', 'লীন', 'লুপ্ত'] ,
['অদৃষ্ট', 'অদেখা', 'অপরীক্ষিত'] ,
['অদৃষ্টবাদী', 'দৈববাদী'] ,
['অদ্বৈত', 'অদ্বৈতবাদী'] ,
['অদ্বৈতবাদ', 'একাত্মবাদ', 'একাত্মবাদী', 'একেশ্বরবাদ', 'একেশ্বরবাদী'] ,
['অদ্বয়তারক', 'অদ্বয়তারক উপনিষদ', 'অদ্বয়তারকোপনিষদ'] ,
['অদ্ভুত কাজ', 'চমত্কার'] ,
['অদ্ভুত রস', 'অদ্ভুত-রস'] ,
['অদ্ভুত', 'আজব'] ,
['অদ্য', 'আজ'] ,
['অদ্রি তনয়া', 'অশ্বললিত'] ,
['অদ্রি', 'অশ্ম', 'পাথর', 'পাথর', 'পাষাণ', 'প্রস্তর', 'শিলা'] ,
['অদ্রি-তনয়া', 'উগ্রশেখরা', 'গঙ্গা', 'জাহ্নবী', 'ত্রিমার্গগা', 'ত্রিমার্গা', 'ধর্মদ্রবী', 'ধাত্রী', 'নন্দিনী', 'পুরন্দরা', 'পুষ্যগর্ভা', 'বৃষারণী', 'বৃষাশ্রিতা', 'বৈষ্ণবী', 'ভদ্রসোমা', 'ভাগীরথী', 'মহাবিল', 'মহাভদ্রা', 'মালিনী', 'সুরনদী', 'স্বর্ণধুনী', 'স্বর্বাপী', 'হৈমবতী'] ,
['অধঃ', 'নীচে', 'নীচের দিকে'] ,
['অধঃক্ষিপ্ত', 'অবক্ষিপ্ত'] ,
['অধঃক্ষেপ', 'তলানি'] ,
['অধঃপতন', 'অধোগতি'] ,
['অধঃপতনকারী', 'অবনতিকারী', 'ক্ষতিকারক'] ,
['অধঃপতিত হওয়া', 'অধোগমন', 'অবনতি হওয়া'] ,
['অধঃপতিত', 'অধোগত', 'পতিত'] ,
['অধঃপাত', 'অধোগমন', 'অবনতি', 'পতন'] ,
['অধম', 'অধম পুরুষ', 'উন', 'নীচ পুরুষ', 'বাজারী', 'ম্লেচ্ছ', 'শূদ্র', 'সস্তা'] ,
['অধমতম', 'তুচ্ছাতিতুচ্ছ', 'নিকৃষ্টতম'] ,
['অধমতা', 'নিকৃষ্টমনতা', 'নীচতা'] ,
['অধমর্ণ', 'ঋণী', 'দেনাদার'] ,
['অধর', 'ওষ্ঠ', 'ঠোঁট'] ,
['অধর-বিম্ব', 'অধরবিম্ব'] ,
['অধরামধু', 'অধরামৃত'] ,
['অধরোষ্ঠ', 'নীচের ঠোট'] ,
['অধর্ম কর্ম', 'দুষ্কর্ম', 'পাপকর্ম', 'পাপাচার'] ,
['অধর্ম', 'অনাচার', 'কদাচার', 'কলুষ', 'কুকর্ম', 'দুরাচার', 'পাপ'] ,
['অধস্তন', 'অধীন', 'অধীনস্থ'] ,
['অধার্মিক', 'অনাচারী', 'পতিত', 'পাপাচারী', 'পাপাত্মা', 'পাপী'] ,
['অধি দেবতা', 'ইষ্ট দেবতা', 'ইষ্টদেব', 'কূল দেবতা', 'কূলদেবতা'] ,
['অধি-দিন', 'অধি-দিবস', 'অধিদিন', 'অধিদিবস'] ,
['অধিক কোণ', 'অধিককোণ'] ,
['অধিক ভাগ', 'অধিকাংশ'] ,
['অধিক হওয়া', 'প্রধান হওয়া', 'প্রবল হওয়া', 'বাড়া', 'বৃদ্ধি হওয়া', 'বেশী হওয়া'] ,
['অধিক-অঙ্গ', 'অধিকাঙ্গ'] ,
['অধিকতঃ', 'খুব', 'বেশী করে'] ,
['অধিকতম', 'সবচেয়ে অধিক', 'সর্বাধিক', 'সর্বোচ্চ'] ,
['অধিকতর ভালো', 'বেশী ভালো', 'শ্রেয়স্কর'] ,
['অধিকতর', 'অধিকাংশত', 'অধিকাধিক', 'প্রায়', 'প্রায়শই', 'বেশিরভাগ', 'সাধারণত', 'সাধারণভাবে'] ,
['অধিকভাবে', 'অধিকাংশ ক্ষেত্রে', 'প্রায়শই'] ,
['অধিকরণ', 'অধিকরণ কারক'] ,
['অধিকরণ-শুল্ক', 'অধিকরণশুল্ক'] ,
['অধিকর্তা', 'নিয়ামক'] ,
['অধিকর্ম', 'অনুরক্ষণ', 'দেখা', 'দেখাশোনা', 'রক্ষা', 'সামলানো'] ,
['অধিকর্মা', 'অধীক্ষক', 'তত্ত্বাবধায়ক', 'দারোগা'] ,
['অধিকার করা', 'কব্জা করা', 'দখল করা'] ,
['অধিকার প্রাপ্ত', 'অধিকারযুক্ত', 'অধিকারী'] ,
['অধিকার বিষয়ক', 'আধিকারিক'] ,
['অধিকার', 'অধিকৃতি', 'কব্জা', 'জোর', 'দখল', 'শক্তি', 'স্বত্ত্ব'] ,
['অধিকার-পত্র', 'অধিকারপত্র'] ,
['অধিকারচ্যূত', 'বেদখল'] ,
['অধিকারপূর্ণ', 'অধিকারযুক্ত'] ,
['অধিকাররহিত', 'অধিকারহীনতা', 'অনধিকার'] ,
['অধিকারশূণ্য', 'অনধিকার'] ,
['অধিকারী', 'দাবীদার'] ,
['অধিকারে থাকা', 'কব্জা করা', 'দখলে চলে যাওয়া', 'হাতে চলে যাওয়া'] ,
['অধিকৃত', 'অধিগত', 'অধিগৃহীত'] ,
['অধিক্রম', 'আরোহণ'] ,
['অধিক্রমণ', 'আক্রমণ', 'হামলা'] ,
['অধিক্ষিপ্ত', 'ফেলে দেওয়া'] ,
['অধিগত', 'অবগত', 'জানা', 'জ্ঞাত', 'পরিচিত', 'বিজ্ঞাত', 'বিদিত'] ,
['অধিগম', 'জ্ঞান', 'তথ্য', 'পাণ্ডিত্য', 'প্রতীতি', 'প্রাপ্তি'] ,
['অধিদেবী', 'ইষ্টদেবী', 'কূলদেবী'] ,
['অধিনব তারা', 'মহানব তারা', 'মহানোভা', 'সুপারনোভা'] ,
['অধিনায়ক', 'দলপতি', 'দলাধিপতী', 'দলীয় প্রধান'] ,
['অধিনায়িকা', 'দলনেত্রী'] ,
['অধিনিয়ম', 'অ্যাক্ট'] ,
['অধিপতি', 'অধিভূ', 'অধীশ', 'অবনীশ', 'নরপতি', 'নরপাল', 'নরাধিপতি', 'নরেশ', 'নৃপ', 'নৃপতি', 'ভূপতি', 'মহীপাল', 'রাজা'] ,
['অধিপত্র', 'অনুজ্ঞা-পত্র', 'অনুজ্ঞাপত্র', 'ওয়ারেন্ট'] ,
['অধিপ্রাণবাদমূলক', 'অধিপ্রাণবাদী'] ,
['অধিবক্তা', 'উকিল'] ,
['অধিবর্ষ', 'লিপ ইয়ার'] ,
['অধিবাস', 'আবাস', 'আবাসস্থল'] ,
['অধিবাসী', 'জঙ্গল নিবাসী', 'জঙ্গলবাসী', 'নিবাসী', 'বসবাসকারী', 'বাসিন্দা'] ,
['অধিবিন্না', 'কৃতসপত্নী', 'প্রথমা পত্নী'] ,
['অধিবেশন', 'এজলাস', 'জলসা', 'বৈঠক', 'মজলিস', 'সভা'] ,
['অধিভার', 'অধিশুল্ক', 'সারচার্জ'] ,
['অধিভৌতিক', 'পঞ্চভৌতিক', 'ভৌতিক'] ,
['অধিমত', 'নির্ণয়', 'ন্যায়', 'সুরাহা'] ,
['অধিমাস', 'মলমাস'] ,
['অধিরথ', 'মহারথ', 'সারথী', 'সুত'] ,
['অধিরোহিণী', 'সিঁড়ি'] ,
['অধিষ্ঠাতা', 'প্রধান', 'মূখ্য', 'মূল', 'সর্বেসর্বা'] ,
['অধিষ্ঠান', 'সংস্থা', 'সংস্থান'] ,
['অধিষ্ঠিত', 'অবস্থিত', 'সথিত'] ,
['অধিস্থাপন', 'লাগানো'] ,
['অধীণস্থ', 'বশীকরণ'] ,
['অধীত', 'আগত'] ,
['অধীন নৃপতি', 'জায়গিরদার', 'তালুকদার', 'সামন্ত'] ,
['অধীন ভাবে', 'পরবশতঃ', 'পরাধীনভাবে'] ,
['অধীন হওয়া', 'পরাধীন হওয়া'] ,
['অধীন', 'গোলাম', 'পরাধীন'] ,
['অধীনতা', 'অধীনত্ব'] ,
['অধীনস্থ করার ক্রিয়া', 'উত্সর্গ করার ক্রিয়া'] ,
['অধীনস্হ করা', 'বশে করা'] ,
['অধীর', 'চঞ্চল', 'চপল'] ,
['অধীরতা', 'আকুলতা', 'আতুরতা', 'কাতরতা', 'ধৈর্যহীনতা'] ,
['অধীশ', 'প্রভু', 'মালিক', 'স্বামী'] ,
['অধীশ্বর', 'মহারাজ', 'মহারাজা'] ,
['অধৈর্য', 'আর্ত', 'উত্কণ্ঠিত', 'কাতর', 'বিচলিত', 'বিচলিত', 'ব্যাকুল'] ,
['অধোগামী', 'নিম্নগামী'] ,
['অধোমুখ', 'উল্টো'] ,
['অধ্যক্ষতা', 'সভাপতিত্ব'] ,
['অধ্যদেশ', 'ফরমান'] ,
['অধ্যবসায়', 'ঘোর পরিশ্রম', 'সাধনা'] ,
['অধ্যবসায়ী', 'দৃঢ়প্রতিজ্ঞ'] ,
['অধ্যাত্মা', 'অধ্যাত্মা উপনিষদ'] ,
['অধ্যাদেশ', 'আজ্ঞপ্তি', 'হুকুম'] ,
['অধ্যাপক', 'আচার্য', 'গুরু', 'প্রফেসর', 'প্রাধ্যাপক', 'মাস্টার', 'শিক্ষক'] ,
['অধ্যাপন', 'অধ্যাপনাকার্য', 'শিক্ষণ'] ,
['অধ্যাপিকা', 'আচার্যা', 'শিক্ষিকা'] ,
['অধ্যাসন', 'উপবেশন'] ,
['অধ্যায়', 'অনুচ্ছেদ', 'পরিচ্ছেদ', 'পাঠ'] ,
['অধ্যয়ণ', 'পঠন'] ,
['অধ্যয়ণশীলতা', 'অনুশীলন', 'অভ্যাস'] ,
['অধ্যয়ন কক্ষ', 'অধ্যয়ন-কক্ষ', 'অধ্যয়নকক্ষ'] ,
['অধ্যয়ন করা', 'পড়া'] ,
['অধ্যয়ন বিষয়ক', 'শিক্ষণ সংক্রান্ত'] ,
['অধ্যয়ন', 'জ্ঞানার্জন', 'পঠন', 'পঠন-পাঠন', 'পড়া'] ,
['অধ্যয়নশীল', 'বিদ্যার্থী'] ,
['অধ্রুব', 'অনির্দিষ্ট', 'অনিশ্চিত', 'অনিয়ত'] ,
['অধ্রূব', 'অবিরাম', 'অস্থির', 'গতিমান', 'গতিময়', 'গতিশীল', 'চলমান', 'চালু', 'সঞ্চরণশীল'] ,
['অনঙ্গ দেব', 'কামদেব', 'মদনদেব'] ,
['অনঙ্গ-ক্রীড়া', 'কেলি', 'মিথুন', 'মৈথুন', 'রত', 'রতি', 'রতিকর্ম', 'রতিকলহ', 'রতিকেলি', 'রতিক্রিয়া', 'রতিসংহতি', 'সংগ্রহণ', 'সংসর্গ', 'সঙ্গম', 'সত্রীসেবন', 'সম্ভোহ', 'সহবাস', 'স্ত্রীকরণ', 'স্ত্রীগমন', 'স্ত্রীসংসর্গ', 'স্ত্রীসমাগম', 'স্ত্রীসুখ'] ,
['অনচ্ছ', 'আলোনিরোধক'] ,
['অনতঃসত্ত্বা', 'গর্ভবতী', 'পোঁয়াতি'] ,
['অনতিক্রম', 'অনতিক্রমণ'] ,
['অনতিক্রমনীয়', 'অলঙ্ঘনীয়', 'অলঙ্ঘ্য'] ,
['অনতিক্রম্য', 'অপার', 'দুস্তর'] ,
['অনতিক্রান্ত', 'অনতিবাহিত'] ,
['অনধিগত', 'অপ্রাপ্ত', 'অলব্ধ'] ,
['অনধিগম্য', 'অপ্রাপ্য', 'অলভ্য', 'দুষ্প্রাপ্য'] ,
['অনধ্যক্ষ', 'অপ্রত্যক্ষ', 'পরোক্ষ'] ,
['অননুকৃত', 'মূল', 'মৌলিক', 'স্বকৃত', 'স্বরচিত'] ,
['অননুজ্ঞা', 'অননুমতি', 'অনুমতিহীনতা', 'নিষেধাজ্ঞা'] ,
['অননুরক্ত', 'অভক্ত', 'অভক্তিমান', 'ভক্তিহীন'] ,
['অনন্ত', 'অনবসান', 'অনির্দিষ্ট', 'অন্তহীন', 'অসমাপ্য', 'অসীম', 'সীমারহিত', 'সীমাহীন'] ,
['অনন্তজ্ঞান', 'অনন্তদর্শন'] ,
['অনন্ততা', 'অমিততা', 'আতিশয্য', 'আধিক্য'] ,
['অনন্তদৃষ্টি', 'অনেকলোচন', 'অপ্সরেশ', 'অমরেশ্বর', 'অলকেশ', 'ইন্দ্র', 'ইন্দ্রদেব', 'দানবারি', 'দেবরাজ', 'দেবেন্দ্র', 'দৈত্যারি', 'পাকহন্তা', 'পুরন্দর', 'বজ্রধর', 'বিশ্বভূজ', 'রম্ভাপতি', 'শচীন্দ্র', 'সুরনাথ', 'সুরনায়ক', 'সুরপতি', 'সুরভানু', 'সুরেন্দ্র'] ,
['অনন্তদেব', 'ধরণীধর', 'নাগেশ', 'ভূমিধর', 'শেষনাগ', 'সর্পরাজ'] ,
['অনন্তনাগ', 'অনন্তনাগ জেলা', 'অনন্তনাগ শহর'] ,
['অনন্তপুর', 'অনন্তপুর জেলা', 'অনন্তপুর শহর'] ,
['অনন্তলোকীয়', 'মহাজাগতিক'] ,
['অনন্পূর্ণ দেবী', 'অনন্পূর্ণা', 'অন্নদা'] ,
['অনন্য', 'অপ্রতিম', 'অপ্রতিরূপ', 'একনিষ্ট'] ,
['অনন্যগতি', 'অনন্যগতিক', 'উপায়হীন', 'নিরুপায়', 'বিকল্পহীন'] ,
['অনন্যতা', 'অপূর্বতা', 'বিলক্ষণতা'] ,
['অনন্যোপায় হয়ে', 'অপারগ হয়ে', 'বাধ্য হয়ে'] ,
['অনপনেয়', 'অমোচনীয়', 'দুরপনেয়'] ,
['অনবকাশ', 'অনবসর'] ,
['অনবনত', 'অনমনীয়', 'কঠোর'] ,
['অনবরত', 'অবিরত', 'অবিরাম', 'ক্রমাগত', 'নিরন্তর'] ,
['অনবরততা', 'নিরন্তরতা'] ,
['অনবরুদ্ধ', 'অবরোধহীন', 'অবাধ', 'অব্যহত', 'নির্বিঘ্ন', 'নিষ্কণ্টক', 'বাধাহীন'] ,
['অনবলম্বিত', 'আধারহীন', 'নিরাধার', 'ভিত্তিহীন'] ,
['অনবসর', 'অনুপযুক্ত সময়', 'কুকাল', 'কুসময়', 'খারাপ সময়', 'বেমক্কা'] ,
['অনবহেলিত', 'অনুপেক্ষিত'] ,
['অনভিজ্ঞ', 'অনভ্যস্ত', 'কাঁচা', 'নতুন'] ,
['অনভিলাষ', 'অনাকাঙ্থা', 'অনিচ্ছা', 'অপ্রীতি', 'অরুচি'] ,
['অনভিলাষী', 'অনিচ্ছুক', 'আকাঙ্ক্ষাহীন', 'ইচ্ছাহীন', 'নিষ্কাম', 'নিস্পৃহ'] ,
['অনভিষ্ট', 'অপছন্দের', 'অপ্রিয়'] ,
['অনভ্যাস', 'অপক্কতা', 'অসিদ্ধতা'] ,
['অনরসা', 'অন্দরসা'] ,
['অনর্গল', 'অসংগত', 'অসংগতিপূর্ণ', 'আজে-বাজে'] ,
['অনর্ঘ্য', 'অপুজ্য'] ,
['অনর্থক', 'অর্থগত', 'অর্থশূণ্য', 'অর্থহীন', 'অলীক', 'নিরর্থক', 'বৃথা', 'বেমতলব'] ,
['অনর্থকারী', 'অনিষ্টকারী', 'অপকার কর্তা', 'অপকারক', 'অপকারী', 'ক্ষতিকর', 'ক্ষতিকারক', 'হানিকর', 'হানিকারক'] ,
['অনলঙ্কৃত', 'অলঙ্কারহীন'] ,
['অনশন', 'অনাহার', 'উপোস', 'নিরাহার', 'নিরাহার ব্রত'] ,
['অনশ্ব', 'অশ্বহীন'] ,
['অনসূয়', 'ঈর্ষাহীন', 'দ্বেষহীন'] ,
['অনাগত', 'আগামী', 'ভবিতব্য', 'ভবিষ্যত কালীন'] ,
['অনাঙ্ক্ষা', 'অনাভিলাষিতা', 'অনিচ্ছা', 'অনিহা', 'ইচ্ছাহীনতা', 'নিষ্পৃহতা'] ,
['অনাচারিতা', 'চরিত্রহীনতা', 'দুরাচারিতা', 'ব্যাভিচারিতা'] ,
['অনাচ্ছাদন', 'অনাবরণ', 'উন্মোচন'] ,
['অনাচ্ছাদিত স্থান', 'খোলা জায়গা'] ,
['অনাচ্ছাদিত', 'অনাবৃত', 'আঢাকা', 'আলগা', 'খোলা'] ,
['অনাজ্ঞাকারী', 'অবজ্ঞাকারী'] ,
['অনাত্মীয়', 'অনাত্ম্য'] ,
['অনাথ আশ্রম', 'অনাথালয়', 'অনাথাশ্রম'] ,
['অনাথ', 'অনাশ্রিত', 'অবলম্বনহীন', 'অসহায়', 'আশ্রয়হীন', 'নিঃসহায়', 'নিরবলম্ব', 'নিরবলম্বন', 'নিরাশ্রিত', 'নিরাশ্রয়', 'বেচারা'] ,
['অনাদর করা', 'অপমান করা', 'অপমানিত করা', 'অবমাননা করা', 'তিরষ্কার করা'] ,
['অনাদৃত', 'অসম্মানিত', 'উপেক্ষিত', 'তিরস্কৃত', 'তিরস্কৃত মন্ত্র'] ,
['অনাপত্তি প্রমাণপত্র', 'এনওসি', 'নো অব্জেকশন সার্টিফিকেট'] ,
['অনাবশ্যক', 'অনুপযোগী', 'অপ্রয়োজনীয়', 'অর্থহীন', 'নিষ্প্রয়োজনীয়', 'ফালতু', 'বেকার'] ,
['অনাবশ্যকতা', 'অনুপযোগিতা', 'ব্যর্থতা'] ,
['অনাবৃষ্টি', 'খরা', 'বৃষ্টিহীনতা'] ,
['অনাবেদক', 'অনাবেদনকারী'] ,
['অনামী', 'নামহীন', 'বেনামী'] ,
['অনারূঢ়', 'অবিবাহিত', 'অবিবাহিত পুরুষ', 'কুমার'] ,
['অনারেরিয়াম', 'সম্মানদক্ষিণা'] ,
['অনার্দ্র', 'রুক্ষ', 'শুকনো', 'শুষ্ক'] ,
['অনার্দ্রতা', 'শুষ্কতা'] ,
['অনার্য জাতির', 'অনার্য জাতীয়'] ,
['অনার্য', 'অনার্য জাতি'] ,
['অনালাপ', 'চুপ'] ,
['অনাশ্রিত', 'আশ্রয়শূণ্য', 'আশ্রয়হীন', 'নিরাশ্রয়'] ,
['অনাসক্ত', 'নির্লিপ্ত', 'মোহমুক্ত'] ,
['অনাসক্তি', 'আসক্তিহীনতা', 'বিষয়ত্যাগ'] ,
['অনাস্থা', 'অশ্রদ্ধা', 'শ্রদ্ধাবিহীন'] ,
['অনাহার', 'অপুষ্টি', 'উপবাস'] ,
['অনাহারী', 'উপবাসী', 'উপোসি', 'ব্রতী'] ,
['অনিঃস্পৃহতা', 'অবৈরাগ্য', 'বিষয়াসক্তি'] ,
['অনিকেত', 'জিপ্সী', 'পরিব্রাজক', 'যাযাবর'] ,
['অনিত্য', 'অশাশ্বত.ক্ষণজীবী', 'ক্ষয়শীল', 'নশ্বর', 'বিনাশশীল', 'ভঙ্গুর'] ,
['অনিত্যতা', 'অস্থায়ীত্ব'] ,
['অনিদ্র', 'বিনিদ্র'] ,
['অনিদ্রা', 'অনিদ্রা রোগ', 'নিদ্রাহীনতা'] ,
['অনিদ্রিত', 'জাগা', 'জাগ্রত'] ,
['অনিনি', 'অনিনি শহর'] ,
['অনিন্দনীয়', 'অনিন্দ্য'] ,
['অনিবার্য', 'অবশ্যম্ভাবী', 'অবারিত'] ,
['অনিমগ্ন', 'অমগ্ন', 'অলীন'] ,
['অনিমণ্ত্রিত', 'নিমণ্ত্রণহীন'] ,
['অনিমিষাচার্য', 'গীঃপতি', 'গীষ্পতি', 'গুরু', 'ত্রিদশগুরু', 'ত্রিদশাচার্য', 'দেবগুরু', 'দেবপূজ্য', 'দেবাচার্য', 'দেবেজ্য', 'দ্বাদশাংশু', 'বাগীশ', 'বৃহতীপতি', 'বৃহস্পতি', 'বৃহস্পতি ঋষি', 'সুরগুরু', 'সুরাচার্য'] ,
['অনিমেষ', 'একদৃষ্টি', 'একদৃষ্টিতে'] ,
['অনিরুদ্ধ', 'ঊষানাথ', 'কামসূত'] ,
['অনির্ণীত', 'অমীমাংসিত'] ,
['অনির্ণয়', 'অনিশ্চিত'] ,
['অনির্ধারিত', 'অনিশ্চিত', 'অপ্রতিপন্ন', 'বৈকল্পিক'] ,
['অনির্বচনীয়', 'অবর্ণনীয়', 'বর্ণনাতীত'] ,
['অনির্বীজকৃত শুয়োর', 'শুয়োর', 'শূকর'] ,
['অনিল', 'জগদ্বল', 'দৈত্যদেব', 'পবন', 'পবনদেব', 'পবনদেবতা', 'বায়ুদেব', 'মরুত্', 'হাওয়া'] ,
['অনিলাত্মজ', 'দেবব্রত', 'নাগবল', 'বকরিপু', 'বকারি', 'ভীম', 'মারুতাত্মজ'] ,
['অনিশ্চিতকালীন', 'অনিশ্চিতকালের'] ,
['অনিশ্চয়াত্মক', 'সংশয়াত্মক'] ,
['অনিষিদ্ধ', 'নিষেধহীন', 'প্রতিবন্ধকতা হীন', 'বাঁধাহীন'] ,
['অনিষ্ট চিন্তা', 'খারাপ চিন্তা'] ,
['অনিষ্ট', 'অপকার', 'অহিত', 'খারাপ', 'হানি'] ,
['অনিয়ন্ত্রণ', 'নিয়ন্ত্রণহীনতা'] ,
['অনিয়ন্ত্রত', 'নিয়ন্ত্রণহীন'] ,
['অনিয়ন্ত্রিত', 'মনের মতো', 'স্বেচ্ছাপ্রণোদিত'] ,
['অনিয়ম করা', 'গণ্ডগোল করা'] ,
['অনিয়ম', 'অপক্রম', 'অপ্রথা', 'অরীতি', 'বেনিয়ম', 'ব্যতিক্রম'] ,
['অনিয়মবদ্ধ', 'অনিয়মিত', 'নিয়মবিহীন'] ,
['অনীক', 'ফৌজ', 'বাহিনী', 'লস্কর', 'সেনা'] ,
['অনীকিনী', 'কমল সরোবর', 'কমলাকর', 'পদ্ম সরোবর'] ,
['অনীতি', 'অনৈতিকতা', 'নীতিবিহীনতা', 'নীতিহীনতা'] ,
['অনীহা', 'অনেহ', 'অপ্রীতি', 'অপ্রেম', 'অস্নেহ'] ,
['অনুক', 'আগের জন্ম', 'ইষ্টকা', 'দুর্বেষ্টিকা', 'পূর্বজন্মে'] ,
['অনুকম্পা', 'অনুগ্রহ', 'করুণা', 'কারুণ্য', 'কৃপা', 'দয়া', 'দয়া নদী'] ,
['অনুকম্পিত', 'অনুগ্রীহিত', 'উপকৃত'] ,
['অনুকরণ করা', 'অনুসরণ করা', 'নকল করা'] ,
['অনুকরণ', 'অনুগমন', 'অনুসরণ', 'নকল', 'প্রতিকৃতি'] ,
['অনুকরণকারী', 'অনুকর্তা', 'নকলকারী', 'নকুলে'] ,
['অনুকর্তা', 'নকলবাজ'] ,
['অনুকর্ষণ', 'আকর্ষণ', 'আকর্ষণশক্তি', 'টান'] ,
['অনুকারক', 'অনুকারী'] ,
['অনুকারী', 'আজ্ঞাকারী', 'আজ্ঞানুগামী', 'আজ্ঞানুসার', 'আজ্ঞাপালক', 'আজ্ঞাবহ', 'তাঁবেদার'] ,
['অনুকূল', 'অনুযায়ী', 'অনুরূপ', 'অনুসার', 'অনুসারে', 'মাফিক'] ,
['অনুকূলতা', 'আনুকূল্য'] ,
['অনুকৃত', 'অমৌলিক'] ,
['অনুক্ত', 'বেদাধ্যয়ন'] ,
['অনুক্তি', 'পুনকথন'] ,
['অনুক্রমণিকা', 'তালিকা', 'নির্দেশিকা', 'ফর্দ', 'সূচী'] ,
['অনুক্রমহীনতা', 'ক্রমহীনতা', 'শৃঙ্খলাহীনতা'] ,
['অনুক্রমিকভাবে', 'ক্রমানুযায়ী', 'ক্রমানুসারে', 'পর্যায়ক্রম', 'যথাক্রমে'] ,
['অনুগমন', 'অনুসরণ', 'সহমরণ'] ,
['অনুগামী', 'অনুবর্তী', 'অনুযায়ী', 'অনুযায়ী ব্যক্তি', 'অনুসারী', 'পশ্চাদ্বর্তী'] ,
['অনুগৃহীত', 'উপকৃত', 'কৃতজ্ঞ', 'ধন্যবাদী'] ,
['অনুগ্রহপাত্র', 'কৃপাপাত্র', 'দয়াপাত্র'] ,
['অনুগ্রাহক', 'অনুগ্রাহী', 'উপকার কর্তা', 'উপকারক', 'উপকারী'] ,
['অনুচর বর্গ', 'অনুচরগণ', 'সেবক বর্গ'] ,
['অনুচর', 'বন্ধু', 'বান্ধব', 'মিত্র', 'শরিক', 'সখা', 'সঙ্গী', 'সহচর', 'সাথী', 'হিতৈষী'] ,
['অনুচরী', 'চাকরানী', 'দাসী', 'পরিচারিকা', 'সেবিকা'] ,
['অনুচান', 'নিধিগোপ', 'বিদ্যাপ্রেমী'] ,
['অনুচিত নীতি', 'কুনীতি', 'খারাপ নীতি', 'মন্দ নীতি'] ,
['অনুচিত', 'অনৈতিক', 'অন্যায়', 'খারাপ', 'নীতিবিরুদ্ধ', 'নৈতিকতাহীন', 'বাজে'] ,
['অনুচ্ছেদ', 'উপধারা', 'প্রবন্ধ'] ,
['অনুজ', 'কনিষ্ঠ', 'ছোট', 'ছোটো ভাই', 'ছোটো ভ্রাতা', 'সহোদর'] ,
['অনুজা', 'অনুজাতা', 'কনিষ্ঠা', 'ছোটো বোন'] ,
['অনুজ্ঞা', 'অনুমতি', 'আজ্ঞা', 'আদেশ', 'স্বীকৃতি', 'হুকুম'] ,
['অনুজ্ঞাপত্র', 'অনুমতিপত্র', 'লাইসেন্স'] ,
['অনুজ্ঞাপ্রাপ্ত', 'আদেশপ্রাপ্ত'] ,
['অনুতপ্ত হওয়া', 'অনুতাপ করা', 'আফসোস করা'] ,
['অনুতাপ', 'আফশোষ', 'পশ্চাতাপ'] ,
['অনুতোষ', 'তুষ্টি', 'তৃপ্তি', 'পরিতৃপ্তি', 'পরিতোষ', 'সন্তুষ্টি', 'সন্তোষ'] ,
['অনুত্তীর্ণ হওয়া', 'ফেল করা'] ,
['অনুত্তীর্ণ', 'ফেল'] ,
['অনুত্সাহী', 'উত্সাহহীন', 'স্ফূর্তিহীন'] ,
['অনুদনীয়', 'অনুবাদ যোগ্য', 'ভাষান্তর যোগ্য'] ,
['অনুদান', 'চাঁদা'] ,
['অনুদানপ্রদত্ত', 'ভরতুকিপ্রদত্ত'] ,
['অনুদার', 'সংকীর্ণ'] ,
['অনুদিত কৃতি', 'অনুবাদ কর্ম', 'অনুবাদিত কৃতি', 'ভাষান্তরিত কৃতি'] ,
['অনুদিত', 'অনুবাদিত', 'ভাষান্তরিত'] ,
['অনুদেশ', 'উপদেশ', 'নির্দেশ'] ,
['অনুদ্বিগ্ন', 'প্রশান্ত', 'শান্ত'] ,
['অনুদ্বেগ', 'নিরুদ্বিগ্নতা', 'শান্তি'] ,
['অনুদ্যত', 'ধীর', 'মন্দ', 'শিথিল'] ,
['অনুদ্যমী', 'উদ্যোগহীন'] ,
['অনুদ্যোগী', 'নিশ্চেষ্ট'] ,
['অনুধাবন', 'পিছনে দৌড়ানো', 'স্মরণ'] ,
['অনুনাদিত', 'অনুনাদী'] ,
['অনুনীতি', 'কোমলতা', 'নম্রতা', 'বিনতি', 'বিনম্রতা', 'বিনয়'] ,
['অনুনয় করা', 'অনুরোধ করা', 'নিবেদন করা', 'প্রার্থণা করা'] ,
['অনুনয়', 'অনুরোধ', 'আবেদন', 'আর্জি', 'প্রার্থনা', 'বিনয়', 'মিনতি', 'যাচনা করা'] ,
['অনুপ', 'মোষ', 'শিপ্রা'] ,
['অনুপপুর', 'অনুপপুর জেলা', 'অনুপপুর শহর'] ,
['অনুপযুক্ত', 'অপারগ', 'অযোগ্য'] ,
['অনুপযুক্ততা', 'অনৈতিচ্য', 'অযথার্থ্য', 'অযোগ্যতা', 'অসঙ্গতি'] ,
['অনুপস্থিতি', 'অবর্তমান', 'অবিদ্যমানতা', 'না থাকা'] ,
['অনুপস্হিত', 'গরহাজির'] ,
['অনুপাত.দর', 'হার'] ,
['অনুপূরক', 'পরিশিষ্ঠ'] ,
['অনুপূর্বা', 'দোজবরু'] ,
['অনুপ্রাণিত', 'প্রবর্তিত', 'প্রেরিত'] ,
['অনুপ্রাশন', 'অন্নপ্রাশন'] ,
['অনুপ্রাস', 'অনুপ্রাস অলঙ্কার'] ,
['অনুপ্রেক্ষা', 'গভীর অনুসন্ধান', 'স্থির দৃষ্টিতে তাকানো'] ,
['অনুবন্ধ', 'অনুবন্ধিত', 'অনুষঙ্গ', 'টান', 'সমঝোতা', 'সম্পর্ক'] ,
['অনুবন্ধকারী', 'সম্পর্কস্থাপক'] ,
['অনুবর্তন', 'অন্ধ অনুকরণ', 'নকল', 'সাদৃশ্য'] ,
['অনুবর্তী সার্বজনিক নির্গম', 'এফপিও', 'ফলো-অন পাব্লিক অফার'] ,
['অনুবাদ করা', 'তর্জ্জমা করা', 'ভাষান্তর করা'] ,
['অনুবাদ কারী', 'অনুবাদক', 'ভাষান্তরকারী'] ,
['অনুবাদ', 'আখ্যা', 'তর্জ্জমা', 'ব্যাখ্যা', 'ভাব বিস্তার', 'ভাষান্তর', 'ভাষান্তরণ'] ,
['অনুবাদক', 'ভাষান্তরকারী'] ,
['অনুবাসন-বস্তি', 'অনুবাসনবস্তি'] ,
['অনুবিভাগ', 'সেকশন'] ,
['অনুবীক্ষণ যন্ত্র', 'মাইক্রোস্কোপ', 'সূক্ষদর্শক যন্ত্র', 'সূক্ষদর্শী'] ,
['অনুবৃত্তিকারী', 'পেনশনর'] ,
['অনুভব করা', 'অনুভাবনা', 'দেখা', 'নাড়াচাড়া করা'] ,
['অনুভব', 'অনুভূতি', 'সংজ্ঞা', 'সংবেদন'] ,
['অনুভবহীন ব্যক্তি', 'অমানবিক ব্যক্তি'] ,
['অনুভবুপূর্ণতা', 'দক্ষতা'] ,
['অনুভাজন', 'রেশনিং'] ,
['অনুভূত হওয়া', 'মনে হওয়া'] ,
['অনুভূতি', 'আবেগ', 'খেয়াল', 'ভাবনা', 'মনোভাবনা', 'সচেতনতা'] ,
['অনুভূতিপ্রবণ', 'ভাবপ্রবণ', 'ভাবুক'] ,
['অনুভূতিহীন', 'চেতনাশূন্যতা'] ,
['অনুভোগ', 'করমুক্ত জমি'] ,
['অনুমতি দত্ত', 'অনুমতি প্রদত্ত', 'স্বীকৃত'] ,
['অনুমান করা', 'আন্দাজ করা'] ,
['অনুমান', 'অনুমিতি', 'আন্দাজ'] ,
['অনুমানপত্র', 'আয়ব্যয়ক', 'বাজেট'] ,
['অনুমিত', 'আনুমানিক'] ,
['অনুমোদক', 'পক্ষে', 'সমর্থক', 'সমর্থনকারী'] ,
['অনুমোদন', 'বাহবা', 'মঞ্জুরী', 'সমর্থন', 'সম্মতি'] ,
['অনুমোদিত', 'সমর্থিত'] ,
['অনুযাগ', 'অনুয়াজ', 'অনুয়াজা'] ,
['অনুযোক্তা', 'অভিযোক্তা'] ,
['অনুযোগ', 'অভিযোগ', 'নালিশ'] ,
['অনুরক্ত', 'অনুরাগী', 'আসক্ত', 'প্রেমাসক্ত', 'মুগ্দ্ধ', 'মোহিত'] ,
['অনুরক্তি', 'অনুরাগ', 'আসক্তি'] ,
['অনুরঞ্জন', 'রঙ করা', 'রঙ্গন', 'রঞ্জন', 'রাঙানো'] ,
['অনুরণিত', 'গুঞ্জরিত', 'প্রতিধ্বণিত'] ,
['অনুরত', 'নিষ্ঠাবান'] ,
['অনুরাগ', 'প্রণয়', 'প্রেম'] ,
['অনুরাগী হওয়া', 'আসক্ত'] ,
['অনুরাধা', 'অনুরাধা নক্ষত্র'] ,
['অনুরূপ', 'এক রকম', 'একই রকমের', 'সদৃশ', 'সমরূপ', 'সমান', 'হুবহু'] ,
['অনুরূপতা', 'অভিন্নতা', 'অভেদ', 'একত্ব', 'একরূপতা', 'সদৃশ্যতা', 'সমতা', 'সমরূপতা', 'সমানতা', 'সর্বসমতা', 'সাদৃশ্য'] ,
['অনুরূপী', 'প্রতিরূপী', 'সমরূপী'] ,
['অনুরেখন', 'ট্রেসিং'] ,
['অনুরোধ করা', 'অ্যাপিল করা', 'আবেদন করা', 'সুপারিশ করেছেন'] ,
['অনুরোধ পত্র', 'আবেদন', 'আর্জি', 'দরখাস্ত'] ,
['অনুরোধ', 'ফাই-ফরমাইশ'] ,
['অনুরোধ-পত্র', 'অনুরোধক'] ,
['অনুর্বর জমি', 'অনুর্বরা'] ,
['অনুর্বর', 'উষর'] ,
['অনুর্বরতা', 'বন্ধ্যাত্ব'] ,
['অনুলগ্নক', 'সংলগ্ন-পত্র', 'সংলগ্নক'] ,
['অনুলাপ', 'পুনরুক্তি'] ,
['অনুলিপি', 'কপি', 'নকল', 'প্রতিলিপি'] ,
['অনুলিপিত্র', 'ডুপ্লিকেটর'] ,
['অনুলেখ', 'অনুলেখন'] ,
['অনুলেখন', 'পৃষ্ঠাঙ্কন'] ,
['অনুলেপন', 'অবলেপন', 'আলেপন', 'লেপন'] ,
['অনুলোম বিবাহ', 'অনুলোম-বিবাহ', 'অনুলোমবিবাহ'] ,
['অনুশাসন', 'নিয়মপালন'] ,
['অনুশাসনহীন', 'অবাধ্য'] ,
['অনুশিক্ষণ', 'কোচিং'] ,
['অনুশীলন ম্যাচ', 'অভ্যাস ম্যাচ', 'ওয়র্মআপ ম্যাচ'] ,
['অনুশীলনী', 'কুচকাওয়াজ'] ,
['অনুশীলনীয়', 'বিচার্য'] ,
['অনুষ্ঠাতা', 'অনুষ্ঠানকারী', 'উদ্যোক্তা'] ,
['অনুষ্ঠান', 'উত্সব', 'উদ্ধোধন', 'কার্যক্রম', 'ধর্ম কর্ম', 'ধর্ম-কর্ম', 'ধর্মীয় অনুষ্ঠান', 'ধার্মিক অনুষ্ঠান', 'ধার্মিক কর্ম', 'ধার্মিক কাজ', 'ধার্মিক কার্য্য', 'ধার্মিক কৃত্য', 'ধার্মিক-অনুষ্ঠান', 'পরব', 'প্রোগ্রাম', 'সমারোহ'] ,
['অনুষ্ণ', 'ঠাণ্ডা', 'শীতল'] ,
['অনুসন্ধান করা', 'অন্বেষণ করা', 'অবগত হওয়া', 'খোঁজা', 'গবেষণা করা', 'চিন্তা করা', 'দুশ্চিন্তা করা', 'দেখা', 'বিচার করা', 'ভাবা'] ,
['অনুসন্ধান', 'অন্বীক্ষা', 'অন্বেষণ', 'খোঁজখবর', 'গবেষণা', 'তথ্যানুসন্ধান', 'তদন্ত'] ,
['অনুসন্ধানকারী কমিটি', 'তদন্তকারী কমিশন'] ,
['অনুসন্ধানকারী', 'অনুসন্ধানী', 'অন্বেষণকারী', 'অন্বেষী', 'গবেষক', 'তল্লাশিকারী'] ,
['অনুসন্ধেয়', 'অন্বেষনীয়'] ,
['অনুসরণ করা', 'পিছনে যাওয়া', 'মেনে চলা'] ,
['অনুসারতা', 'অনুসারিতা'] ,
['অনুসুয়া', 'ঈর্ষাহীনতা', 'দ্বেষহীনতা'] ,
['অনুসূচিত ক্ষেত্র', 'অনুসূচিত-ক্ষেত্র'] ,
['অনুস্বর', 'নুক্তা', 'বিন্দি', 'বিন্দু'] ,
['অনুস্মরণ', 'খেয়াল', 'স্মরণ', 'স্মৃতি'] ,
['অনূঢ়া', 'অপরিণীতা', 'অবিবাহিতা'] ,
['অনৃণতা', 'ঋণরহিততা'] ,
['অনৃত', 'অসত্য', 'মিথ্যা'] ,
['অনৃতভাষী', 'মিথ্যাভাষী', 'মিথ্যুক', 'মিথ্যেবাদী'] ,
['অনেক দিনের পরিচিত', 'পূর্ব পরিচিত'] ,
['অনেক দূর', 'সুদূর'] ,
['অনেক প্রকারের', 'অনেক রকমের'] ,
['অনেক বার', 'বহু বার'] ,
['অনেক', 'একাধিক', 'দীর্ঘ', 'নানা', 'প্রচুর', 'বহু', 'বহুগুণে', 'বিবিধ', 'বেশী', 'লম্বা', 'সুদীর্ঘ'] ,
['অনেকান্তবাদ', 'আর্হত-দর্শন', 'আর্হতদর্শন', 'জৈন-দর্শন', 'জৈনদর্শন'] ,
['অনৈক্য', 'দ্বিমত', 'মতভেদ', 'মতান্তর'] ,
['অনৈতিক কাজ', 'অপকর্ম', 'দুষ্কর্ম', 'পাপকাজ', 'বাজে কাজ'] ,
['অনৈশ্বর্য', 'অভাব', 'ক্ষুদ্রতা', 'গরিবি', 'দারিদ্র', 'ফকিরি'] ,
['অনৈশ্বর্য্যপ্রদ', 'অসমৃদ্ধিপ্রদ'] ,
['অনৈসর্গিক প্রক্রিয়া', 'অপ্রাকৃতিক প্রক্রিয়া'] ,
['অনৈসর্গিক', 'অপ্রাকৃতিক', 'অস্বাভাবিক'] ,
['অন্ত হওয়া', 'মিটে যাওয়া', 'শেষ হওয়া', 'সমাপ্ত হওয়া'] ,
['অন্ত', 'অন্তিম ভাগ', 'অবধি', 'ইতি', 'উপসংহার', 'খতম', 'পরিণতি', 'পরিণাম', 'ফল', 'ফলাফল', 'মাত্রা', 'শেষ', 'সমাপ্তি', 'সীমা'] ,
['অন্ত-লঘু', 'অন্তলঘু'] ,
['অন্তঃ সলিলা', 'অন্তঃসলিলা'] ,
['অন্তঃ', 'অন্তর্বর্তী', 'ভেতরের'] ,
['অন্তঃ-পরিধি', 'অন্তঃপরিধি'] ,
['অন্তঃকরণ', 'অন্তঃপুর', 'অন্তর', 'অন্তরমন', 'অন্তরাত্মা', 'চিত্ত', 'মন', 'মানস', 'হৃদয়'] ,
['অন্তঃক্রিয়া', 'গুপ্তক্রিয়া'] ,
['অন্তঃপুর', 'হারেম'] ,
['অন্তঃশুল্ক', 'আবকারি শুল্ক'] ,
['অন্তঃসলিলবাহিনী', 'অন্তঃসলিলা'] ,
['অন্তঃসারযুক্ত', 'তাত্ত্বিক'] ,
['অন্তঃসারশূণ্য', 'অর্থহীন', 'নির্গুণ'] ,
['অন্তঃস্রাবী গ্রন্থি', 'নলিকাবিহীন গ্রন্থি'] ,
['অন্তঃস্রাবী-তন্ত্র', 'অন্তঃস্রাবীতন্ত্র'] ,
['অন্তইন্দ্রিয়', 'আন্তরিক ইন্দ্রিয়'] ,
['অন্তবর্ণ', 'অন্তিম বর্ণ', 'ব্যঞ্জন বর্ণ হ', 'হ'] ,
['অন্তভ', 'রেবতী', 'রেবতী নক্ষত্র'] ,
['অন্তমিল', 'অন্ত্যানুপ্রাস'] ,
['অন্তর করা', 'পার্থক্য করা'] ,
['অন্তর', 'অসামঞ্জস্যতা', 'তফাত', 'দূরত্ব', 'পার্থক্য', 'বৈষম্যতা', 'ব্যবধাণ', 'ভিন্নতা', 'ভেদ'] ,
['অন্তরঙ্গ', 'অভিন্ন হৃদয়', 'গাঢ়', 'ঘনিষ্ঠ', 'প্রগাঢ়', 'হরিহর আত্মা'] ,
['অন্তরঙ্গতা', 'ঘনিষ্ঠতা', 'সংসর্গ', 'সান্নিধ্য'] ,
['অন্তররাজ্যীয়', 'অন্তর্প্রদেশীয়'] ,
['অন্তরা', 'মধ্য', 'মধ্য', 'মধ্যবর্তী', 'মধ্যস্থিত', 'মাঝখানের'] ,
['অন্তরানুভূতি', 'অন্তর্জ্ঞান', 'অন্তর্বোধ', 'আত্মজ্ঞান', 'আত্মানুভূতি'] ,
['অন্তরাভিমুখী', 'অন্তর্মুখী', 'অন্তর্লীন'] ,
['অন্তরাল', 'অন্তর্পট', 'আড়াল', 'মধ্যবর্তী সময়', 'মধ্যবর্তী স্থান'] ,
['অন্তরিক্ষ কেন্দ্র', 'অন্তরিক্ষ স্টেশান', 'মহাকাশ কেন্দ্র'] ,
['অন্তরিক্ষ', 'অর্ণব', 'মহাকাশ'] ,
['অন্তরিত', 'অপ্রত্যক্ষ', 'আচ্ছন্ন', 'আজগুবি', 'গোপন', 'নিভৃত'] ,
['অন্তরীক্ষ', 'অন্তরীক্ষ ঋষি'] ,
['অন্তর্গত হওয়া', 'আসা'] ,
['অন্তর্গত', 'অন্তর্ভূক্ত', 'সামিল'] ,
['অন্তর্জাতীয়', 'আন্তর্জাতিক'] ,
['অন্তর্দিশা', 'উপদিশা'] ,
['অন্তর্দেশীয়', 'দেশের অন্তর্গত'] ,
['অন্তর্নিবিষ্ট', 'অন্তর্নিহিত'] ,
['অন্তর্নিহিত অর্থ', 'অন্তর্নিহিত ভাব', 'অব্যক্ত ভাব'] ,
['অন্তর্নিহিত', 'আত্মসাত্', 'নিহিত'] ,
['অন্তর্বাস', 'অভ্যণ্তরীণ বস্ত্র', 'পেটিকোট', 'সায়া'] ,
['অন্তর্বেদ', 'ব্রহ্মাবর্ত'] ,
['অন্তর্বেদী', 'ব্রহ্মাবর্তী'] ,
['অন্তর্মনাঃ', 'অন্তর্মুখ'] ,
['অন্তর্যামী', 'আদিকর্তা', 'ঈশ', 'ঈশ্বর', 'ব্রহ্ম', 'সর্বজ্ঞাতা'] ,
['অন্তর্রাষ্ট্রীয় সীমানা', 'অন্তর্রাষ্ট্রীয় সীমান্ত ক্ষেত্র'] ,
['অন্তর্লীন', 'বিলীন'] ,
['অন্তর্হাস্য', 'গুপ্ত হাস্য'] ,
['অন্তহীন', 'অবধিহীন', 'সীমাহীন'] ,
['অন্তিক', 'প্রতিবেশী'] ,
['অন্তিম কাল', 'অন্তিম সময়', 'কাল', 'মরণ কাল', 'মৃত্যু', 'মৃত্যু কাল'] ,
['অন্তিম যাত্রা', 'জানাজা', 'শবযাত্রা'] ,
['অন্তিম সংস্কার', 'অন্ত্যেষ্টি', 'অন্ত্যেষ্টি ক্রিয়া'] ,
['অন্তিম সতর্কবাণী', 'আল্টিমেটাম', 'চরম সতর্কবাণী'] ,
['অন্তিম সময়', 'সন্ধ্যা', 'সাঁঝ বেলা'] ,
['অন্তিম সময়ে', 'শেষ পর্যন্ত', 'শেষ সময়ে', 'শেষে'] ,
['অন্তিম সীমা', 'পরিসীমা', 'সীমান্ত'] ,
['অন্তিম', 'চরম', 'শেষ'] ,
['অন্তেবাসী', 'গুরুগৃহবাসী', 'নীচকুলজাত', 'নীচবংশজাত', 'সমীপবর্তী'] ,
['অন্ত্যানুপ্রাস', 'তুকান্ত'] ,
['অন্ত্রবৃদ্ধি', 'হার্নিয়া'] ,
['অন্ত্রাণ্ডবৃদ্ধি', 'হাইড্রোসিল'] ,
['অন্দর মহল', 'হারেম'] ,
['অন্ধ কুঠুরি', 'কাল কুঠুরি'] ,
['অন্ধ তমিস্র', 'ঘোর অন্ধকার'] ,
['অন্ধ ভক্তি', 'অন্ধভক্তি'] ,
['অন্ধ', 'অন্ধ দোষ', 'কানা', 'কানি', 'দৃষ্টিহীন'] ,
['অন্ধ-বিশ্বাস', 'অন্ধবিশ্বাস'] ,
['অন্ধক মুনি', 'অন্ধকমুনি'] ,
['অন্ধকার করা', 'আঁধার করা'] ,
['অন্ধকার পক্ষ', 'কৃষ্ণ পক্ষ', 'কৃষ্ণপক্ষ'] ,
['অন্ধকার রাত', 'আঁধার রাত'] ,
['অন্ধকার', 'আঁধার', 'তমিস্র'] ,
['অন্ধকারপূর্ণ', 'আঁধার', 'তমোময়'] ,
['অন্ধকারী', 'অন্ধকারী রাগ'] ,
['অন্ধকূপ', 'অন্ধকূপ নরক'] ,
['অন্ধতামিস্র', 'অন্ধতামিস্র নরক', 'মৃত্যু ভয়'] ,
['অন্ধত্ব', 'দৃষ্টিহীনতচা', 'নেত্রহীনতা'] ,
['অন্ধ্র', 'অন্ধ্রপ্রদেশ'] ,
['অন্ন', 'আনাজ', 'আহার', 'আহার্য্য পদার্থ', 'খাওয়ার জিনিষ', 'খাদ্য', 'খাদ্য পদার্থ', 'খাদ্য বস্তু', 'খাদ্যপদার্থ', 'খাদ্যবস্তু', 'খাদ্যশস্য', 'খাবার', 'ডায়েট', 'ধান', 'ভাত', 'ভোজন', 'ভোজ্য পদার্থ', 'রুটি', 'শস্য'] ,
['অন্ন-কূট', 'অন্নকূট'] ,
['অন্ন-কোষ্ঠ', 'অন্নকোষ্ঠ', 'ধনসার'] ,
['অন্ন-দাতা', 'অন্নদাতা', 'প্রতিপালক'] ,
['অন্ন-দান', 'অন্নদান'] ,
['অন্ন-দোষ', 'অন্নদোষ'] ,
['অন্ন-পাক', 'অন্নপাক'] ,
['অন্ন-বিকার', 'অন্নবিকার'] ,
['অন্ন-ভাগ', 'অন্নভাগ'] ,
['অন্ন-মল', 'অন্নমল'] ,
['অন্ন-রস', 'অন্নরস'] ,
['অন্ন-লিপ্সা', 'অন্নলিপ্সা'] ,
['অন্ন-সংস্কার', 'অন্নসংস্কার'] ,
['অন্নজ', 'অন্নজাত'] ,
['অন্নজল', 'খাদ্যদ্রব্য এবং পানীয় জল', 'ভাত জল'] ,
['অন্নদা একাদশী', 'ভাদ্রপদ-কৃষ্ণ একাদশী'] ,
['অন্নপূর্ণ', 'অন্নপূর্ণ উপনিষদ', 'অন্নপূর্ণোপনিষদ'] ,
['অন্নপ্রাসন', 'মুখেভাত'] ,
['অন্নাভাব', 'খাদ্যাভাব'] ,
['অন্বাহার্য শ্রাদ্ধ', 'মাসিক শ্রাদ্ধ'] ,
['অন্বিতার্থ', 'গূঢ় অর্থ', 'গূঢ়ার্থ'] ,
['অন্বেষণ করা', 'খোঁজা', 'সন্ধান করা'] ,
['অন্বয়', 'সম্পর্ক', 'সম্বন্ধ'] ,
['অন্য পারে', 'অপর দিকে'] ,
['অন্য পুরুষ', 'অন্যপুরুষ', 'পরপুরুষ'] ,
['অন্য', 'অন্যান্য', 'অপর', 'অপরাপর'] ,
['অন্যগোত্রের', 'বিষমগোত্রীয়'] ,
['অন্যতম', 'সর্বশ্রেষ্ঠ', 'সর্বোত্কৃষ্ট', 'সর্বোত্তম'] ,
['অন্যদিকে নিয়ে যাওয়া', 'বিপরীত দিকে নিয়ে যাওয়া'] ,
['অন্যপূর্বা', 'দিধিষু', 'দোজবর'] ,
['অন্যবাপ', 'কলকণ্ঠ', 'কাফল পাকু', 'কায়ফল পাক্কা', 'কিঙ্কিরাত'] ,
['অন্যমনস্ক', 'আনমনা', 'উদাস', 'ভুলোমনা'] ,
['অন্যমনস্কতা', 'আনমোনাভাব', 'উদাসীনতা'] ,
['অন্যরাষ্ট্রীয়', 'পরদেশী', 'বিদেশী', 'বিলেতী'] ,
['অন্যান্য দিনের মত', 'রোজকার মত', 'সবসময়ের মতো', 'সর্বদার ন্যায়'] ,
['অন্যায্য', 'অবিহিত', 'অবৈধ', 'শাস্ত্রবিরুদ্ধ'] ,
['অন্যায় সহ্য করা', 'প্রহার সহ্য করা', 'সহ্য করা'] ,
['অন্যায়', 'অপরাধ', 'ন্যায়হীন', 'ন্যায়হীনতা', 'পাপ'] ,
['অন্যায়কর্তা', 'অন্যায়কারী'] ,
['অন্যের', 'পরকীয়', 'পরের'] ,
['অন্যোন্যাভাব', 'ইতরেতরাভাব'] ,
['অপকর্ষ', 'অপকর্ষণ', 'অপভ্রংশ অবরোহ', 'অবনতি', 'কম', 'ক্ষরণ', 'পতন'] ,
['অপকার', 'ক্ষতি', 'লোকসান', 'হানি'] ,
['অপকীর্তি', 'অপযশপ্রদানকারী'] ,
['অপক্ক', 'অপরিণত', 'অপরিপক্ক', 'অর্ধশিক্ষিত', 'আধপাকা', 'কাঁচা'] ,
['অপক্ষ', 'নির্দল নির্দলীয়'] ,
['অপগত', 'চ্যূত'] ,
['অপগমন', 'পলায়ন'] ,
['অপগ্রহ', 'প্রতিকূল গ্রহ', 'প্রতিকূল-গ্রহ', 'প্রতিকূলগ্রহ'] ,
['অপঘন', 'নিরভ্র', 'মেঘবিহীন', 'মেঘহীন', 'স্বচ্ছ'] ,
['অপচার', 'কুপথ্য'] ,
['অপচয়', 'বিজারণ', 'বিনাশকারী'] ,
['অপচয়িত', 'বরবাদ'] ,
['অপণ্য', 'অবিক্রেয়'] ,
['অপত্য', 'ছেলে-মেয়ে', 'সন্ততি', 'সন্তান'] ,
['অপথ্য', 'খারাপ খাবার'] ,
['অপদার্থ', 'অবস্তু', 'অসার'] ,
['অপদ্রব্য', 'নিকৃষ্ট দ্রব্য'] ,
['অপপ্রচার', 'কুপ্রচার'] ,
['অপপ্রবৃত্তি', 'কুপ্রবৃত্তি', 'দুষ্প্রবৃত্তি'] ,
['অপবচন', 'অপশব্দ', 'গালাগাল', 'গালী'] ,
['অপবাদ', 'অপযশ', 'কলঙ্ক', 'কলুষ', 'কালিমা', 'দাগ', 'লাঞ্ছনা'] ,
['অপবাহক', 'ক্রেণ'] ,
['অপবাহুক রোগ', 'ভূজস্তম্ভ রোগ'] ,
['অপবিত্র ভূমি', 'অপবিত্র স্থান'] ,
['অপবিত্র', 'অশুচি', 'অশুদ্ধ', 'কলুষিত', 'দূষিত'] ,
['অপবিত্রতা', 'অশুচিতা', 'অশুদ্ধতা', 'অশৌচ'] ,
['অপবিদ্ধ', 'পরিত্যক্ত', 'প্রত্যাখ্যাত'] ,
['অপবিদ্যা', 'কুবিদ্যা'] ,
['অপব্যয় করা', 'বাজে খরচ করা'] ,
['অপব্যয়', 'ফালতু খরচ', 'বাজে খরচা'] ,
['অপব্যয়ী ব্যক্তি', 'অমিতব্যয়ী ব্যক্তি', 'বেহিসেবী ব্যক্তি'] ,
['অপভ্রংশ', 'অপভ্রংশ ভাষা', 'অপভ্রষ্ট', 'খারাপ', 'খারাপ ভাবে', 'বাজে', 'বাজে ভাবে', 'বিকল', 'বিকারগ্রস্ত', 'বিকৃত'] ,
['অপভ্রষ্ট', 'পতিত', 'বিচ্যুত'] ,
['অপমর্শ', 'অপহরণ'] ,
['অপমান সহ্য করা', 'বরদাস্ত করা', 'বিষপান করা'] ,
['অপমান', 'অবমাননা', 'অবহেলা'] ,
['অপমানিত', 'অবহেলিত'] ,
['অপমিশ্রণ', 'মিশ্রণ', 'রসায়ন', 'সংগম', 'সংমিশ্রণ'] ,
['অপযোগ', 'দুষ্ট যোগ'] ,
['অপর', 'পর', 'পরজন'] ,
['অপরত্ব', 'পর মনে করা'] ,
['অপরদিশা', 'অপরা', 'দগ্ধা', 'পশ্চিম', 'পশ্চিম দিশা'] ,
['অপরা বিদ্যা', 'পদার্থ বিদ্যা', 'লৌকিক বিদ্যা'] ,
['অপরা', 'অপরাজিতা', 'অমৃতমালিনী', 'অষ্টভূজা', 'আদি শক্তি', 'আর্যা', 'ঈশা', 'ঈশানী', 'কল্যাণী', 'কালদমনী', 'কৌশিকী', 'গায়ত্রী', 'চামুন্ডা', 'চামুন্ডেশ্বরী', 'জগদম্বা', 'জয়া', 'ত্রিনয়না', 'ত্রিভুবনসুন্দরী', 'দূর্গা', 'দেবী', 'নন্দিনী', 'পরমেশ্বরী', 'পর্বতাত্মজা', 'বামদেবী', 'বিজয়া', 'ভালচন্দ্র', 'ভূতনায়িকা', 'মহামায়া', 'মহাশ্বেতা', 'মাতেশ্বরী', 'মায়া', 'রেবতী', 'শাম্ভবী', 'শারদা', 'শিবানী', 'শুভঙ্করী', 'শুম্ভঘাতিনী', 'শুম্ভমর্দিনী', 'সর্বমঙ্গলা', 'সিংহবাহিনী'] ,
['অপরাক্রমী', 'শৌর্যবিহীন'] ,
['অপরাজিত', 'অপরাস্ত', 'অপ্রতিহত', 'অবিজিত'] ,
['অপরাজিতা', 'নীলপুষ্পা', 'বিক্রান্ত', 'বৈষ্ণবী', 'মহাপুষ্পা', 'মহাশ্বেতা', 'শিতোদ্রিকার্ণী', 'শ্বেতধামা', 'শ্বেতা'] ,
['অপরাধ করা', 'কসুর করা', 'ভুল করা'] ,
['অপরাধ কর্তা', 'অপরাধকারী', 'অপরাধী', 'আসামী', 'দোষী'] ,
['অপরাধ কারী', 'অপরাধী', 'দোষী'] ,
['অপরাধ বিজ্ঞান', 'অপরাধ-বিজ্ঞান', 'অপরাধবিজ্ঞান'] ,
['অপরাধ বিজ্ঞানী', 'অপরাধবিজ্ঞানী', 'অপরাধবৈজ্ঞানীক'] ,
['অপরাধ বিভাগ', 'ক্রাইম ব্রাঞ্চ', 'তদন্ত বিভাগ'] ,
['অপরাধ', 'ত্রুটি', 'বিপর্যয়', 'ভুল'] ,
['অপরাধপূর্ণতা', 'দোষপূর্ণতা'] ,
['অপরাধপ্রমাণ', 'অভিশাস্তি', 'দোষনির্ণয়', 'দোষী সাব্যস্তকরণ'] ,
['অপরাধমূলক', 'অপরাধী'] ,
['অপরাধী', 'দন্ডিত', 'দোষযুক্ত', 'দোষী', 'সাজাপ্রাপ্ত'] ,
['অপরাধের নথিপত্র', 'অভিযোগপত্র', 'মামলা সংক্রান্ত নথিপত্র'] ,
['অপরাবর্তী', 'কর্মবীর'] ,
['অপরাহ্ণ', 'তৃতীয় প্রহর'] ,
['অপরাহ্নের', 'বিকালের'] ,
['অপরিগৃহীত', 'পরিত্যক্ত'] ,
['অপরিজ্ঞাত', 'অবিজ্ঞাত', 'অবিদিত'] ,
['অপরিণীতা', 'অবিবাহিতা নারী', 'অব্যূড়', 'অরক্ষণীয়া'] ,
['অপরিপক্ক', 'অর্ধপক্ক', 'আধকাঁচা', 'আধগলা', 'আধপাকা'] ,
['অপরিপক্ক্ব', 'কাঁচা'] ,
['অপরিপূর্ণ', 'অপূর্ণ'] ,
['অপরিবর্তনশীল', 'অপরিবর্তনীয়'] ,
['অপরিমিত', 'সীমাহীন'] ,
['অপরিমেয় কাল', 'আনন্ত্য'] ,
['অপরিশুদ্ধ', 'অশুদ্ধ', 'ভুল', 'ভেজাল'] ,
['অপরিশোধিত', 'অশুদ্ধ', 'অশোধিত', 'অসংশোধিত'] ,
['অপরিশ্রমী', 'অপ্রযত্নশীল', 'উদ্যমহীন', 'উদ্যোগহীন', 'পুরুষার্থহীন'] ,
['অপরীক্ষিত', 'অপ্রত্যয়িত', 'অপ্রমাণিত'] ,
['অপরোক্ষ', 'ইন্দ্রিয় গোচর', 'ইন্দ্রিয়গম্য', 'ইন্দ্রিয়গোচর', 'ইন্দ্রিয়গ্রাহ্য', 'নয়নগোচর', 'প্রত্যক্ষ', 'সমক্ষ', 'সাক্ষাত্'] ,
['অপর্যাপ্ততা', 'অপূর্ণতা', 'অভাব', 'অল্পতা', 'ন্যূনতা', 'লাঘব'] ,
['অপলক দৃষ্টি', 'স্থির দৃষ্টি'] ,
['অপলক', 'নির্নিমিখ', 'নির্নিমেষ'] ,
['অপশব্দ', 'কুবচন', 'খারাপ কথা', 'দুরালাপ', 'দুরুক্তি'] ,
['অপসারণ', 'দূর করা'] ,
['অপসারিত করা', 'কর্মচ্যুত করা', 'খারিজ করা', 'তাড়িয়ে দেওয়া', 'নিবৃত্তি দেওয়া', 'বরখাস্ত করা'] ,
['অপসারিত', 'অবকৃষ্ট', 'নিষ্কাশিত', 'নীচে নামানো', 'বহিষ্কৃত'] ,
['অপসিদ্ধান্ত', 'ভ্রান্ত সিদ্ধান্ত'] ,
['অপস্নান', 'ঘাট কামানো'] ,
['অপস্মারী', 'অপস্মারীণি'] ,
['অপহরণ করা', 'ওঠানো', 'লুটে নেওয়া', 'হরণ করা'] ,
['অপহরণ', 'অভিহার', 'কিডন্যাপ', 'লুন্ঠন', 'হরণ'] ,
['অপহরণকারী', 'অপহারক'] ,
['অপহৃত', 'চোরাই'] ,
['অপাঠযোগ্য', 'অপাঠ্য'] ,
['অপাঠ্য', 'দুষ্পাঠ্য'] ,
['অপাত্র', 'অযোগ্য', 'কুপাত্র'] ,
['অপাত্রতা', 'কুপাত্রতা'] ,
['অপাদান', 'অপাদান কারক'] ,
['অপান', 'অপান বায়ু'] ,
['অপাপবিদ্ধ', 'পাপশূণ্য'] ,
['অপারিবারিক', 'পরিবার বহির্ভূত'] ,
['অপারেটর', 'সঞ্চালক'] ,
['অপারেশন করা', 'শল্যক্রিয়া করা', 'সার্জারি করা'] ,
['অপারেশন থিয়েটার', 'শল্য-চিকিত্সা কক্ষ'] ,
['অপারেশন', 'কাঁটাছেঁড়া', 'শল্য কর্ম', 'শল্য চিকিত্সা', 'শল্যকর্ম', 'শল্যক্রিয়া', 'শল্যচিকিত্সা', 'শল্যোপচার'] ,
['অপার্থিব', 'অভৌতিক'] ,
['অপুজ্য', 'অবরেণ্য'] ,
['অপুত্র', 'নিপুত্র'] ,
['অপুষ্ট', 'কমজোর', 'দুর্বল'] ,
['অপুষ্প', 'অপুষ্পক'] ,
['অপূর্ণ পক্ষাঘাত', 'মৃদপঘাত'] ,
['অপূর্ণতা', 'অভাব', 'অসমাপ্তি'] ,
['অপূর্ণভূত', 'অপূর্ণভূত ক্রিয়া'] ,
['অপৃথক', 'অভিন্ন'] ,
['অপেক্ষমাণ', 'অপেক্ষাকারী', 'প্রতীক্ষাকারী'] ,
['অপেক্ষা করা', 'পথ চেয়ে থাকা', 'প্রতিক্ষা করা'] ,
['অপেক্ষা', 'তুলনা', 'প্রতিক্ষা'] ,
['অপেক্ষাকৃত', 'তুলনায়', 'মোকাবিলা'] ,
['অপেয়', 'দূষিত'] ,
['অপৌরুষ', 'নপুংসক', 'পুরুষত্বহীন', 'পৌরুষহীন', 'বীর্যরহিত', 'বীর্যহীন', 'শুক্রহীন'] ,
['অপ্রকটিত', 'অব্যক্ত', 'অব্যক্ত উপনিষদ', 'অব্যক্তোপনিষদ', 'অলক্ষিত'] ,
['অপ্রকাশনীয়', 'অপ্রকাশ্য'] ,
['অপ্রকাশ্য', 'গোপনীয়'] ,
['অপ্রকৃত', 'অবাস্তবিক', 'অযথাযথ', 'অযথার্থ', 'কল্পিত', 'কাল্পনিক', 'কৃত্রিম', 'খেয়ালী', 'নকল', 'মিথ্যা', 'লোকদেখানো'] ,
['অপ্রচলিত মুদ্রা', 'অবিনিমেয় মুদ্রা'] ,
['অপ্রতিবন্ধ', 'নিরঙ্কুশ', 'প্রতিবন্ধরহিত', 'প্রতিবন্ধহীন', 'প্রতিবন্ধহীনতা', 'ব্যাঘাতশূণ্য', 'যথেচ্ছাচারী', 'স্বেচ্ছাচ্ছারী', 'স্বৈরাচারী'] ,
['অপ্রতিরথ', 'অপ্রতিরথ ঋষি'] ,
['অপ্রতীত', 'অস্পষ্ট'] ,
['অপ্রত্যাশিত', 'আকস্মিক', 'আশাতীত', 'দৈবিক', 'দৈবী', 'হঠাত্'] ,
['অপ্রত্যয়ী', 'শঙ্কাপ্রবণ', 'সংশয়শীল', 'সংশয়ী', 'সন্দেহপ্রবণ'] ,
['অপ্রদত্ত অনুমতি', 'অপ্রাপ্ত অনুমতি'] ,
['অপ্রধান কয়েল', 'গৌণ কয়েল', 'দ্বিতীয় কয়েল', 'সেকেণ্ডারী কয়েল'] ,
['অপ্রধান ব্যক্তি', 'অপ্রমুখ ব্যক্তি', 'গৌণ্য ব্যক্তি'] ,
['অপ্রধান', 'আনুষঙ্গিক', 'গৌণ'] ,
['অপ্রবাহিত', 'গতিহীন', 'জমা', 'প্রবাহহীন', 'শান্ত', 'স্থির'] ,
['অপ্রমাণিত', 'অসিদ্ধ'] ,
['অপ্রমূখতা', 'অপ্রাথমিকতা', 'অপ্রাধান্যতা', 'গৌণ্যতা'] ,
['অপ্রযত্ন', 'অপ্রয়াস', 'নিশ্চেষ্টতা'] ,
['অপ্রশংসনীয়', 'অপ্রশংসিত', 'নিন্দাজনক'] ,
['অপ্রসঙ্গ', 'অবচ্ছেদ', 'অসংসর্গ', 'অসম্পর্ক', 'পার্থক্য', 'পৃথককরণ', 'পৃথকতা', 'বিচ্ছেদ'] ,
['অপ্রসন্ন করে তোলা', 'বিরক্ত করা', 'রাগানো'] ,
['অপ্রসার', 'অবিস্তার'] ,
['অপ্রসূতু', 'নিষ্ফলা', 'বন্ধ্যা'] ,
['অপ্রাকৃতিক স্থান', 'মানব নির্মিত স্থান'] ,
['অপ্রাকৃতিক', 'অস্বাভাবিক'] ,
['অপ্রাপ্তবয়স্ক', 'নাবালিক'] ,
['অপ্রাপ্তযৌবন', 'অল্পবয়স্ক', 'নাবালক', 'নাবালিকা'] ,
['অপ্রাপ্তি', 'অলভ্যতা'] ,
['অপ্রামাণিক', 'ভিত্তিহীন'] ,
['অপ্রাসঙ্গিক', 'অবিষয়', 'অসংলগ্ন', 'বিষয়জ্ঞানশূণ্য', 'বিষয়বোধশূণ্য', 'বিষয়াতীত'] ,
['অপ্রিয় লাগা', 'খারাপ লাগা', 'গায়ে লাগা'] ,
['অপ্রিয়', 'অপ্রীতিকর', 'অরুচিকর', 'রুচিহীন'] ,
['অপ্রিয়বাদী', 'অপ্রিয়ভাষী', 'অপ্রিয়ম্বাদী'] ,
['অপ্রোথিত', 'অবিদ্ধ'] ,
['অপ্সরা', 'দেব নর্তকী', 'দেবাঙ্গনা'] ,
['অপয়া', 'অভাগা', 'দুর্ভাগা', 'দুর্ভাগ্যবান'] ,
['অফল', 'ঝাউ', 'ফলবিহীন', 'বহুগ্রন্থি'] ,
['অফলপ্রসূ', 'শৈল্পিক অভিঘাতহীন'] ,
['অফলা', 'অমরা', 'অরজা', 'ঘৃতকুমারী', 'বহুকন্যা'] ,
['অফার করা', 'উপলব্ধ করা'] ,
['অফিস', 'কার্যালয়', 'দফতর'] ,
['অফিসার', 'আধিকারীক', 'আমলা'] ,
['অবঊর্ধনুজ গ্রন্থি', 'অবঊর্ধনুজ লালা গ্রন্থি'] ,
['অবকলিত', 'সংকলিত'] ,
['অবকাশ অনুমতি', 'ছুটির অনুমতি'] ,
['অবকাশ', 'কার্যাবকাশ', 'ছুটি', 'ফুরসত্', 'বিরাম কাল', 'বিশ্রাম কাল'] ,
['অবকীর্ণ', 'ইতস্তত বিক্ষিপ্ত', 'কৌমার্যভঞ্জিত', 'খণ্ডিত', 'চূর্ণিত'] ,
['অবকীর্ণী', 'ক্ষতব্রত', 'ব্রতলঙ্ঘনকারী'] ,
['অবকেশী', 'অল্পকেশবিশিষ্ট'] ,
['অবক্র', 'ঋজু', 'বক্রহীন', 'মোড়হীন', 'সোজা'] ,
['অবক্ষয়', 'বিকার'] ,
['অবগত করা', 'আলোকপাত করা', 'জানানো', 'জ্ঞাত করা'] ,
['অবগত করানো', 'বলা', 'বোঝানো'] ,
['অবগত হওয়া', 'জানা', 'জ্ঞাত হওয়া', 'বোঝা'] ,
['অবগতি', 'জানা', 'বোধ'] ,
['অবগাহন', 'মন্থন', 'মন্থন করা', 'স্নান'] ,
['অবগাহিত', 'স্নাত', 'স্নান করা'] ,
['অবগুণ্ঠন মুদ্রা', 'অবগুণ্ঠনমুদ্রা'] ,
['অবগুণ্ঠন', 'আচ্ছাদন', 'ঘোমটা', 'ঢাকা', 'লুকানো'] ,
['অবগুণ্ঠনবতী', 'ঘোমটা পরিহিতা'] ,
['অবগুন্ঠন', 'ঘোমটা', 'পরদা', 'যবনিকা'] ,
['অবচলুক', 'চর্মকার', 'চামার'] ,
['অবচূড়', 'কেতন', 'ঝাণ্ডা', 'ধ্বজা', 'পতাকা', 'ব্যানার'] ,
['অবচেতনতা', 'মগ্নচৈতন্য'] ,
['অবচ্ছিন্ন', 'চ্ছিন্ন', 'ছিন্ন', 'বিচ্ছিন্ন', 'বিভক্ত', 'বিশ্লিষ্ট'] ,
['অবচ্ছেদক', 'নিয়ামক', 'পরিচ্ছেদক', 'বিভাজক'] ,
['অবচ্ছেদন', 'বাঁটোয়ারা', 'বিখন্ডন', 'বিভাজন'] ,
['অবজীহ্বী গ্রন্থি', 'অবজীহ্বী লালা গ্রন্থি'] ,
['অবজ্ঞা করা', 'অবহেলা করা', 'অশ্রদ্ধা করল', 'তাচ্ছিল্য করা'] ,
['অবজ্ঞা', 'অবজ্ঞা অলংকার', 'অবহেলা', 'অবাধ্যতা'] ,
['অবজ্ঞার যোগ্য', 'অবজ্ঞেয়', 'অশ্রদ্ধেয়', 'উপেক্ষণীয়', 'হেয়'] ,
['অবতরণ', 'উতরাই', 'নামা'] ,
['অবতরণিকা', 'প্রস্তাবনা', 'প্রাককথন', 'ভূমিকা', 'মুখবন্ধ'] ,
['অবতার', 'দেবাংশধারী'] ,
['অবতারিত', 'অবরোপিত'] ,
['অবদমিত', 'দমিত'] ,
['অবধ', 'অযোধ্যা', 'অযোধ্যা নগরী', 'কোশল', 'সাকেত'] ,
['অবধান', 'অভিনিবেশ', 'একাগ্রচিত্তে', 'একাগ্রতা', 'পরিচালনা', 'মনোনিবেশ', 'মনোযোগ', 'সংঞ্চালন'] ,
['অবধানতা', 'সতর্কতা', 'সাবধানতা'] ,
['অবধারণ', 'নির্ধারণ', 'ব্যবস্থাপন'] ,
['অবধারণীয়', 'অবধার্য'] ,
['অবধি জ্ঞান', 'অবধি দর্শন'] ,
['অবধুত', 'অবধুত উপনিষদ', 'অবধুতোপনিষদ'] ,
['অবধেশ', 'দশরথ', 'রাজা দশরথ'] ,
['অবনত', 'নত'] ,
['অবনতিশীল', 'পতনশীল', 'পতনোন্মুখ'] ,
['অবনদ্ধ বাদ্য', 'অবনদ্ধবাদ্য', 'আনদ্ধ বাদ্য', 'আনদ্ধবাদ্য'] ,
['অবনমিত থাকা', 'ঝুঁকে থাকা'] ,
['অবনমিত শ্রেণী', 'দলিত বর্গ'] ,
['অবনমিত', 'নমিত'] ,
['অবন্তিকা', 'অবন্তী', 'উজ্জয়ন', 'উজ্জয়ন নগর', 'উজ্জয়নী'] ,
['অবপাত', 'খেদা', 'দোমা', 'ফাঁদ', 'ভোল'] ,
['অববোধক', 'উপদেশক', 'উপদেশমূলক', 'জাগরয়িতা'] ,
['অবভাস', 'ভ্রান্ত ধারণা', 'মিথ্যা জ্ঞান'] ,
['অবভৃত', 'অবভৃত যজ্ঞ'] ,
['অবম তিথি', 'ক্ষয় তিথি'] ,
['অবমানন', 'অবমাননা', 'মানহানি'] ,
['অবমাননা', 'অবহেলা'] ,
['অবরত', 'আবর্ত'] ,
['অবরুদ্ধ করা', 'অবরোধ করা', 'আটকানো'] ,
['অবরুদ্ধ দওয়া', 'ফাঁসা', 'বন্ধ হওয়া'] ,
['অবরুদ্ধ', 'থেমে থাকা', 'বন্ধ', 'বন্ধ হয়ে থাকা', 'রুদ্ধ', 'সংবৃত'] ,
['অবরূদ্ধ', 'বন্ধ করা'] ,
['অবরোধ করা', 'নাক গলানো', 'বাধা দেওয়া', 'হস্তক্ষেপ করা'] ,
['অবরোধ', 'ঘেরা', 'বেড়া'] ,
['অবরোধক', 'অবরোধী', 'বাধক'] ,
['অবরোধপূর্ণ', 'অবরোধাত্মক', 'রোধাত্মক'] ,
['অবরোধী', 'বাধাপ্রদানকারী'] ,
['অবরোপিত', 'উত্পাটিত', 'উন্মূলিত', 'বিনাশিত'] ,
['অবরোহক', 'অবরোহণকারী'] ,
['অবরোহণ', 'নামা'] ,
['অবর্জাভেটরি', 'জন্তর-মন্তর', 'বৈধগৃহ', 'বৈধশালা', 'মানমন্দির', 'যন্ত্রগৃহ', 'যন্ত্রশালা'] ,
['অবর্তমান', 'অবিদ্যমান', 'অস্তিত্ত্ববিহীন', 'সত্তাশূণ্য'] ,
['অবলক', 'অবলখ'] ,
['অবলম্বন করা', 'টিকে থাকা', 'সামলে থাকা', 'সাহায্যে নেওয়া'] ,
['অবলম্বন ব্যতিরেকে', 'অবলম্বনহীন'] ,
['অবলম্বন', 'আধার', 'আশ্রয়', 'ভরসা'] ,
['অবলম্বনযোগ্য', 'ভরসাষোগ্য'] ,
['অবলম্বী', 'আধারিত', 'আশ্রিত', 'নির্ভরশীল'] ,
['অবলা', 'মূক প্রাণী'] ,
['অবলীঢ়', 'চাটা'] ,
['অবলুণ্ঠিত', 'ভূমিতে লুটানো'] ,
['অবলুন্ঠন', 'গড়াগড়ি', 'লুটোপুটি'] ,
['অবলেপন', 'নেপন'] ,
['অবলেহন', 'অবলেহ্য', 'চাটা'] ,
['অবলেহ্য', 'লেহনীয়'] ,
['অবলোকন', 'দর্শন', 'দর্শন উপনিষদ', 'দর্শনোপনিষদ', 'দৃষ্টিপাত', 'দেখা'] ,
['অবলোকিত', 'দৃষ্ট', 'দেখা', 'নিরীক্ষিত', 'বিলোকিত'] ,
['অবলোহিত বিকিরণ', 'ইনফ্রারেড কিরণ'] ,
['অবশ হওয়া', 'চেতনাহীন হওয়া'] ,
['অবশিষ্ট', 'পরিশিষ্ট', 'বেঁচে যাওয়া'] ,
['অবশেষ', 'বর্জ্য', 'বাকী', 'শেষ'] ,
['অবশোষিত', 'শোষিত'] ,
['অবশ্যই', 'নিঃসংশয়ে', 'নিঃসন্দেহে', 'বিনা সংশয়ে', 'বিনা সন্দেহে'] ,
['অবষ্টম্ভ', 'পক্ষপতন'] ,
['অবসকাশগ্রহণ', 'অবসরগ্রহণ', 'অবসরপ্রাপ্তি', 'রিটায়ারমেন্ট'] ,
['অবসন্ন', 'অবসাদগ্রস্ত', 'বিনাশোন্মুখ'] ,
['অবসরপ্রাপ্ত', 'রিটায়ার্ড'] ,
['অবসরভাতা সম্পর্কিত', 'অবসরভাতার'] ,
['অবসাদ', 'অশক্ততা', 'অশক্তি', 'অসামর্থ্য', 'উত্সাহহীনতা', 'ক্লান্তি', 'দুর্বলতা', 'পরিশ্রান্তি', 'বলহীনতা', 'বিষাদ', 'শক্তিবৈকল্য', 'শক্তিহীনতা', 'শ্রান্তি'] ,
['অবসাদপূর্ণ', 'দুঃখপূর্ণ', 'শোকাহত'] ,
['অবসাদহীনতা', 'শোকহীনতা'] ,
['অবসান', 'ইতি', 'উপসংহার', 'নিষ্পত্তি', 'পরিণতি', 'পরিসমাপ্তি', 'সমাপ্তি'] ,
['অবস্কারক', 'শব ভক্ষণকারী', 'শবালী'] ,
['অবস্থা খারাপ হওয়া', 'হাওয়া বের হওয়া'] ,
['অবস্থা পাল্টানো', 'পাশা পাল্টানো'] ,
['অবস্থা', 'গতি', 'দশা', 'পরিস্থিতি', 'স্থিতি', 'হাল'] ,
['অবস্থান নির্ধারণ', 'স্থান নির্ধারণ'] ,
['অবস্থাপন', 'আস্থাপন', 'প্রতিষ্ঠান', 'স্থাপন', 'স্থাপনা'] ,
['অবস্থিত হওয়া', 'হওয়া'] ,
['অবস্য', 'অবস্য ঋষি'] ,
['অবস্যু', 'অবস্যু ঋষি'] ,
['অবস্হান করা', 'অবস্হিত হওয়া'] ,
['অবহ', 'বায়ু'] ,
['অবহেলা করা', 'উপেক্ষা করা', 'কান না দেওয়া', 'গা না করা'] ,
['অবহেলা', 'অমনোনিবেশ', 'অমনোযোগ', 'অসর্তকতা', 'অসাবধাণতা', 'অসাবধাণী', 'চিত্তবিক্ষেপ', 'সাবধাণহীনতা'] ,
['অবহেলিত', 'উপেক্ষিত'] ,
['অবাই', 'জোতা'] ,
['অবাক হয়ে দেখা', 'তাকিয়ে থাকা', 'হাঁ করে তাকিয়ে দেখা'] ,
['অবাদী', 'অবিবাদী', 'অবিরোধী'] ,
['অবাধিত', 'স্বতন্ত্র', 'স্বাধীন', 'স্বেচ্ছাচারী'] ,
['অবালী', 'অবালী পাখি'] ,
['অবালেন্দু', 'পূর্ণ চন্দ্রমা', 'পূর্ণচন্দ্র', 'পূর্ণচন্দ্রমা', 'পূর্ণচাঁদ', 'পূর্ণেন্দু'] ,
['অবিকল', 'আদ্যান্ত', 'আদ্যোপান্ত', 'নকল', 'পুরো', 'সমগ্র', 'সম্পূর্ণ', 'হুবহু'] ,
['অবিকশিত', 'অস্মিত'] ,
['অবিকার', 'বিকারহীনতা'] ,
['অবিকৃত', 'আসল'] ,
['অবিচার', 'অবিবেক'] ,
['অবিচ্যুয়ারি', 'আলোক', 'টিপ্পণী'] ,
['অবিতর্কিত', 'বিতর্কাতীত'] ,
['অবিদ্ধকর্ণী', 'পাড়া', 'বৃহত্তিক্তা'] ,
['অবিদ্য', 'বিদ্যাশূণ্য', 'মূর্খ', 'শাস্ত্রজ্ঞানহীন'] ,
['অবিধান', 'অবিধি', 'অবিধিক'] ,
['অবিনাশ', 'চিরস্থায়ীত্ব', 'বিনাশাভাব'] ,
['অবিনাশী', 'চিরন্তন', 'চিরস্থায়ী', 'চিরায়ত', 'নিত্য', 'শাশ্বত', 'সনাতন'] ,
['অবিনীত', 'অবিন্ম্র', 'অহংকারী', 'উদ্ধত', 'গর্বিত', 'দর্পী', 'দাম্ভিক'] ,
['অবিবাদ', 'অবিবাদিত', 'নির্বিবাদ', 'বিবাদরহিত', 'বিবাদহীন'] ,
['অবিবেচকের মতো', 'চিন্তাবিহীনভাবে'] ,
['অবিভক্ত কোষিকা', 'আদি ভ্রূণকোষ'] ,
['অবিভক্ত', 'অভিন্ন', 'আনুষঙ্গিক', 'জোড়া', 'শ্লিষ্ট', 'সংবদ্ধ', 'সংযুক্ত', 'সংযোজিত', 'সংশ্লিষ্ট', 'সাঁটা'] ,
['অবিরাম বৃষ্টি', 'বৃষ্টি'] ,
['অবিলম্বে', 'এখনি'] ,
['অবিশুদ্ধতা', 'অশুদ্ধতা'] ,
['অবিশ্বস্ত', 'অবিশ্বাসী'] ,
['অবিশ্বাস', 'বিশ্বাসহীনতা'] ,
['অবিশ্বাসি ব্যক্তি', 'অবিশ্বীসি'] ,
['অবিশ্বাসী', 'সন্দেহপ্রবণ'] ,
['অবিষম', 'একই', 'সদৃশ', 'সম', 'সমান'] ,
['অবিষা', 'নির্বীষীতৃণ'] ,
['অবিস্তৃত', 'পাতলা', 'বিস্তারহীন', 'সংকীর্ণ', 'সরু'] ,
['অবিস্মরণীয়', 'স্মরণীয়'] ,
['অবীচি', 'অবীচি নরক'] ,
['অবীরা', 'স্বাধীন নারী'] ,
['অবুঝ', 'নির্বোধ', 'বিবেকহীন'] ,
['অবুঝপনা', 'আনাড়িপনা', 'বেওকুফি', 'মুর্খামি'] ,
['অবুদ্ধি', 'খাটো বুদ্ধি', 'স্বল্প বুদ্ধি'] ,
['অবেদ্যা', 'বিবাহ অযোগ্যা'] ,
['অবৈজ্ঞানিক', 'বিজ্ঞান বিরুদ্ধ', 'বিজ্ঞান বিরোধী'] ,
['অবৈতনিক', 'নির্বেতন'] ,
['অবৈদিক', 'বেদ বিরুদ্ধ'] ,
['অবৈধ কার্যকলাপ', 'অবৈধ চক্র', 'অবৈধ ব্যবসা'] ,
['অবৈধ সওদা করা', 'বেআইনি সওদা করা'] ,
['অবৈধ সম্বন্ধ', 'ব্যাভিচার', 'লম্পটতা'] ,
['অবৈধ', 'জারজ', 'বিধিবিরুদ্ধ'] ,
['অবৈয়াকরণ', 'অব্যুত্পন্ন', 'প্রকৃতিপ্রত্যয়শূণ্য', 'ব্যুতপত্তিহীন'] ,
['অব্জ', 'নিচুল', 'হিজ্জল'] ,
['অব্বাসী', 'অব্বাসী তুলো'] ,
['অব্যক্তগতি', 'অব্যক্তমূর্তি'] ,
['অব্যঞ্জন', 'ব্যঞ্জনরহিত', 'লক্ষণবিহীন', 'লক্ষণরহিত', 'লক্ষণশূণ্য', 'সুলক্ষণহীন'] ,
['অব্যবধান', 'আসন্নতা', 'নিকটতা', 'নৈকট্য', 'বাধাবিঘ্নহীনতা', 'সমীপতা', 'সান্নিধ্য'] ,
['অব্যবসায়ী', 'ক্রিয়াশূণ্য', 'চেষ্টারহিত', 'বেরোজগেরে'] ,
['অব্যবস্থা', 'কুব্যবস্থা', 'গড়বড়'] ,
['অব্যবস্থিত', 'ক্রমহীন ভাবে', 'ক্রমহীনতঃ', 'ছিনন্-ভিন্ন', 'ভাঙা', 'যেখানে সেখানে'] ,
['অব্যবহারিকতা', 'অভদ্রতা'] ,
['অব্যবহৃত', 'আনকোরা', 'নতুন'] ,
['অব্যর্থ', 'অমোঘ'] ,
['অব্যর্থতা', 'চির-অভ্রান্ততা'] ,
['অব্যাকৃত ধর্ম', 'অব্যাকৃতধর্ম'] ,
['অব্যাখ্যেয়', 'দুর্বোধ্য'] ,
['অব্যাঘাত', 'ব্যাঘাতহীন'] ,
['অব্যাপকতা', 'সীমিততা'] ,
['অব্যাপ্তিশীল', 'অব্যাপ্য', 'ব্যাপ্তিরহিত', 'সংকীর্ণ', 'সীমাবদ্ধ'] ,
['অব্যয়ীভাব', 'অব্যয়ীভাব সমাস'] ,
['অব্রণ', 'অব্রণশুক্র'] ,
['অব্রত', 'ব্রতরহিত', 'ব্রতহীন'] ,
['অব্রতী', 'ব্রতরহিত'] ,
['অবয়বতন্ত্র', 'সন্ধিতন্ত্র'] ,
['অবয়াব', 'পাট্টা'] ,
['অভঞ্জন', 'তরল পদার্থ', 'দ্রব', 'দ্রব পদার্থ'] ,
['অভদ্র', 'অশিষ্ট', 'অশ্লীল', 'অসভ্য', 'শিষ্টাচারহীন'] ,
['অভদ্রতা', 'অভব্যতা', 'অশালীনতা', 'অসভ্যতা', 'অসৌজন্য', 'বদমেজাজ', 'বেয়াদপি'] ,
['অভশঙ্কিত', 'অভিশঙ্কী'] ,
['অভাগা', 'দুর্ভাগা'] ,
['অভাজ্য গুণনীয়ক', 'প্রাইম ফ্যাক্টর'] ,
['অভাব', 'দুর্লভ্যতা'] ,
['অভাবী', 'দারিদ্রপীড়িত', 'দুর্দশাগ্রস্ত'] ,
['অভিকথন', 'অভিশাপ', 'অভিহিংসা', 'দোষারোপ', 'দোষারোপণ'] ,
['অভিকল্পন', 'যোজনা', 'স্কিম'] ,
['অভিক্রিয়া', 'প্রতিক্রিয়া'] ,
['অভিখ্যা', 'কীর্তি', 'খ্যাতি', 'নাম', 'প্রখ্যাতি', 'প্রতিষ্ঠা', 'প্রসিদ্ধি', 'যশ', 'সুখ্যাতি', 'সুনাম'] ,
['অভিঘাত', 'আঘাত', 'খারাপ লাগা', 'ঘাত', 'চোট', 'ধাক্কা', 'প্রহার'] ,
['অভিচার', 'অভিচারণ', 'কৃত্যা'] ,
['অভিজাত', 'উচ্চবংশীয়'] ,
['অভিজাত-ভবন', 'ব্রিটিশ হাউস-অফ-লর্ড', 'হাউস-অফ-লর্ড'] ,
['অভিজাত্য', 'কৌলীন্য'] ,
['অভিজিত্', 'অভিজিত্ নক্ষত্র'] ,
['অভিজ্ঞ ব্যক্তি', 'কুশলী ব্যক্তি', 'দক্ষ ব্যক্তি', 'পাকা লোক'] ,
['অভিজ্ঞ', 'অভিজ্ঞতাশালী', 'অভিজ্ঞতাসম্পন্ন', 'অভ্যস্ত', 'কুশল', 'জ্ঞানী', 'দক্ষ', 'ধুরন্ধর', 'নিপুণ', 'পটু', 'পরিপক্ক', 'পাকা', 'পারদর্শী', 'বিচক্ষণ', 'সিদ্ধহস্ত', 'হুঁশিয়ার'] ,
['অভিজ্ঞতা', 'জ্ঞান'] ,
['অভিজ্ঞা', 'অলৌকিক জ্ঞান', 'চিহ্ন', 'নিশান', 'পারলৌকিক জ্ঞান', 'প্রতীক', 'সংকেত', 'স্মারক', 'স্মৃতিচিহ্ন'] ,
['অভিজ্ঞান', 'চেনা', 'জানা', 'সনাক্তকরণ'] ,
['অভিধান রচয়িতা', 'সংকলক'] ,
['অভিধান', 'শব্দকোশ', 'শব্দকোষ'] ,
['অভিধেয়', 'কথনীয়', 'বর্ণনীয়'] ,
['অভিধ্যা', 'অভিলাষ'] ,
['অভিনন্দন পত্র', 'গ্রীটিং কার্ড'] ,
['অভিনন্দন', 'তারিফ', 'প্রশংসা', 'প্রশস্তি', 'স্তুতি'] ,
['অভিনন্দনীয়', 'প্রশংসনীয়'] ,
['অভিনন্দিত', 'প্রশংসিত', 'বন্দিত'] ,
['অভিনব', 'নতুন', 'নবীন', 'নূতন', 'সাম্প্রতিক', 'হালের'] ,
['অভিনবত্ব', 'নতুন কিছু করা'] ,
['অভিনিবেশ', 'মনোযোগ'] ,
['অভিনিবেশিত', 'প্রবিষ্ট'] ,
['অভিনেতা', 'স্টার'] ,
['অভিনেয়', 'অভিনয়যোগ্য'] ,
['অভিন্ন', 'পূর্ণ সংখ্যা', 'পূর্ণাঙ্ক'] ,
['অভিন্নহৃদয় বন্ধু', 'ঘনিষ্ঠ বন্ধু', 'হরিহর আত্মা'] ,
['অভিনয়', 'নাটক'] ,
['অভিপ্রায় নিয়ে', 'উদ্দেশ্য নিয়ে', 'উদ্দেশ্যপূর্বক'] ,
['অভিপ্রায়', 'অর্থ', 'আশয়', 'তাত্পর্য'] ,
['অভিপ্রেত', 'ঈপ্সিত', 'কাঙ্খিত', 'বাঞ্ছিত', 'মনোবাঞ্ছিত'] ,
['অভিপ্সু', 'অভিলাষী', 'ইচ্ছু', 'ইচ্ছুক'] ,
['অভিবন্দনীয়', 'নমস্য', 'প্রণম্য', 'বন্দনীয়'] ,
['অভিবন্দিত', 'অভিবাদিত'] ,
['অভিবাদনকারী', 'অভ্যর্থনাকারী'] ,
['অভিবাদনযোগ্য', 'অভিবাদ্য'] ,
['অভিব্যক্ত করা', 'প্রকট করা', 'ব্যক্ত করা'] ,
['অভিব্যক্ত', 'প্রকট', 'প্রকাশ', 'ব্যক্ত'] ,
['অভিব্যঞ্জনা করা', 'ভাব অভিব্যক্ত করা', 'ভাবাভিব্যক্ত করা', 'ভাবাভিব্যক্তি করা'] ,
['অভিব্যাপক', 'সর্বব্যপী', 'সর্বব্যাপক', 'সর্বব্যাপ্ত'] ,
['অভিভাবক', 'সংরক্ষক'] ,
['অভিভাষণ', 'কথোকতা', 'বক্তৃতা', 'সম্ভাষণ'] ,
['অভিভাষী', 'বক্তা'] ,
['অভিভাষ্য', 'কথ্য', 'বক্তব্য', 'বলার মতো', 'বাচ্য', 'ভাষ্য'] ,
['অভিভূত', 'আপ্লুত'] ,
['অভিমত', 'বিচার', 'মত', 'রায়', 'সম্মতি'] ,
['অভিমর্দন', 'চূর্ণন', 'দলন', 'মর্দন'] ,
['অভিমান', 'অস্মিতা', 'গর্ব', 'মান'] ,
['অভিমানিনী', 'অহংকারী', 'অহংকারী মহিলা'] ,
['অভিযাত', 'অভিযাত বর্গ'] ,
['অভিযুক্ত', 'আসামী'] ,
['অভিযোগ পত্র', 'অভিযোগপত্র'] ,
['অভিযোগ সম্পর্কিত', 'অভিযোগকারী', 'অভিযোগপত্র'] ,
['অভিযোগ', 'আরোপ', 'কেস', 'নালিশ', 'মামলা', 'মোকদ্দমা'] ,
['অভিযোগকারী', 'বাদী'] ,
['অভিরক্ষণ', 'সুরক্ষণ'] ,
['অভিরক্ষিত', 'সম্যগরক্ষিত', 'সুরক্ষিত'] ,
['অভিরতি', 'সন্তুষ্টি'] ,
['অভিরম্য', 'আকর্ষক', 'চিত্তগ্রাহী', 'চিত্তাকর্ষক', 'প্রভাবশালী', 'প্রভাবী', 'প্রিয়দর্শন', 'মনোভিরকাম', 'মনোমুগ্ধকারী', 'মনোরম', 'মনোরম্যস অভিরমণীয়', 'মনোহর', 'মনোহারী', 'মুগ্ধকারী', 'সুন্দর', 'সুরম্য'] ,
['অভিরুচি', 'ইচ্ছা', 'পছন্দ', 'প্রবৃত্তি', 'রুচি'] ,
['অভিরূপ', 'অভিরূপক', 'তারকেশ', 'তারাধীপ', 'তারাধীশ', 'তারানাথ', 'তারাপীড়', 'তারেশ', 'ত্রিনেত্রচূড়ামণি', 'নক্ষত্রনাথ', 'নক্ষত্রেশ', 'পরিজন্মা', 'বিধু', 'শশধর', 'শশভৃত', 'শশমৌলি', 'শশলক্ষণ', 'শশলাঞ্ছন', 'শশাঙ্ক', 'সিন্ধুপুত্র'] ,
['অভিলাষ হওয়া', 'ইচ্ছা হওয়া'] ,
['অভিলাষ', 'আকাঙ্খা', 'ইচ্ছা', 'কামনা', 'ক্ষুধা', 'চেষ্টা', 'তৃষা', 'তৃষ্ণা', 'পিপাসা', 'বাঞ্ছা', 'মনোকামনা', 'মনোবাঞ্ছা', 'মনোবাসনা', 'লালসা', 'লিপ্সা'] ,
['অভিলাষপূর্ণ', 'ইচ্ছাপূর্ণ', 'কামনাপূর্ণ', 'সকাম'] ,
['অভিলেখ', 'আলেখ', 'দস্তাবেজ', 'রেকর্ড'] ,
['অভিলেখাগার', 'অভিলেখালয়'] ,
['অভিশঙ্কা', 'আশঙ্কা', 'আশঙ্কা', 'ভ্রান্তি', 'শঙ্কা', 'সংশয়', 'সন্দেহ'] ,
['অভিশাপ দেওয়া', 'গাল দেওয়া', 'শাপ দেওয়া'] ,
['অভিশাপ', 'শাপ'] ,
['অভিষঙ্গ', 'ভূতাবেশ'] ,
['অভিষদ', 'অ্যাসোসিয়েশন', 'কমিটি', 'গোষ্ঠী', 'পরিষদ', 'সভা', 'সমিতি'] ,
['অভিষেক', 'অভিষেচন', 'সুপ্রতিষ্ঠা'] ,
['অভিসরণ', 'অভিসার'] ,
['অভিসার', 'ডেট', 'মিলন', 'সংযোগ', 'সমন্বয়'] ,
['অভিসারক', 'অভিসারী'] ,
['অভিসারিকা', 'অভিসারিণী'] ,
['অভিহিত', 'আখ্যাত', 'উক্ত', 'কথিত', 'বলা'] ,
['অভিহিতি', 'উক্তি', 'উদ্ধৃতি', 'উপাধি', 'কথন', 'খেতাব', 'নকল', 'পদবী', 'বচন', 'বুলি'] ,
['অভীবর্ত', 'অভীবর্ত ঋষি'] ,
['অভীষণ', 'অভয়ঙ্কর', 'অরৌদ্র'] ,
['অভীষ্টা', 'রেণুকা', 'হেমগন্ধিনী'] ,
['অভুক্ত', 'না খাওয়া', 'নিরন্ন'] ,
['অভুঙ্গর', 'দৃঢ়', 'পাকা', 'মজবুত', 'শক্ত'] ,
['অভেদ্য', 'দুর্ভেদ্য'] ,
['অভ্যঙ্গ', 'অভ্যঞ্জন', 'তেলমালিশ', 'তৈলমর্দন'] ,
['অভ্যন্তর', 'কেন্দ্র', 'মাঝে'] ,
['অভ্যন্তরীণ অঙ্গ', 'আন্তঃশারীরিক অঙ্গ', 'ভেতরের অঙ্গ'] ,
['অভ্যন্তরীণ শারীরিক অংশ', 'শরীরের অভ্যন্তর ভাগ'] ,
['অভ্যর্থনা', 'আতিথেয়তা', 'সমাদর'] ,
['অভ্যস্ত করা', 'জমানো'] ,
['অভ্যস্ত', 'গ্রস্ত'] ,
['অভ্যাগত', 'সম্মুখাগত'] ,
['অভ্যাস করা', 'আওড়ানো', 'সাধনা করা'] ,
['অভ্যাস', 'চরিত্র', 'রেওয়াজ', 'স্বভাব'] ,
['অভ্যুচ্ছ্রয়', 'উন্নীতকরণ'] ,
['অভ্যুত্থান', 'অভ্যুদয়', 'উত্পত্তি', 'উদ্ভব', 'উদয়', 'উন্নতি', 'জন্ম', 'ভব'] ,
['অভ্যুত্থানকারী', 'অভ্যুত্থায়ী'] ,
['অভ্যুত্থানের যোগ্য', 'অভ্যুদয়ের যোগ্য', 'উন্নতির যোগ্য'] ,
['অভ্যুথান', 'উত্তোলন', 'ওলট পালট', 'হুলুথুলু'] ,
['অভ্যুদয়', 'উথ্থান', 'উদয়', 'উন্নতি', 'উন্নয়ন', 'প্রগতি', 'বিকাশ'] ,
['অভ্যুপগত', 'উপাগত', 'নিকটাগত', 'সমীপাগত'] ,
['অভ্যুপগম সিদ্ধান্ত', 'বিশ্বাস'] ,
['অভ্যুপগমন', 'সমীপগমন'] ,
['অভ্রষ্ট', 'অভ্রান্ত'] ,
['অভ্রান্ত', 'ভ্রমহীন', 'ভ্রান্তিশূণ্য'] ,
['অভয়-দক্ষিণা', 'অভয়দক্ষিণা'] ,
['অভয়দ', 'অভয়প্রদ', 'আশ্বাসদায়ক'] ,
['অভয়া', 'অমৃতা', 'পথ্যা', 'পাচনী', 'বনতিক্ত', 'বিজয়া', 'রোহিণী', 'হত্তুকি', 'হরড়া', 'হরতুকি', 'হরিড়া', 'হরীতকী', 'হৈমবতী'] ,
['অভয়ারণ্য', 'সংরক্ষিত চারণভূমি', 'সংরক্ষিত বন', 'সংরক্ষিত বনাঞ্চল'] ,
['অমঙ্গল', 'অমাঙ্গলিক', 'অশুভ'] ,
['অমঙ্গলসূচক চিহ্ন', 'অশুভ ইঙ্গিত', 'অশুভ লক্ষণ'] ,
['অমত', 'অসম্মত', 'অসহমত', 'ভিন্নমত'] ,
['অমত্ত', 'মত্ততারহিত'] ,
['অমধুর', 'কটু', 'কটুতা', 'কটুত্ব', 'কড়া', 'তিক্ত'] ,
['অমনুষ্য', 'অমানুষ'] ,
['অমনোযোগী হয়ে', 'অসাবধানতঃ', 'অসাবধানী হয়ে', 'বেপড়োয়া ভাবে'] ,
['অমমতা', 'অমমত্ব'] ,
['অমর', 'অমর গণ', 'অমর পবন', 'অমরকোষ', 'অমরণশীল', 'অমরসিং', 'অমর্ত্য', 'কুলিশ বৃক্ষ', 'চিরঞ্জীবী', 'বজ্রকন্টক', 'মৃত্যুঞ্জয়ী', 'শাখাকন্ট', 'সমন্তদুগ্ধ', 'সেহুড়'] ,
['অমরকণ্টক', 'আম্রকূট'] ,
['অমরকাষ্ঠ', 'অমরতরু', 'ইন্দ্রদারু', 'দেবকাষ্ঠ', 'দেবদারু', 'মহাদারু', 'সুরদারু', 'সুরদ্রু'] ,
['অমরখ', 'অমরখ সঞ্চারী ভাব'] ,
['অমরতা', 'অমরত্ব', 'জেবত্ব', 'সুরত্ব'] ,
['অমরদাস', 'গুরু অমরদাস'] ,
['অমরদ্বিজ', 'দ্বিজ'] ,
['অমরনাথ', 'বাবা অমরনাথ'] ,
['অমরপক্ষ', 'পিতৃ পক্ষ', 'পিতৃপক্ষ', 'মহালয়া'] ,
['অমরপুষ্প', 'অমরপুষ্পক', 'কল্পতরু', 'কল্পদ্রুম', 'কল্পবৃক্ষ', 'কল্পলতা', 'কামতরু'] ,
['অমরপুষ্পক', 'ইক্ষুগন্ধা', 'গোখরু'] ,
['অমরা', 'অমরাপুরি', 'অমরাবতী', 'অমরালয়', 'ইন্দ্র লোক', 'ইন্দ্রধানী', 'ইন্দ্রপুরী', 'ইন্দ্রলোক', 'দেবপুরী', 'পুষা', 'শক্রপুরি', 'সুদর্শনা'] ,
['অমরাবতী', 'অমরাবতী জেলা', 'অমরাবতী শহর'] ,
['অমরালয়', 'অমৃতলোক', 'স্বর্গ'] ,
['অমরী', 'দেবাঙ্গনা'] ,
['অমরু', 'অমরুক'] ,
['অমরেলি', 'অমরেলি জেলা', 'অমরেলি শহর'] ,
['অমল', 'নেশা', 'মদ'] ,
['অমলতা', 'উজ্জলতা', 'নির্দোষিতা', 'নির্মলতা', 'পরিচ্ছন্নতা', 'শুদ্ধতা', 'স্বচ্ছতা'] ,
['অমলবেত', 'অম্লবেত', 'চুক', 'বরাঙ্গী', 'বৃদ্ধরাজ', 'রক্তসার', 'রাজাম্ল'] ,
['অমহত্ব', 'মহত্বহীনতা'] ,
['অমানবিক', 'অমানুষিক', 'পাশবিক'] ,
['অমানুষ', 'অসুর', 'দানব', 'দৈত্য', 'রাক্ষস'] ,
['অমানুষিক', 'আসুরিক', 'দানবিক'] ,
['অমাবস্যা', 'অমাবস্যা তিথি'] ,
['অমার্জিত', 'অশ্লীল', 'অসংস্কৃত'] ,
['অমিতাভ', 'অমিতাভ বুদ্ধ'] ,
['অমিত্র', 'শত্রু'] ,
['অমিশুকে', 'একাচোরা'] ,
['অমিশ্রিত', 'খাঁটি', 'পৃথক', 'বিশুদ্ধ'] ,
['অমিয়', 'অমৃত', 'পীযুষ', 'মধু', 'সুধা'] ,
['অমীমাংসিত', 'অসমাধিত'] ,
['অমুক', 'এই', 'ওই নির্দেশক সর্বনাম', 'সেই'] ,
['অমূর্ত', 'আকারবিহীন', 'আকৃতিবিহীন', 'নিরবয়ব', 'নিরাকার', 'বিমূর্ত', 'মূর্তিবিহীন'] ,
['অমূলক', 'নির্মূল', 'মূলহীন'] ,
['অমূল্য', 'বহুমূল্য', 'মহার্ঘ', 'মূল্যবান', 'মূল্যাতীত'] ,
['অমৃত-নাদ', 'অমৃত-নাদ উপনিষদ', 'অমৃত-নাদোপনিষদ'] ,
['অমৃত-বিন্দু', 'অমৃত-বিন্দু উপনিষদ'] ,
['অমৃতক্ষার', 'অ্যামোনিয়া', 'চন্দনসার', 'নৌসাদর', 'বিদারক'] ,
['অমৃতগতি', 'অমৃতগতি ছন্দ'] ,
['অমৃতধ্বনি', 'অমৃতধ্বনি ছন্দ'] ,
['অমৃতপ', 'অমৃতপানকারী'] ,
['অমৃতফল', 'আঙুর', 'আবী', 'দ্রাক্ষ লতা', 'নাশপাতি'] ,
['অমৃতবল্লরী', 'অমৃতলতা', 'ইন্দুরেখা', 'গুডুচি', 'মধুপর্ণী'] ,
['অমৃতরসা', 'কপিল দ্রাক্ষ'] ,
['অমৃতলোক', 'বৈকুন্ঠ', 'স্বর্গ'] ,
['অমৃতসর', 'অমৃতসর জেলা', 'অমৃতসর শহর'] ,
['অমৃতা', 'অরিষ্ঠা', 'অরুণা', 'অলি', 'ইন্দ্রায়ণ', 'কামিনী', 'মালিকা', 'মৃগভক্ষা'] ,
['অমৃতাংশু', 'ইন্দু', 'কলাধর', 'চন্দ্র', 'চন্দ্রমা', 'চাঁদ', 'নিশিকর', 'রাকেশ', 'শশাঙ্ক', 'শশি', 'সুধাকর'] ,
['অমেরুদণ্ডী জন্তু', 'অমেরুদণ্ডী প্রাণী'] ,
['অমোঘা', 'তন্ডুল', 'তন্ডুলা', 'তন্ডুলীয়ক', 'তন্ডুলীয়িকা', 'বায়বরঙ্গ', 'বায়বিডঙ্গ', 'বায়বিড়ঙ্গ', 'হরিতকি'] ,
['অম্বক', 'অরবিন্দ', 'তামা', 'তাম্র', 'তাম্রক', 'তাম্রধাতু', 'রক্ত', 'রক্তধাতু', 'রবিপ্রিয়', 'রবিসঞ্জক'] ,
['অম্বরীশ', 'ইন্দিরা রমণ', 'কমলাপতি', 'কমলেশ', 'গরুড়ধ্বজ', 'চক্রধর', 'চক্রধর', 'চক্রপাণি', 'জগদীশ', 'জগদীশ্বর', 'জনার্দন', 'ত্রিলোকনাথ', 'ত্রিলোকেশ', 'ত্রিলোকেশ্বর', 'দেবেশ্বর', 'নারায়ণ', 'বিশ্বম্ভর', 'বিষ্ণু', 'রমাকান্ত', 'রমাপতি', 'রমেশ', 'লক্ষ্মীকান্ত', 'শারঙ্গপাণি', 'শ্রীনিবাস', 'শ্রীরমণ', 'সত্যনারায়ণ', 'সুপ্রসাদ', 'সুরেশ', 'হরি'] ,
['অম্বলের রোগ', 'অম্ল রোগ', 'অম্লত্ব', 'অ্যাসিডিটি', 'আম্লিকতা'] ,
['অম্বা', 'আম্মাজী', 'মাই', 'মাতাজী'] ,
['অম্বালা', 'অম্বালা জেলা'] ,
['অম্বিকানাথ', 'মহাশক্তি', 'মহাসেন', 'শক্তিধর', 'শক্তিপাণি', 'সেনানী', 'সেনাপতি'] ,
['অম্বুজ', 'ইন্দীবর', 'কমল', 'কোকনদ', 'জলজ', 'তামরস', 'নীরজ', 'পঙ্কজ', 'পদ্ম', 'পুষ্কর', 'প্রফুল্ল', 'পয়োজ', 'বারিরুহ', 'রাজীব', 'শ্রীবাস', 'শ্রীবাসক'] ,
['অম্বুজা', 'অম্বুজা রাগ'] ,
['অম্বুজাসনা', 'ইন্দিরা', 'কমলা', 'চঞ্চলা', 'নারয়ণী', 'পদ্মহস্তা', 'পদ্মা', 'পদ্মালয়া', 'পদ্মাসনা', 'বিষ্ণুপ্রিয়া', 'ভার্গভী', 'রমা', 'লক্ষ্মী', 'শ্রী', 'সর্বমঙ্গলা', 'সিন্ধুসুতা'] ,
['অম্বুদ', 'কলায়িনী', 'তড়িত্বান', 'তয়োধর', 'নাগরমোথা', 'বিষধ্বংসী', 'শিশিরা'] ,
['অম্বুধি', 'জলধি', 'পয়োধর', 'বারিধি', 'বারিরাশি', 'বারীন্দ্র', 'মকরালয়', 'রত্নাকর', 'সমুদ্র', 'সাগর', 'সিন্ধু'] ,
['অম্ল', 'অ্যাসিড'] ,
['অম্লতা', 'অম্লত্ব', 'টকত্ব', 'টকভাব'] ,
['অম্লসার', 'অম্লসার গন্ধক', 'আরনাল', 'কাঞ্জী', 'বজ্র', 'মহারস', 'লেবু'] ,
['অম্লান ফুল', 'বারোমাসী', 'সতেজ'] ,
['অযথার্থতা', 'অসত্যতা', 'মিথ্যাত্ব'] ,
['অযশস্বী', 'যশহীন'] ,
['অযাজ্য-যাজনকারী', 'অযাজ্যযাজী'] ,
['অযোগ্য পুত্র', 'কুপুত্র'] ,
['অযোধ্যা কাণ্ড', 'অযোধ্যাকাণ্ড'] ,
['অযোনিজ হওয়া', 'অযোনিজত্ব'] ,
['অরইল গাছ', 'অরইল বৃক্ষ'] ,
['অরকগীর', 'কম্বল'] ,
['অরকনানা', 'পুদিনার রস'] ,
['অরঘা', 'অর্ঘপাত্র', 'অর্ঘা'] ,
['অরণ্য কাণ্ড', 'অরণ্যকাণ্ড'] ,
['অরণ্য সীমান্ত', 'সীমান্ত', 'সীমান্ত ক্ষেত্র'] ,
['অরণ্য', 'অরণ্য সন্ন্যাসী', 'জঙ্গল', 'বন'] ,
['অরণ্যবাস', 'বনবাস'] ,
['অরণ্যবাসী', 'বনবাসী'] ,
['অরবল', 'অরবল শহর'] ,
['অরবিন্দ', 'ইন্দিবর', 'উত্পল', 'কমল', 'কোকনদ', 'নীলাঙ্গ', 'পদ্ম', 'পাঁকজন্মা', 'পুণ্ডরীক', 'বক', 'শতদল', 'সররুহ', 'সরোজ', 'সারস'] ,
['অররিয়া', 'অররিয়া জেলা', 'অররিয়া শহর'] ,
['অরহন', 'রেহন'] ,
['অরাজক', 'নৃপরহিত'] ,
['অরাজকতা', 'নৈরাজ্য', 'শাসনহীনতা'] ,
['অরাতি', 'অরি'] ,
['অরি', 'প্রতিদ্বন্দ্বী', 'বিপক্ষ', 'শত্রু'] ,
['অরিত্র', 'দাঁড়', 'হাল'] ,
['অরিন্দম', 'শত্রুঘ্ন', 'শত্রুজিত্', 'শত্রুনাশক'] ,
['অরিমর্দন', 'শত্রুঘ্ন'] ,
['অরিমেদ', 'দুর্গন্ধযুক্ত খয়ের'] ,
['অরিরাষ্ট্র', 'শত্রুরাষ্ট্র'] ,
['অরিষ্ট ঋষি', 'অরিষ্টনেমী'] ,
['অরিষ্ট নেমীনাথ', 'অরিষ্ট নেমীনাথ ভগবান', 'অরিষ্টনেমী'] ,
['অরিষ্ট', 'অরিষ্ট মদ্য', 'অরিষ্ট যোগ', 'অরিষ্টাসুর', 'অর্ক', 'কাত্থ', 'ফলিন', 'বৃষভ', 'বৃষভাসুর', 'মৃত্যুর লক্ষ্ণণ', 'রসুন', 'রীঠা', 'শুদ্ধিকন্দ'] ,
['অরিষ্টনেমি', 'অরিষ্টনেমি ঋষি', 'নেমি', 'নেমিনাথ'] ,
['অরিষ্টনেমী', 'কশ্যপ প্রজাপতি'] ,
['অরিষ্ঠা', 'নাগবালা', 'বিশ্বদেবা', 'সর্পদণ্ডী'] ,
['অরিহন', 'বীতরাগ'] ,
['অরুক্ষ', 'চিপচিপে', 'চ্যাটচ্যাটে', 'তেলতেলে', 'তৈলাক্ত'] ,
['অরুচি', 'অরুচি রোগ', 'ঘৃণা', 'জুগুপ্সা', 'বিতৃষ্ণা'] ,
['অরুচিকর', 'কুত্সিত', 'ঘৃণিত', 'ঘৃণ্য', 'জঘন্য', 'বীভত্স'] ,
['অরুণ মল্লার', 'অরুণমল্লার', 'অরুণমল্লার রাগ'] ,
['অরুণ', 'অরুণ ঝিল', 'অরুণ দেশ', 'অর্ক', 'আচার্য অরুণ', 'ইন্দ্রাশন', 'কাকিণী', 'কাশ্যপ', 'ঘুঙ্ঘুচি', 'তাপস', 'তাম্রিকা', 'দিনেশ', 'বিভাকর', 'বিভাবসু', 'ভানু', 'রত্তী', 'রবি সারথী', 'সূর্য', 'সূর্য উপনিষদ', 'সূর্যদেব', 'সূর্যোপনিষদ'] ,
['অরুণশিখা', 'কুক্কুট', 'কুলঙ্গ', 'নিশাবেদ', 'মোরগ', 'রাত্রিবেদ', 'শিখন্ডী', 'শিখী', 'শৌন্ড'] ,
['অরুণা', 'অরুণা নদী', 'ইন্দ্রাশন', 'ইন্দ্রায়ণ', 'কদম্ব পুষ্প', 'কোন্দো', 'গুঞ্জা', 'ঘুঘঞ্চি', 'তাম্রিকা', 'মদনাগ্রক', 'মাকল', 'মৃগভক্ষা', 'রক্তা', 'রতী'] ,
['অরুণাচলবাসী', 'অরুণাচলী', 'অরুণাচলীয়'] ,
['অরুণাচলীয়', 'অরুণাচলের'] ,
['অরুণাত্মজ', 'অর্কজ', 'কর্ণ', 'কানীন', 'রবিনন্দ', 'রবিনন্দন', 'রাধেয়', 'সূততনয়', 'সূতপুত্র'] ,
['অরুণাত্মজা', 'অর্কজা', 'কালিন্দী', 'ভানুজা', 'যমানুজা', 'যমুনা', 'সূর্যসুতা'] ,
['অরুণাপ্রিয়া', 'ত্বাষ্ট্রী', 'শরায়ু', 'সজ্ঞা'] ,
['অরুণাভ', 'লালিমাযুক্ত'] ,
['অরুণিমা', 'রক্তিমতা', 'লালিমা', 'লালী'] ,
['অরুণোদয়মসপ্তমী', 'মাকরীসপ্তমী'] ,
['অরুন্তুদ', 'কঠোর', 'পরুষ', 'মর্মপীড়াদায়ক'] ,
['অরুপক', 'নির্বীজ সমাধি'] ,
['অরুপতা', 'নির্জীব সমাধি'] ,
['অরূণাচল', 'অরূণাচল প্রদেশ'] ,
['অরূপতা', 'রূপশূণ্যতা'] ,
['অরোচক', 'অসার', 'নীরস', 'ফিকে', 'রসহীন', 'রুচিহীন'] ,
['অর্ক', 'কোবিদ', 'জ্ঞানী', 'পণ্ডিত', 'বিজ্ঞ', 'বিদ্বান', 'সুমন'] ,
['অর্কক্ষীর', 'আকন্দের আঠা'] ,
['অর্কক্ষেত্র', 'কোণার্ক'] ,
['অর্কজ', 'অর্কতনয়', 'অশ্বিনীকুমার'] ,
['অর্কজা', 'অর্কতনয়া', 'তাপী', 'তাপ্তী', 'তাপ্তী নদী'] ,
['অর্কনয়ন', 'বিরাট', 'বিরাট পুরুষ'] ,
['অর্কপত্রা', 'অর্কপত্রিকা', 'অর্কপত্রী', 'অহিগন্ধা', 'রুদ্র জটা', 'সুনন্দা'] ,
['অর্কপুষ্পী', 'অর্কপ্রিয়া', 'ওড়পুষ্প', 'জবা', 'প্রতিকা', 'রাগপুষ্পী', 'হরিবল্লভা'] ,
['অর্কবৈধ', 'তালীশপত্র', 'তালীশপত্রী'] ,
['অর্কব্রত', 'করগ্রহণ'] ,
['অর্কভ', 'সূর্যকান্ত নক্ষত্র'] ,
['অর্কভক্তা', 'সূর্যোপাসিকা'] ,
['অর্গল', 'অর্গলা', 'আগল', 'ছিটকানি', 'ছিটকিনি', 'পিল', 'প্রতিবন্ধক', 'শিকল', 'শেকল', 'হুড়কা'] ,
['অর্গলা', 'আন্দু', 'আলান'] ,
['অর্গলী ভেড়া', 'ভেড়া'] ,
['অর্গলের', 'হুড়কার'] ,
['অর্ঘ', 'জলতর্পন', 'জলদান', 'তর্পন', 'মধু', 'মধু রাগ'] ,
['অর্ঘার্থ জল', 'অর্ঘ্য', 'জল'] ,
['অর্ঘ্য', 'জল ছিটানো'] ,
['অর্চনা করা', 'আরাধনা করা', 'উপাসনা করা', 'পূজা করা'] ,
['অর্চনা', 'আরাধনা', 'উপাসনা', 'পূজন', 'পূজা'] ,
['অর্চিত', 'পূজিত'] ,
['অর্জন করা', 'পাওয়া', 'প্রাপ্ত করা', 'প্রাপ্ত হওয়া', 'রোজগার করা'] ,
['অর্জনীয়', 'প্রাপ্য', 'সংগ্রহণীয়'] ,
['অর্জিত অবকাশ', 'অর্জিত ছুটি'] ,
['অর্জিত', 'আয় করা'] ,
['অর্জুন কাঠের', 'অর্জুনের'] ,
['অর্জুন দেব', 'গুরু অর্জুন দেব'] ,
['অর্জুন', 'অর্জুন গাছ', 'ইন্দ্রতরু', 'একনিষ্ট পুত্র', 'একমাত্র ছেলে', 'কৌন্তেয়', 'ধনঞ্জয়', 'পার্থ', 'বাসবী', 'সব্যসাচী'] ,
['অর্জুনী', 'উষা', 'উষাকাল', 'করতোয়া', 'বাণাসুতা', 'বাহুদা', 'ভোর', 'সকাল'] ,
['অর্থ করা', 'অর্থ বোঝা', 'মানে করা', 'মানে বোঝা'] ,
['অর্থ চিন্তা', 'অর্থ সংক্রান্ত চিন্তা'] ,
['অর্থ প্রদানকারী', 'অর্থদ', 'ধনপ্রদ', 'বিত্ত প্রদানকারী', 'বিত্তপ্রদানকারী'] ,
['অর্থ বিচারালয়', 'দীওয়ানী', 'দীওয়ানী বিচারালয়'] ,
['অর্থ বিজ্ঞান', 'অর্থবিজ্ঞান'] ,
['অর্থ বোঝানো', 'বোঝানো', 'ব্যাখ্যা করা'] ,
['অর্থ ব্যবস্থা', 'অর্থ-ব্যবস্থা', 'অর্থব্যবস্থা', 'আর্থিক ব্যবস্থা'] ,
['অর্থ শাস্ত্র', 'অর্থনীতি', 'অর্থশাস্ত্র'] ,
['অর্থ সংক্রান্ত আজ্ঞা', 'অর্থ সংক্রান্ত সূচনা'] ,
['অর্থ সংগ্রাহক', 'বিল কালেক্টর'] ,
['অর্থ সম্পর্কিত', 'অর্থসংক্রান্ত'] ,
['অর্থ সম্বন্ধীয়', 'অর্থগত'] ,
['অর্থ হওয়া', 'মানে হওয়া'] ,
['অর্থ', 'ইন্দ্রিয় বিষয়', 'ইন্দ্রিয়ার্থ', 'টাকা-পয়সা', 'ধন', 'ধন-দৌলত', 'নিধি', 'ফাণ্ড', 'বিত্ত', 'বিষয়', 'বৈভব', 'মক্ষ্মী'] ,
['অর্থদ', 'অলকাধিপতি', 'অলকাধীপ', 'অলকাপতি', 'ঈশ্বরসখ', 'কুবের', 'ধননাথ', 'নিধিনাথ', 'নিধিপ', 'বসুপ্রদ', 'মনুরাজ', 'মনুষ্যধর্মা', 'রত্নকর', 'রত্নগর্ভ'] ,
['অর্থদণ্ড', 'জরিমানা', 'ফাইন'] ,
['অর্থনীতিবিদ্', 'অর্থশাস্ত্রজ্ঞ'] ,
['অর্থপিশাচ', 'অর্থলোসুপ', 'ধনলোভী', 'ধনলোলুপ'] ,
['অর্থপূর্ণ হওয়া', 'গুরুত্বপূর্ণ হওয়া'] ,
['অর্থপূর্ণ', 'অর্থযুক্ত', 'গুরুত্বপূর্ণ', 'সার্থক'] ,
['অর্থবান', 'ধণী', 'ধণী ব্যক্তি', 'ধনকুবের', 'ধনপতি', 'ধনবান', 'পয়সাওলা', 'মালদার'] ,
['অর্থবিজ্ঞানী', 'অর্থবিদ'] ,
['অর্থভান্ডার', 'আকর', 'জ্ঞান ভান্ডার', 'ভান্ডার'] ,
['অর্থমন্ত্রী', 'দিওয়ান', 'বিত্তমন্ত্রী'] ,
['অর্থলালসা', 'অর্থলোলুপতা'] ,
['অর্থশাস্ত্রীয়', 'অর্থশাস্ত্রের'] ,
['অর্থসমাহার', 'অর্থোপার্জন', 'উপার্জন', 'ধনোপার্জন'] ,
['অর্থহীন কথা', 'আগড়বাগড়', 'নির্বোধ কথাবার্তা', 'বাজে বকবক'] ,
['অর্থহীন', 'উল্টোপাল্টা'] ,
['অর্থাগম', 'আমদানী', 'আয়', 'ইনকাম', 'ধনাগম'] ,
['অর্থাতরন্যাস', 'অর্থাতরন্যাস অলঙ্কার'] ,
['অর্থান্তর', 'ভিন্ন অর্থ'] ,
['অর্থার্থী', 'ধন প্রার্থনাকারী', 'ধনযাচী', 'ধনান্বেষী'] ,
['অর্দ্ধ', 'আধ', 'আধা', 'পঞ্চাশ শতাংশ'] ,
['অর্ধ চন্দ্রমা', 'অর্ধচন্দ্র', 'অর্ধচন্দ্রমা', 'অর্ধেক চাঁদ'] ,
['অর্ধ নারীশ্বর', 'অর্ধনারীশ্বর'] ,
['অর্ধ বিরাম', 'অর্ধবিরাম', 'কমা'] ,
['অর্ধ', 'অর্ধেক'] ,
['অর্ধ-নারাচ', 'অর্ধনারাচ', 'প্রমাণিকা'] ,
['অর্ধকোশ', 'মাইল'] ,
['অর্ধগঙ্গা', 'অর্ধজাহ্নবী', 'কাবেরি নদী'] ,
['অর্ধগোলাকার', 'অর্ধবৃত্তাকার'] ,
['অর্ধচন্দ্র', 'গলাধাক্কা', 'চন্দ্র', 'চন্দ্রিকা', 'নখের দাগ'] ,
['অর্ধচন্দ্রমা', 'শকলেন্দু'] ,
['অর্ধচন্দ্রিকা', 'কোপলতা'] ,
['অর্ধজ্যোতিকা', 'অর্ধজ্যোতিকা তাল'] ,
['অর্ধদগ্ধ', 'আধপোড়া'] ,
['অর্ধদেশ', 'অর্ধেক রাজত্ব'] ,
['অর্ধনয়ন', 'জ্ঞানচক্ষু', 'তৃতীয় নেত্র', 'তৃতীয় নয়ন'] ,
['অর্ধপিষ্ট', 'আধপেষা'] ,
['অর্ধপ্রদেশ', 'অর্ধসেতু'] ,
['অর্ধবার্ষিকী', 'ষাণ্মাসিক'] ,
['অর্ধমাগধী', 'অর্ধমাগধী ভাষা', 'প্রাকৃত', 'প্রাকৃত ভাষা'] ,
['অর্ধমুদিত', 'আধখোলা', 'আধবোজা'] ,
['অর্ধমৃত', 'আধমরা'] ,
['অর্ধশত', 'পঞ্চাশ', '৫০'] ,
['অর্ধশতক', 'হাফ সেঞ্চুরি'] ,
['অর্ধশায়িত', 'আধশোয়া'] ,
['অর্ধসম', 'অর্ধেক'] ,
['অর্ধসরকারী', 'আধাসরকারী'] ,
['অর্ধসিদ্ধ', 'আধসিদ্ধ'] ,
['অর্ধস্বচ্ছতা', 'ঈষদচ্ছতা', 'স্বচ্ছপ্রায়তা'] ,
['অর্ধাঙ্গ ঘাত', 'অর্ধাঙ্গ পক্ষাঘাত'] ,
['অর্ধাঙ্গিনী', 'কলত্র', 'জীবনসঙ্গিনী', 'জীবনসাথী', 'দারা', 'দয়িতা', 'ধর্মপত্নী', 'পত্নী', 'বধু', 'ভার্যা', 'সহগামিনী', 'স্ত্রী'] ,
['অর্ধেক পরিমাণ', 'অর্ধেক মাত্রা'] ,
['অর্ন্তবর্গ', 'উপবিভাগ'] ,
['অর্ন্তবিকার', 'অর্ন্তবেগ', 'মনোবিকার', 'মনোবিকৃতি', 'মনোবেগ', 'যতি'] ,
['অর্পণ করে', 'নিবেদন করা'] ,
['অর্পণ', 'বিনিয়োগ'] ,
['অর্পিত করা', 'চড়ানো', 'দেওয়া'] ,
['অর্বুদ', 'আব', 'টিউমার', 'দশ কোটি', '১০০০০০০০০,'] ,
['অর্বুদপতি', 'ধনকুবের'] ,
['অর্যমা', 'পিতৃনাথ'] ,
['অর্শ', 'অর্শরোগ'] ,
['অর্হ', 'অর্হণীয় ব্যক্তি', 'পূজনীয় ব্যক্তি', 'পূজ্য'] ,
['অর্হন', 'জিন', 'জৈন্যদেব', 'তীর্থঙ্কর'] ,
['অলংকরণ', 'সজ্জা', 'সাজ', 'সাজসজ্জা'] ,
['অলংকার', 'অলঙ্কার'] ,
['অলকপ্রভা', 'আলকাপুরি', 'কুবেরপুরী', 'বসুসারা', 'বসুস্থলী'] ,
['অলক্তক', 'অলক্তরস', 'আলতা', 'জতুরস', 'যাব', 'যাবক', 'লক্তক', 'লাক্ষারস'] ,
['অলক্ষণ', 'অশুভ চিহ্ন', 'অশুভ লক্ষণ', 'খারাপ লক্ষণ'] ,
['অলঙ্করণ', 'ভূষণ', 'সুশোভিতকরণ'] ,
['অলঙ্কার', 'আভূষণ', 'গয়না'] ,
['অলঙ্কারপূর্ণ', 'অলঙ্কৃত', 'আভূষিত', 'বিভূষিত', 'ভূষিত', 'সজ্জিত'] ,
['অলঙ্কারযুক্ত', 'অলঙ্কৃত'] ,
['অলঙ্কৃত করা', 'সজ্জিত করা', 'সাজানো'] ,
['অলঙ্কৃত', 'বিভূষিত', 'ভূষিত', 'সম্মানিত'] ,
['অলঝাইমার্স', 'অলঝাইমার্স রোগ'] ,
['অলপ্পুঝা', 'অলপ্পুঝা জেলা', 'অলপ্পুঝা শহর'] ,
['অলবর', 'অলবর জেলা', 'অলবর শহর'] ,
['অলম্বুষা', 'গোরখমুণ্ডী', 'পলঙ্কষা'] ,
['অলর্ক', 'রাজার্ক', 'রুণিকা'] ,
['অলস', 'অলস ব্যক্তি', 'অলস লোক', 'আলস্যপূর্ণ', 'ঢিলে-ঢালা'] ,
['অলসতা', 'আলসেমি', 'আলস্য'] ,
['অলহিষ্ণু', 'ঠুনকো মেজাজ', 'বদরাগ'] ,
['অলাবু', 'কদু', 'তুম্ব', 'তুম্বক', 'তুম্বি', 'তুম্বী', 'পিণ্ডফল', 'লাউ', 'লাউকি'] ,
['অলি', 'বান্ধবী', 'মধুব্রত', 'মধুরসিক', 'মধুরাজ', 'মধুসুদন', 'মেয়ে বন্ধু', 'সখী', 'সঙ্গীনী', 'সহচরী', 'স্ত্রী মিত্র', 'হেলি'] ,
['অলিকুল', 'ভ্রমরের ঝাঁক'] ,
['অলিখিত', 'অলিপিবদ্ধ'] ,
['অলিঙ্গ', 'পরব্রহ্ম', 'লিঙ্গশূণ্য'] ,
['অলিন্দ', 'বারান্দা'] ,
['অলিপ্রিয়', 'কোকনদ', 'লাল কমল', 'লাল পদ্ম'] ,
['অলিবাগ', 'অলিবাগ শহর'] ,
['অলিম্পিক', 'অলিম্পিক খেলা', 'অলিম্পিয়াড'] ,
['অলুক', 'কুন্তল', 'কেশ', 'চিকুর', 'চুল'] ,
['অল্প অংশ', 'অল্পাংশ', 'ন্যূন অংশ'] ,
['অল্প অল্প', 'অল্প অল্প করে', 'অল্প করে'] ,
['অল্প আওয়াজ', 'মৃদু শব্দ', 'হাল্কা আওয়াজ'] ,
['অল্প গরম', 'ঈষদুষ্ণ', 'সামান্য গরম'] ,
['অল্প পরিচিতি', 'কম পরিচিতি'] ,
['অল্প বিরাম', 'অল্প বিরাম চিহ্ন'] ,
['অল্প', 'অল্প একটু', 'আংশিক', 'কম', 'খানিক', 'খানিকটা', 'রতিভর'] ,
['অল্প-বেশি', 'ছোটো-খাটো', 'বিক্ষিপ্ত'] ,
['অল্পকাল', 'অল্পসময়'] ,
['অল্পকিছু', 'অল্পসংখ্যক', 'কতিপয়', 'কিছু', 'কোনো কিছু', 'কোনো জিনিস', 'হাতে গোনা'] ,
['অল্পজ্ঞানী', 'স্বল্পজ্ঞানী'] ,
['অল্পব্যয়', 'স্বল্পব্যয়'] ,
['অল্পভাষিতা', 'মিতভাষিতা'] ,
['অল্পভোজী', 'অল্পাহারী', 'মিতাহারী', 'স্বল্পভোজী', 'স্বল্পাহারী'] ,
['অল্পমূল্য রত্ন', 'উপরত্ন'] ,
['অল্পমূল্য', 'সস্তা', 'স্বল্পমূল্য'] ,
['অল্পসংখ্যক', 'একমুটো', 'হাতে গোনা কয়েকজন'] ,
['অল্পস্থায়ী ঘুম', 'ঝিমানো'] ,
['অল্পাহার', 'মিতাহার'] ,
['অল্পায়ু', 'স্বল্প জীবী', 'স্বল্পায়ু'] ,
['অশক্ত করে দেওয়া', 'দুর্বল করা', 'ভাঙা', 'ভেঙে ফেলা'] ,
['অশক্ত হওয়া', 'ক্ষীণ হওয়া', 'দুর্বল হওয়া', 'ভাঙ্গা'] ,
['অশক্তি', 'উপঘাত', 'নপুংসকতা', 'নপুংসত্ব', 'পুরুষত্বহীনতা', 'পৌরুষহীনতা'] ,
['অশঙ্ক', 'অশঙ্কিত', 'নিঃশঙ্ক', 'নির্ভয়', 'নিশ্চিত'] ,
['অশত্রু', 'প্রতিদ্বন্দ্বিবিহীন', 'শত্রুবিহীন', 'শত্রুরহিত'] ,
['অশনা', 'অসনা', 'অসৈনা', 'পীতশাল'] ,
['অশনীয়', 'আহার্য্য', 'খাদ্য', 'ভক্ষণীয়', 'ভোজ্য'] ,
['অশব্দ', 'নিঃশব্দ', 'শব্দহীন'] ,
['অশরীরী', 'দেহরহিত', 'বিমূর্ত', 'শরীরহীন'] ,
['অশান্ত', 'অস্থির', 'অস্থিরচিত্ত', 'উত্কণ্ঠিত', 'চঞ্চল', 'বিচলিত'] ,
['অশান্ততা', 'অস্থিরচিত্ততা', 'উদ্বিগনতা', 'ব্যাগ্রতা'] ,
['অশান্তি', 'আকুলতা', 'আতঙ্ক', 'উদ্বিগ্নতা', 'উদ্বেগ', 'উপদ্রব', 'বাওয়াল', 'ব্যকুলতা', 'হাঙ্গামা'] ,
['অশান্তিপূর্ণ', 'উপদ্রুত'] ,
['অশিক্ষিত', 'নিরক্ষর'] ,
['অশিত', 'উচ্ছিষ্ট', 'ভক্ষিত', 'ভুক্ত'] ,
['অশিষ্টভাবে', 'অসভ্যভাবে'] ,
['অশীলতা', 'কুস্বভাব'] ,
['অশুচি', 'অশুদ্ধ', 'দূষিত', 'নোংরা', 'মলিন', 'ময়লা'] ,
['অশুদ্ধ সোনা', 'অশুদ্ধ স্বর্ণ'] ,
['অশুদ্ধি', 'মলিনতা', 'মালিন্য'] ,
['অশুভ আঁতাত', 'গোপন ষড়যন্ত্র'] ,
['অশুভ আত্মা', 'দুষ্ট আত্মা', 'শয়তান'] ,
['অশুভ খবর', 'অশুভ সংবাদ', 'দুঃসংবাদ'] ,
['অশুভ্র', 'অশ্বেত'] ,
['অশূন্যশয়নদ্বিতীয়া', 'অশূন্যশয়নব্রত'] ,
['অশোক অষ্টমী', 'অশোকাষ্টমী', 'দূর্গাষ্টমী'] ,
['অশোক', 'অশোক গাছ', 'বীতশোক', 'সম্রাট অশোক', 'হেমপুষ্প'] ,
['অশোকনগর', 'অশোকনগর জেলা', 'অশোকনগর শহর'] ,
['অশ্ব', 'ঘোটক', 'ঘোড়া', 'তুরগ', 'তুরঙ্গ', 'তুরঙ্গম', 'হয়'] ,
['অশ্ব-যান', 'অশ্ব-রথ', 'অশ্বযান', 'অশ্বরথ', 'ঘোড়া গাড়ি', 'ঘোড়া-গাড়ি'] ,
['অশ্বগতি', 'ঘোড়ার গতি'] ,
['অশ্বগ্রীব', 'হয়গ্রীব', 'হয়গ্রীব উপনিষদ', 'হয়গ্রীবোপনিষদ'] ,
['অশ্বথামা', 'দ্রোণপুত্র', 'দ্রোণি'] ,
['অশ্বপাল', 'অশ্বপালক', 'অশ্বপেশক', 'অশ্বরক্ষ', 'অশ্বরক্ষক', 'অশ্বাধ্যক্ষ', 'সহিস'] ,
['অশ্বমুখ', 'কিংপুরুষ', 'কিন্নর', 'কিন্নর জেলা', 'কুবেরসখা', 'মর্তমুখ'] ,
['অশ্বল', 'অশ্বল ঋষি'] ,
['অশ্বশক্তি', 'হর্স পাওয়ার'] ,
['অশ্বশাল', 'অশ্বশালা', 'আস্তাবল', 'ঘোড়াশাল', 'তুরঙ্গমশালা', 'তুরঙ্গশালা', 'হয়-শালা', 'হয়শালা'] ,
['অশ্বসূক্তি', 'অশ্বসূক্তি ঋষি'] ,
['অশ্বারোহণ', 'ঘোড়সওয়ারি', 'হর্স রাইডিং'] ,
['অশ্বারোহী সেনাদলের প্রধান', 'রিসালদার', 'রিসালাদার'] ,
['অশ্বারোহী', 'ঘোড়সওয়ার'] ,
['অশ্বিনী কুমার', 'অশ্বিনেয়', 'দেবচিকিত্সক', 'যমজ', 'রবিনন্দন'] ,
['অশ্বিনী', 'অশ্বিনী নক্ষত্র', 'ঘুড়ী', 'ঘোটকি', 'তুরগী', 'তুরঙ্গী', 'প্রসুতা', 'বামী', 'হয়ী'] ,
['অশ্বেত', 'কালো', 'কৃষ্ণাঙ্গ'] ,
['অশ্বেতাঙ্গ', 'কালো'] ,
['অশ্মক', 'ট্রাবানকোর', 'তিরূবিথান্কূর', 'তিরূবিথামকূর'] ,
['অশ্মভেদ', 'পখানভেদ'] ,
['অশ্রবণীয়', 'অশ্রাব্য'] ,
['অশ্রু বওয়া', 'অশ্রুপাত হওয়া', 'জল পড়া', 'জল বওয়া'] ,
['অশ্রু', 'চোখের জল', 'নয়নবারি'] ,
['অশ্রুত', 'না শোনা'] ,
['অশ্রুপূর্ণ হয়ে', 'সজল', 'সাশ্রু'] ,
['অশ্রুপূর্ণ', 'সাশ্রু'] ,
['অশ্লীল গান', 'অশ্লীল গান', 'নোংরা গান'] ,
['অশ্লীল', 'কামুকতাপূর্ণ', 'নোংরা'] ,
['অশ্লেষা', 'অশ্লেষা নক্ষত্র', 'শ্লেষা নক্ষত্র'] ,
['অষ্ট ধাতু', 'অষ্ট-ধাতু', 'অষ্টধাতু'] ,
['অষ্টআশি', '৮৮', '৮৮,'] ,
['অষ্টকমল', 'অষ্টচক্র'] ,
['অষ্টকূল', 'অষ্টবংশ'] ,
['অষ্টগন্ধ', 'গন্ধাষ্টক'] ,
['অষ্টদলবিশিষ্ট', 'আটটি পাপড়ি যুক্ত'] ,
['অষ্টভূজ', 'অষ্টভূজা'] ,
['অষ্টম', 'অষ্টম শ্রেণী', 'আট', '৮'] ,
['অষ্টাঙ্গ', 'অষ্টাঙ্গ যোগ'] ,
['অষ্টাদশ', 'আঠারো', '১৮,'] ,
['অষ্টাপদ', 'কনক', 'কাঞ্চন', 'সুবর্ণ', 'সোনা', 'স্বর্ণ', 'হিরণ্ময়', 'হৈম'] ,
['অষ্টাবক্র', 'অষ্টাবক্র ঋষি'] ,
['অসংগ', 'অসংবদ্ধ', 'অসংযুক্ত', 'অসংযোজিত', 'অসংলগ্ন', 'অসংশ্লিষ্ট', 'অসংস়ৃষ্ট', 'অসংহত', 'পৃথক. আলাদা'] ,
['অসংগঠিত', 'অসংবদ্ধ', 'একতাহীন', 'ঐক্যহীন', 'সংগঠনহীন'] ,
['অসংগতী', 'অসংলগ্ন', 'অসঙ্গততা', 'বিক্ষিপ্ত', 'বৈশম্য'] ,
['অসংযম', 'আত্মনিয়ন্ত্রণহীনতা'] ,
['অসগ্ন', 'অসগ্ন ঋষি'] ,
['অসঘন', 'পাতলা'] ,
['অসঙ্গ', 'কুসঙ্গ'] ,
['অসঞ্চয়ী', 'খরুচে'] ,
['অসত্য বলা', 'মিথ্যা বলা', 'মিথ্যে বলা'] ,
['অসত্যবাদ', 'মায়াবাদ', 'মিথ্যাবাদ'] ,
['অসন্তুষ্ট হওয়া', 'রুষ্ট হওয়া', 'রেগে যাওয়া'] ,
['অসন্তুষ্ট', 'কুপিত', 'রুষ্ট'] ,
['অসন্তোষ', 'ক্রোধ', 'রাগ'] ,
['অসন্তোষজনক', 'অসন্তোষপ্রদ'] ,
['অসন্দিগ্ধ', 'সন্দেহহীন'] ,
['অসফল হওয়া', 'পরাজিত হওয়া', 'ফেল হওয়া', 'বিফল হওয়া', 'ব্যর্থ হওয়া', 'হেরে যাওয়া'] ,
['অসফল', 'নিরর্থক', 'নিষ্ফল', 'ব্যর্থ'] ,
['অসফলতা', 'পরাজয়', 'পরাভব', 'বিফলতা', 'মাত', 'হার'] ,
['অসবরগ', 'কঞ্জী', 'নির্মাল্যা', 'বভনেটী', 'বৃষফর্ণিকা', 'ব্রক্ষমন্ডুকী', 'ভারঙ্গী', 'ভূগজা . দ্বিজা . ফঞ্জী', 'মালালিকা', 'মালালী', 'রতিসত্বরা', 'লঙ্কায়িত', 'লঙ্কোদক', 'শচি', 'শাকবালেয়', 'সৃপক্কা'] ,
['অসভ্য', 'নোংরা'] ,
['অসম', 'অসমতল', 'আসাম', 'উঁচু-নীচু', 'এবড়ো-খেবড়ো'] ,
['অসমঞ্জ', 'অসমঞ্জস'] ,
['অসমান', 'আলাদা', 'উঁচুনীচু', 'নির্জন', 'পৃথক', 'ভিন্ন'] ,
['অসম্পূর্ণ', 'আধখ্যাচড়া', 'আধা'] ,
['অসম্ভবতা', 'অসম্ভাবনা'] ,
['অসম্ভাষ্য', 'কথা বলার অযোগ্য'] ,
['অসম্মতি', 'অস্বীকৃতি', 'নামঞ্জুরী', 'বৈমত্যতা'] ,
['অসময়', 'দুঃসময়', 'ভুল সময়'] ,
['অসময়ে', 'ভুল সময়ে'] ,
['অসহনশীল', 'অসহিষ্ণু'] ,
['অসহনশীলতা', 'অসহিষ্ণুতা'] ,
['অসহনীয়', 'অসহ্য', 'দুঃসহ'] ,
['অসহমত হওয়া', 'একমত না হওয়া'] ,
['অসহযোগ', 'অসহযোগ আন্দোলন', 'অসহযোগকারী', 'অসহযোগীতা'] ,
['অসহায়', 'গতিহীন', 'নিঃসহায়', 'নিরাশ্রয়', 'নিরুপায়'] ,
['অসহায়তা', 'নিঃসহায়তা', 'নিরাশ্রয়তা'] ,
['অসাঢ়া', 'কাঁচা চিনি'] ,
['অসাঢ়ু', 'মোটা বিস্তীর্ণ শিলাভূমি'] ,
['অসাধারণ', 'অসামান্য', 'জাঁকজমকপূর্ণ', 'বিশেষ', 'সুন্দর', 'স্পেশাল'] ,
['অসাধু', 'খল', 'দুর্জন', 'দুষ্ট', 'নকল সাধু', 'পাজি', 'পামর', 'প্রবঞ্চক', 'শঠ'] ,
['অসাধুতা', 'দুষ্টতা', 'নীচতা', 'পামরতা', 'শঠতা'] ,
['অসাবধান', 'গাফিলতি'] ,
['অসামঞ্জস্য', 'সামঞ্জস্যহীনতা'] ,
['অসামঞ্জস্যপূর্ণ', 'সামঞ্জস্যহীন'] ,
['অসামাজিক কাজ', 'অসামাজিক কার্য'] ,
['অসামান্যতা', 'আসাধারণতা'] ,
['অসি', 'তলোয়ার'] ,
['অসিত', 'অসিত ঋষি'] ,
['অসিধারী', 'তলোয়ারধারী'] ,
['অসিপত্র', 'অসিপত্র নরক', 'অসিপত্র-বন', 'অসিপত্র-বন নরক'] ,
['অসীম', 'উঁচু', 'উদাত্ত', 'বড়', 'মহান', 'শ্রেষ্ঠ'] ,
['অসুন্দর', 'কদর্য', 'কুত্সিত', 'কুত্সীত', 'কুদর্শন', 'কুরূপ', 'বিশ্রী'] ,
['অসুবিধা', 'কষ্ট'] ,
['অসুর স্ত্রী', 'অসুরী', 'আসুরী'] ,
['অসুর', 'দানব', 'দৈত্য', 'রাক্ষস'] ,
['অসুরবধ', 'অসুরসংহার'] ,
['অসুরাচার্য', 'দানব গুরু', 'ভার্গব', 'শুক্র', 'শুক্রবার', 'শুক্রাচার্য'] ,
['অসুরারি', 'দেব', 'দেবতা', 'সুর'] ,
['অসুস্থ হওয়া', 'বমি পাওয়া'] ,
['অসুস্থ', 'আর্ত', 'রুগ্ণ', 'রোগগ্রস্থ', 'রোগী'] ,
['অসূয়া', 'আক্রোশ', 'ঈর্ষা', 'কোপ', 'ক্রোধ', 'ক্ষোভ', 'তমিস্র', 'দ্বেষ', 'রোষ', 'হিংসা'] ,
['অসূয়াহীনভাবে', 'ঈর্ষাহীনভাবে', 'দ্বেষহীনভাবে'] ,
['অসেবনীয়', 'অসেব্য'] ,
['অসৈনিক', 'দেশবাসী', 'নাগরিক', 'রাষ্ট্র সদস্য'] ,
['অস্কাবাদ', 'অস্খাবাদ'] ,
['অস্ট্রিয়ান', 'অস্ট্রিয়ান ভাষা', 'অস্ট্রিয়াবাসী'] ,
['অস্ট্রিয়ার', 'অস্ট্রীয়'] ,
['অস্ট্রেলিয়া', 'অস্ট্রেলিয়া মহাদ্বীপ'] ,
['অস্ট্রেলিয়ান ডলার', 'ডলার'] ,
['অস্ট্রেলিয়ান', 'অস্ট্রেলিয়ান ভাষা', 'অস্ট্রেলিয়াবাসী', 'অস্ট্রেলীয়'] ,
['অস্ত যাওয়া', 'ডোবা'] ,
['অস্তগত', 'ডোবা'] ,
['অস্তমতী', 'গঠইবন', 'তৃণগন্ধা', 'ত্রিপর্ণিকা', 'ত্রিপর্ণী', 'দীর্ঘমূলা', 'ধবনি', 'ধ্রবা', 'নিশ্চলা', 'নীলপুষ্প', 'পর্ণী', 'পালিন্দী', 'পালিন্ধী', 'পীতনী', 'পীতিনী', 'বাতঘ্নী', 'রুদ্র-জটা', 'রুদ্রজটা', 'শালপর্ণ', 'শালপর্ণী', 'শালিনী', 'শালিপর্ণী', 'সরিবন', 'সোম্যা'] ,
['অস্তর', 'আস্তর'] ,
['অস্তাচল', 'পশ্চিমাচল'] ,
['অস্তিত্ব', 'উপস্থিতি', 'বিদ্যমানতা'] ,
['অস্তিত্বহীনতা', 'সত্ত্বাহীনতা'] ,
['অস্তুতি', 'আক্ষেপ', 'টীকা-টিপ্পনি', 'নিন্দা', 'পরচর্চা'] ,
['অস্ত্র বিরাম', 'অস্ত্রবিরতি', 'যুদ্ধ বিরতি', 'যুদ্ধ বিরাম'] ,
['অস্ত্র শস্ত্র', 'অস্ত্র-শস্ত্র', 'হাতিয়ার'] ,
['অস্ত্র সমর্পণ করা', 'নতজানু হওয়া'] ,
['অস্ত্র', 'অস্ত্রের', 'ক্ষেপণাস্ত্র', 'প্রহরণ', 'হাতিয়ার'] ,
['অস্ত্রচিকিতসক', 'অস্ত্রোপচারক', 'শল্যচিকিতসক', 'শল্যবিদ'] ,
['অস্ত্রজীবী', 'যোদ্ধা', 'সংগ্রামী'] ,
['অস্ত্রধারী', 'সশস্ত্র'] ,
['অস্ত্রবিদ্যা', 'অস্ত্রশিক্ষা'] ,
['অস্ত্রবেদ', 'ধনুর্বেদ'] ,
['অস্ত্রশস্ত্র', 'আয়ুধ', 'হাতিয়ার'] ,
['অস্ত্রশালা', 'অস্ত্রাগার', 'অস্ত্রালয়'] ,
['অস্ত্রহীন করা', 'নিরস্ত্রীকরন'] ,
['অস্ত্রহীন', 'নিরস্ত্র', 'নিশস্ত্র'] ,
['অস্ত্রোপচার', 'শল্যচিকিত্সা'] ,
['অস্থি ক্ষয়রোগ', 'বোন টিবি'] ,
['অস্থি', 'হাড়'] ,
['অস্থি-নির্মিত', 'অস্থিনির্মিত'] ,
['অস্থিপঞ্জর', 'কঙ্কাল', 'হাড়-পাঁজর'] ,
['অস্থিবন্ধনী', 'লিগামেণ্ট', 'সন্ধিবন্ধনী'] ,
['অস্থিভঙ্গ', 'ফ্র্যাক্চার'] ,
['অস্থিমালা', 'অস্থিহার'] ,
['অস্থিময়', 'হাড়সর্বস্ব'] ,
['অস্থির হওয়া', 'বিচলিত হওয়া'] ,
['অস্থিরতা', 'গতিময়তা', 'গতিশীলতার', 'চলমানতা'] ,
['অস্পষ্ট ভাবে', 'অস্পষ্টতঃ'] ,
['অস্পষ্টতা', 'ধোঁয়াশা'] ,
['অস্বাদ', 'মজা', 'রস', 'স্বাদ'] ,
['অস্বার্থ', 'নিস্বার্থ'] ,
['অস্বাস্থ্য', 'রুগ্নতা', 'রোগগ্রস্থতা'] ,
['অস্বীকারকারী', 'প্রত্যাখ্যানকারী'] ,
['অস্বীকৃত', 'নামঞ্জুর', 'সম্মতিহীন'] ,
['অস্বীকৃতি চিহ্ন', 'কাটা চিহ্ন', 'ভুল চিহ্ন'] ,
['অস্মিতা', 'অহং', 'অহংকার', 'বিমোহ', 'মমতা', 'মোহ'] ,
['অস্হায়ী', 'ক্ষণিক', 'স্বল্পকালীন'] ,
['অহংকার করা', 'গর্ব করা', 'ডাঁট দেখানো'] ,
['অহংকার করে', 'গর্বভরে', 'গর্বের সঙ্গে', 'সগর্বে'] ,
['অহংকার প্রকাশ করা', 'গর্ব প্রকাশ করা'] ,
['অহংকার রোহিত', 'অহংকার হীন', 'দম্ভহীন', 'দর্পরোহিত', 'দর্পশূণ্য', 'দর্পহীন', 'নিরহংকারী'] ,
['অহংকার', 'অহংমত্যতা', 'গর্ব', 'ঘোর', 'দম্ভ', 'দর্প', 'নেশা'] ,
['অহংকারী হওয়া', 'গর্বিত হওয়া', 'ফুলে যাওয়া'] ,
['অহংকারী', 'উদ্ধত', 'উদ্ধত ছন্দ', 'দাম্ভিক'] ,
['অহংবোধ', 'আত্মবৈশিষ্ট'] ,
['অহঙ্কার করা', 'গর্ব করা', 'বড়াই করা'] ,
['অহরণীয়', 'অহার্য'] ,
['অহরহ', 'দিন-রাত', 'দিনরাত', 'নিত্য', 'নিত্য প্রতি', 'নিরন্তর', 'নিশিদিন', 'প্রতি সময়ে', 'প্রতিদিন', 'রাতদিন', 'রোজ', 'সদা', 'সবসময়', 'সর্বথা', 'সর্বদা'] ,
['অহল্যা', 'গৌতমী'] ,
['অহি', 'টগণ', 'বৃত্ত', 'বৃত্রাসুর', 'রাহু'] ,
['অহিংস', 'অহিংস্র'] ,
['অহিক্ষেত্র', 'দক্ষিণ পাঞ্চাল'] ,
['অহিনগু', 'রাজা অহিনগু'] ,
['অহিমেধ', 'সপ্রযজ্ঞ'] ,
['অহির্বুঘ্ন', 'অহির্বুশ্ন'] ,
['অহীর', 'গো পালক', 'গোপ', 'গোয়ালা', 'ঘোষ', 'ঘোষস আভীর', 'যাদব'] ,
['অহীশ', 'ত্রেমাতুর', 'লক্ষণ', 'সৌমিত্র'] ,
['অহেরু', 'শতবতী', 'শতমূলী'] ,
['অহোরা-বহোরা', 'হেরাফেরি'] ,
['অহ্ণ', 'দিন', 'দিবস'] ,
['অ্যাকসিডেন্ট', 'দুর্ঘটনা'] ,
['অ্যাকাউন্ট', 'খাতা'] ,
['অ্যাকাউন্টেন্ট', 'গণক', 'গাণনিক', 'জমানবিশ', 'লেখাকর্মী', 'হিসাবরক্ষক'] ,
['অ্যাকাডেমি', 'একাডেমি'] ,
['অ্যাকুয়ারিয়াম', 'মত্সালয়'] ,
['অ্যাক্টিভ য়ুথেনেসিয়া', 'প্রত্যক্ষ ইচ্ছামৃত্যু'] ,
['অ্যাটম বোম', 'পরমাণুবোমা'] ,
['অ্যাটম', 'পরমাণু'] ,
['অ্যাটমিক', 'পরমানবিক'] ,
['অ্যাটলাস', 'অ্যাটলাস পর্বত', 'মানচিত্রাবলী'] ,
['অ্যাডলফ হিটলার', 'হিটলার'] ,
['অ্যাড্রিনালিন', 'ইপিনেফ্রিন'] ,
['অ্যাণ্টিস্টেরিলিটি ভিটামিন', 'এলফা টোকোফেরাল', 'খাদ্যজ ই', 'ভিটামিন ই'] ,
['অ্যাণ্টিহিমোরেহিজক ফ্যাক্টর', 'খাদ্যজ কে', 'ভিটামিন কে'] ,
['অ্যাথলেটিক্স', 'খেলা'] ,
['অ্যানালগ কম্পিউটার', 'রেখীয় সংগণক'] ,
['অ্যানিমিক', 'রক্তশূণ্য'] ,
['অ্যানিমিয়া', 'রক্তক্ষয়', 'রক্তাল্পতা'] ,
['অ্যানেস্থিসিয়া', 'সঞ্জাহরণ'] ,
['অ্যান্টিগুয়া-বাসী', 'অ্যান্টিগুয়াবাসী'] ,
['অ্যান্টিনা', 'শুঁড়', 'শুঙ্গ'] ,
['অ্যান্টিসেপ্টিক', 'জীবাণুনাশক'] ,
['অ্যাপার্টমেন্ট', 'ফ্ল্যাট'] ,
['অ্যাপিল', 'পুনরাবেদন'] ,
['অ্যাপেন্ডিক্স', 'আন্ত্র পুচ্ছ'] ,
['অ্যাভিটামিনোসিস', 'ভিটামিনহীনতা', 'হাইপোভিটামিনোসিস'] ,
['অ্যামাইটল', 'ব্লু অ্যাঙ্গেল', 'ব্লু অ্যামাইটল', 'ব্লু ডেভিল'] ,
['অ্যামিবা', 'অ্যামিবাণু'] ,
['অ্যালজীরিয়া বাসী', 'অ্যালজীরিয়ান'] ,
['অ্যালবাম', 'রেকর্ড অ্যালবাম'] ,
['অ্যাশট্রে', 'ছাইদান'] ,
['অ্যাশোশিয়েশান অফ সাউথইস্ট এশিয়ান নেশান্স', 'আসিয়ান'] ,
['অ্যাসিড-খোদাই করা', 'নকশা করা'] ,
['অ্যাসিসটেন্ট', 'শরিক', 'সহযোগী', 'সহায়ক', 'সাহায্যকারী'] ,
['অ্যাস্থামা', 'হাঁপানি'] ,
['অয়েলপেন্ট', 'তেলরঙ'] ,
['অয়েলফেয়ার প্রোগ্রাম', 'কল্যাণকারী কার্যক্রম'] ,
['আঁকড়া', 'আঁকড়ি', 'আংটা', 'বলিশ', 'সমিক'] ,
['আঁকা', 'টানা', 'পেন্টিং', 'বর্ণনা করা'] ,
['আঁচ উনুন', 'স্টোভ'] ,
['আঁটসাঁট', 'চক্রান্ত', 'দুরভিসন্ধি', 'ভেতরের চাল', 'ষড়যন্ত্র'] ,
['আঁড়ই', 'আঢক', 'আমন', 'শালিধান', 'হৈমন্তিক'] ,
['আঁশ', 'তন্তু', 'তুলো', 'রোঁয়া', 'শল্ক'] ,
['আঁহা', 'আজ্ঞে না', 'না', 'নয়'] ,
['আংটা', 'কড়া', 'কুণ্ডা', 'বলয়'] ,
['আংটি', 'আঙট'] ,
['আই ড্রপ', 'আইড্রপ'] ,
['আই প্যাড', 'আইপ্যাড'] ,
['আইএএস', 'ভারতীয় প্রশাসনিক সেবা'] ,
['আইএসআই', 'ইন্টার সার্ভিস ইন্টেলিজেন্স'] ,
['আইজোল', 'আইজোল জেলা'] ,
['আইজ্যাক নিউটন', 'নিউটন'] ,
['আইন বিশেষজ্ঞ', 'আইনজ্ঞ'] ,
['আইন বিষয়ক', 'আদালতি'] ,
['আইন', 'ন্যায়াদেশ', 'বিধান', 'বিধি'] ,
['আইনসম্মত', 'বৈধ'] ,
['আইনি', 'বিধিমত'] ,
['আইপি অ্যাডরেস', 'ইন্টারনেট প্রোটোকল অ্যাডরেস'] ,
['আইপিএস', 'ভারতীয় পুলিস সেবা'] ,
['আইবিআরডি', 'ওয়ার্ল্ড ব্যাঙ্ক', 'বিশ্ব ব্যাঙ্ক'] ,
['আইভরি কোস্ট', 'কোট টি আইভরি'] ,
['আইরিশ পন্ট', 'আইরিশ পাউন্ড', 'পাউন্ড'] ,
['আইরিশ', 'আইরিশ ভাষা'] ,
['আইসক্রীম কোন', 'কোন'] ,
['আইসল্যান্ডবাসী', 'আইসল্যান্ডীয়'] ,
['আইসল্যান্ডিক', 'আইসল্যান্ডিক লিপি', 'আইসল্যান্ডীয়'] ,
['আইসিআইসিআই', 'আইসিআইসিআই ব্যাঙ্ক'] ,
['আইসিসি', 'ইন্টারন্যাশানাল ক্রিকেট কাউন্সিল'] ,
['আইসোটোপ', 'সমস্থানিক'] ,
['আউট করা', 'আউট করে দেওয়া'] ,
['আউট', 'আউট হয়ে যাওয়া'] ,
['আউস', 'ভাদোই'] ,
['আওয়াজ করা', 'চিত্কার করা', 'চিল্লালো', 'বলা', 'বাজতে থাকা', 'শব্দ করা', 'হল্লা করা'] ,
['আওয়াজ দেওয়া', 'ডাক দেওয়া', 'ডাকা'] ,
['আওয়াজ', 'কন্ঠ স্বর', 'কলরব', 'কুজন গুঞ্জন', 'গলা', 'ঘোষ', 'ঘোষণা', 'ধ্বনি', 'নাদ', 'নিনাদ', 'বুলি', 'শব্দ', 'স্বর'] ,
['আওয়াধি', 'আওয়াধি ভাষা'] ,
['আওয়ার অ্যাঙ্গেল', 'এইচ এ'] ,
['আক', 'আদিত্য', 'চিত্রভানু', 'দিবসকর', 'রবিপ্রিয়'] ,
['আকবরপুর', 'আকবরপুর জেলা', 'আকবরপুর শহর', 'কানপুর দেহান', 'কানপুর দেহান জেলা'] ,
['আকর ভাষা', 'আকরভাষা', 'মূল ভাষা', 'মূলভাষা'] ,
['আকর', 'কোষাগার', 'ভান্ডার'] ,
['আকরিক', 'কাঁচা ধাতু'] ,
['আকর্ণ-ধনুরাসন', 'আকর্ণধনুরাসন'] ,
['আকর্ষক', 'চিত্তাকর্ষক'] ,
['আকর্ষণ শক্তি', 'চুম্বকত্ব'] ,
['আকর্ষণ', 'মনোরম', 'মনোহর', 'সুরম্যতা', 'সৌন্দর্য'] ,
['আকর্ষিত', 'আকৃষ্ট', 'মন্ত্রমুগ্ধ'] ,
['আকলন পক্ষ', 'আকলন-পক্ষ'] ,
['আকল্প', 'আলেখন', 'আলেখ্য', 'গোছগোছ', 'নকশা', 'পরিকল্পনা', 'রূপরেখা', 'শৃঙ্গার করা', 'সাজসজ্জা', 'সাজা'] ,
['আকশি', 'কাঁটা'] ,
['আকস্মিক অবকাশ', 'আকস্মিক ছুটি'] ,
['আকস্মিক ঘটনা', 'আপাত'] ,
['আকস্মিক-তহবিল', 'আকস্মিক-নিধি'] ,
['আকস্মিত তদন্ত', 'রেড'] ,
['আকাঙ্ক্ষা', 'আশা', 'ইচ্ছা', 'কামনা', 'বাসনা'] ,
['আকাঙ্খা', 'প্রত্যাশা'] ,
['আকাট মূর্খ', 'গণ্ডমূর্খ', 'জড়বুদ্ধি সম্পন্ন', 'মূর্খ'] ,
['আকার দেওয়া', 'গড়া', 'রূপ দেওয়া'] ,
['আকার প্রদত্ত', 'গঠিত', 'গড়া'] ,
['আকার', 'আকৃতি', 'গঠন', 'প্রতিভাস', 'মূর্তি', 'রূপ', 'স্বরূপ'] ,
['আকারযুক্ত বস্তু', 'স্থূল বস্তু'] ,
['আকারযুক্ত', 'মূর্তিমান', 'সাকার', 'সাক্ষাত্'] ,
['আকাল-পীড়িত', 'আকালপীড়িত', 'খরা-গ্রস্থ', 'খরাগ্রস্থ'] ,
['আকাশ কক্ষ', 'আকাশকক্ষ'] ,
['আকাশ কুসুম', 'আকাশকুসুম', 'আকাশপুষ্প'] ,
['আকাশ নিদ্রা', 'আকাশ-নিদ্রা', 'আকাশনিদ্রা'] ,
['আকাশ প্রদীপ', 'কাগজের লন্ঠন'] ,
['আকাশ ভাষিত', 'আকাশভাষিত'] ,
['আকাশ যান', 'নভঃযান'] ,
['আকাশ', 'ত্রিদিব', 'নভস্থল', 'শূণ্য'] ,
['আকাশ-ছোঁয়া', 'আকাশভেদী', 'গগনচুম্বী', 'গগনভেদী', 'গগনস্পর্শী'] ,
['আকাশ-বৃত্তি', 'আকাশবৃত্তি'] ,
['আকাশগঙ্গা', 'ছায়াপথ', 'ত্রিদশাদীর্ঘিকা', 'দিব্যসরিতা', 'মন্দাকিনী', 'সুরনদী', 'স্বর্গনদী'] ,
['আকাশচর', 'খেচর', 'নভশ্চর'] ,
['আকাশছোঁয়া দাম হওয়া', 'দাম বাড়া', 'দামী হওয়া'] ,
['আকাশবচন', 'আকাশবাণী', 'দিব্য বাণী', 'দিব্যবাক্য', 'দেববাণী', 'দৈববাণী'] ,
['আকাশবাণী কেন্দ্র', 'রেডিও স্টেশন'] ,
['আকাশভেদী', 'গগনভেদী'] ,
['আকাশী', 'আকাশী রঙ'] ,
['আকুঞ্চনীয়', 'কুঞ্চনসাধ্য'] ,
['আকৃতি', 'রূপ'] ,
['আকৃষ্ট হওয়া', 'মন্ত্রমুগ্ধ হওয়া'] ,
['আক্রমক', 'আক্রমণকারী'] ,
['আক্রমণ করা', 'চড়াও হওয়া', 'হামলা করা'] ,
['আক্রমণ হওয়া', 'হামলা হওয়া'] ,
['আক্রমণ', 'হামলা'] ,
['আক্রমণীয়', 'আক্রমণের যোগ্য'] ,
['আক্রমিতা', 'আক্রান্তা'] ,
['আক্রুর', 'মধুপ্রিয়'] ,
['আক্ষেপ করা', 'আহ্-আহ্ করা', 'কোঁকানো', 'বিলাপ করা', 'শোক প্রকাশ করা'] ,
['আক্ষেপ রোগ', 'আক্ষেপক'] ,
['আখ খাওয়া', 'আখ চোষা'] ,
['আখ', 'ইক্ষু', 'ইক্ষুদন্ড', 'মধুযষ্টি', 'মধুরস'] ,
['আখড়া', 'আড্ডা', 'আশ্রম', 'কেন্দ্র', 'গড়', 'মঠ', 'মল্ল ভূমি'] ,
['আখরোট', 'আখরোট গাছ', 'খুবানী', 'খোবানি', 'মধুপিলু'] ,
['আখ্যান', 'কাহিনী', 'গল্প'] ,
['আখ্যায়িকা', 'কল্পকথা', 'কল্পকাহিনী', 'কাল্পনিক কাহিনী'] ,
['আগড়ম বাগড়ম বকা', 'বকবক করা'] ,
['আগত', 'সমাগত'] ,
['আগতপতিকা', 'আগমপতিকা'] ,
['আগন্তুক', 'আসা'] ,
['আগমন করা', 'আসা', 'পৌঁছানো'] ,
['আগমন হওয়া', 'আসা'] ,
['আগমবিদ্যা', 'বেদবিদ্যা'] ,
['আগরতলা', 'আগরতলা শহর'] ,
['আগাম', 'দাদন', 'বায়না'] ,
['আগামী দিনে', 'ভবিষ্যত কালে', 'ভবিষ্যতে'] ,
['আগামী সময়', 'উত্তর কাল', 'কাল', 'ভবিষ্যত', 'ভবিষ্যত কাল'] ,
['আগামী', 'ভাবী'] ,
['আগামীকাল', 'কাল'] ,
['আগুন লাগানো', 'জ্বালানো', 'জ্বালিয়ে দেওয়া', 'দাহ', 'পোড়ানো'] ,
['আগুন', 'কাঠের আগুন'] ,
['আগুপিছু', 'সামনে-পেছন'] ,
['আগে থেকে', 'প্রথম থেকেই'] ,
['আগে পিছে', 'সামনেপিছনে'] ,
['আগে', 'আগেকার', 'আদিতে', 'আরম্ভে', 'পূর্বে', 'প্রথম', 'প্রথমত', 'প্রারম্ভে', 'শুরুতে', 'সবথেকে আগে', 'সর্বপ্রথম', 'সামনে'] ,
['আগে-আগে', 'সামনের দিকে'] ,
['আগেই', 'প্রথমেই'] ,
['আগেকার', 'পুরোনো'] ,
['আগের বছর', 'গত বছর'] ,
['আগের মত করা', 'নিয়ে আসা'] ,
['আগের মত', 'যথাপূর্বক'] ,
['আগ্নেয়', 'আগ্নেয় ভাষা সমূহ', 'আগ্নেয়গিরি'] ,
['আগ্নেয়গিরি', 'আগ্নেয়গিরি-পর্বত', 'আগ্নেয়গিরি-পাহাড়', 'আগ্নেয়পর্বত'] ,
['আগ্রহ দেখানো', 'রূচি থাকা'] ,
['আগ্রহপূর্বক', 'আগ্রহের সঙ্গে', 'আগ্রহের সহিত'] ,
['আগ্রহী হওয়া', 'উত্সাহী হওয়া'] ,
['আগ্রহী', 'উত্সাহী', 'উত্সুক'] ,
['আগ্রা', 'আগ্রা জেলা', 'আগ্রা শহর'] ,
['আঘাত করা', 'ব্যথা দেওয়া'] ,
['আঘাত পাওয়া', 'বিদ্ধ করা'] ,
['আঘাত প্রাপ্ত', 'আহত', 'ঘায়েল', 'চোট প্রাপ্ত', 'জখম ব্যক্তি'] ,
['আঘাত', 'ধাক্কা', 'ধোলাই', 'পেটানো', 'প্রহার', 'মার'] ,
['আঘাতপ্রাপ্ত', 'আহত'] ,
['আঘার', 'ঘৃত আহুতি'] ,
['আঘ্রাণ', 'গন্ধ নেওয়া', 'শোঁকা'] ,
['আঘ্রাত', 'আঘ্রাত গ্রহণ', 'শোঁকা'] ,
['আঙুর রস', 'দ্রাক্ষারস'] ,
['আঙুর', 'আঙ্গুর', 'আবী', 'দ্রাক্ষা', 'মধুরসা'] ,
['আঙ্গামী', 'আঙ্গামী জনজাতি'] ,
['আঙ্গিনা', 'উঠোন'] ,
['আঙ্গিরস', 'উতথ্য', 'উতন্থ'] ,
['আঙ্গুল', 'আঙ্গুল জেলা', 'আঙ্গুল শহর'] ,
['আঙ্গোলার', 'আঙ্গোলীয়'] ,
['আচমন', 'নেত্রবালা'] ,
['আচরণ করা', 'ব্যবহার করা'] ,
['আচরণ', 'আচার-ব্যবহার', 'চাল-চলন', 'ব্যবহার'] ,
['আচারবান', 'চরিত্রবান', 'শিষ্টাচারী', 'সচ্চরিত্র', 'সদাচারী', 'সুশীল'] ,
['আচারশাস্ত্র', 'নীতিবিদ্যা', 'নীতিশাস্ত্র'] ,
['আচার্য কোকদেব', 'কোক', 'কোকদেব'] ,
['আচার্য ভাব মিশ্র', 'ভাব মিশ্র'] ,
['আচার্য', 'কুলপতি', 'চ্যান্সেলর'] ,
['আচার্যা', 'শিক্ষিকা'] ,
['আচার্য্য বিনোভা ভাবে', 'বিনায়ক নরহরি ভাবে', 'বিনোভা', 'বিনোভা ভাবে'] ,
['আচার্য্য', 'পুরোহিত'] ,
['আচ্ছন্ন', 'আচ্ছাদিত', 'আবৃত', 'ঢাকা'] ,
['আচ্ছাদক বস্তু', 'আচ্ছাদন', 'আবরণ', 'আস্তরন', 'কবচ'] ,
['আচ্ছাদন', 'আবরণ', 'চাপা', 'ঢাকনা', 'পিধান'] ,
['আচ্ছাদনযোগ্য', 'আচ্ছাদনীয়', 'আচ্ছাদ্য'] ,
['আচ্ছাদিত', 'ঢাকা'] ,
['আছার মারা', 'ভূপতিত করা'] ,
['আজ অবধি', 'আজ পর্যন্ত', 'এখনও অবধি', 'এখনও পর্যন্ত'] ,
['আজ', 'আধুনিক কাল', 'বর্তমান', 'বর্তমান কাল'] ,
['আজকাল', 'আপাতত', 'এই সময়', 'এখন', 'বর্তমানে'] ,
['আজমীর দরগা শরীফ', 'আদমীর শরিফ', 'দরগা শরীফ'] ,
['আজমীর', 'আজমীর জেলা', 'আজমীর শহর'] ,
['আজরবেজান', 'আজরবেজানি গণতন্ত্র', 'আজরবেজানি গণরাজ্য'] ,
['আজরবেজানবাসী', 'আজরবেজানি'] ,
['আজরবেজানি মনট', 'মনট'] ,
['আজাদ হিন্দ ফৌজ', 'আজাদ হিন্দ সেনা'] ,
['আজাদ', 'চন্দ্রশেখর আজাদ'] ,
['আজান দেব', 'আজানদেব'] ,
['আজারবৈজানি', 'আজারবৈজানি ভাষা', 'আজেরি'] ,
['আজীবন কারাবাস', 'যাবজ্জীবন কারাদন্ড'] ,
['আজীবন', 'আমরণ', 'জীবন ভর', 'মৃত্যু পর্যন্ত', 'সারা জীবন'] ,
['আজ্ঞপ্ত', 'আদিষ্ট', 'উপদিষ্ট', 'নিযুক্ত'] ,
['আজ্ঞা চক্র', 'আজ্ঞাচক্র', 'শিবনেত্র'] ,
['আজ্ঞা পালন করা', 'কথা শোনা'] ,
['আজ্ঞা', 'আদেশ', 'হুকুম'] ,
['আজ্ঞাকর্তা', 'আদেশদাতা'] ,
['আজ্ঞানুগমন', 'আজ্ঞানুসরণ', 'আজ্ঞাপালন'] ,
['আজ্ঞানুসার', 'আদেশানুসার'] ,
['আজ্ঞাপালন করা', 'কথা শোনা'] ,
['আজ্ঞাপালন', 'আজ্ঞাভঙ্গ', 'হুকুম তামিল'] ,
['আজ্ঞাপূর্বক', 'আদেশপূর্বক'] ,
['আজ্ঞে', 'হ্যাঁ'] ,
['আঞ্চলিক', 'প্রাদেশিক'] ,
['আট আনা', 'আধুলী', 'পঞ্চাস পয়সা'] ,
['আটক', 'নিরুব্ধ', 'বন্দী'] ,
['আটকানো', 'আটকে দেওয়া', 'আটকে যাওয়া', 'ঝোলানো', 'টাঙ্গানো', 'থামানো', 'বন্ধ করা', 'লাগানো', 'সাঁটা', 'সামলানো'] ,
['আটকামো', 'জড়ানো', 'ফাঁসা'] ,
['আটকে থাকা', 'থাকা'] ,
['আটকে যাওয়া', 'গতিরুদ্ধ হওয়া', 'থামা', 'থেমে যাওয়া', 'ফেঁসে যাওয়া', 'বন্ধ হওয়া'] ,
['আটকে রাখা', 'থামিয়ে রাখা', 'সামলানো', 'স্থগিত রাখা'] ,
['আটত্রিশ', '৩৮,'] ,
['আটষট্টি', '৬৮', '৬৮,'] ,
['আটাত্তর', '৭৮', '৭৮,'] ,
['আটানব্বই', '৮৯', '৯৮,'] ,
['আটানো', 'পোরা', 'ভরা', 'ভরাট হওয়া', 'ভরানো', 'সমতল হওয়া'] ,
['আটান্ন', '৫৮', '৫৮,'] ,
['আঠা', 'গাম', 'নির্যাস', 'বেষ্টক'] ,
['আঠারো মাসে বছর', 'রেডটেপ', 'লালফিতে'] ,
['আঠাল', 'চটচটে'] ,
['আড় চোখে', 'কটাক্ষ'] ,
['আড়', 'আড় তাল', 'আড় মাছ', 'কোণ', 'কোণা'] ,
['আড়ম্বরপূর্ণ প্রদর্শনী কক্ষ', 'বিশাল প্রদর্শনী কক্ষ', 'সুসজ্জিত প্রদর্শনী কক্ষ'] ,
['আড়ম্বরের দিন', 'জাঁকজমকপূর্ণ দিন', 'জৌলুসের দিন', 'বিভবের দিন'] ,
['আড়া-ত্যাড়া', 'ট্যাঁড়া-ব্যাঁকা'] ,
['আড়াআড়ি', 'তির্যক'] ,
['আড়াইশো', 'দুশো পঞ্চাশ', '২৫০,'] ,
['আড়াকস', 'করাতী'] ,
['আড়াল', 'পর্দা'] ,
['আডি', 'আডি মাছ', 'করঙ্কুল', 'কালো বুজ্জা', 'ভুকাক', 'শরালি'] ,
['আড্ডা', 'আস্তানা', 'কোঠা', 'গল্প', 'গালগপ্পো', 'ঠিকানা', 'ঠেকা', 'পরিবহন স্থল', 'বেশ্যালয়', 'স্টেশন'] ,
['আড্ডাখানা', 'আড্ডার জায়গা'] ,
['আতঙ্ক', 'ত্রাস', 'দর্প', 'ভয়', 'সন্ত্রাস'] ,
['আতঙ্কগ্রস্ত করা', 'ভয় পাওয়ানো'] ,
['আতঙ্কবাদী', 'উগ্রবাদী'] ,
['আতঙ্কিত হওয়া', 'ঘাবড়ে যাওয়া'] ,
['আতঙ্কিত', 'ভীত', 'সন্ত্রস্ত'] ,
['আততায়ী', 'ঘাতক', 'নৃশংস', 'বর্বর', 'হিংসাপ্রবণ'] ,
['আতপ', 'আতপ চাল'] ,
['আতশবাজি', 'বাজি'] ,
['আতশি', 'আতশী'] ,
['আতি পাতি', 'আতিপাতি'] ,
['আতিশয্য', 'আধিক্য', 'প্রাচুর্য', 'বিপুলতা'] ,
['আত্ম শক্তি', 'আন্তরিক তেজ', 'আন্তরিক শক্তি', 'প্রাণশক্তি'] ,
['আত্ম', 'নিজস্ব', 'নিজের', 'স্বকীয়', 'স্বায়ত্ব'] ,
['আত্মকথন', 'আত্মকথা'] ,
['আত্মকথা', 'আত্মচরিত', 'আত্মজীবনী'] ,
['আত্মক্ষমতা', 'আত্মশক্তি'] ,
['আত্মগৌরব', 'আত্মসম্মান'] ,
['আত্মঘাতক', 'আত্মঘাতী'] ,
['আত্মজা', 'কন্যা', 'কন্যা রাশি', 'কন্যারাশি', 'তনুজা', 'তনয়া', 'দুহিতা', 'নন্দিনী', 'সুতা'] ,
['আত্মজ্ঞ', 'আত্মারাম', 'আধ্যাত্মজ্ঞ', 'ব্রহ্মজ্ঞানি', 'সিদ্ধ'] ,
['আত্মজ্ঞান', 'আত্মদর্শন', 'আত্মপ্রবোধ', 'আত্মবোধ', 'আত্মসংবেদন', 'আত্মসাক্ষাত্কার', 'আত্মানুভূতি'] ,
['আত্মজ্ঞানী', 'আত্মদর্শী', 'আত্মদ্রষ্টা'] ,
['আত্মতত্বজ্ঞ', 'বেদান্তি'] ,
['আত্মতুষ্ট', 'আত্মতৃপ্ত'] ,
['আত্মতুষ্টি', 'আত্মতৃপ্তি', 'মনস্তুষ্টি'] ,
['আত্মত্যাগ', 'আত্মদান'] ,
['আত্মত্যাগী', 'আত্মবিসর্জনকারী', 'স্বার্থবর্জনকারী'] ,
['আত্মদর্শন', 'আত্মনিরীক্ষণ'] ,
['আত্মদর্শী', 'আত্মদ্রষ্টা'] ,
['আত্মনিবেদন', 'আত্মপরিত্যাগ', 'আত্মসমর্পণ'] ,
['আত্মনির্ভর', 'স্বনির্ভর'] ,
['আত্মনির্ভরতা', 'স্বনির্ভরতা'] ,
['আত্মনিয়ন্ত্রণ', 'সংযম'] ,
['আত্মপক্ষ সমর্থন করা', 'সাফাই দেওয়া'] ,
['আত্মপক্ষীয়', 'নিজের', 'স্বপক্ষী', 'স্বপক্ষীয়'] ,
['আত্মপ্রশংসা', 'আত্মশ্লাঘা'] ,
['আত্মবলি', 'আত্মবলিদান'] ,
['আত্মবলিদান করা', 'আত্মাহুতি দেওয়া', 'আত্মোত্সর্গ করা'] ,
['আত্মবলিদান', 'আত্মাহুতি', 'আত্মোত্সর্গ'] ,
['আত্মবিজ্ঞান', 'আধ্যাত্ম-বিদ্যা'] ,
['আত্মমর্যাদাসম্পন্ন', 'আত্মাভিমানী'] ,
['আত্মরক্ষামূলক ব্যবস্থা', 'মজবুত করা', 'সুরক্ষিতকরণ'] ,
['আত্মসম্মান', 'নিজসম্মান'] ,
['আত্মা বিষয়ক', 'আত্মা সম্পর্কিত', 'আত্মিক'] ,
['আত্মা', 'আত্মা উপনিষদ', 'জীবনি-শক্তি', 'প্রাণ', 'প্রেতাত্মা', 'বিভূ', 'সুক্ষ্ম শরীর'] ,
['আত্মানুশাসন', 'শ়ৃঙ্খলা বা সংযম'] ,
['আত্মাবলম্বী', 'স্বাবলম্বী'] ,
['আত্মাবোধ', 'আত্মাবোধ উপনিষদ', 'আত্মাবোধোপনিষদ'] ,
['আত্মীয় সম্পর্কিত', 'স্বজন সম্পর্কিত', 'স্বজনীয়'] ,
['আত্মীয়', 'আপনজন', 'কাঁদার লোক', 'কুটুম্ব', 'জ্ঞাতি', 'পরিজন', 'বন্ধু-বান্ধব', 'বান্ধব', 'শরীক', 'সম্বন্ধী', 'স্বজন'] ,
['আত্মীয়তা', 'একাত্মতা', 'সম্পর্ক', 'সম্বন্ধ'] ,
['আত্রেয়ী', 'আত্রেয়ী নদী'] ,
['আদম', 'বাবা আদম'] ,
['আদমচশ্ম', 'আদমচশ্ম ঘোড়া'] ,
['আদমে সানী', 'নোয়াহ'] ,
['আদর করা', 'ভালবাসা', 'শ্রদ্ধা করা', 'সম্মান করা', 'হাত বোলানো'] ,
['আদর', 'বাত্সল্য', 'ভালোবাসা', 'শিশু প্রেম', 'সন্তান প্রেম'] ,
['আদরণীয়া', 'মাননীয়া', 'সম্মানীয়া'] ,
['আদরের সঙ্গে', 'সমাদরপূর্বক', 'সসম্মানে', 'সাদরে'] ,
['আদর্শ', 'উদাহরণ', 'নমুনা'] ,
['আদা', 'কটুকন্দ', 'বওয়াদা', 'মূলজ', 'রাজাদ্রি', 'শৃঙ্গ'] ,
['আদালত', 'এজলাস', 'কোর্ট', 'ন্যায় অধিকরণ', 'ন্যায়সভা', 'ন্যায়াধিকরণ', 'ন্যায়ালয়'] ,
['আদালতসম্বন্ধীয়', 'আদালতি', 'আদালতী', 'আদালতের'] ,
['আদায় করা', 'আসা', 'উসুল করা', 'পাওয়া', 'প্রাপ্ত হওয়া', 'প্রাপ্তি হওয়া'] ,
['আদায়', 'উসুলস অনুপ্রাপ্তি'] ,
['আদায়ীকৃত', 'উশুল করা', 'উসুল করা'] ,
['আদি নিবাস', 'মূল নিবাস'] ,
['আদি পুরুষ', 'মনু'] ,
['আদি', 'আরম্ভ', 'এক', 'প্রথম', 'প্রারম্ভ', 'পয়লা', 'শুরু', '১লা'] ,
['আদিকবি', 'বাল্মিকী', 'বাল্মিকী ঋষি', 'বাল্মিকী মুনি'] ,
['আদিত্য', 'বসু', 'সাবিত্র'] ,
['আদিবাসি', 'আদিম নিবাসী', 'মূল-নিবাসী'] ,
['আদিম কাল', 'পুরাতন কাল', 'পুরাতনকাল', 'প্রাচীন কাল', 'প্রাচীনকাল'] ,
['আদিম মানব', 'আদিমানব'] ,
['আদিম', 'পুরাকালীন', 'পুরাতন', 'পুরানো', 'প্রাচীন', 'প্রাচ্য'] ,
['আদিরস', 'শৃঙ্গার', 'শৃঙ্গার রস'] ,
['আদিল শাহ', 'আদিলশাহ'] ,
['আদিলাবাদ', 'আদিলাবাদ জেলা', 'আদিলাবাদ শহর'] ,
['আদিস আবাবা', 'আদিস আবেবা', 'নিউ ফ্লাওয়ার'] ,
['আদুরে', 'প্রিয়'] ,
['আদৃত', 'সমাদৃত'] ,
['আদেশ দেওয়া', 'আর্জি করা', 'হুকুম দেওয়া'] ,
['আদেশক', 'আদেশকর্তা', 'আদেষ্টা'] ,
['আদ্ধা', 'আদ্ধা কাওয়ালী'] ,
['আদ্যা', 'কালি', 'কালিকা', 'কালিকা দেবী', 'চণ্ডকালী', 'মহারৌদ্রী', 'মুক্তকেশী', 'শ্যামা'] ,
['আদ্রক', 'শুঁট', 'শুকনো আদা', 'শুন্ঠি', 'শুষ্কার্দ্র'] ,
['আদ্রা', 'আদ্রা নক্ষত', 'আদ্রা নক্ষত্র', 'আদ্রানক্ষত্র', 'ইর্শ', 'কালিনী'] ,
['আধ কোটি', 'পঞ্চাশ লাখ', '৫০০০০০০,'] ,
['আধাত্মিক জ্ঞান', 'আধাত্মিকজ্ঞান', 'আধাত্মিকতা', 'জ্ঞান-তত্ব', 'তত্ব-জ্ঞান'] ,
['আধার', 'আশ্রয়', 'থলি', 'পাত্র', 'পায়া', 'বুনিয়াদী', 'ভিত্তি', 'ভীত', 'মূল', 'মৌলিক'] ,
['আধিদৈবিক', 'দিব্য', 'দেবতাকৃত', 'দৈব', 'দৈবজাত', 'দৈবিক', 'দৈবী', 'পারলৌকিক'] ,
['আধিপত্য', 'প্রভাব', 'প্রভুত্ব', 'শাসনাধিকার'] ,
['আধিভৌতিক', 'ভূতজাত'] ,
['আধুনিক ব্যক্তি', 'আধুনিকমনস্ক মানুষ', 'মডার্ন'] ,
['আধুনিক', 'নতুন', 'বর্তমান', 'বর্তমান কাল', 'বর্তমান কালের', 'সাম্প্রতিক', 'হাল আমলের'] ,
['আধুনিকতম', 'সর্বাধুনিক'] ,
['আধেয়', 'বন্ধকযোগ্য', 'বন্ধকীয়', 'রচনীয়'] ,
['আনদ্ধ', 'আবদ্ধ', 'চর্মাবৃত'] ,
['আনন', 'চেহারা', 'বদন', 'মুখ', 'মুখ মণ্ডল', 'মুখমণ্ডল'] ,
['আনন্দ উপভোগ করা', 'আনন্দ নেওয়া', 'আনন্দ লাভ করা'] ,
['আনন্দ করা', 'নাচা', 'ফুর্তি করা'] ,
['আনন্দ', 'আনন্দ জেলা', 'আনন্দ শহর', 'আনন্দদায়ক', 'আনন্দপ্রদ', 'আমোদ', 'আমোদ-প্রমোদ', 'উল্লাস', 'খুশি', 'খুশী', 'পরিতোষ', 'প্রফুল্লতা', 'প্রসন্নতা', 'মজা', 'রস', 'রসাস্বাদন', 'সুখপ্রদ', 'স্বাদ', 'হর্ষ'] ,
['আনন্দদায়ক করে দেওয়া', 'সুখপ্রদ বানানো'] ,
['আনন্দদায়ক', 'আনন্দদায়ক মনে হওয়া', 'আনন্দদায়ী', 'আনন্দপ্রদ', 'তোষক', 'প্রসন্নতাদায়ক', 'সখপ্রদ', 'সন্তোষ সাধক', 'সুখকর', 'সুখদায়ক', 'সুখপ্রদ'] ,
['আনন্দপূর্ণ', 'আনন্দময়', 'উল্লাসপূর্ণ', 'সানন্দ'] ,
['আনন্দপ্রদ', 'মনোরঞ্জক', 'মনোরঞ্জনপূর্ণ'] ,
['আনন্দভৈরব', 'আনন্দভৈরব রস'] ,
['আনন্দমত্তা', 'আনন্দসম্মোহিতা'] ,
['আনন্দময়', 'হাসিখুশি'] ,
['আনন্দিত করা', 'খুশী করা'] ,
['আনন্দিত হওয়া', 'খুশী হওয়া', 'প্রসন্ন হওয়া'] ,
['আনন্দিত', 'আমোদিত', 'আহ্লাদিত', 'উল্লসিত', 'খুশি', 'তুষ্ট', 'পুলকিত', 'প্রফুল্ল', 'প্রসন্ন', 'বিনোদিত'] ,
['আনর্ত', 'সৌরাষ্ট্র নিবাসী', 'সৌরাষ্ট্র বাসী'] ,
['আনা', 'করা', 'নিয়ে আসা'] ,
['আনাজের গুদাম', 'গুদাম'] ,
['আনাড়ী', 'কুতর্কী'] ,
['আনানো', 'চেয়ে পাঠানো'] ,
['আনাম', 'আনামিজ'] ,
['আনামিজ', 'আনামী'] ,
['আনুকূল্য', 'সদাশয়তা'] ,
['আনুগত্য', 'বিশ্বাস'] ,
['আনুবংশিক শত্রুতা', 'বংশগত শত্রুতা'] ,
['আনৃশংস্য', 'দয়া', 'সহৃদয়তা'] ,
['আন্টার্টিক', 'আন্টার্টিক ক্ষেত্র', 'আন্টার্টিক জোন'] ,
['আন্ডারগ্রউন্ড হওয়া', 'গা ঢাকা দেওয়া'] ,
['আন্তরিক', 'হার্দিক'] ,
['আন্তর্জাতিক ক্ষেত্র', 'আন্তর্জাতিক স্তর'] ,
['আন্তর্জাতিক পারমাণবিক শক্তি সংস্থা', 'আন্তর্জাতিক শক্তি এজেন্সি'] ,
['আন্তর্জাতিক', 'বহুদেশীয়', 'বহুরাষ্ট্রীয়'] ,
['আন্ত্রিকজ্বর', 'টাইফয়েডে', 'সান্নিপাতিক জ্বর'] ,
['আন্দাজ করা', 'ধারণা করা', 'বোঝা'] ,
['আন্দাজ', 'আন্দাজ মতো'] ,
['আন্দামান নিকোবর', 'আন্দামান নিকোবর দ্বীপপুঞ্জ'] ,
['আন্দামান', 'আন্দামান জেলা'] ,
['আন্দোলন', 'ঢেউয়ের আন্দোলন'] ,
['আন্দোলিত', 'কম্পিত'] ,
['আন্নামালাই', 'আন্নামালাই শহর'] ,
['আপডেট করা', 'হালনাগাদ করা'] ,
['আপণ', 'দোকান'] ,
['আপত্কাল', 'বিপদকাল', 'সঙ্কট কাল', 'সঙ্কট-কাল'] ,
['আপত্কালীন পরিস্থিতি', 'এমার্জেন্সী'] ,
['আপত্তি জানানো', 'বিরোধিতা করা'] ,
['আপত্তিকর', 'আপত্তিজনক'] ,
['আপদকালীন', 'দুর্যোগপূর্ণ'] ,
['আপন জন', 'নিজের লোক'] ,
['আপন ভাই', 'নিজের ভাই', 'সহোদর'] ,
['আপস্তম্ব', 'আপস্তম্ব ঋষি'] ,
['আপাত', 'দৃষ্ট হওয়া', 'দেখতে পাওয়া', 'দেখানো'] ,
['আপাতত', 'এই সময়', 'এখন', 'সম্প্রতি'] ,
['আপীল', 'আবেদন', 'আবেদন পত্র', 'আবেদন-পত্র', 'নিবেদন'] ,
['আপূষ', 'টিন', 'রঙ্গ', 'রাঙ', 'স্বর্ণজ'] ,
['আপেল', 'আপেল গাছ'] ,
['আপ্লাবন', 'ডুবিয়ে দেওয়া'] ,
['আফগান', 'আফগানি', 'আফগানী', 'পশ্তু', 'পশ্তো'] ,
['আফতাবা', 'গাড়ু'] ,
['আফশোস', 'খেদ', 'গ্লানি', 'দুঃখ'] ,
['আফিং', 'আফিঙ', 'আফিম'] ,
['আফিম', 'পোস্ত'] ,
['আফিমবিজ', 'খসখস', 'পোস্তো'] ,
['আফ্রিকা-বাসী', 'আফ্রিকান'] ,
['আফ্রিকান গাধা', 'জেব্রা'] ,
['আফ্রিকান', 'আফ্রিকার', 'কাফ্রি', 'নিগ্রো', 'নিগ্রোয়েড'] ,
['আফ্রিকি দেশ', 'আফ্রিকি রাষ্ট্র'] ,
['আফ্রিকীয় বনমানুশবিশেষ', 'শিম্পাঞ্জী'] ,
['আবগার', 'মদ্যব্যবসায়ী', 'শুঁড়ি'] ,
['আবগারি দপ্তর', 'আবগারি বিভাগ'] ,
['আবত্সারক্ষ', 'আবত্সারক্ষ ঋষি'] ,
['আবদ্ধ', 'বদ্ধ'] ,
['আবরক ঝিল্লি', 'ছিছড়া', 'মেমব্রেন'] ,
['আবরণ শক্তি', 'আবরণশক্তি'] ,
['আবরণ', 'কবচ', 'ক্যাটারাক্ট', 'খোলোস', 'ছানি', 'ছাল', 'থলি', 'বস্তা'] ,
['আবরণহীণ', 'কবচহীন'] ,
['আবরণহীন', 'পর্দাহীন'] ,
['আবরু', 'কুন্ঠা', 'ত্রপা', 'দ্বিধা', 'ব্রীড়া', 'ভরম', 'মন্দাস্য', 'লজ্জা', 'লাজ', 'লাজলজ্জা', 'শরম', 'সংকোচ', 'সম্ভ্রম', 'হায়া', 'হ্রী'] ,
['আবর্জনা পাত্র', 'ডাস্টবিন'] ,
['আবর্জনা', 'নোংরা'] ,
['আবর্ত', 'জলঘূর্ণি'] ,
['আবর্তণ', 'আবৃত্তি', 'পুনরাবর্তণ', 'পুনরাবৃত্তি'] ,
['আবর্তমণি', 'রাজাবর্ত পাথর', 'রাজাবর্তক'] ,
['আবর্তিত হওয়া', 'ঘোরা', 'ঘোরা-ফেরা', 'চক্কর খাওয়া', 'হাঁটা'] ,
['আবলি', 'মালা'] ,
['আবলুসী', 'আবলুসের'] ,
['আবশ্যক', 'প্রয়োজনীয়'] ,
['আবশ্যকতা থাকা', 'প্রয়োজন হওয়া'] ,
['আবশ্যকতা', 'প্রত্যাশা'] ,
['আবহাওয়া', 'জল-হাওয়া', 'জলবায়ু'] ,
['আবাদ', 'চাষ', 'ফলন', 'ফসল', 'শস্য'] ,
['আবাদী', 'কৃষিযোগ্য', 'জনসংখ্যা', 'জোতার যোগ্য'] ,
['আবার', 'পুনঃ', 'পুনরায়'] ,
['আবাস দেওয়া', 'ঘর দেওয়া'] ,
['আবাসন', 'কোয়ার্টার', 'বসতি'] ,
['আবাসহীন ব্যক্তি', 'ঘরবাড়িহীন', 'বেঘর'] ,
['আবাসিক ছাত্র', 'ছাত্রাবাসী'] ,
['আবাসিক মহাবিদ্যালয়', 'রেশিডেন্সিয়াল কলেজ'] ,
['আবাসিক', 'গৃহবাসী', 'গৃহযুক্ত', 'বসতি'] ,
['আবাসিত', 'সুস্থিত', 'স্থিত'] ,
['আবির', 'আম্বর', 'গুলাল', 'ফল্গু', 'ফাগ', 'ফাগু', 'ফাগুয়া'] ,
['আবির্ভাব', 'প্রকটীকরণ'] ,
['আবির্ভূত', 'আলোকিত', 'প্রকটিত', 'প্রস্ফুটিত'] ,
['আবির্হোত্র', 'আবির্হোত্র ঋষি'] ,
['আবিষ্করণ', 'আবিষ্কার', 'খোঁজ', 'তল্লাশ'] ,
['আবিষ্কর্তা', 'আবিষ্কারক'] ,
['আবিষ্কার করা খুঁজে বের করা', 'বের করা'] ,
['আবিষ্কার করা', 'বার হওয়া'] ,
['আবিষ্কারপ্রবণ', 'কল্পনাপ্রবণ'] ,
['আবিষ্ট', 'আবেশপূর্ণ', 'আবেশিত'] ,
['আবিসিনিয়া', 'ইথিয়োপিয়া'] ,
['আবী', 'আবী রুটি'] ,
['আবৃত করা', 'ঢাকা দেওয়া'] ,
['আবৃত', 'মোড়ানো', 'সংবৃত'] ,
['আবেগ', 'ভাব', 'ভাবনা', 'মনোবৃত্তি', 'মনোভাব', 'মানসিক ভাব'] ,
['আবেদক', 'আবেদন কর্তা', 'আবেদনকারী', 'প্রার্থী', 'ফরিয়াদী'] ,
['আবেদন', 'চাওয়া', 'প্রার্থনা'] ,
['আবেদনকারী', 'দরখাস্তকারী', 'প্রার্থণাকারী', 'প্রার্থী', 'যাচক'] ,
['আবেদনীয়', 'আবেদ্য'] ,
['আবেশ', 'চার্জ'] ,
['আবেস্তা', 'জেন্দ-আবেস্তা'] ,
['আব্বা', 'জনক', 'জন্মদাতা', 'পিতা', 'বাপ'] ,
['আভা', 'আভাস', 'চমক', 'জ্যোতি', 'ঝলক', 'তেজ', 'দীপ্তি', 'দ্যূতি', 'প্রভা'] ,
['আভামণ্ডল', 'প্রভামণ্ডল'] ,
['আভাস দেওয়া', 'ঝলক দেওয়া'] ,
['আভাস হওয়া', 'মনে হওয়া', 'লাগা'] ,
['আভাস', 'কোনো রঙের ছোপ'] ,
['আভাহীন', 'কান্তিহীন', 'তেজহীন', 'নিষ্প্রভ', 'নিস্তেজ', 'প্রভাহীন', 'ফিকে'] ,
['আভিধানিক অর্থ', 'বাচ্যার্থ'] ,
['আভীর', 'আভীর উপজাতি', 'আভীর ছন্দ', 'আভীর জনপদ', 'আভীর রাগ'] ,
['আভ্যন্তরীণ বিষয়ের মন্ত্রালয়', 'গৃহমন্ত্রক'] ,
['আভ্যুদয়িক', 'আভ্যুদয়িক শ্রাদ্ধ. নান্দীমুখ শ্রাদ্ধ', 'নান্দীমুখ'] ,
['আম আচার', 'আমের আচার'] ,
['আম', 'আম গাছ', 'আমাসা মল', 'কাঁচা ফল', 'কামসখা', 'চ্যূত', 'পিকপ্রিয়', 'পিকবন্ধু', 'বসন্তদ্রুম', 'মাকন্দ.অলিপ্রিয়', 'রসাল.আম্র'] ,
['আমণ্ত্রণ', 'নিমণ্ত্রণ'] ,
['আমদানী', 'ইমপোর্ট'] ,
['আমদানীকৃত', 'ইম্পোর্টেড'] ,
['আমন্ত্রণ', 'নিমন্ত্রণ'] ,
['আমন্ত্রিত করা', 'ডাকা', 'তলব করা', 'নিমন্ত্রণ', 'নিমন্ত্রণ দেওয়া', 'নিমন্ত্রনা', 'নিমন্ত্রিত করা'] ,
['আমন্ত্রিত', 'নিমন্ত্রিত'] ,
['আমবন', 'আমবাগান'] ,
['আমবালা', 'আমবালা শহর'] ,
['আমমোক্তারনামা', 'ওকালতনামা', 'মোক্তারনামা'] ,
['আমল', 'সময়'] ,
['আমলকি', 'আমলকি গাছ'] ,
['আমলকী একাদশী', 'ফাগুনসুদী একাদশী', 'ফাল্গুন-শুক্ল একাদশী'] ,
['আমলকী', 'আমলা'] ,
['আমলা', 'সরকারি কর্মচারী'] ,
['আমশি', 'আমসি'] ,
['আমহেরিক', 'আমহেরিক ভাষা'] ,
['আমাজন', 'আমাজন নদী'] ,
['আমানত', 'গচ্ছিত দ্রব্য'] ,
['আমানা', 'দরজা'] ,
['আমাশা', 'আমাশা রোগ', 'আমাশয়', 'আমাশয় রোগ'] ,
['আমাশয়', 'উদর', 'উদরাশয়', 'কৌষ্ঠ্য', 'জঠর', 'পেট'] ,
['আমাহলুদ', 'হেমকান্তি'] ,
['আমিক্ষা', 'ছানা', 'পনীর'] ,
['আমিষ', 'আমিষ আহার', 'আমিষাহার', 'মাংসাহার'] ,
['আমিষহারী', 'আমিষাশী', 'মাংসখোর', 'মাংসভক্ষী', 'মাংসাহারী'] ,
['আমুদে', 'খোশমেজাজী', 'প্রসন্নচিত্ত', 'প্রসন্নমনা', 'মজাদার', 'রসিক'] ,
['আমেদাবাদ', 'আমেদাবাদ জেলা', 'আমেদাবাদ শহর'] ,
['আমেরিকা', 'ইউ এস এ', 'ইউএস', 'ইউএসএ', 'ইউনাইটেড স্টেটস অফ আমেরিকা', 'যুক্ত রাষ্ট্র', 'সংযুক্ত রাজ্য আমেরিকা'] ,
['আমেরিকান ডলার', 'ডলার'] ,
['আমেরিকান সামোয়া', 'এএস', 'পূর্ব সামোয়া'] ,
['আমোদ প্রমোদ করা', 'মজা', 'মনোরঞ্জন করা'] ,
['আমোদ প্রমোদ', 'আমোদ-প্রমোদ', 'বিনোদন', 'বিলাস', 'মনোরঞ্জন', 'রঙ্গরস'] ,
['আম্বাসা', 'আম্বাসা শহর'] ,
['আম্বিকেয়', 'ধৃতরাষ্ট্র'] ,
['আম্বেদকর নগর', 'আম্বেদকরনগর', 'আম্বেদকরনগর জেলা'] ,
['আম্মা', 'আম্মি', 'মা', 'মাতা'] ,
['আম্রপালী', 'আম্রপালী আম'] ,
['আম্লান', 'তাজা'] ,
['আর এন এ', 'রাইবোনিউক্লিক অম্ল', 'রাইবোনিউক্লিক অ্যাসিড'] ,
['আর ডব্লু সার্ভিস', 'রবার্ট উইলিয়াম সার্ভিস', 'সার্ভিস'] ,
['আর', 'এবার থেকে', 'পরবর্তীকালে', 'পিঙ্গল', 'পিতল', 'পেতল', 'রাজপত্রী', 'সুলোহক'] ,
['আর-টু', 'ফরগেট মি ড্রাগ', 'রোফি', 'সার্কিল', 'সার্কেল'] ,
['আরও ভআলো বানানো', 'উত্কৃষ্টতর বানানো'] ,
['আরকোল', 'কাকড়া'] ,
['আরক্ষক', 'প্ররক্ষক', 'রক্ষক', 'রক্ষা কর্তা', 'রক্ষী', 'সুরক্ষা কর্মী'] ,
['আরক্ষা বাহিনী', 'পুলিশ'] ,
['আরক্ষিত সেনাবাহিনী', 'রিজার্ভ ফোর্স'] ,
['আরণ্য', 'আরণ্যক', 'জংলী', 'বন্য'] ,
['আরণ্যক', 'জংলী', 'বন্য'] ,
['আরব', 'আরব গণরাজ্য', 'আরব দেশ', 'আরববাসী', 'আরবিস্তান'] ,
['আরবিআই', 'ভারতীয় রিজার্ভ ব্যাঙ্ক', 'রিজার্ভ ব্যাঙ্ক অফ ইন্ডিয়া'] ,
['আরবী', 'আরবী ঘোড়া', 'আরবী ভাষা', 'আরবী লিপি', 'তাজী'] ,
['আরমেনিয়', 'আরমেনিয়ান'] ,
['আরমেনিয়ান', 'আরমেনিয়ান ভাষা'] ,
['আরম্ভ করা', 'ওঠানো', 'তোলা', 'শুরু করা'] ,
['আরম্ভ কর্তা', 'আরম্ভক'] ,
['আরম্ভ', 'আরম্ভ হওয়া', 'প্রারম্ভ হওয়া', 'শুরু', 'শুরু হওয়া', 'সূত্রপাত'] ,
['আরশি', 'আয়না', 'দর্পণ', 'মুকুর'] ,
['আরা', 'আরা শহর', 'করাত'] ,
['আরাধনা করা', 'পূজা করা'] ,
['আরাধনাকারী', 'উপাসক', 'পূজারী', 'ভক্ত'] ,
['আরাধ্য', 'পূজ্য'] ,
['আরাবল্লী', 'আরাবল্লী পর্বতমালা'] ,
['আরাম করা', 'ক্লান্তি দূর করা', 'ক্লান্তি মেটানো', 'ঝিমানো', 'বিশ্রাম করা'] ,
['আরাম কুর্সি', 'আরামকেদারা'] ,
['আরাম কেদারা', 'কুরসি', 'কেদারা', 'চেয়ার'] ,
['আরাম', 'নিবৃত্তি', 'বিশ্রাম', 'ভোগ-বিলাস', 'মুক্তি', 'রেহাই', 'সুখ', 'স্বস্তি'] ,
['আরি', 'করাত'] ,
['আরুণেয়', 'আরুণেয় উপনিষদ', 'আরুণেয়োপনিষদ'] ,
['আরূঢ়', 'সওয়ার'] ,
['আরেখ', 'রূপরেখা', 'রেখা-চিত্র', 'রেখাচিত্র'] ,
['আরোগ্য নিকেতন', 'আরোগ্য শালা', 'স্বাস্থ্যনিবাস', 'স্যানিটোরিয়াম'] ,
['আরোগ্য বিজ্ঞান', 'স্বাস্থ্যবিজ্ঞান'] ,
['আরোগ্য', 'শরীর', 'স্বাস্থ্য'] ,
['আরোধক', 'প্রতিবন্ধক', 'রোধক'] ,
['আরোপ করা', 'লাগানো'] ,
['আরোপ মুক্ত', 'মুক্ত'] ,
['আরোহ', 'প্রাচীন পশুচর্ম'] ,
['আরোহক', 'আরোহিত'] ,
['আরোহণ', 'সওয়ারী'] ,
['আরোহী', 'আরোহী স্বর'] ,
['আর্কেটিক', 'আর্কেটিক ক্ষেত্র'] ,
['আর্চ', 'চাপ'] ,
['আর্জুমন্দ বোনা বেগম', 'মুমতাজ মহল', 'মুমতাজমহল'] ,
['আর্জেন্টিনা সম্পর্কিত', 'আর্জেন্টিনার', 'আর্জেন্টিনিয়ান', 'আর্জেন্টিনীয়'] ,
['আর্জেন্টিনাবাসী', 'আর্জেন্টিনিয়ান'] ,
['আর্ট গ্যালারী', 'চিত্রশালা'] ,
['আর্ত', 'দুঃখী', 'ব্যথিত'] ,
['আর্তনাদ করা', 'কাঁদা', 'চিল চিত্কার করা', 'তারস্বরে চিত্কার করা'] ,
['আর্তনাদ', 'আর্তস্বর'] ,
['আর্তি', 'কষ্ট', 'বেদনা'] ,
['আর্থিক অনুদান', 'আর্থিক সাহায্য'] ,
['আর্থিক পরামর্শদাতা পরিষদ', 'পিএমঈএসী'] ,
['আর্থিক মন্দা', 'রিসেশন'] ,
['আর্থিক সম্পত্তি', 'আর্থিক সাধন', 'দ্র্যবাত্মক সাধন'] ,
['আর্থিক সহায়তা', 'আর্থিক সাহায্য'] ,
['আর্থিক', 'টাকা-পয়সার', 'বিত্তসম্পর্কিত'] ,
['আর্দ্র করা', 'ভেজানো'] ,
['আর্দ্র ভূমি', 'আর্দ্র মাটি', 'আর্দ্র মৃত্তিকা', 'ভেজা মাটি'] ,
['আর্দ্র', 'আর্দ্রতা', 'ভেজা', 'সোঁদা', 'স্যাঁতসেতে'] ,
['আর্দ্রতা', 'সিক্ততা'] ,
['আর্ধা', 'সারঙ্গ'] ,
['আর্মি', 'পল্টন', 'সেনাদল'] ,
['আর্মেনিয়া বাসী', 'আর্মেনিয়ান'] ,
['আর্মেনিয়া', 'আর্মেনিয়া গণরাজ্য'] ,
['আর্মেনিয়ান', 'আর্মেনিয়ান লিপি'] ,
['আর্য বিবাহ', 'ঋষি বিবাহ'] ,
['আর্য', 'আর্য জাতি', 'আর্যজাতীয়', 'কুলীন', 'বৈদিক'] ,
['আর্য-গীতি', 'আর্যগীতি', 'আর্যগীতিকা'] ,
['আর্য-পুত্র', 'আর্যপুত্র'] ,
['আর্যা ছন্দ', 'আর্যাছন্দ'] ,
['আর্যাবর্ত', 'উত্তর ভারত'] ,
['আর্ষ প্রয়োগ', 'আর্ষ-প্রয়োগ', 'আর্ষপ্রয়োগ'] ,
['আর্ষ', 'আর্ষপ্রণীত', 'ঋষিপ্রণীত'] ,
['আল কায়দা', 'আলকায়দা'] ,
['আল মেগ্রীব', 'মরোক্কো'] ,
['আলগা করা', 'খোলা'] ,
['আলগা হওয়া', 'খুলে যাওয়া', 'খোলা'] ,
['আলগা হয়া যাওয়া', 'ঢিলে হওয়া'] ,
['আলজেরিয়ান', 'আলজেরিয়ার'] ,
['আলপিন', 'কাঁটা', 'পিন'] ,
['আলফান্সো', 'হাপুস', 'হাপুস আম'] ,
['আলবাই', 'পূর্ণা'] ,
['আলবেনিয়ান ভাষা', 'আলবেনীয় ভাষা'] ,
['আলবেনিয়ান', 'আলবেনিয়ান লিপি', 'আলবেনীয় লিপি'] ,
['আলবেনিয়াবাসী', 'আলবেনীয়'] ,
['আলমোড়া', 'আলমোড়া জেলা', 'আলমোড়া শহর'] ,
['আলসেস আলসেস', 'এল্ক'] ,
['আলস্যহীন', 'নিরলস'] ,
['আলস্যের', 'ক্লান্তির'] ,
['আলাঙ্গ', 'আলাঙ্গ শহর'] ,
['আলাদ করে দেওয়া', 'দূর করে দেওয়া', 'বার করে দেওয়া', 'হটিয়ে দেওয়া'] ,
['আলাদা আলাদা', 'পৃথক পৃথক', 'বিভিন্ন', 'ভিন্ন ভিন্ন'] ,
['আলাদা করা বস্তু', 'পৃথককৃত বস্তু'] ,
['আলাদা করা', 'ছাড়ানো', 'দূর করা', 'পৃথক করা', 'পৃথকীকরণ', 'বাছা', 'মিটিয়ে ফেলা', 'হঠানো'] ,
['আলাদা করে', 'স্বতন্ত্র ভাবে'] ,
['আলাদা রাখা', 'আলাদাভাবে রক্ষিত করা'] ,
['আলাদা হওয়া', 'পৃথক হওয়া', 'বেরিয়ে যাওয়া'] ,
['আলাদা', 'দূর'] ,
['আলাপ করার মতো', 'আলাপনীয়'] ,
['আলাপচারী', 'আলাপী'] ,
['আলাবামিন', 'এক-আয়োডিন', 'এস্টাটিন'] ,
['আলি', 'জলবন্ধক', 'বাঁধ', 'সেতু'] ,
['আলিগড়', 'আলিগড় জেলা', 'আলিগড় শহর'] ,
['আলিঙ্গন করা', 'জড়িয়ে ধরা'] ,
['আলিঙ্গন', 'গলা জড়িয়ে ধরা', 'সংগ্রহণ'] ,
['আলিপুর', 'আলিপুর জেলা'] ,
['আলু', 'আলুকি', 'কন্দ'] ,
['আলু-বালু', 'আলুবালু', 'ওলচি'] ,
['আলুকি', 'মিষ্টিআলু', 'রাঙ্গাআলু', 'শকরকন্দ'] ,
['আলুনি', 'আলুনো', 'লবণহীন'] ,
['আলেকিত', 'আলোপূর্ণ', 'দীপ্তিপূর্ণ'] ,
['আলো দেওয়া', 'আলো ফেলা'] ,
['আলো বাড়ানো', 'উদ্দীপিত করা', 'জ্যোতি বাড়ানো'] ,
['আলো', 'দীপক', 'দীপক রাগ', 'দীপ্তি', 'বাতি', 'লাইট'] ,
['আলোক-ভেদ্য', 'আলোকপ্রবাহী'] ,
['আলোকচিত্র গ্রহণ', 'আলোকচিত্রশিল্প', 'ফোটোগ্রাফি'] ,
['আলোকভেদ্য', 'পারদর্শক', 'স্বচ্ছ'] ,
['আলোকস্তম্ভ', 'বাতিঘর'] ,
['আলোকিত করা', 'উজ্জ্বল করা'] ,
['আলোকিত হওয়া', 'দীপ্তিময় হওয়া'] ,
['আলোচক', 'আলোচনাকারী'] ,
['আলোচনা গোষ্ঠী', 'আলোচনা সভা'] ,
['আলোচনা বিষয়ক', 'আলোচনাত্মক'] ,
['আলোচনা', 'কথোপকথন'] ,
['আলোড়িত', 'বিলোড়িত'] ,
['আলোর খুঁটি', 'ল্যাম্পপোস্ট'] ,
['আলোয়ান', 'ওড়না', 'চাদর', 'শাল'] ,
['আল্পস', 'আল্পস পর্বত'] ,
['আল্ফা', 'ইউনাইটেড লিবারাল ফ্রন্ট অফ আসাম'] ,
['আল্ফান্সো আম', 'হাপুস', 'হাপুস আম'] ,
['আল্লাহ', 'করিম', 'খোদা', 'মালিক'] ,
['আলয়', 'গৃহ', 'ধাম', 'নিকেতন', 'নিলয়', 'বাড়ি', 'সদন'] ,
['আশঙ্কা', 'খটকা', 'ভয়', 'শঙ্কা'] ,
['আশঙ্কাপূর্ণ', 'আশঙ্কিত', 'চিন্তিত'] ,
['আশঙ্কাহীন', 'নিঃশঙ্ক', 'শঙ্কাহীন'] ,
['আশা করা', 'চাওয়া', 'প্রত্যাশা করা'] ,
['আশা', 'আশা রাগ', 'প্রত্যাশা', 'বাসনা', 'শিহরণ'] ,
['আশাজনক', 'আশাব্যঞ্জক'] ,
['আশানুকূল', 'প্রত্যাশানুকূল', 'প্রত্যাশিত', 'যথাবাঞ্ছিত'] ,
['আশান্বিত', 'আশাপূর্ণ', 'আশাবাদী'] ,
['আশাহীন', 'হতাশ'] ,
['আশি', '৮০', '৮০,'] ,
['আশির্বাদ', 'তিলক'] ,
['আশিষ', 'আশীর্বাদ'] ,
['আশীবিষ', 'ফণী', 'ভুজঙ্গ', 'ভুজঙ্গম', 'সর্প', 'সাপ'] ,
['আশীর্বাদ দেওয়া', 'আশীষ দেওয়া'] ,
['আশুকারী', 'ক্ষিপ্রকারী'] ,
['আশেপাশে ঘোরা', 'ঘুরঘুর করা'] ,
['আশ্চর্য করে দেওয়া', 'হতচকিত করা', 'হয়রান করা'] ,
['আশ্চর্য কাণ্ড', 'সর্বনাশ'] ,
['আশ্চর্য পূর্বক', 'বিস্ময় পূর্বক', 'সবিস্ময়ে'] ,
['আশ্চর্য', 'আশ্চর্যজনক', 'আশ্চর্যান্বিত', 'চমত্কৃত', 'তাজ্জব', 'বিচিত্র', 'বিস্ময়'] ,
['আশ্চর্যচকিত হওয়া', 'ভ্যাবাচ্যাকা খাওয়া'] ,
['আশ্বস্ত', 'আশ্বাসনীয়', 'আশ্বাসিত'] ,
['আশ্বাস দানকারী', 'আশ্বাসক'] ,
['আশ্বাস', 'ভরসা', 'সান্ত্বণা'] ,
['আশ্বিনী পূর্ণিমা', 'কোজাগরী'] ,
['আশ্রম', 'আশ্রম সন্ন্যাসী', 'চতুরাশ্রম'] ,
['আশ্রমবাসী', 'আশ্রমী'] ,
['আশ্রিত হওয়া', 'নির্ভরশীল হওয়া'] ,
['আশ্রিত', 'আশ্রয়প্রাপ্ত', 'আশ্রয়ী', 'দাস', 'পরাবলম্বী', 'পরাশ্রিত', 'পরাশ্রয়ী'] ,
['আশ্রিতা', 'পরাবলম্বী', 'পরাশ্রিতা'] ,
['আশ্রেয়', 'আশ্রেয়ণীয়'] ,
['আশ্রয় দেওয়া', 'শরণ দেওয়া', 'স্থাপন করা'] ,
['আশ্রয় নেওয়া', 'শরণ নেওয়া'] ,
['আশ্রয় স্থল', 'আশ্রয়স্থল', 'আশ্রয়স্থান', 'শরণস্থল'] ,
['আশ্রয়', 'উদ্দেশ্য', 'ছত্রছায়া'] ,
['আশ্রয়হীন', 'উদ্বাস্তু', 'গৃহহীন', 'নিরাশ্রয়'] ,
['আশ্রয়হীনতা', 'নিরাশ্রয়তা'] ,
['আষাঢ় কৃষ্ণ একাদশী', 'যোগিনী একাদশী'] ,
['আষাঢ়', 'আষাঢ়মাস'] ,
['আষাঢ়জাত', 'আষাঢ়সম্বন্ধীয়', 'আষাঢ়ীয়'] ,
['আষাঢ়ি', 'খারিফ'] ,
['আষাঢ়ী পূর্ণিমা', 'গুরু পূর্ণিমা'] ,
['আসন গ্রহণ করা', 'আসীন হওয়া', 'বসা', 'বসে থাকা', 'বিরাজ করা'] ,
['আসন', 'কুশাসন', 'জায়গা', 'বসার জায়গা', 'যোগমুদ্রা', 'যোগাসন', 'সিট'] ,
['আসন্ন প্রসবা', 'আসন্নপ্রসবা'] ,
['আসন্ন', 'সন্নিকট'] ,
['আসবাবপত্র', 'ফার্নিচার'] ,
['আসল তথ্য', 'তথ্য'] ,
['আসল', 'খাঁটি', 'খাদহীন', 'ধণ', 'নির্ভেজাল', 'পুঁজি', 'বিশুদ্ধ', 'বিশুদ্ধ চক্র', 'ভালো', 'মূল', 'মূলধণ', 'শুদ্ধ'] ,
['আসলে', 'বস্তুতঃ', 'বাস্তবে', 'সত্যি সত্যি'] ,
['আসা যাওয়া', 'যাতায়াত'] ,
['আসা', 'ওঠা', 'পড়া'] ,
['আসালা', 'চন্দ্রশূর', 'চন্সুর', 'সুয়াসরা', 'হালোংজোপিডিয়াম সেটিবাম'] ,
['আসীন', 'বসে থাকা', 'বিরাজমান উপবিষ্ট'] ,
['আসূতি', 'জনন', 'প্রসব'] ,
['আস্কারা দেওয়া', 'ছাড় দেওয়া'] ,
['আস্কারা', 'প্রশ্রয়'] ,
['আস্চর্য হওয়া', 'তাজ্জব হওয়া', 'বিস্ময় হওয়া'] ,
['আস্তরণ', 'ধাতুর পাত', 'পাত'] ,
['আস্তার-পংক্তি', 'আস্তারপংক্তি'] ,
['আস্তিক', 'আস্তিক ঋষি', 'ঈশ্বরনিষ্ঠ', 'ঈশ্বরবাদী'] ,
['আস্তিকতাবাদ', 'ঈশ্বর নিষ্ঠা', 'ঈশ্বরবাদ'] ,
['আস্তিন', 'হাতা'] ,
['আস্তে', 'আস্তে করে', 'ধীরে'] ,
['আস্থা', 'নিষ্ঠা', 'শ্রদ্ধা'] ,
['আস্ফালন করা', 'তড়পানো'] ,
['আস্মারা', 'আস্মেরা'] ,
['আস্রাব', 'থুতু'] ,
['আহত হওয়া', 'ঘায়েল হওয়া'] ,
['আহত', 'ঘায়েল'] ,
['আহবা', 'আহবা শহর'] ,
['আহমেদনগর', 'আহমেদনগর জেলা'] ,
['আহরণ', 'সংগ্রহ'] ,
['আহাম্মক', 'নির্বুদ্ধি', 'বুদ্ধু', 'বেওকুফ', 'বোকা', 'মুর্খ'] ,
['আহার ব্যাঞ্জন', 'ব্যাঞ্জন'] ,
['আহার মাত্রা', 'খোরাক'] ,
['আহার', 'ভক্ষ্য', 'ভোজন', 'শিকার'] ,
['আহার-বিহার', 'আহারবিহার'] ,
['আহারপাক', 'বিপাক', 'হজম', 'হজম ক্রিয়া', 'হজম হওয়া'] ,
['আহুত', 'ব্রহ্মযজ্ঞ'] ,
['আহুতি', 'আহুতি দান', 'হবি', 'হবিষ্', 'হব্য', 'হোম'] ,
['আয় কর বিভাগ', 'আয়কর বিভাগ', 'ইনকাম ট্যাক্স বিভাগ'] ,
['আয় কর', 'আয়কর', 'ইনকাম ট্যাক্স'] ,
['আয় ব্যয়', 'আয়ব্যয়'] ,
['আয়', 'রোজগার'] ,
['আয়ত', 'বিস্তারিত', 'বিস্তৃত'] ,
['আয়তন', 'প্রসার', 'বিস্তার', 'বিস্তৃতি'] ,
['আয়তাকার', 'সমকোণ', 'সমভূজ'] ,
['আয়না', 'দর্পণ'] ,
['আয়নাকার', 'ক্ষৌরকার', 'নাপিত', 'মুন্ডক'] ,
['আয়রন', 'ইস্ত্রী', 'প্রেস'] ,
['আয়া', 'দাই', 'দাইমা'] ,
['আয়ান', 'আয়ান ঘোষ'] ,
['আয়াম', 'চতুর্থ আয়াম', 'সময়'] ,
['আয়ার্ল্যাণ্ড', 'আয়ার্ল্যাণ্ড দ্বীপ'] ,
['আয়াস', 'পরিশ্রম', 'শ্রম'] ,
['আয়ু', 'ইহকাল', 'জীবন', 'জীবন কাল', 'জীবনকাল', 'বয়স'] ,
['আয়ুর্বেদ চিকিত্সক', 'কবিরাজ', 'বৈদ্য'] ,
['আয়ুষ্মান', 'চিরঞ্জীবী', 'দীর্ঘজীবী', 'দীর্ঘায়ু'] ,
['আয়েশী', 'বিলাসী', 'ভোগপরায়ণ', 'ভোগবিলাসী'] ,
['আয়োজক', 'আয়োজনকারী'] ,
['আয়োজন', 'তোড়জোড়', 'প্রস্তুতি', 'বন্দোবস্ত', 'ব্যবস্থা', 'ব্যবস্থাপনা'] ,
['আয়োদ ঋষি', 'ধৌম্য', 'ধৌম্য ঋষি'] ,
['ই বি হোয়াইট', 'এলিয়ন ব্রুক্স হোয়াইট', 'হোয়াইট'] ,
['ই', 'স্বরবর্ণ ই'] ,
['ই-পত্র', 'ই-মেল'] ,
['ইঁট', 'বাঁট'] ,
['ইঁদুর', 'বজ্রদন্ত', 'মুষিক'] ,
['ইংরাজী', 'ইংরাজী ভাষা', 'ইংলিশ'] ,
['ইংলিশ', 'সাইড'] ,
['ইউ এ ই', 'ইউনাইটেড আরব আমিরাত', 'সংযুক্ত আরব আমিরাত'] ,
['ইউ এস এস আর', 'রাশিয়া', 'সোভিয়েত রাষ্ট্রসংঘ', 'সোভিয়েত সঙ্ঘ'] ,
['ইউক্রেনবাসী', 'ইউক্রেনী'] ,
['ইউক্রেনী', 'ইউক্রেনী ভাষা'] ,
['ইউনাইটেড আরব আমিরাত দিরেম', 'দিরেম'] ,
['ইউনাইটেড নেশনস্', 'সংযুক্ত রাষ্ট্রসংঘ'] ,
['ইউনাইটেড', 'ব্রিটেন'] ,
['ইউনান', 'গ্রীস', 'গ্রীস দেশ'] ,
['ইউনানি লিপি', 'গ্রীক লিপি'] ,
['ইউনানি', 'গ্রীক'] ,
['ইউনিট', 'একক', 'একক স্থান'] ,
['ইউনিফর্ম', 'পরিচ্ছদ'] ,
['ইউনিসেফ', 'জাতিসংঘ শিশু তহবিল'] ,
['ইউনিয়ন', 'কেন্দ্রীয় শাসন', 'সংগঠন', 'সঙ্ঘ'] ,
['ইউনেস্কো', 'সংযুক্ত রাষ্ট্র শিক্ষা বিষয়ক বৈজ্ঞানিক এবং সাংস্কৃতিক সংগঠন'] ,
['ইউপিয়া', 'ইউপিয়া শহর'] ,
['ইউরাল', 'ইউরাল পর্বত'] ,
['ইউরিয়া', 'কার্বামাইড'] ,
['ইউরেনাস', 'য়ুরেনাস'] ,
['ইউরোপ', 'য়ুরোপ'] ,
['ইউরোপিয়ান', 'ইউরোপীয়'] ,
['ইকওয়েডর বাসী', 'ইকওয়েডরিয়ান'] ,
['ইকওয়েডর', 'ইকওয়েডর গণতন্ত্র', 'ইকওয়েডর গণরাজ্যে'] ,
['ইকুয়েডরীয়', 'ইকুয়েডরের'] ,
['ইকোয়েটোরিয়াল গিনি', 'ইকোয়েটোরিয়াল গিনি গণরাজ্য'] ,
['ইক্ষণিক', 'সামুদ্রিক', 'হস্তরেখা পন্ডিত', 'হস্তরেখা বিশেষজ্ঞ', 'হস্তরেখাবিদ্'] ,
['ইক্ষুগন্ধা', 'গোখরু', 'পিকাক্ষ'] ,
['ইক্ষুমতী', 'ইক্ষুমতী নদী'] ,
['ইখরাজ', 'উখভোজ', 'উখরাজ'] ,
['ইঙ্গলা', 'ইড়া', 'ইড়া নাড়ী', 'চন্দ্র নাড়ী'] ,
['ইঙ্গিত', 'ইশারা', 'সাংকেতিক'] ,
['ইঙ্গুদ', 'তীক্ষ্ণকন্টক', 'পুটিকন্টক', 'পুতিগন্ধ', 'পৃথুকা', 'হিঙ্গোট'] ,
['ইচ্ছা পূর্ণ', 'ইচ্ছা পূর্তি', 'ইচ্ছা প্রাপ্তি', 'কামনা-সিদ্ধি'] ,
['ইচ্ছা প্রকাশ করা', 'কামনা করা', 'চাওয়া'] ,
['ইচ্ছা শক্তি', 'ইচ্ছাশক্তি'] ,
['ইচ্ছা সহকারে', 'নিজের খুশিতে', 'স্বেচ্ছাপূর্বক', 'স্বেচ্ছায়'] ,
['ইচ্ছা হওয়া', 'শখ হওয়া'] ,
['ইচ্ছাকরে', 'ইচ্ছাপূর্বক', 'জেনেবুঝে'] ,
['ইচ্ছাচারী', 'স্বেচ্ছাগামী'] ,
['ইচ্ছানুকুল', 'ইচ্ছানুসারে', 'যথাবাঞ্ছিত', 'যথেচ্ছ'] ,
['ইচ্ছাপত্রহীন', 'উইলবিহীন'] ,
['ইচ্ছাপূর্ণতা', 'কামনাপূর্ণতা', 'মনোরথপূর্ণতা'] ,
['ইচ্ছামৃত্যু', 'দয়া-মৃত্যু', 'মার্সি কিলিং'] ,
['ইজরায়েল বাসী', 'ইজরায়েলী'] ,
['ইজাফত', 'জের'] ,
['ইজারাদার', 'ঠিকাদার'] ,
['ইজারাদারি', 'ইজারাদারী', 'ঠিকাদারি', 'ঠিকাদারী', 'ঠিকেদারি', 'ঠিকেদারী'] ,
['ইজ্জত', 'নাম', 'নাম-ডাক', 'প্রতিষ্ঠা', 'মর্যাদা', 'মান-সম্মান', 'সমাদর', 'সম্মান'] ,
['ইঞ্জিন', 'ইঞ্জিন চালক যন্ত্র', 'চালক যন্ত্র'] ,
['ইঞ্জিনিয়ার', 'যন্ত্রকুশলী', 'যন্ত্রবিদ্'] ,
['ইঞ্জিনিয়ারিং', 'যন্ত্রবিদ্যা'] ,
['ইঞ্জেকশান লাগানো', 'সুঁচ লাগানো'] ,
['ইটাবা', 'ইটাবা জেলা'] ,
['ইটালিয়ান', 'ইটালীয় ভাষা', 'ইতালীয়'] ,
['ইটালীবাসী', 'ইটালীয়'] ,
['ইড়া-পিঙ্গলা-সুষুম্না সঙ্গম', 'ত্রিবেণী'] ,
['ইডেন', 'ইডেনগার্ডেন'] ,
['ইণ্টারভিউ', 'মৌখিক পরীক্ষা', 'সাক্ষাত্কার'] ,
['ইণ্টিরিয়ার', 'ইণ্টিরিয়ার বিভাগ', 'ডিপার্টমেণ্ট অফ দ্যা ইণ্টিরিয়ার'] ,
['ইণ্ডিক', 'ইন্দো-আর্য', 'ইন্দো-আর্যান'] ,
['ইণ্ডিয়ানা', 'ইন'] ,
['ইতস্ততঃ', 'এদিক-ওদিক', 'যেখানে-সেখানে'] ,
['ইতালিয়ান রাইস', 'ইতালীয় ভাত'] ,
['ইতালিয়ান লিরা', 'ইতালীয় লিরা', 'লিরা'] ,
['ইতিবৃত্ত', 'ইতিহাস', 'পুরনো কথা', 'পুরা কথা', 'পুরাখ্যান', 'পৌরাণিক কথা'] ,
['ইতিহাসজ্ঞ', 'ইতিহাসবিদ', 'ঐতিহাসিক'] ,
['ইথিয়োপিয়ান', 'ইথিয়োপিয়ার', 'ইথিয়োপীয়'] ,
['ইদুক্কী', 'ইদুক্কী জেলা'] ,
['ইনফ্লুয়েঞ্জা', 'ফ্লু'] ,
['ইনসিওরেন্স', 'বীমা'] ,
['ইনস্ট্রুমেণ্টাল রোল', 'করণের ভূমিকা'] ,
['ইনস্পেক্টর', 'নিরীক্ষক', 'নিরীক্ষণকারী'] ,
['ইন্টারনেট সাইট', 'ওয়েবসাইট', 'সাইট'] ,
['ইন্টারনেট সার্ভিস প্রোভাইডার', 'ইন্টারনেট সেবা প্রদাতা', 'সার্ভিস প্রোভাইডার'] ,
['ইন্টারনেট', 'নেট'] ,
['ইন্ডিয়া', 'ভারত', 'ভারত বর্ষ', 'ভারতবর্ষ', 'হিন্দ', 'হিন্দুস্তান'] ,
['ইন্ডিয়ান পিনাল কোড', 'ভারতীয় দণ্ড বিধি', 'ভারতীয় দণ্ড সংহিতা'] ,
['ইন্দও', 'মত্তগয়ন্দ', 'মালতী'] ,
['ইন্দিবর', 'নীলকমল', 'নীলপদ্ম', 'নীলেন্দু'] ,
['ইন্দিরা', 'ইন্দিরা গান্ধী'] ,
['ইন্দু কলা', 'কলা', 'চন্দ্রকলা', 'শশীখণ্ড'] ,
['ইন্দু-বদনা', 'ইন্দুবদনা'] ,
['ইন্দুকর', 'চন্দ্রকিরণ', 'চন্দ্ররশ্মি', 'চন্দ্ররেখা', 'চন্দ্রালোক', 'চন্দ্রিমা'] ,
['ইন্দুজা', 'নর্মদা', 'নর্মদা জেলা', 'পূর্বগঙ্গা', 'বেদগর্ভা', 'রেবা', 'সোমসুতা', 'সোমোদ্রবা'] ,
['ইন্দুবদনা', 'চন্দ্রবদনা', 'চন্দ্রমুখী'] ,
['ইন্দুমণি', 'চন্দ্রকান্ত', 'চন্দ্রকান্ত মণি'] ,
['ইন্দোনেশিয়ান', 'ইন্দোনেশীয়', 'বাহাসা'] ,
['ইন্দ্র কুমার গুজরাল', 'ইন্দ্রকুমার গুজরাল'] ,
['ইন্দ্র দমন', 'ইন্দ্রদমন'] ,
['ইন্দ্র সাবর্ণি মনু', 'ইন্দ্রসাবর্ণি', 'ভৌত্য', 'ভৌত্যমনু'] ,
['ইন্দ্রগিরি', 'মহেন্দ্র পর্বত', 'মহেন্দ্রাচল'] ,
['ইন্দ্রজব', 'ইন্দ্রজৌ', 'ইন্দ্রফল', 'যবফল'] ,
['ইন্দ্রজাল', 'চমত্কার', 'জাদু', 'প্রপঞ্চ', 'ভেলকি', 'মায়া', 'যাদু'] ,
['ইন্দ্রজিত্', 'মেঘনাদ'] ,
['ইন্দ্রপুরোহিতা', 'তিষ্য', 'পুষ্প', 'পুষ্প নক্ষত্র', 'পুষ্যা', 'পুষ্যা নক্ষত্র'] ,
['ইন্দ্রসভা', 'ইন্দ্রের সভা'] ,
['ইন্দ্রসেন', 'বলি', 'বলিদান', 'বিরোচন-সুত', 'রাজা বলি'] ,
['ইন্দ্রা', 'ইন্দ্রাণী', 'ঐন্দ্রাণী', 'দেবরানি', 'পুলোমজা', 'পৌলমী', 'বাসবী', 'শচী'] ,
['ইন্দ্রাণী', 'বাঁ চোখের মণি'] ,
['ইন্দ্রাস্ত্র', 'তুঞ্জ', 'বজ্র', 'বজ্রশনি', 'বহুধার'] ,
['ইন্দ্রিয়', 'গো', 'জ্ঞানেন্দ্রিয়', 'ধাতু', 'বীর্য'] ,
['ইন্দ্রিয়জিত্', 'জিতেন্দ্রিয়'] ,
['ইন্দ্রিয়জয়', 'সংযম'] ,
['ইন্দ্রিয়নিগ্রহ', 'প্রত্যাহার'] ,
['ইন্দ্রিয়ারাম', 'বিষয়াসক্ত', 'ভোগাসক্ত', 'ভোগী'] ,
['ইন্ধন', 'জ্বালানি'] ,
['ইন্নর', 'পেউস', 'পেউসরী', 'পেউসী'] ,
['ইন্সট্রাকশন', 'কমাণ্ড', 'স্টেটমেন্ট'] ,
['ইন্সপেক্টর জেনারেল', 'মহানিরীক্ষক'] ,
['ইবাদত-খানা', 'মসজিদে'] ,
['ইমন', 'ইমন-রাগ'] ,
['ইমন-কল্যাণ', 'ইমনকল্যাণ'] ,
['ইমাম-বাড়া', 'ইমামবাড়া'] ,
['ইমামী', 'ইমামের'] ,
['ইমারত', 'বাড়ি', 'ভবন'] ,
['ইম্ফল পশ্চিম', 'ইম্ফল পশ্চিম জেলা'] ,
['ইম্ফল পূর্ব', 'ইম্ফল পূর্ব জেলা'] ,
['ইম্যুন সিস্টেম', 'প্রতিরক্ষা তন্ত্র', 'প্রতিরক্ষী তন্ত্র', 'সংক্রাম্য তন্ত্র', 'সংক্রাম্যতন্ত্র'] ,
['ইম্যুনিটি', 'রোগ প্রতিরোধক ক্ষমতা'] ,
['ইরবিন', 'ইরবিন আম'] ,
['ইরাকবাসি', 'ইরাকী'] ,
['ইরাকি ঘোড়া', 'ইরাকের ঘোড়া'] ,
['ইরাকি দিনার', 'দিনার'] ,
['ইরাকী', 'ইরাকী ভাষা'] ,
['ইরাডিয়েটেড -ডাইহাইড্রোঅর্গোস্ট্রোল', 'খাদ্যজ ডি ', 'ভিটামিন ডি '] ,
['ইরানি দিনার', 'দিনার'] ,
['ইরানী', 'পার্সিয়ান'] ,
['ইরাবতী', 'ভদ্রমদা'] ,
['ইরুড় জেলা', 'ইরোড জেলা'] ,
['ইরুড়', 'ইরুড় শহর'] ,
['ইরেজ়ার', 'রবার'] ,
['ইর্শিতা', 'ইর্শিত্ব'] ,
['ইলা', 'কাদম্বরী', 'জ্ঞানদা', 'বাগেশ্বরী', 'বাগ্দেবী', 'বিমলা', 'বীণাবাদিনি', 'বুদ্ধিমতি', 'বুদ্ধিমতি নারী', 'ব্রহ্মাণী', 'ব্রাহ্মী', 'ভারতী', 'মহাশ্বেতা', 'শারদা', 'শুক্লা', 'শ্বেতপদ্মাসনা', 'শ্বেতা', 'সরস্বতী', 'হংসবাহিনী'] ,
['ইলাবর্ত্ত', 'ইলাবৃত'] ,
['ইলাহী-গজ', 'ইলাহীগজ'] ,
['ইলিশ', 'ইলিশ মাছ'] ,
['ইলেকট্রিক তাঁত', 'পাওয়ারলুম'] ,
['ইলেকট্রিক', 'বৈদ্যুতিন'] ,
['ইলেরু', 'ইলেরু শহর'] ,
['ইল্ম-শাহী', 'ইল্মশাহী'] ,
['ইশারা করা', 'সংকেত দেওয়া'] ,
['ইশারা', 'সাংকেতিক কথন'] ,
['ইষ', 'যুগন্ধর', 'হলদন্ড'] ,
['ইসবগুল', 'ইসবগোল'] ,
['ইসরো', 'ভারতীয় অন্তরিক্ষ অনুসন্ধান কেন্দ্র', 'ভারতীয় অন্তরিক্ষ অনুসন্ধান সংগঠন'] ,
['ইসলাম', 'ইসলাম ধর্মের'] ,
['ইস্কন', 'হরে কৃষ্ণ'] ,
['ইস্ট', 'খমির', 'খামি', 'খামির', 'খামিরা', 'খাম্বিরা', 'গাঁজ'] ,
['ইস্টইন্ডিজ', 'মলয় দ্বীপপুঞ্জ'] ,
['ইস্তখার', 'প্রার্থনা'] ,
['ইস্তফা', 'পদত্যাগপত্র'] ,
['ইস্তাহার', 'বিজ্ঞাপন'] ,
['ইস্তাহারী', 'বিজ্ঞাপিত'] ,
['ইস্তেহার', 'পোস্টার', 'প্রচার', 'বিজ্ঞপ্তি', 'বিজ্ঞাপন', 'ম্যনিফেস্টো'] ,
['ইস্তোনিয়ান', 'ইস্তোনীয়'] ,
['ইস্তোনিয়ার', 'ইস্তোনীয়'] ,
['ইস্ত্রি করা', 'পালিশ করা'] ,
['ইহলোক', 'পৃথিবী', 'মর্ত্য', 'মর্ত্যলোক', 'সংসার'] ,
['ইহলৌকিক', 'লৌকিক', 'সাংসারিক'] ,
['ইহুদী', 'ইহুদী ধর্ম', 'হিব্রু'] ,
['ইয়ত্তা', 'মর্যাদা', 'সীমা'] ,
['ইয়ারফোন', 'কর্ণভাষ', 'হেডফোন'] ,
['ইয়ার্কি মারা', 'ঠাট্টা করা', 'মজা করা'] ,
['ইয়ার্কি', 'উপহাস', 'পরিহাস'] ,
['ইয়ুরোপীয় দেশ', 'ইয়ুরোপীয় রাষ্ট্র'] ,
['ইয়েতি', 'হিমমানব'] ,
['ইয়েমেন বাসী', 'ইয়েমেনি'] ,
['ইয়েমেন', 'ইয়েমেন গণরাজ্য'] ,
['ইয়েমেনি রিয়ালে', 'রিয়াল'] ,
['ইয়েলোহ্যামার', 'তুতী'] ,
['ঈ', 'স্বরবর্ণ ঈ'] ,
['ঈকুল হওয়া', 'উচাটন হওয়া', 'উদ্বিগ্ন হওয়া'] ,
['ঈঙ্গিত দেওয়া', 'সংকেত দেওয়া'] ,
['ঈজিপ্ট', 'মিশর', 'মিশরীয় সাম্রাজ্য', 'মিশরের আরব গণতন্ত্র', 'সংযুক্ত আরব গণতন্ত্র'] ,
['ঈজিপ্সিয়ান পাউন্ড', 'মিশরীয় পাউন্ড'] ,
['ঈজিপ্সিয়ান', 'মিশরীয়'] ,
['ঈদ', 'ঈদ-উল-ফিতর'] ,
['ঈদ-উল-জোহা', 'বকরি-ঈদ'] ,
['ঈর্ষতঃ', 'ঈর্ষাপূর্বক', 'দ্বেষপূর্বক'] ,
['ঈর্ষা করা', 'জ্বলা'] ,
['ঈর্ষাপূর্ণ', 'দ্বেষপূর্ণ', 'বিদ্বেষপূর্ণ'] ,
['ঈর্ষাপূর্ণতা', 'ঈর্ষালুতা', 'দ্বেষপূর্ণতা'] ,
['ঈশা', 'ঈশামসী', 'ঐশ্বর্যময়ী স্ত্রী', 'ঐশ্বর্যা', 'খ্রীষ্ট', 'যীশু'] ,
['ঈশান', 'ঈশান কোণ', 'উত্তর পূর্ব', 'উত্তর-পূর্ব', 'উত্তরপূর্ব'] ,
['ঈশারা', 'গুপ্ত সংকেত'] ,
['ঈশ্বর প্রণিধান', 'ঈশ্বর-প্রণিধান', 'ঈশ্বরপ্রণিধান'] ,
['ঈশ্বর বিহীন', 'ঈশ্বর রহিত'] ,
['ঈশ্বর', 'ভগবান'] ,
['ঈশ্বরত্ব', 'প্রভুতা', 'প্রভুত্ব'] ,
['ঈশ্বরদূত', 'দেবদূত', 'পৈগম্বর', 'রসূল'] ,
['ঈশ্বরনিষ্ঠ', 'ঈশ্বরপরায়ণ'] ,
['ঈশ্বরপ্রদত্ত', 'ভগবানপ্রদত্ত'] ,
['ঈশ্বরহীন', 'নিরীশ্বর', 'প্রভুহীন'] ,
['ঈশ্বরী', 'শক্তি'] ,
['ঈশ্বরীয়', 'পরমেশ্বরীয়'] ,
['ঈষিকা', 'চোখের মণি'] ,
['উ', 'স্বরবর্ণ উ'] ,
['উঁগনী', 'ঔঁগাই'] ,
['উঁচু করা', 'ওঠানো'] ,
['উঁচু হওয়া', 'ওঠা'] ,
['উঁচু', 'উচ্চ', 'উত্তঙ্গ', 'উন্নত', 'ওঠা', 'তুঙ্গ', 'দৃঢ়', 'লম্বা', 'শ্রেষ্ঠ'] ,
['উঁজ্জরী', 'উঁজ্জারী', 'উজারী'] ,
['উইপোকা', 'ঘুনপোকা'] ,
['উইল', 'সম্পত্তি'] ,
['উইলিয়াম ক্লাউড ডাকেনফিল্ড', 'ফিল্ডস'] ,
['উইলিয়াম নগর', 'উইলিয়ামনগর'] ,
['উইলিয়াম শেক্সপীয়ার', 'শেক্সপীয়ার'] ,
['উকাব', 'রাঘর'] ,
['উকারি', 'উকারি বাঁদর'] ,
['উকি', 'ক্ষুদ্রিকা', 'হিক্কা', 'হৃল্লাস', 'হেঁচকি'] ,
['উকিলের নিয়োগপত্র', 'ওকালতনামা'] ,
['উকো', 'উখা', 'কুঁদ', 'ফাইল', 'রেত', 'রেতি'] ,
['উখরুল', 'উখরুল জেলা', 'উখরুল শহর'] ,
['উখলি', 'উদূখল', 'খল', 'হামানদিস্তা'] ,
['উখাড়', 'উখেড়'] ,
['উখালিয়া', 'ব্রতের আগে আহারগ্রহণ'] ,
['উগদ', 'জংলি ডুঙ্গি'] ,
['উগরে দেওয়া', 'থুতু ফেলা'] ,
['উগান্ডা নিবাসী', 'উগান্ডান', 'উগান্ডাবাসী'] ,
['উগার', 'উগ্গার'] ,
['উগ্গাহ', 'উগ্গাহা'] ,
['উগ্র বিষ', 'হলাহল'] ,
['উগ্র মহিলা', 'চন্ডিকা', 'চন্ডী', 'ঝগড়ুটে মহিলা'] ,
['উগ্র', 'কঠোর', 'কড়া', 'করুণাহীন', 'ক্রূর', 'তীক্ষ্ণ', 'তীব্র', 'দুর্দম', 'দয়ারহিত', 'দয়াহীন', 'নির্দয়', 'নির্দয়ী', 'নৃশংস', 'প্রচণ্ড', 'প্রবল', 'বস্তনাভ', 'বিকট', 'ভীষণ', 'ভয়ঙ্কর', 'রূঢ়'] ,
['উগ্রগন্ধা', 'উগ্রা', 'ঘোড়বচ', 'জীবা', 'রক্তা', 'শতপর্ণিকা', 'শতপর্বা', 'শতপর্বিকা'] ,
['উগ্রচণ্ডা', 'কর্কশ', 'চণ্ডিকা', 'চণ্ডী', 'ঝগড়াটি'] ,
['উগ্রতা', 'বিভীষিকা', 'ভীষণতা ভয়াবহতা', 'রুক্ষতা'] ,
['উগ্রপন্থী', 'উগ্রবাদী'] ,
['উচাটন', 'উদাসীনতা', 'ঔদাসীন্য', 'বিরক্তি', 'বৈরাগ্য'] ,
['উচিত', 'উপযুক্ত', 'ঠিক', 'নীতিপূর্ণ', 'নৈতিক', 'নৈতিকতাপূর্ণ', 'যথাযথ', 'সঠিক'] ,
['উচ্চ অংশ', 'উপরী ভাগ', 'শীর্ষ ভাগ'] ,
['উচ্চ অধিকার প্রাপ্ত', 'উচ্চ অধিকারিক'] ,
['উচ্চ আয়োগ', 'হাই কমিশন'] ,
['উচ্চ কমিশন', 'হাই কমিশন'] ,
['উচ্চ কূল', 'উচ্চ বংশ', 'কূলীন পরিবার', 'কূলীন বংশ'] ,
['উচ্চ পদাধিকারি', 'উচ্চাধিকারি', 'বরিষ্ঠ অধিকারি'] ,
['উচ্চ বংশ', 'কুলীন বংশ', 'প্রসিদ্ধ বংশ'] ,
['উচ্চ বর্গ', 'কুলীন কুল', 'কুলীন বর্গ'] ,
['উচ্চ বিচারালয়', 'হাই কোর্ট'] ,
['উচ্চ মর্যাদাসম্পন্ন ব্যক্তি', 'হাই কমিশনার'] ,
['উচ্চ রক্তচাপ', 'হাই ব্লাডপ্রেসার', 'হাইপার টেনশন'] ,
['উচ্চ', 'তার'] ,
['উচ্চ-স্তরীয়', 'উচ্চস্তরীয়'] ,
['উচ্চতম বিচারালয়', 'সর্বোচ্চ বিচারালয়', 'সুপ্রিম কোর্ট'] ,
['উচ্চতা', 'শীর্ষ'] ,
['উচ্চনাদ', 'ডাক', 'বৃংহন'] ,
['উচ্চপদস্থ', 'উচ্চপদাধিকারী', 'উচ্চপদাধিষ্ঠিত', 'উচ্চপদাসীন'] ,
['উচ্চবংশজাত', 'কুলীন', 'কুলীন ব্যক্তি'] ,
['উচ্চবর্গীয় স্তন্যপায়ী প্রাণী', 'প্রাইমেট'] ,
['উচ্চাকাঙ্খা', 'স্বপ্ন'] ,
['উচ্চারণ করা', 'বলা'] ,
['উচ্চারণ করে পড়া', 'জোরে জোরে পড়া', 'পাঠ করা'] ,
['উচ্চারণ স্থল', 'উচ্চারণ স্থান'] ,
['উচ্চৈঃশ্রবা', 'উচ্চৈঃশ্রবা ঘোড়া'] ,
['উচ্ছল', 'উচ্ছৃঙ্খল', 'তরঙ্গায়িত', 'ধৃষ্ট'] ,
['উচ্ছিষ্ট', 'উচ্ছিষ্ট ভোজন', 'ভুক্তাবশেষ'] ,
['উচ্ছে', 'ত্রিফলিকা'] ,
['উচ্ছেদ করা', 'সরানো'] ,
['উচ্ছেদ বাদ', 'উচ্ছেদবাদ'] ,
['উচ্ছেদ', 'উত্পাটন'] ,
['উচ্ছেদন', 'ওপড়ানো'] ,
['উজবেক', 'উজবেকি', 'উজবেকিস্তানবাসী'] ,
['উজবেকিস্তানি সোম', 'সোম'] ,
['উজলী', 'গৈবর'] ,
['উজ়ানো', 'ছড়ানো'] ,
['উজাড়', 'ধ্বংস', 'ধ্বস্ত', 'শেষ'] ,
['উজিরালি', 'উজিরি', 'দেওয়ানি'] ,
['উজীর', 'দেওয়ান', 'মন্ত্রী', 'মিনিস্টার'] ,
['উজ্জাসন', 'মারণ'] ,
['উজ্জ্বল করা', 'উজ্জ্বলতা আনা', 'চকচকে করা', 'চমক আনা', 'পরিষ্কার করা', 'সাফ করা'] ,
['উজ্জ্বল', 'কান্তিমান', 'জ্যোতিসম্পন্ন', 'ঝকঝকে', 'ধবল', 'ধলা', 'পরিষ্কার', 'প্রদীপ্ত', 'রজত', 'শুক্ল', 'শুভ্র', 'শ্বেত', 'সাদা'] ,
['উজ্জয়িনী', 'উজ্জয়িনী জেলা'] ,
['উট', 'উষ্ট্র', 'রথ'] ,
['উটি', 'উধগমণ্ডলম'] ,
['উঠানো', 'উঠিয়ে দেওয়া', 'ওঠানো', 'জাগানো'] ,
['উঠে আসা', 'তৈরী হওয়া'] ,
['উঠে যাওয়া', 'উড়ে যাওয়া', 'ওঠা', 'ফিকে হয়ে যাওয়া', 'শেষ হওয়া', 'সমাপ্ত হওয়া'] ,
['উড', 'এলেন প্রাইস উড', 'গ্রান্ট উড', 'শ্রীমতী হেনরি উড', 'স্যার হেনরি উড', 'স্যার হেনরি জোসেফ উড'] ,
['উড়ন্ত গাড়ি', 'উড়ন্তকেল্লা'] ,
['উড়ন্ত', 'উড্ডীয়মান'] ,
['উড়ব', 'উড়ব রাগ'] ,
['উড়াকু দল', 'দ্রুতগামী উদ্ধারকারীদল', 'ফ্লাইং স্কোয়াড'] ,
['উড়ান', 'ফ্লাইট', 'বিমান'] ,
['উড়ানবিহীন পাখি', 'স্থল পক্ষি', 'স্থল বিহঙ্গ'] ,
['উড়ানো', 'ওড়ানো'] ,
['উড়িষ্যা', 'উত্কল'] ,
['উড়িষ্যাবাসী', 'ওড়িয়া'] ,
['উড়িয়া', 'উড়িয়া ভাষা'] ,
['উড়িয়ে দেওয়া', 'ওড়ানো', 'ডুবানো', 'নষ্ট করা', 'বরবাদ করা', 'হারানো'] ,
['উড়ে যাওয়া', 'ওড়া'] ,
['উড়োজাহাজ কোম্পানী', 'এয়ারওয়েজ', 'এয়ারলাইনস'] ,
['উড়োজাহাজ', 'এরোপ্লেন', 'বায়ুযান', 'বিমান'] ,
['উড্ডুপি', 'উড্ডুপি জেলা', 'উড্ডুপি শহর'] ,
['উতক্ষেপন ক্ষেত্র', 'উতক্ষেপন পরিসর'] ,
['উতঙ্ক', 'উতঙ্ক ঋষি'] ,
['উতর্কষতা', 'শ্রী', 'সৌন্দর্য'] ,
['উতসাহপূর্ণ', 'তেজোদীপ্ত'] ,
['উত্কণ্ঠিত', 'উদ্বিগ্ন', 'ব্যাকুল'] ,
['উত্কর্ষ', 'ভালোত্ব', 'শ্রেষ্ঠতা'] ,
['উত্কর্ষকারী', 'উন্নতকারী', 'উন্নতিকারী', 'উন্নতিশীল'] ,
['উত্কর্ষতা', 'শিখর'] ,
['উত্কল', 'উত্কল ঋষি'] ,
['উত্কারিকা', 'উপগাছ', 'উপনাহ'] ,
['উত্কীর্ণ করা', 'খোদাই করা'] ,
['উত্কীর্ণ', 'খোদাই করা', 'খোদিত'] ,
['উত্কীর্ণ-প্রতিমা', 'উত্কীর্ণ-প্রতিমা'] ,
['উত্কীর্তন', 'ঘোষণা', 'প্রখ্যাপন', 'বিঘোষণা'] ,
['উত্কৃষ্ট কৃতি', 'উত্কৃষ্ট রচণা', 'মাস্টার পিস্', 'মাস্টার পিস্'] ,
['উত্কৃষ্ট', 'উত্তম', 'পুঙ্গব', 'শ্রেষ্ঠ'] ,
['উত্কোচ', 'ঘুষ'] ,
['উত্ক্রম মাপ', 'এন্ট্রপি'] ,
['উত্তঙ্ক', 'উত্তঙ্ক ঋষি'] ,
['উত্তপ্ত', 'তপ্ত'] ,
['উত্তম পুরুষ', 'প্রথম পুরুষ'] ,
['উত্তম রুচি', 'সুরুচি'] ,
['উত্তম', 'ভালো'] ,
['উত্তর অ্যাটলান্টিক সংগঠন', 'দা নর্থ অ্যাটলান্টিক ট্রিটি অর্গানাইজেশন', 'নর্থ অ্যাটলান্টিক ট্রিটি অর্গানাইজেশন', 'নেটো'] ,
['উত্তর আমেরিকা', 'নর্থ আমেরিকা'] ,
['উত্তর আমেরিকান', 'উত্তর আমেরিকাবাসী'] ,
['উত্তর আমেরিকার দেশ', 'উত্তর আমেরিকার রাষ্ট্র'] ,
['উত্তর কন্নড়', 'উত্তর কন্নড় জেলা'] ,
['উত্তর কাছার হিল্স', 'উত্তর কাছার হিল্স জেলা'] ,
['উত্তর কাণ্ড', 'উত্তরকাণ্ড'] ,
['উত্তর কালীন', 'উত্তরবর্তী'] ,
['উত্তর কোরিয়া নিবাসী', 'উত্তর কোরিয়ান'] ,
['উত্তর গোয়া', 'উত্তর গোয়া জেলা'] ,
['উত্তর চব্বিশ পরগণা', 'উত্তর চব্বিশ পরগণা জেলা'] ,
['উত্তর ত্রিপুরা', 'উত্তর ত্রিপুরা জেলা'] ,
['উত্তর দেওয়া', 'উত্তর বলা', 'জবাব দেওয়া'] ,
['উত্তর পশ্চিম', 'উত্তর পশ্চিম আমেরিকা', 'উত্তর-পশ্চিম', 'বায়ু কোণ', 'বায়ুকোণ'] ,
['উত্তর পাওয়া', 'সমাধান হওয়া'] ,
['উত্তর মধ্য আমেরিকা', 'মিড ওয়েস্ট'] ,
['উত্তর সিকিম', 'উত্তর সিকিম জেলা'] ,
['উত্তর সিয়াঙ্গ', 'উত্তর সিয়াঙ্গ জেলা'] ,
['উত্তর', 'উত্তর কুমার', 'উত্তর দিক', 'উত্তুরে', 'জবাব', 'ফল'] ,
['উত্তর-ফাল্গুনি', 'উত্তরাফাল্গুনি নক্ষত্র'] ,
['উত্তর-মধ্যবর্তী ভাগ', 'উত্তর-মধ্যভাগ'] ,
['উত্তরকাশী', 'উত্তরকাশী জেলা', 'উত্তরকাশী শহর'] ,
['উত্তরপত্র', 'উত্তরপুস্তিকা'] ,
['উত্তরভাদ্রপদ', 'উত্তরভাদ্রপদ নক্ষত্র'] ,
['উত্তরসূরী', 'উত্তরাধিকারী'] ,
['উত্তরস্নাতক', 'পোষ্ট গ্র্যাজুয়েশন', 'স্নাতকোত্তর'] ,
['উত্তরা-ফাল্গুনী', 'উত্তরা-ফাল্গুনী নক্ষত্র'] ,
['উত্তরাখণ্ড', 'উত্তরাঞ্চল'] ,
['উত্তরাধিকার কর', 'উত্তরাধিকারসূত্রে প্রাপ্ত সম্পত্তিবাবদ দেয় কর'] ,
['উত্তরাভাদ্রপদ', 'উত্তরাভাদ্রপদ নক্ষত্র'] ,
['উত্তরার্ধ', 'শেষার্ধ'] ,
['উত্তরাষাঢ়া', 'উত্তরাষাঢ়া নক্ষত্র'] ,
['উত্তাপ', 'উষ্ণ', 'উষ্ণতা', 'গরম', 'তাপ', 'তেজ', 'প্রতাপ'] ,
['উত্তীর্ণ হওয়া', 'পাস করা', 'সফল হওয়া'] ,
['উত্তীর্ণ', 'পাশ'] ,
['উত্তেজক', 'উত্তেজনা প্রদানকারী', 'উদ্দীপক', 'উদ্দীপিত'] ,
['উত্তেজনা ছড়ানো', 'হইচই ছড়ানো', 'হইচই ফেলা'] ,
['উত্তেজনা', 'উদ্বেগ', 'জোশ'] ,
['উত্তেজিত করা', 'উস্কে দেওয়া'] ,
['উত্তেজিত হওয়া', 'গরম হওয়া'] ,
['উত্তেজিত', 'উদ্দীপিত'] ,
['উত্তোলন', 'ওঠানো'] ,
['উত্ত্যক্ত করা', 'বারবার অনুরোধ করে বিরক্ত করা', 'বায়না করা'] ,
['উত্থান-একদশী', 'দেবোত্থান', 'দেবোত্থান একদশী'] ,
['উত্পন্ন করা', 'উত্পাদন করা', 'জন্ম দেওয়া', 'তৈরি করা', 'তৈরী করা'] ,
['উত্পন্ন হওয়া', 'জন্ম দেওয়া', 'জাগানো', 'জাত', 'তৈরী হওয়া'] ,
['উত্পন্ন', 'উত্পাদিত', 'জনিত', 'জাত', 'প্রসূত', 'সঞ্জাত', 'সূত'] ,
['উত্পাটনযোগ্য', 'উত্পাটনীয়', 'উন্মূলনযোগ্য'] ,
['উত্পাটিত করা', 'উপড়ানো', 'উপড়ে ফেলা'] ,
['উত্পাত', 'উপদ্রব'] ,
['উত্পাদক', 'গুনণীয়ক', 'ফ্যাক্টর'] ,
['উত্পাদন করা', 'চাষ করা'] ,
['উত্পাদিত হওয়া', 'প্রস্তুত হওয়া'] ,
['উত্পীড়ক', 'দুর্বলের নির্মম'] ,
['উত্পীড়িত বর্গ', 'উত্পীড়িত সমুদায়'] ,
['উত্পীড়িত', 'নিপীড়িত', 'পীড়িত'] ,
['উত্প্রেক্ষা', 'উত্প্রেক্ষা অলঙ্কার'] ,
['উত্স', 'উত্স স্থল', 'উদ্গম', 'কারণ'] ,
['উত্সব পালন', 'পালন করা'] ,
['উত্সব', 'সমারোহ'] ,
['উত্সর্গ', 'ত্যাগ', 'পরিত্যাগ'] ,
['উত্সাহ', 'উদ্যম', 'মনোবল', 'শক্তি', 'সাহস'] ,
['উত্সাহজনক', 'উত্সাহব্যঞ্জক'] ,
['উত্সাহবর্ধক', 'উত্সাহব্যঞ্জক'] ,
['উত্সাহযুক্ত', 'নির্ভয়', 'সাহসিক'] ,
['উত্সাহিত করা', 'প্রোত্সাহিত করা'] ,
['উত্সাহী হওয়া', 'উদ্যোগী থাকা', 'উদ্যোগী হওয়া', 'তত্পর থাকা'] ,
['উথলানো', 'জলচ্ছাস', 'স্ফীত হওয়া'] ,
['উথলে ওঠা', 'উপচে পড়া'] ,
['উদক', 'জল', 'পুষ্কর', 'বারি', 'সলিল'] ,
['উদকক্রিয়া', 'উদকদান'] ,
['উদগার', 'বমি'] ,
['উদর', 'পেট'] ,
['উদর-অগ্নি', 'জঠরাগ্নি'] ,
['উদর-সংক্রান্ত', 'পেটের'] ,
['উদরশূল', 'পেট ব্যথা'] ,
['উদরাময়', 'উদরাময় রোগ', 'মল রোগ'] ,
['উদল', 'রুদল'] ,
['উদাত্ত', 'উদার', 'দাতা', 'দানকর্তা', 'দানবীর', 'দানশীল', 'দানী'] ,
['উদান', 'উদান বায়ু', 'উদানবায়ু'] ,
['উদার', 'উদারচেতা', 'উদারমনস্ক'] ,
['উদারতা', 'দানশীলতা', 'দিলখোলা', 'মহত্ব', 'সহৃদয়তা'] ,
['উদাস হওয়া', 'মলিন হওয়া'] ,
['উদাসীন করানো', 'নিরাসক্ত করানো'] ,
['উদাসীন', 'নিরপেক্ষ', 'পক্ষপাতরহিত'] ,
['উদাহরণ', 'দৃষ্টান্ত', 'নমুনা'] ,
['উদিত হয়', 'উদয় হওয়া'] ,
['উদ্গীরণ', 'নিঃসরণ', 'নির্গমন'] ,
['উদ্ঘাটিত করা', 'ফাঁস করা'] ,
['উদ্দালক', 'উদ্দালক ঋষি'] ,
['উদ্দেশ্য থাকা', 'প্রয়োজন হওয়া'] ,
['উদ্দেশ্য', 'লক্ষ্য'] ,
['উদ্দেশ্যবিহীন', 'নিরূদ্দেশ্য', 'প্রয়োজনহীন'] ,
['উদ্ধত', 'ধৃষ্ট'] ,
['উদ্ধার করা', 'ত্রাণ করা', 'নিষ্কৃতি দেওয়া', 'নিস্তার করা', 'বাঁচান', 'বাঁচানো', 'বাঁচিয়ে রাখা', 'বার করা', 'বৈতরণী পার করা', 'মুক্তি দেওয়া', 'মোচন করা', 'রক্ষা করা'] ,
['উদ্ধার পাওয়া', 'নিষ্কৃতি পাওয়া', 'মুক্ত হওয়া'] ,
['উদ্ধার হওয়া', 'বাইরে বার করে রাখা'] ,
['উদ্ধার', 'নিষ্কৃতি', 'নিস্তার', 'মুক্তি'] ,
['উদ্ধারকারী', 'ত্রাতা'] ,
['উদ্বর্ত', 'উদ্বৃত্ত', 'বাড়তি'] ,
['উদ্বাস্তু', 'বসতিহীন', 'রিফিউজি', 'শরণার্থী'] ,
['উদ্বিগ্ন হয়ে', 'চিন্তিত হয়ে'] ,
['উদ্বিগ্ন', 'হতাশ'] ,
['উদ্বিড়াল', 'ভোঁদর'] ,
['উদ্বেগপূর্ণ', 'মানসিক চাপযুক্ত'] ,
['উদ্বেলিত', 'ছলকানো'] ,
['উদ্বোধনী অনুষ্ঠান', 'ওপেনিং', 'প্রারম্ভিক প্রদর্শন'] ,
['উদ্ভিজ্জ', 'প্রাকৃতিক'] ,
['উদ্ভিদ সমূহ', 'জঙ্গল'] ,
['উদ্ভিদ', 'গাছপালা'] ,
['উদ্ভিদবিজ্ঞান', 'উদ্ভিদশাস্ত্র', 'বনস্পতি বিজ্ঞান', 'বনস্পতি শাস্ত্র'] ,
['উদ্যত', 'ততপর', 'তৈরি', 'প্রস্তুত'] ,
['উদ্যম করা', 'পরিশ্রম করা', 'শ্রম করা'] ,
['উদ্যম', 'উদ্যোগ'] ,
['উদ্যমহীনতা', 'পরিশ্রমহীনতা'] ,
['উদ্যমী', 'উদ্যোগী', 'কর্মঠ', 'পরিশ্রমী', 'প্রযত্নশীল', 'প্রয়াসশীল', 'শিল্পোদ্যোগী'] ,
['উদ্যান', 'উপবন', 'তপোবন', 'পার্ক', 'বাগান', 'বাগিচা', 'বাগীচা', 'বাটিকা'] ,
['উদ্যানপালক', 'মালী'] ,
['উদ্যোগ পরিষদ সংঘ', 'ফিক্কি', 'ফেডারেশন অফ ইন্ডিয়ান চেম্বার্স অফ কমার্স অ্যান্ড ইন্ডাস্ট্রী'] ,
['উদ্যোগ শিক্ষা', 'শিল্পসংক্রান্ত শিক্ষা'] ,
['উদ্যোগ', 'চেষ্টা', 'প্রচলন', 'প্রবর্তন', 'প্রারম্ভ', 'প্রয়াস', 'সূচনা', 'সূত্রপাত'] ,
['উদ্যোগী', 'উদ্যোমী', 'কর্মঠ', 'কর্মোদ্যোগী', 'পরিশ্রমী'] ,
['উদয়পুর', 'উদয়পুর জেলা', 'উদয়পুর শহর'] ,
['উদয়াচল', 'পূর্বাচল'] ,
['উধমপুর', 'উধমপুর জেলা', 'উধমপুর শহর'] ,
['উধমসিংহ নগর', 'উধমসিংহ নগর জেলা', 'উধমসিংহনগর'] ,
['উনআশি', '৭৯', '৭৯,'] ,
['উনা', 'উনা জেলা', 'উনা শহর'] ,
['উনান', 'উনুন'] ,
['উন্নত করা', 'উন্নত হওয়া', 'বাড়ানো', 'বিকশিত করা', 'বিকাশ করা'] ,
['উন্নত', 'বিকশিত', 'শ্রেষ্ঠ', 'সুবিকশিত'] ,
['উন্নতি', 'উন্নয়ন', 'প্রবর্ধন', 'বর্ধন', 'বাড়া', 'বিকাশ', 'বৃদ্ধি', 'শুশ্রূষা'] ,
['উন্নতিকর', 'উন্নতিকারক', 'উন্নতিদায়ী'] ,
['উন্নতিশীল', 'প্রগতিশীল', 'বিকাশশীল'] ,
['উন্নাও', 'উন্নাও জেলা', 'উন্নাও শহর'] ,
['উন্নয়ন করা', 'ওঠানো'] ,
['উন্নয়নমূলক শিক্ষা', 'উপচরমূলক শিক্ষা'] ,
['উন্মত্ত', 'উন্মাদ', 'খেপা', 'পাগল', 'পাগল ব্যক্তি', 'পাগল লোক', 'বিক্ষিপ্ত', 'ভ্রান্ত', 'মানসিক রোগগ্রস্ত', 'মূর্চ্ছিত'] ,
['উন্মত্ততা', 'মত্ততা'] ,
['উন্মাদ', 'উন্মাদ রোগ', 'চিত্ত বিভ্রম', 'পাগলামো', 'মাদন'] ,
['উন্মাদিনী', 'পাগলী'] ,
['উন্মার্গগামী করা', 'পথভ্রষ্ট করা', 'বিভ্রান্ত করা'] ,
['উন্মীলন করা', 'চোখ খোলা'] ,
['উন্মুক্ত হওয়া', 'পালানো', 'বন্ধন মুক্ত হওয়া', 'মুক্ত হওয়া'] ,
['উন্মুক্ত', 'খোলা', 'বন্ধনমুক্ত', 'মুক্ত', 'মুক্ত'] ,
['উন্মুক্তকরণ', 'খোলা'] ,
['উন্মুক্ততা', 'খোলাভাব'] ,
['উপ প্রধান', 'উপ সভাপতি'] ,
['উপ প্রধানমন্ত্রী', 'উপপ্রধানমন্ত্রী'] ,
['উপ মুখ্যমন্ত্রী', 'উপ-মুখ্যমন্ত্রী', 'উপমুখ্যমন্ত্রী'] ,
['উপকরণ', 'সামগ্রী'] ,
['উপকাপ্তান', 'ভাইস ক্যাপ্টেন'] ,
['উপকার', 'কল্যাণ', 'ভালো', 'মঙ্গল', 'হিত'] ,
['উপকারিতা', 'উপযোগিতা'] ,
['উপকূলবাসী', 'তটবাসী'] ,
['উপক্রম', 'প্রস্তুতি'] ,
['উপক্ষেত্র', 'উপভাগ'] ,
['উপগিরি', 'ছোটো পর্বত', 'টিলা'] ,
['উপগোত্র', 'বংশনাম'] ,
['উপগ্রহ', 'প্রাকৃতিক উপগ্রহ'] ,
['উপগ্রাম', 'পল্লী'] ,
['উপচারিকা', 'ডাক্তারনি'] ,
['উপচে পড়া', 'ছাপিয়ে বয়ে যাওয়া', 'প্লাবন'] ,
['উপজাতি অধ্যুষিত', 'উপজাতিদের'] ,
['উপজাতির', 'উপজাতীয়'] ,
['উপড়ে ফেলা', 'ধ্বংস করা', 'নষ্ট করা', 'নাশ করা', 'শেষ করে দেওয়া'] ,
['উপত্যকা', 'পাহাড়ের পাদদেশ'] ,
['উপদংশ', 'ফিরিঙ্গী রোগ'] ,
['উপদেশ প্রদানকারী', 'উপদেষ্টা'] ,
['উপদেশ', 'শিক্ষা'] ,
['উপনিবেশ', 'কলোনি', 'কলোনী'] ,
['উপনির্দেশক', 'ডেপুটি ডায়রেক্টর'] ,
['উপন্যাস লেখক', 'ঔপন্যাসিক'] ,
['উপন্যাস-সম্পর্কিত', 'উপন্যাসের'] ,
['উপনয়ন', 'উপনয়ন সংস্কার'] ,
['উপপত্নি', 'রক্ষিতা'] ,
['উপপত্নী', 'রক্ষিতা'] ,
['উপপাদনীয়', 'উপপাদ্য'] ,
['উপপাদ্য', 'প্রমেয়'] ,
['উপবাসী', 'উপবাসের সময় উপযুক্ত', 'ক্ষুধার্ত'] ,
['উপবীত', 'পৈত্যে', 'ব্রহ্মসুত্র'] ,
['উপবৃত্ত', 'ডিম্বাকার বৃত্ত'] ,
['উপভোক্তা', 'উপযোগকর্তা', 'ভোক্তা'] ,
['উপভোগ করা', 'কাজে লাগানো', 'নেওয়া', 'প্রয়োগ করা', 'ব্যবহার করা', 'সেবন করা'] ,
['উপভোগ', 'খাওয়া', 'ভোগ', 'রসস্বাদন', 'সেবন'] ,
['উপমন্ডলাধিকারি', 'তহসিলদার'] ,
['উপমন্যু', 'উপমন্যু ঋষি'] ,
['উপমা', 'উপমা অলঙ্কার'] ,
['উপমার্গ', 'বাইপাস', 'বাহ্য-পথ'] ,
['উপমিত', 'উপমেয়'] ,
['উপমেয়োপমা', 'পরস্পোপমা'] ,
['উপযুক্ত পাত্র', 'যোগ্য ব্যক্তি'] ,
['উপযুক্ত', 'ঠিক', 'দক্ষ', 'পটু', 'যথাযথ', 'যথোচিত', 'যোগ্য', 'সঙ্গত', 'সঠিক', 'সমর্থ'] ,
['উপযুক্ততা', 'প্রয়োজনীয়তা', 'সমীচীনতা'] ,
['উপযোগ', 'ব্যবহার'] ,
['উপযোগী হওয়া', 'কাজে আসা'] ,
['উপযোগী', 'প্রয়োজনীয়', 'লাভজনক', 'লাভদায়ক', 'লাভদায়ী', 'হিতকর'] ,
['উপযোগীতা', 'কাজে লাগানো', 'কার্য', 'প্রয়োগ', 'প্রয়োজন', 'ব্যবহার'] ,
['উপর', 'ওপর'] ,
['উপর-নীচ', 'ওঠা-নামা'] ,
['উপরাষ্ট্রপতি', 'ভাইস প্রেসিডেন্ট'] ,
['উপরিকথিত', 'উপরোক্ত', 'উপর্যুক্ত', 'পূর্বোক্ত'] ,
['উপরে ওঠা', 'চড়া'] ,
['উপরের বার্থ', 'উপরের সিট'] ,
['উপরের বোল্টা', 'বরকিনা ফৈসো', 'বুরকিনা ফৈসো'] ,
['উপরের', 'বাইরের'] ,
['উপশম', 'শান্ত'] ,
['উপশমন', 'নিবারণ'] ,
['উপশাখা', 'প্রশাখা'] ,
['উপশুল্ক', 'কর'] ,
['উপসভাপতি', 'ভাইস-প্রেসিডেন্ট'] ,
['উপসমিতি', 'সাব-কমেটি'] ,
['উপস্তুত', 'উপস্তুত ঋষি'] ,
['উপস্থিত', 'পেশ', 'প্রস্তুত', 'বিদ্যমান', 'মজুত', 'হাজির'] ,
['উপস্থিতি-তালিকাপুস্তক', 'উপস্থিতি-নামাবলী', 'এটেনডেন্স রেজিস্ট্রার', 'হাজিরাখাতা'] ,
['উপস্হিত হওয়া', 'গিয়ে পৌঁছানো'] ,
['উপস্হিত', 'বর্তমান', 'বিদ্যমান'] ,
['উপস্হিতি', 'হাজিরা'] ,
['উপহার', 'তোফা'] ,
['উপহারাদি', 'উপহারাদি দেওয়ার প্রথা'] ,
['উপহাসাস্পদ', 'উপহাসের যোগ্য'] ,
['উপাচার্য', 'ভাইস চ্যান্সেলার'] ,
['উপাত্ত', 'তথ্য'] ,
['উপাদান', 'কাঁচা মাল', 'কাঁচামাল'] ,
['উপাদেয়', 'মজাদার', 'মশলাদার', 'রঙীন'] ,
['উপাধান', 'তাকিয়া', 'বালিশ', 'মস্তাকাধান'] ,
['উপান্ত', 'প্রান্ত দেশ', 'বাইরের অংশ', 'মার্জিন'] ,
['উপার্জন করা', 'জীবিকোপার্জন'] ,
['উপাসক', 'পূজারী', 'ভক্ত', 'সাধক', 'সেবক'] ,
['উপাসনা গৃহ', 'উপাসনালয়', 'পূজার ঘর'] ,
['উপাসনা স্থল', 'পূজা স্থল', 'পূজা স্থান'] ,
['উপাসিকা', 'পুজারী'] ,
['উপায়', 'চারা', 'বিকল্প', 'বিধি', 'মাধ্যম', 'মার্গ', 'রাস্তা'] ,
['উপায়হীনতা', 'বিকল্পহীনতা'] ,
['উপুড় হওয়া', 'উল্টে যাওয়া'] ,
['উপুড় হয়ে', 'উল্টে'] ,
['উপেক্ষনীয়', 'লঙ্ঘনীয়'] ,
['উপোস', 'ব্রত'] ,
['উভচর', 'উভয়চর'] ,
['উভয়', 'দুই'] ,
['উভয়-সঙ্কট', 'দোলাচাল', 'দ্বিধা'] ,
['উমরিয়া', 'উমরিয়া জেলা', 'উমরিয়া শহর'] ,
['উরুক্রম', 'ত্রিপাদ', 'ত্রিবিক্রম', 'বামন', 'বামনাবতার'] ,
['উরুক্ষয়', 'উরুক্ষয় ঋষি'] ,
['উরুগুয়ান পেসো', 'পেসো'] ,
['উরুগুয়ান', 'উরুগুয়ে বাসী', 'উরুগুয়েবাসী'] ,
['উরুগুয়ে সম্পর্কিত', 'উরুগুয়ের'] ,
['উরুগুয়ে', 'উরুগুয়ে নদী'] ,
['উরুচক্রি', 'উরুচক্রি ঋষি'] ,
['উর্দু', 'উর্দু ভাষা'] ,
['উর্ধ্বগ্রীব', 'উর্ধ্বগ্রীব ঋষি'] ,
['উর্বর জমি', 'উর্বর ভূমি'] ,
['উলুপি', 'শিশুমার'] ,
['উল্কা', 'উল্কাখণ্ড', 'উল্কাপিণ্ড'] ,
['উল্টানো', 'উল্টে যাওয়া'] ,
['উল্টো অর্থ', 'বিপরীত অর্থ'] ,
['উল্টো পাল্টা', 'উল্টো-পাল্টা'] ,
['উল্টো', 'প্রতিকূল', 'বিপরীত', 'বিরুদ্ধ'] ,
['উল্টো-পাল্টা বকা', 'প্রলাপ', 'বকবক'] ,
['উল্লম্ব', 'লম্ব'] ,
['উল্লালা', 'চন্দ্রমণি'] ,
['উল্লিখিত', 'কথিত'] ,
['উল্লেখ', 'চর্চা'] ,
['উল্লেখনীয়', 'উল্লেখযোগ্য'] ,
['উল্লেখযোগ্য', 'উল্লেখ্য'] ,
['উশনাকাব্য', 'উশনাকাব্য ঋষি'] ,
['উশীনর', 'রাজা উশীনর'] ,
['উশীর', 'খসখস', 'বেনার মূল'] ,
['উশৃঙ্খল', 'দুর্দমনীয়'] ,
['উষর জমি', 'পতিত জমি'] ,
['উষ্ণ ক্রান্তিয়', 'ট্রপিকাল জোন'] ,
['উষ্ণ', 'গরম'] ,
['উষ্ণীষ', 'পাগ', 'পাগড়ি'] ,
['উসকো-খুসকো', 'এলোমেলো'] ,
['উস্মানাবাদ', 'উস্মানাবাদ জেলা'] ,
['ঊ', 'স্বরবর্ণ ঊ'] ,
['ঊদ্ভব', 'মধুপ'] ,
['ঊনচল্লিশ', '৩৯,'] ,
['ঊনত্রিশ', '২৯'] ,
['ঊননব্বই', '৮৯,'] ,
['ঊনপঞ্চাশ', '৪৯', '৪৯,'] ,
['ঊনষাট', '৫৯,'] ,
['ঊনসত্তর', '৬৯,', '৭৯'] ,
['ঊনিশ', '১৯'] ,
['ঊরূ', 'জঙ্ঘা', 'জানু'] ,
['ঊর্মি', 'কল্লোল', 'তরঙ্গ'] ,
['ঊর্মিল', 'তরঙ্গিত', 'লহরিত'] ,
['ঊষা', 'প্রত্যুষ', 'প্রভাত', 'ভোর'] ,
['ঋ', 'স্বরবর্ণ ঋ'] ,
['ঋক', 'ঋচা', 'বেদমন্ত্র', 'বৈদিক ছন্দ', 'মন্ত্র'] ,
['ঋগ বেদ', 'ঋগবেদ', 'রিচা'] ,
['ঋচীক', 'ঋচীক ঋষি'] ,
['ঋজিস্বা', 'ঋজিস্বা ঋষি'] ,
['ঋজু কোণ', 'ঋজুকোণ'] ,
['ঋজ্রাশ্ব', 'ঋজ্রাশ্ব ঋষি'] ,
['ঋণ নেওয়া', 'ঋণগ্রহণ করা', 'ধার নেওয়া'] ,
['ঋণ', 'দেনা', 'ধার'] ,
['ঋণকারি', 'ঋণগ্রহিতা'] ,
['ঋতু', 'রজস্রাব'] ,
['ঋতুপর্ণ', 'ঋতুপর্ণ ঋষি'] ,
['ঋতুমতি', 'রজস্বলা'] ,
['ঋতুমতী', 'রজঃস্বলা'] ,
['ঋতুরাজ', 'কামসখা', 'বলাঙ্গক', 'বসন্ত', 'বসন্ত ঋতু', 'শিশিরান্ত'] ,
['ঋদ্ধি-সিদ্ধি', 'সুখ-সম্পত্তি'] ,
['ঋষভ', 'ঋষভ ঋষি', 'ঋষভ স্বর', 'রিষভ'] ,
['ঋষি', 'মন্ত্রকার', 'মুনি', 'মুনী'] ,
['ঋষ্যশৃঙ্গ', 'ঋষ্যশৃঙ্গ ঋষি', 'শৃঙ্গী', 'শৃঙ্গী ঋষি'] ,
['এ গ্রুপ', 'এ ব্লাড গ্রুপ', 'এ রক্ত বর্গ'] ,
['এ ডি', 'খ্রীষ্টাব্দ', 'সন'] ,
['এ বি ব্লাডগ্রুপ', 'এ বি রক্তবর্গ', 'রক্তবর্গ এ বি'] ,
['এ', 'স্বরবর্ণ এ'] ,
['এঁটেলমাটি', 'কাদামাটি'] ,
['এই কারণে', 'তাই'] ,
['এই জায়গাতেই', 'এখানেই'] ,
['এই দিকে', 'এখানে', 'এধারে', 'এপাড়ে'] ,
['এই ধরণের', 'এইপ্রকার', 'এইরকম'] ,
['এই পরিমাণ', 'এতটা', 'এতটুকু'] ,
['এই প্রকারে', 'এই ভাবে', 'এইভাবে', 'এইরূপ', 'এভাবে', 'এমন'] ,
['এই বার', 'এবার'] ,
['এই সবে-সবে', 'এই সময়েই', 'এখন-এখন', 'এখনই'] ,
['এইচ আই ভি', 'এইচআইভি'] ,
['এইচআরডব্লু', 'হ্যুম্যান রাইটস ওয়াচ'] ,
['এইচটিএমএল', 'হাইপারটেক্স্ট মার্কআপ ল্যাঙওয়েজ'] ,
['এইচডি দেবে গোউড়া', 'হরদন হল্লী ডোডে দেবেগৌড়া'] ,
['এইচডিএফসি', 'এইচডিএফসি ব্যাঙ্ক'] ,
['এএন', 'এসোসিয়েট ইন নার্সিং', 'পরিচর্যা সহকারী'] ,
['এক আঁটি পাতা', 'পর্ণসমূহ'] ,
['এক কোটি', 'কোটি,'] ,
['এক তরফে', 'এক দিকে', 'এক ধারে'] ,
['এক ধরণের হওয়া', 'একরকম হওয়া', 'সদৃশ হওয়া', 'সমরূপসম্পন্ন হওয়া'] ,
['এক প্রকার নমনীয় ডাল', 'কাঠি'] ,
['এক বয়সী', 'সমবয়সী', 'সমবয়স্ক'] ,
['এক রকম', 'ডুপ্লিকেট'] ,
['এক সমান', 'তুল্য', 'সদৃশ', 'সমকক্ষ', 'সমতুল্য', 'সমান'] ,
['এক সের এর এক চতুর্থাংশ', 'পাব'] ,
['এক হওয়া', 'একজোট হওয়া', 'মিলিত হওয়া', 'মিলে যাওয়া'] ,
['এক', 'এক তারিখ', 'পয়লা', '১', '১,'] ,
['এক-তৃতীয়াংশ', 'তৃতীয়াংশ'] ,
['এক-নিমেষ', 'নিমেষ-মাত্র'] ,
['একক', 'মান', 'মাপ', 'মাপক', 'সিঙ্গেলস্'] ,
['একচর', 'একশৃঙ্গ', 'খড়গী', 'গণ্ড', 'গণ্ডক', 'গণ্ডাঙ্গ', 'গণ্ডার'] ,
['একচল্লিশ', '৪১,'] ,
['একচাকাবিশিষ্ট', 'একচাকার'] ,
['একচারিণী', 'পরিব্রতা', 'সতী'] ,
['একচ্ছত্র', 'একাধিপত্য', 'সংরক্ষিত'] ,
['একচ্ছত্রাধিপত্য', 'স্বেচ্ছাচারিতা'] ,
['একছত্র', 'একতন্ত্র'] ,
['একজন-দুজন', 'দু-একজন'] ,
['একটি শিঙ্গ যুক্ত', 'একশৃঙ্গ', 'একশৃঙ্গ যুক্ত'] ,
['একতন্ত্রিকা', 'একতন্ত্রী', 'একতারা'] ,
['একতরফা', 'একদিকের', 'একপক্ষীয়', 'একবারের'] ,
['একতা', 'ঐক্য', 'সংগঠন'] ,
['একত্র করা', 'একত্রিত করা', 'জড়ো করা', 'জমা করা', 'জোগাড়', 'জোগাড় করা', 'নেওয়া', 'যুক্ত করানো', 'শামিল করা', 'সংগ্রহ করা'] ,
['একত্র', 'একত্রিত', 'একত্রীকরণ', 'জমা', 'যোগাড়', 'সংগ্রহ', 'সমগ্রীকৃত'] ,
['একত্রিত হওয়া', 'জমা হওয়া', 'জমে যাওয়া'] ,
['একত্রিত', 'জমা', 'সমগ্র'] ,
['একত্রিশ', '৩১,'] ,
['একত্রীকরণ', 'সংযোগ'] ,
['একদন্ত', 'একদ্রংস্ট্র', 'কুঞ্জরবন্দন', 'গজানন', 'গজাস্য', 'গণদেব', 'গণনাথ', 'গণপতি', 'গণাগ্রণা', 'গণাধিপ', 'গণেশ', 'দ্বৈমাতুর', 'বিঘ্নহর', 'বিনায়ক', 'লম্বোদর', 'সিদ্ধিদাতা', 'হেরম্ব'] ,
['একদম', 'ঠিক', 'পুরোপুরি', 'পূর্ণত', 'সম্পূর্ণত'] ,
['একদিবসীয়', 'ওয়ান ডে'] ,
['একদেশী', 'একদেশীয়'] ,
['একনিষ্ট পুত্রী', 'একমাত্র মেয়ে'] ,
['একনিষ্ঠতা', 'একাশ্রয়তা'] ,
['একবর্ষজীবি', 'একবর্ষীয়'] ,
['একমত', 'একরায়', 'রাজী', 'সম্মত', 'সহমতদ'] ,
['একমাত্র', 'একলা', 'একা', 'একাকী', 'কেবল', 'কেবলমাত্র', 'শুধুমাত্র'] ,
['একরকম', 'একরকমের', 'সদৃশ'] ,
['একরাত্রী', 'একরাত্রী যজ্ঞ'] ,
['একলা', 'একা', 'একাকী', 'নিঃসঙ্গ'] ,
['একশ নব্বই', '১৯০'] ,
['একশ পঁচাত্তর', '১৭৫'] ,
['একশ', 'একশ বছর', 'একশত', '১০০,'] ,
['একশতম', 'শততম'] ,
['একশফ', 'একশফ পশু', 'একশফ প্রাণী'] ,
['একশো পঞ্চাশ', 'দেড়শো', '১৫০', '১৫০,'] ,
['একশো ষাট', '১৬০,'] ,
['একশো সাত', '১০৭,'] ,
['একশো', '১০০'] ,
['একষট্টি', '৬১', '৬১,'] ,
['একসঙ্গে ঘটা', 'একসঙ্গে হওয়া'] ,
['একসঙ্গে', 'একসাথে', 'সংযুক্ত ভাবে', 'সঙ্গে', 'সাথে সাথে'] ,
['একসূত্র', 'মিলিত', 'মিশ্রিত', 'যুক্ত', 'সংশ্লিষ্ট', 'সম্মিলিত'] ,
['একস্ব অধিকার পত্র', 'পেটেন্ট', 'সরকারি সনদ'] ,
['একা', 'নির্জন স্থান', 'ফাঁকা জায়গা', 'লোকশূণ্য'] ,
['একাক্ষ', 'কানা'] ,
['একাক্ষর', 'একাক্ষর উপনিষদ', 'একাক্ষরোপনিষদ'] ,
['একাগ্রচিত্ত', 'তন্ময়'] ,
['একাগ্রতা সহকারে', 'মনোযোগ সহকারে'] ,
['একাত্তর', '৭১', '৭১,'] ,
['একাদশ', 'এগারো', '১১'] ,
['একাধিকার', 'একাধিপত্য'] ,
['একাধিপতী', 'চক্রবর্তী', 'সর্বেশ্বর'] ,
['একানব্বই', '৯১', '৯১,'] ,
['একান্ত', 'জনশূন্য', 'নিভৃত', 'নির্জন'] ,
['একান্ন', '৫১,'] ,
['একাবলী', 'একাবলী কাব্যালঙ্কার'] ,
['একাশি', '৮১', '৮১,'] ,
['একীভবন', 'সংযোগ'] ,
['একে অপরের সাথে', 'নিজেদের মধ্যে', 'পরস্পর'] ,
['এক্জিকিউটিভ', 'কার্যনির্বাহী কর্তা'] ,
['এক্স রে মেশিন', 'এক্স রে যন্ত্র'] ,
['এক্স রে', 'এক্স-রে'] ,
['এক্স-রশ্মি', 'এক্স-রে'] ,
['এক্সট্রিমা', 'এক্সট্রিমা আম'] ,
['এক্সপায়ার্ড', 'নির্দিষ্ট সময় পেরিয়ে যাওয়া'] ,
['এক্সিক্যুটিভ', 'কার্যকারিণী'] ,
['এগিয়ে যাওয়া', 'চলা', 'বেরিয়ে যাওয়া'] ,
['এগোনো', 'সামনে এগোনো'] ,
['এজেন্ট', 'দালাল', 'প্রতিনিধি', 'ব্রোকার'] ,
['এটা', 'এটা জেলা', 'এটা শহর'] ,
['এডওয়ার্ড ডি হোয়াইট', 'এডওয়ার্ড হোয়াইট', 'হোয়াইট'] ,
['এডওয়ার্ড', 'এডওয়ার্ড আম'] ,
['এডমিন', 'পাইরিডক্সমিন', 'পাইরিডক্সিন', 'পাইরিডক্সিন', 'ভিটামিন বি', 'হাইড্রোক্লোরাইড'] ,
['এড়-গজ', 'এড়গজ'] ,
['এডিটর', 'লেখা পরীক্ষক', 'সম্পাদক'] ,
['এত', 'এতটা'] ,
['এতরেয়', 'এতরেয় উপনিষদ'] ,
['এন এস আই', 'এনএসআই', 'ন্যাশানল স্টক এক্সচেঞ্জ', 'রাষ্ট্রীয় স্টক এক্সচেঞ্জ'] ,
['এনএসি', 'জাতীয় পরামর্শদাতা পরিষদ'] ,
['এনজিও', 'গৈর সরকারি সংস্থা'] ,
['এন্জাইম', 'কিণ্বক'] ,
['এন্ডোর বাসী', 'এন্ডোরবাসী', 'এন্ডোরান'] ,
['এফ আই আর', 'এফআইআর'] ,
['এফিডেবিট', 'হলফনামা'] ,
['এবড়ো-খেবড়ো', 'রুক্ষ'] ,
['এভাবে', 'এরকমভাবে'] ,
['এভারগ্রিন স্টেট', 'ওয়াশিংটন', 'ডব্লু এ'] ,
['এভারেষ্ট', 'মাউন্ট এভারেষ্ট'] ,
['এম আর্ক', 'মাস্টার অফ আর্কিটেক্চার'] ,
['এম পি', 'মধ্য প্রদেশ', 'মধ্যপ্রদেশ'] ,
['এম বি এ', 'এমবিএ', 'মাস্টার ইন বিজনেজ অ্যডমিনিস্ট্রেশান'] ,
['এমডি', 'ব্যাবস্থাপনা পরিচালক', 'ম্যানেজিং ডিরেক্টর', 'সিএমডি'] ,
['এমন সময়ে', 'এর মধ্যে'] ,
['এম্পারার প্রজাপতি', 'প্রজাপতি'] ,
['এম্পারার', 'এম্পারার আঙুর', 'এম্পারার পতঙ্গ'] ,
['এম্পোরিয়াম', 'ডিপার্টমেন্ট স্টোর'] ,
['এরকা', 'কিলক', 'কিলিক'] ,
['এরণ্ড', 'রেড়ি'] ,
['এরিট্রিয়ান', 'এরিট্রিয়ার'] ,
['এরিয়া', 'ক্ষেত্র', 'পরিধি'] ,
['এরোনটিক্স', 'বিমান-বিজ্ঞান', 'বিমান-বিদ্যা'] ,
['এর্নাকুলম', 'এর্নাকুলম জেলা', 'এর্নাকুলম শহর'] ,
['এল বেডা', 'দোহা'] ,
['এল সালভাডোরীয়', 'এল সালভাডোরের', 'সালভাডোরের'] ,
['এল সালভাদোর কোলন', 'কোলন'] ,
['এল সাল্ভাডোর বাসী', 'এল সাল্ভাডোরী'] ,
['এল সাল্ভাডোর', 'এল সাল্ভাডোর গণতন্ত্র', 'এল সাল্ভাডোর গণরাজ্য', 'সাল্ভাডোর'] ,
['এলাকা পর্যবেক্ষক', 'সর্কল ইন্সপেক্টর'] ,
['এলাকা', 'ক্ষেত্র', 'প্রদেশ', 'ভূ-খণ্ড', 'ভূ-ভাগ', 'ভূখণ্ড', 'ভূমি'] ,
['এলাচ', 'এলাচ দানা'] ,
['এলাচদানা', 'নকুলদানা'] ,
['এলাহাবাদ', 'এলাহাবাদ জেলা', 'এলাহাবাদ শহর', 'প্রয়াগ'] ,
['এলিফেন্টা', 'এলিফেন্টা গুহা', 'ঘারাপুরি দ্বীপ'] ,
['এলিস আইল্যান্ড', 'টুবেলু', 'টুবেলু গণরাজ্য', 'টুবেলু দ্বীপ'] ,
['এশিয় খেলা', 'এশিয়ান গেমস'] ,
['এশিয়', 'এশিয়ান', 'এশিয়াবাসী'] ,
['এশিয়া', 'এশিয়া মহাদেশ'] ,
['এশিয়ান', 'এশিয়ার', 'এশীয়'] ,
['এশিয়ার দেশ', 'এশীয় রাষ্ট্র', 'প্রাচ্য'] ,
['এশীয় দেশ', 'এশীয় রাষ্ট্র'] ,
['এসটিএফ', 'বিশেষ কার্য বল', 'স্পেশাল টাস্ক ফোর্স'] ,
['এসফাল্ট', 'পিচ'] ,
['এসে যাওয়া', 'হঠাত করে এসে যাওয়া'] ,
['এস্কর্বিক অ্যাসিড', 'ভিটামিন সি'] ,
['এস্কুডো', 'পর্তুগালী এস্কুডো'] ,
['এ্যাণ্টিকিটিক ভিটামিন', 'খাদ্যজ ডি', 'ভিটামিন ডি'] ,
['এ্যান্ড্রু ডি হোয়াইট', 'এ্যান্ড্রু ডিকসন হোয়াইট', 'হোয়াইট'] ,
['এয়ার মার্শাল', 'বায়ুসেনা অধ্যক্ষ', 'বায়ুসেনাধ্যক্ষ'] ,
['এয়ারপোর্ট', 'বিমান বন্দর'] ,
['এয়োস্ত্রী', 'সধবা'] ,
['ঐ', 'স্বরবর্ণ ঐ'] ,
['ঐচ্ছিক', 'বিকল্পী', 'বিকল্পয়ুক্ত', 'বৈকল্পিক'] ,
['ঐতিহাসিকতা', 'পৌরাণিকতা', 'প্রাচীন কালিনতা', 'প্রাচীনত্ব', 'প্রাচীনত্ব'] ,
['ঐতিহ্য থাকা', 'চলে আসা'] ,
['ঐতিহ্যবাদ', 'পরম্পরাবাদ', 'সনাতনপন্হা'] ,
['ঐতিহ্যবাদী', 'পরম্পরাবাদী', 'সনাতনপন্হী'] ,
['ঐতিহ্যবাহী', 'পৈতৃক', 'বংশানুক্রমিক'] ,
['ঐন্দ্রজালিক', 'জাদুকর', 'মায়াবি', 'মায়াবী', 'মায়িক', 'শৌভিক'] ,
['ঐরাবত', 'গজানন', 'গজেন্দ্র', 'শ্বেতহস্তি'] ,
['ঐশ্বর্য', 'দৌলত', 'ধন', 'ধনসম্পত্তি', 'সম্পত্তি'] ,
['ঐশ্বর্যশালী', 'ধনবান', 'ধনশালী', 'ধনাঢ্য', 'ধনী', 'পয়সাওয়ালা', 'সম্পদশালী'] ,
['ঐশ্বর্য্যদায়ক', 'ঐশ্বর্য্যপ্রদ', 'সমৃদ্ধিদায়ক', 'সমৃদ্ধিপ্রদ'] ,
['ও ব্লাড গ্রুপ', 'ও রক্ত বর্গ'] ,
['ও', 'স্বরবর্ণ ও'] ,
['ওঁ', 'ওঙ্কার', 'ওম্', 'প্রণব', 'প্রণবমন্ত্র'] ,
['ওই জায়গায়', 'ওইখানে', 'ওখানে'] ,
['ওই দিকে', 'ওখানে', 'ওদিকে'] ,
['ওই সময়', 'তখন'] ,
['ওক', 'শাহবলুত'] ,
['ওজন করা', 'পরিমাপ করা', 'মাপা'] ,
['ওজন', 'ভার'] ,
['ওজনদার', 'গুরুত্বপূর্ণ', 'ভারী'] ,
['ওজস্বী', 'কান্তিবান', 'তেজস্বী'] ,
['ওজোনদার হওয়া', 'ভারী হওয়া'] ,
['ওঝাগিরি', 'ওঝার কাজ'] ,
['ওঠবোস', 'ডন বৈঠক'] ,
['ওঠা', 'জাগা', 'জেগে যাওয়া', 'তৈরী হওয়া', 'দাঁড়ানো', 'বাড়তে থাকা', 'বাড়ন্ত', 'বের হওয়া', 'লাফ', 'সামনে আসা'] ,
['ওঠা-নামা', 'ওঠা-পড়া'] ,
['ওঠানো', 'চড়ানো', 'তালিকাভুক্ত করা', 'তোলা', 'ধরা', 'লেখানো'] ,
['ওড়নষষ্ঠী', 'গুহষষ্ঠী'] ,
['ওড়া', 'দোলা'] ,
['ওড়িশি', 'ওড়িশি নৃত্য'] ,
['ওড়িয়া', 'ওড়িয়া লিপি'] ,
['ওনামী', 'ওনামীজ'] ,
['ওপর ওপর', 'ঠাট', 'লোক দেখানো'] ,
['ওপরচালাক', 'বাচাল'] ,
['ওপরে ছোঁড়া', 'ছুঁড়ে দেওয়া'] ,
['ওপার', 'পার'] ,
['ওপেন করা', 'খোলা'] ,
['ওপেন ক্রীড়া প্রতিযোগিতা', 'মুক্ত ক্রীড়া প্রতিযোগিতা'] ,
['ওপেনার', 'ওপেনিং ব্যাট্সম্যান'] ,
['ওবোফ্লেবিন', 'খাদ্যজ জি', 'খাদ্যজ বি', 'ভিটামিন জি', 'ভিটামিন বি', 'রিবোফ্লেবিন', 'ল্যাক্টোফ্লেবিন', 'হিপেটোফ্লেবিন'] ,
['ওভারশিয়ার', 'পর্যবেক্ষক', 'সুপারিনটেন্ডেন্ট'] ,
['ওভেন', 'ভাটি'] ,
['ওমলেট', 'ডিমভাজা'] ,
['ওমান নিবাসী', 'ওমানি'] ,
['ওমান', 'মস্কট এবং ওমান'] ,
['ওমানি রিয়াল', 'রিয়াল সৈদী'] ,
['ওরেগন', 'ওয়ার'] ,
['ওল', 'জমিকন্দ', 'শূরণ'] ,
['ওলন্দাজ ভাষা', 'ডাচ'] ,
['ওলন্দাজ', 'নেদারল্যান্ডবাসী'] ,
['ওষুধ বিক্রেতা', 'ঔষধ বিক্রেতা'] ,
['ওষুধ', 'ঔষধ'] ,
['ওষুধের গুলি', 'গুলি', 'বড়ি'] ,
['ওসলো', 'ক্রিস্টিনিয়া'] ,
['ওস্তাদ', 'গুরু', 'শিল্পী'] ,
['ওস্মানাবাদ', 'ওস্মানাবাদ শহর'] ,
['ওয়াইগাই', 'ওয়াইগাই নদী'] ,
['ওয়াইফাই', 'ওয়ারলেস লোকাল এরিয়া নেটওয়ার্ক'] ,
['ওয়াক তোলা', 'বমি বমি পাওয়া'] ,
['ওয়াঘা বর্ডার', 'ওয়াঘা সীমান্ত'] ,
['ওয়ারঙ্গেল', 'ওয়ারঙ্গেল জেলা', 'ওয়ারঙ্গেল শহর'] ,
['ওয়ার্কশপ', 'কর্মশালা'] ,
['ওয়ার্ল্ড ওয়াইড ওয়েব', 'ওয়েব', 'ডাব্লুডাব্লুডাব্লু'] ,
['ওয়ার্ল্ড কাপ', 'বিশ্বকাপ'] ,
['ওয়াল হ্যাংগিং', 'চিত্রবিচিত্র নকশা-খচিত ঢাকনা', 'চিত্রবিচিত্র নকশা-খচিত পর্দা'] ,
['ওয়ালরাস', 'সিন্ধুঘোটক'] ,
['ওয়াশিংটন', 'ওয়াশিংটন ডি সি', 'ক্যাপিটাল'] ,
['ওয়াস্টার্ন', 'হর্স অপেরা'] ,
['ওয়েট লিফটিং', 'ভারোত্তলন'] ,
['ওয়েটার', 'বেয়ারা'] ,
['ওয়েলশ', 'কেম্ব্রিয়া'] ,
['ওয়েল্ডিং করা', 'ঝালা', 'ঝালাই করা'] ,
['ওয়েস্ট ইন্ডিস', 'ক্যারিবিয়ান'] ,
['ওয়েস্টার্ন', 'ওয়েস্টার্ন স্যাণ্ডউইচ'] ,
['ওয়্যারলেস', 'তারবিহীন', 'বেতার'] ,
['ঔ', 'স্বরবর্ণ ঔ'] ,
['ঔঙ্গোল', 'ঔঙ্গোল'] ,
['ঔত্সর্গিক', 'নিবেদনীয়', 'নৈবেদ্য'] ,
['ঔদরিক', 'খাদ্যরসিক', 'পেটুক', 'ভোজনরসিক', 'ভোজনলোলুপ'] ,
['ঔদ্ধত্য', 'দম্ভ', 'দর্প', 'দাম্ভিকতা', 'ধৃষ্টতা'] ,
['ঔদ্ধত্যহীনতা', 'নম্রতা', 'বিনয়', 'লজ্জাশীলতা', 'শালীনতা'] ,
['ঔরঙ্গাবাদ', 'ঔরঙ্গাবাদ জেলা', 'ঔরঙ্গাবাদ শহর'] ,
['ঔরস', 'বৈধ'] ,
['ঔরাঙ্গাবাদ', 'ঔরাঙ্গাবাদ জেলা', 'ঔরাঙ্গাবাদ শহর'] ,
['ঔরৈয়া', 'ঔরৈয়া জেলা', 'ঔরৈয়া শহর'] ,
['ঔর্ব', 'ঔর্ব ঋষি'] ,
['ঔষধ বিক্রেতা', 'ঔষধ-বিক্রেতা'] ,
['ঔষধালয়', 'ঔষধের দোকান'] ,
['ঔষ্ঠ্য', 'ঠোঁটের'] ,
['ক', 'ব্যঞ্জনবর্ণ ক'] ,
['কংক্রীট', 'মশলা', 'লেই'] ,
['কংস', 'কংসাসুর', 'ভোজপতি', 'মায়াবান'] ,
['ককটেল', 'কক্টেল'] ,
['কক্ষ পরিচালনা', 'কক্ষ ব্যবস্থাপনা'] ,
['কক্ষ', 'কক্ষতল', 'কক্ষপুট', 'কাঁক', 'কাঁখ', 'কাঁখতল', 'কাঁখতলী', 'কাঙ্খ', 'কাটরা', 'কামরা', 'কুক্ষ', 'কুঠরি', 'কেবিন', 'কোঠা', 'কোষ্ঠ', 'ক্লাস', 'খোপ', 'ঘর', 'প্রকোষ্ঠ', 'বগল', 'বাহুমূল', 'ভুজকোটর'] ,
['কক্ষনো', 'কদাচিত'] ,
['কক্ষপথ', 'চক্কর', 'পরিধি'] ,
['কক্ষপ্রধান', 'ক্যাপ্টেন', 'মনিটর', 'শ্রেণীপ্রধান'] ,
['কক্ষীবান', 'কক্ষীবান ঋষি'] ,
['কখন', 'কখনও না', 'কতক্ষণে'] ,
['কখনও-কখনও', 'কদাচিত্'] ,
['কখনো', 'কোনো সময়'] ,
['কঙ্ক', 'কাঁকপাখি'] ,
['কঙ্কন পরিহিত', 'কাঁকন পরিহিত', 'কেয়ূর পরিহিত'] ,
['কঙ্কন', 'কাঁকন', 'চূড়'] ,
['কঙ্কমালা', 'কত্তাল', 'করতাল', 'খঞ্জনি', 'খত্তাল'] ,
['কঙ্গনী', 'কাঁক', 'প্রিয়ঙ্গু', 'রসা', 'রসায়নবরা', 'স্ত্রী'] ,
['কঙ্গো', 'কঙ্গো গণতন্ত্র', 'কঙ্গো গণতান্ত্রিক প্রজাতন্ত্র', 'কঙ্গো জনতান্ত্রিক গণতন্ত্র', 'কঙ্গো নদী', 'জাইর', 'ফ্রেঞ্চ কঙ্গো', 'বেলজিয়ান কঙ্গো'] ,
['কচনার', 'পাকারি ফুল'] ,
['কচরী', 'পেহঁটা'] ,
['কচাটোর', 'শরাটি', 'শরাটিকা', 'সাদা বুজ্জা'] ,
['কচি-কাচা', 'চিল্লরপার্টি'] ,
['কচু', 'কন্দ', 'কেচুক'] ,
['কচ্ছ', 'কচ্ছ জেলা'] ,
['কচ্ছপ', 'কমঠ', 'কাউঠা', 'কাছিম', 'কূর্ম', 'গুপ্তপাদ'] ,
['কছর', 'কছর জেলা'] ,
['কঞ্জুস', 'কিপটে', 'কৃপণ'] ,
['কঞ্জুসি', 'কার্পণ্য', 'কৃপণতা'] ,
['কটক', 'কটক শহর'] ,
['কটকট করা', 'কিটকিট করা'] ,
['কটকটে ব্যাঙ', 'টোড', 'ভেক'] ,
['কটনি', 'কটনি জেলা', 'কটনি শহর'] ,
['কটা', 'কটাচোখী'] ,
['কটাক্ষ', 'ব্যঙ্গোক্তি'] ,
['কটাচোখি', 'বিড়ালাক্ষী'] ,
['কটাস', 'গন্ধবিড়াল'] ,
['কটি', 'কটিদেশ', 'কোমর'] ,
['কটিবন্ধ', 'কোমরবন্ধ', 'বেল্ট', 'মন্ডল', 'শৃঙ্খলা', 'হার'] ,
['কটিবস্ত্র', 'কোপীন', 'ল্যাঙট'] ,
['কটু ভাষণ', 'কুভাষণ'] ,
['কটূকথা', 'কটূবচন', 'কুবচন'] ,
['কটূফল', 'করলা'] ,
['কটূভাষী', 'মুখরা'] ,
['কটোরা', 'পেয়ালা', 'মধুপাত্র', 'সুধাপাত্র'] ,
['কট্টর', 'কট্টরপন্হী', 'গোঁড়া'] ,
['কট্টরতা ধর্মান্ধতা', 'মতান্ধতা'] ,
['কট্টরপন্থী', 'কট্টরবাদী', 'গোঁড়ামি', 'ধর্মান্ধতা', 'মতান্ধ', 'রক্ষণশীলতা'] ,
['কট্টরপন্হী', 'গোঁড়া', 'মৌলবাদী'] ,
['কঠ', 'কঠোপনিষদ'] ,
['কঠরুদ্র', 'কঠরুদ্র উপনিষদ', 'কঠরুদ্রোপনিষদ'] ,
['কঠিন কাজ', 'কঠিন কার্য', 'দুষ্কর কাজ'] ,
['কঠিন ভাবে', 'কষ্ট করে', 'কোনও মতে'] ,
['কঠিন', 'কঠিন পদার্থ', 'কঠোর', 'কড়া', 'কূট', 'কূটতাপূর্ণ', 'গূঢ়', 'জটিল', 'দুঃসাধ্য', 'দুঃসাধ্যকর', 'দুরূহ', 'দুষ্কর', 'প্যাঁচালো', 'বক্র', 'বিকট', 'মুশকিল', 'শক্ত'] ,
['কঠুয়া', 'কঠুয়া জেলা', 'কঠুয়া শহর'] ,
['কঠোদর', 'কঠোদর রোগ'] ,
['কঠোর পরিশ্রম করা', 'চেষ্টায় ফাঁক না রাখা', 'দিন-রাত এক করা'] ,
['কঠোর ব্যবহারকারী', 'রূঢ়'] ,
['কঠোর হৃদয়', 'পাষাণ হৃদয়'] ,
['কঠোর', 'কড়া', 'কর্কশ', 'রূঢ়'] ,
['কঠোরভাবে', 'ক্রূরতাপূর্বক', 'নির্দয় ভাবে', 'নির্দয়তাপূর্বক', 'বর্বরতাপূর্বক'] ,
['কড়পা', 'কড়পা জেলা', 'কড়পা শহর'] ,
['কড়লুর', 'কড়লুর জেলা', 'কড়লুর শহর', 'কুডলোর', 'কুডলোর জেলা', 'কুডলোর শহর'] ,
['কড়া নিন্দা', 'বিষোদ্গার'] ,
['কড়া', 'গাঁট', 'তেঁতো', 'তেতো', 'শক্ত'] ,
['কড়ির চিত্তি', 'চিত্তি', 'চ্যাপটা কড়ি'] ,
['কড়ে আঙুল', 'কনিষ্ঠা', 'কনিষ্ঠা গৌরী', 'কনে আঙুল'] ,
['কড়ে', 'কনিষ্ঠ'] ,
['কণা', 'কণিকা', 'ছোট কণা'] ,
['কণাদ', 'কণাদ ঋষি'] ,
['কণ্টকহীন', 'কাঁটাহীন', 'নিষ্কণ্টক', 'শূলহীন'] ,
['কণ্টফলা', 'ঘঘরবেল', 'দেবদালী', 'বন্দাল'] ,
['কণ্ঠ', 'গলা'] ,
['কণ্ঠ-মণি', 'কণ্ঠমণি'] ,
['কণ্ঠমণি', 'ঘন্টি'] ,
['কণ্ঠস্থ', 'মুখস্থ'] ,
['কণ্ডেন্সর', 'বাষ্পকে ঠাণ্ডা করে জলে পরিণত করার যন্ত্র'] ,
['কত্থক', 'কত্থক নৃত্য'] ,
['কথক', 'প্রধাণ নট', 'সূত্রধর', 'সূত্রধার'] ,
['কথন', 'কথা', 'বলা', 'বাচ্য'] ,
['কথা অনুসারে', 'কথানুসারে'] ,
['কথা কাটাকাটি', 'ঝগড়া'] ,
['কথা দেওয়া', 'প্রতিজ্ঞা করা', 'বচন দেওয়া'] ,
['কথা না রাখা', 'পাল্টি খাওয়া'] ,
['কথা বলতে আগ্রহী', 'মিশুকে'] ,
['কথা বলা', 'কথাবার্তা বলা', 'বলা', 'বার্তালাপ করা'] ,
['কথা লাগানো', 'কানা ভাঙানি করা', 'লাগানি ভাঙানি করা'] ,
['কথা শোনানো', 'লোক দেখানো'] ,
['কথা', 'ঘটনা', 'বচন', 'বাণী'] ,
['কথা-শোনানো', 'ঝগড়া', 'তর্ক', 'বাকযুদ্ধ'] ,
['কথাকলি', 'কথাকলি নৃত্য'] ,
['কথাবার্তা', 'বার্তালাপ', 'সম্ভাষণ'] ,
['কথারজাল', 'শব্দজাল'] ,
['কথোপকথন', 'সংলাপ'] ,
['কদম', 'কদম্ব', 'হরিপ্রিয়'] ,
['কদমতাল করা', 'মার্চ করা'] ,
['কদর', 'খাতির', 'মান', 'সমাদর', 'সম্মান'] ,
['কদর্যতা', 'রূপহীনতা', 'সৌন্দর্য্যহীনতা'] ,
['কদলী', 'কলা', 'রম্ভা'] ,
['কদলীজঙ্ঘা', 'রম্ভোরূ'] ,
['কদ্রু', 'নাগমাতা'] ,
['কদ্রুজ', 'নাগ', 'নাগ জাতি', 'ভূজঙ্গ', 'ভূজঙ্গম'] ,
['কনক', 'গম', 'গোধূম'] ,
['কনকচম্পা', 'কনকচাঁপা', 'কনিয়ারি', 'কর্ণিকার', 'ক্রণিকার', 'রাজপুষ্প', 'শীর্ণপত্র'] ,
['কনকাচল', 'মহাদ্রোণ', 'সুমেরু', 'সুমেরু পর্বত', 'হিমাচল', 'হিমাদ্রি', 'হেমগিরি', 'হেমপর্বত'] ,
['কনকুটকি', 'ঘোটাধৌবা', 'রেওয়াচিনি'] ,
['কনস্টিটুয়েন্সি', 'নির্বাচনকেন্দ্র', 'নির্বাচনক্ষেত্র', 'নির্বাচনী এলাকা'] ,
['কনিনীকা', 'চোখের মণি'] ,
['কনিষ্টপাণ্ডব', 'পঞ্চমপাণ্ডব', 'সহদেব'] ,
['কনিষ্ঠ', 'ছোট', 'ছোটো'] ,
['কনিষ্ঠা', 'গৌণ পত্নী', 'দুয়া', 'দুয়ো'] ,
['কনে', 'নববধূ'] ,
['কনৌজ', 'কনৌজ জেলা', 'কনৌজ শহর'] ,
['কন্টক', 'কাঁটা'] ,
['কন্টকাকীর্ণ', 'কাঁটাযুক্ত'] ,
['কন্ঠবন্ধনি', 'টাই'] ,
['কন্ঠি', 'কন্ঠি মালা'] ,
['কন্ঠ্য', 'কন্ঠ্য বর্ণ'] ,
['কন্ডাকটর', 'পরিচালক'] ,
['কন্দজ', 'কান্দ', 'মূলজ', 'মূলী', 'মূলী নদী'] ,
['কন্নড়', 'কন্নড় ভাষা', 'কন্নড় লিপি', 'কর্ণাটকবাসী'] ,
['কন্নুর', 'কন্নুর জেলা', 'কন্নুর শহর'] ,
['কন্ব', 'কন্ব ঋষি'] ,
['কন্যা', 'কন্যা রাশি', 'কন্যা রাশি বিশিষ্ট', 'কন্যারাশি', 'ছুকরী', 'বালিকা', 'মেয়ে', 'লেড়কি'] ,
['কন্যাকুমারী', 'কন্যাকুমারী জেলা'] ,
['কপট যুক্তি', 'কুচাল', 'কূট যুক্তি'] ,
['কপট', 'গুপ্তকরণ', 'গোপন', 'গোপনীয়তা', 'চতুর', 'চালবাজ', 'চালু', 'ছদ্ম', 'টালাক', 'ঠগ', 'ধূর্ত', 'পর্দা', 'প্রতারক', 'বকব্রতী', 'লুক্কায়ন', 'সতর্ক'] ,
['কপটতা', 'কুটিলতা', 'চালাকী', 'ধূর্ততা'] ,
['কপটতাপূর্ণ', 'কপটতাময়', 'কুটিল', 'ছলপূর্ণ', 'ছলময়', 'ধূর্ততাপূর্ণ', 'বক্র'] ,
['কপাল মালা', 'মুণ্ডমালা'] ,
['কপাল', 'ললাট'] ,
['কপি', 'খাতা', 'নকল', 'নোটবুক', 'প্রতিলিপি', 'ফুলকপি', 'বাঁদর', 'বানর', 'মর্কট', 'শাখামৃগ'] ,
['কপিকল', 'চরকী', 'পুলী'] ,
['কপিঞ্জল', 'কপিঞ্জল ঋষি'] ,
['কপিলা পিঁপড়ে', 'মাটা পিঁপড়ে'] ,
['কপিলা', 'কপিলা গরু', 'কপিলা নদী', 'ধবলা', 'ধবলী', 'ধবলী গাই', 'রেণুকা', 'সাদা গরু', 'সুনন্দা'] ,
['কপীশ', 'কিষ্কিন্ধাপতি', 'বানররাজ', 'মর্কটপাল', 'সুগ্রীব'] ,
['কপুরথলা', 'কপুরথলা জেলা'] ,
['কপুরি', 'কাফুরি'] ,
['কপোত', 'কভুতর', 'পারাবত', 'পায়রা'] ,
['কফ', 'থুতু', 'শ্লেষ্মা'] ,
['কফি', 'কফি গাছ'] ,
['কফি-হাউস', 'কফিহাউস'] ,
['কবচ', 'বর্ম', 'সাঁজোয়া'] ,
['কবন্ধ', 'ধড়', 'মস্তকহীন দেহ'] ,
['কবর', 'কবর দেওয়া', 'গোর দেওয়া', 'পুঁতে দেওয়া'] ,
['কবরী', 'খোঁপা'] ,
['কবরীধাম', 'কবরীধাম জেলা'] ,
['কবর্ধা', 'কবর্ধা জেলা', 'কবর্ধা শহর'] ,
['কবল', 'ঝাপটা'] ,
['কবাব খেকো', 'কবাব ভক্ষনকারী'] ,
['কবাবচিনি', 'কোরক', 'শীতলচিনি', 'সুগন্ধিফল'] ,
['কবি গঙ্গ', 'গঙ্গ'] ,
['কবি', 'কাব্যকার'] ,
['কবিতা', 'কাব্য', 'পদ', 'পদ্য'] ,
['কবিত্বপূর্ণ', 'কাব্যাত্মক', 'রসাত্মক'] ,
['কবীর পথ', 'কবীর-পথ'] ,
['কবীর পন্হী', 'কবীর-পন্হী', 'কবীরপন্হী'] ,
['কবীর', 'কবীরদাস'] ,
['কব্জা করা', 'হড়প করা', 'হাতিয়ে নেওয়া'] ,
['কব্জা', 'দ্বারসন্ধি'] ,
['কব্জি', 'করমূল', 'পাণি মূল', 'মণিবন্ধ'] ,
['কবয়িত্রী', 'মহিলা কবি'] ,
['কম করা', 'কমতি করা'] ,
['কম করানো', 'স্বল্পকরণ'] ,
['কম দামে', 'ছাড়', 'ডিস্কাউন্ট'] ,
['কম হওয়া', 'কমা', 'ক্ষীণ হওয়া', 'ন্যূন হওয়া', 'হ্রাস পাওয়া'] ,
['কম', 'কমতি'] ,
['কম-বেশী', 'ন্যূনাধিক'] ,
['কমজোর', 'দুর্বল'] ,
['কমণ্ডুল', 'পুণ্ডরীক'] ,
['কমদামী', 'সস্তা'] ,
['কমন হথ্রন', 'ক্রেটিয়েগস আক্সিকাঁথা', 'ক্রেটিয়েগস লেবিয়াগাটা', 'হোয়াইট থর্ন'] ,
['কমনীয়তা', 'কোমলতা', 'পেলবতা', 'সুকুমারতা'] ,
['কমন্দ', 'কমন্ধ'] ,
['কমলা', 'কমলা রঙ', 'কমলালেবু'] ,
['কমলাসন', 'পদ্মাসন'] ,
['কমা', 'নামা'] ,
['কমিউনিজম', 'সাম্যবাদ'] ,
['কমিউনিস্ট', 'সাম্যবাদী'] ,
['কমিটি', 'সমিতি'] ,
['কমিশনার', 'পুলিস প্রধান'] ,
['কমিশানার', 'পিডাবলুসি'] ,
['কমিয়ে দেওয়া', 'ঠাণ্ডা করা', 'শান্ত করা'] ,
['কমেরা বুলবুল', 'পাহাড়ি বুলবুল'] ,
['কমোদ', 'কমোদ রাগ'] ,
['কম্প', 'কম্পন', 'স্পন্দন'] ,
['কম্পক', 'স্পন্দক'] ,
['কম্পন করা', 'কাঁপা', 'থরথর করা', 'থরথর করে কাঁপা'] ,
['কম্পন', 'কাঁপুনি', 'শিহরণ'] ,
['কম্পমান', 'কম্পিত'] ,
['কম্পাস', 'দিকনির্ণয়কারী যন্ত্র', 'দিকনির্দেশক যন্ত্র', 'দিকসূচক', 'দিগদর্শক'] ,
['কম্পিউটার গেম', 'ভিডিয়ো গেম'] ,
['কম্পিউটার প্রোগ্রাম', 'প্রোগ্রাম'] ,
['কম্পিউটার ভাইরাস', 'ভাইরাস'] ,
['কম্পিউটার মেমোরি', 'মেমোরি'] ,
['কম্পিউটার', 'সংগণক', 'সংগণক যন্ত্র'] ,
['কম্পিউটারকৃত', 'সংগণকীকৃত'] ,
['কম্পিউটারিকরণ', 'সংগণকীকরণ'] ,
['কম্পিউটারীয়', 'কম্পিউটারের', 'সংগণকীয়'] ,
['কম্পিত হওয়া', 'কাঁপা', 'থরথর করা', 'শিহরিত হওয়া'] ,
['কম্পিল', 'কাম্পিল'] ,
['কম্পোস্ট', 'কৃত্রিম সার', 'রাসায়ণিক সার', 'সার'] ,
['কম্প্যুটার গ্রাফিক্স', 'সংগণক রেখাচিত্র'] ,
['কম্প্যুটার হার্ডওয়্যার', 'হার্ডওয়্যার'] ,
['কম্বু', 'শঙ্খ', 'শম্বুক', 'শামুক'] ,
['কম্বূ', 'শঙ্খ', 'শাঁখ'] ,
['কম্বোজ', 'কম্বোজ রাগ'] ,
['কম্বোডিয়া', 'কাম্পুচিয়া'] ,
['কম্বোডিয়ার', 'কম্বোডীয়', 'কাম্পুচিয়ার', 'কাম্পুচীয়'] ,
['কম্যুনিস্ট পার্টি অফ ইন্ডিয়া', 'সিপিআই'] ,
['কম্যুনিস্ট পার্টি অফ চায়না', 'সিপিসি'] ,
['কর আরোপণ', 'কর চাপানো', 'কর ধার্য করা'] ,
['কর জমা করা', 'কর দেওয়া'] ,
['কর নির্ধারণ', 'কর-নির্ধারণ'] ,
['কর ভাগ', 'পাণি ভাগ', 'হস্ত ভাগ', 'হাতের অংশ'] ,
['কর মাফ', 'কর মুকুব'] ,
['কর', 'শুঁড়', 'শুণ্ড', 'শুণ্ডিকা', 'সারঙ্গ', 'হস্ত', 'হাত'] ,
['করাধীন', 'খাজনা', 'গজনাসা', 'ট্যাক্স', 'দাদন', 'পথ শুল্ক', 'বাহু', 'ভূজ', 'ভূমিরাজস্ব', 'মাসুল যুক্ত', 'রোডট্যাক্স'] ,
['করক', 'কুকুরমুত্তা', 'কোঁড়ক', 'ছত্রক', 'ছত্রাক', 'ব্যাঙের ছাতা', 'মাশরুম', 'শিলীন্ধ্র'] ,
['করকা', 'শিল'] ,
['করঞ্জ', 'করঞ্জা', 'করঞ্জাস', 'করমচা', 'পানিমন্থ', 'মহাবৃক্ষ', 'সোমবল্ক'] ,
['করণ', 'করণ কারক'] ,
['করণিকবৃত্তি', 'কেরানিগিরি', 'মুহূরিবৃত্তি'] ,
['করণী', 'রাজ-পুষ্পী', 'রাজ-প্রিয়', 'রাজপুষ্পী', 'রাজপ্রিয়'] ,
['করণীয়', 'ধর্মানুসারে করণীয়', 'সাধ্য'] ,
['করতল ধ্বনি', 'করতালি', 'তালি'] ,
['করতল', 'হাত'] ,
['করতালি', 'হাততালি'] ,
['করতে পারা', 'পারা'] ,
['করনা', 'সুদর্শন'] ,
['করনাল', 'করনাল জেলা', 'করনাল শহর', 'কর্নাল'] ,
['করনালী', 'করনালী নদী'] ,
['করবার', 'করবার শহর'] ,
['করভী', 'করেণুকা', 'কুঞ্জরী', 'পদ্মিনী', 'পুষ্করীনী', 'মনাকা', 'হস্তীনি'] ,
['করমালা', 'জপমালা'] ,
['করমুক্ত', 'শুল্কমুক্ত'] ,
['করলা', 'করল্লা', 'করেলা', 'করোলা'] ,
['করসেবা', 'শ্রমদান'] ,
['করা', 'কাজ করা', 'কারণ হওয়া', 'কার্য করা', 'ধরা', 'নিয়োজিত থাকা', 'প্রত্যাখ্যান করা', 'বানানো', 'লেগে থাকা', 'সম্পূর্ণ করা', 'স্পন্দিত রাখা'] ,
['করানো', 'কাজ করানো'] ,
['করি', 'গজ', 'দ্বিপ', 'দ্রুমারু', 'পীল', 'বৃহদঙ্গ', 'মাতঙ্গ', 'লম্বকর্ণ', 'হস্তি', 'হাতি'] ,
['করিবর', 'হস্তিশ্রেষ্ঠ'] ,
['করিমগঞ্জ', 'করিমগঞ্জ জেলা', 'করিমগঞ্জ শহর'] ,
['করিমনগর', 'করিমনগর জেলা', 'করিমনগর শহর'] ,
['করীষ', 'ঘুটে', 'ঘোসি'] ,
['করুণ', 'করুণ রস'] ,
['করুণাময়', 'দয়াবান', 'দয়াময়', 'দয়ালু', 'দয়াশীল', 'সহৃদয়'] ,
['করুণী', 'রাজ-পুষ্পী', 'রাজ-প্রিয়', 'রাজপুষ্পী', 'রাজপ্রিয়', 'সূক্ষ্মা'] ,
['করুনমুখ', 'দুঃখীমুখ'] ,
['করুর', 'করুর জেলা', 'করুর শহর'] ,
['করে দেওয়া', 'পরিবর্তিত করা', 'বানানো', 'বানিয়ে দেওয়া'] ,
['করৌলী', 'করৌলী জেলা'] ,
['কর্ক', 'কোকাহ', 'পঙ্গুল', 'শ্বেতবাজী'] ,
['কর্কট রোগ', 'কর্করোগ', 'ক্যানসার'] ,
['কর্কট', 'কর্কট রাশি', 'কর্কট রাশিবিশিষ্ট', 'কর্কটক', 'কর্কটরাশি', 'কাঁকড়া', 'গুড়িয়াল', 'দানক', 'দালেলা কিলকিলা', 'বাদামী কোরিল্লা', 'মাছরাঙা'] ,
['কর্কশতা', 'কর্কশত্ব', 'কাঠিন্য'] ,
['কর্কশভাব', 'তিক্তভাব', 'নিরসভাব', 'রুক্ষতা', 'রুক্ষভাব', 'রূঢ়ভাব'] ,
['কর্ণ কুন্ডল', 'কর্ণ-কুন্ডল', 'কর্ণকুন্ডল', 'কুন্ডল'] ,
['কর্ণ কুহর', 'কর্ণ ছিদ্র', 'কানের ছিদ্র'] ,
['কর্ণ পটহ', 'কানের পর্দা'] ,
['কর্ণ', 'কান', 'শ্রবণেন্দ্রিয়', 'হাল'] ,
['কর্ণকীট', 'কেঁদরাই', 'কেণ্ডাই', 'কেন্নুই', 'কেন্নো', 'কেল্লাই', 'কেল্লো', 'ক্যারা'] ,
['কর্ণপালি', 'কর্ণলতিকা', 'লতি'] ,
['কর্ণপূর্ব গ্রন্থি', 'কর্ণপূর্ব লালা গ্রন্থি'] ,
['কর্ণপূর্বগ্রন্থিশোথ', 'কানফেড়'] ,
['কর্ণমল', 'কানের খোল', 'কানের ময়লা'] ,
['কর্ণমূল', 'শ্রোতমূল'] ,
['কর্ণাট', 'কর্ণাট রাগ'] ,
['কর্ণিকা', 'মধ্যমা'] ,
['কর্ণোপকর্ণিকা', 'গুজব', 'জনশ্রুতি'] ,
['কর্তন', 'ছিত্তি', 'ছেদন'] ,
['কর্তব্য', 'ধর্ম'] ,
['কর্তব্যপরায়ণ', 'ভরসাযোগ্য'] ,
['কর্তা', 'কর্তা কারক', 'কর্তৃকারক'] ,
['কর্ত্তা', 'কারী'] ,
['কর্দম', 'কর্দম ঋষি', 'কাদা', 'রাজা কর্দম'] ,
['কর্দমাক্ত', 'পঙ্কিল'] ,
['কর্পূর', 'রেণুসার', 'হিমাংশু'] ,
['কর্পোরেট ঘরানা', 'নিগম সংক্রান্ত'] ,
['কর্বর', 'টাইগার', 'বাঘ', 'ব্যঘ্র', 'ব্যাঘ্র', 'শার্দুল', 'শার্দূল', 'শ্বাপদ', 'হিংসারু'] ,
['কর্ম দক্ষতা', 'কার্য কুশলতা'] ,
['কর্ম', 'কর্ম কারক', 'কাজ', 'কাজ-কর্ম', 'কাজকর্ম', 'কার্য', 'কার্য্য', 'কৃত্য', 'ডিউটি'] ,
['কর্মকারের স্ত্রী', 'কামার বউ'] ,
['কর্মচারী বৃন্দ', 'স্টাফ'] ,
['কর্মচারীবৃন্দ', 'স্টাফ'] ,
['কর্মঠ', 'দক্ষ', 'প্রয়ত্নশীল'] ,
['কর্মদক্ষতা', 'ক্ষমতা', 'দক্ষতা', 'নৈপণ্য', 'পটুতা', 'পারদর্শিতা', 'যোগ্যতা', 'সক্ষমতা', 'সামর্থ্য'] ,
['কর্মনাশা', 'কর্মনাশা নদী'] ,
['কর্মফল', 'বিপাক'] ,
['কর্মবিরতি', 'কার্য অন্তরাল', 'কার্যান্তরাল', 'বিরতি'] ,
['কর্মশ্রেষ্ঠ', 'কর্মশ্রেষ্ঠ ঋষি'] ,
['কর্মহীন', 'নিষ্কম্মা', 'নিষ্কর্ম', 'ফালতু', 'বেকার'] ,
['কর্মহীনতা', 'বেকার', 'বেরোজগার'] ,
['কর্মানুসারে', 'যথাকর্ম'] ,
['কর্মারম্ঙ', 'কার্য আরম্ভ', 'কার্যারম্ভ'] ,
['কর্মীদল', 'শ্রমিক দল'] ,
['কর্রক', 'বর্রা'] ,
['কর্ষণ করা', 'খোঁড়া'] ,
['কর্ষণ করানো', 'খোঁড়ানো'] ,
['কর্ষণ', 'কৃষি কার্য', 'কৃষিকর্ম', 'জোতা'] ,
['কর্ষিত ভূমি', 'জোতার'] ,
['কর্ষিত', 'জোতা'] ,
['কল', 'মিল', 'মেশিন', 'যন্ত্র'] ,
['কল-কব্জা', 'যন্ত্রাংশ'] ,
['কলকল ধ্বনি', 'কুলকুল'] ,
['কলঙ্কলেপন', 'কালিমালেপন'] ,
['কলঙ্কিত করা', 'ডোবানো', 'বদনাম করা', 'মাথা নীচু করানো'] ,
['কলঙ্কিত', 'কলূষিত', 'দাগী', 'লাঞ্ছিত'] ,
['কলপেট্টা', 'কলপেট্টা শহর'] ,
['কলবিঙ্ক', 'চটক', 'চটকা', 'চড়ুই', 'পুরুষ চড়াই', 'বলিভুক'] ,
['কলম', 'পেন', 'লেখনী'] ,
['কলমতরাশ', 'চাকু', 'ছুরি'] ,
['কলমিস্ত্রী', 'প্লাম্বার'] ,
['কলরব করা', 'কাকলি করা', 'হাঙ্গামা'] ,
['কলরব', 'হল্লা', 'হৈ হল্লা', 'হৈচৈ'] ,
['কলরি', 'কলরি চিকিত্সা'] ,
['কলশ', 'মঙ্গল কলশ', 'মঙ্গল ঘট', 'মঙ্গলঘট'] ,
['কলস', 'কলসী', 'ঘটি', 'ঘড়া'] ,
['কলসপত্রী', 'কলসপত্রী গাছ'] ,
['কলসি', 'মাটির কলসি'] ,
['কলসী', 'গাগরী', 'ঘড়া'] ,
['কলহ করা', 'কিচকিচ করা', 'ঝগড়া করা', 'ঝামেলা পড়া', 'বিতর্কে পড়া', 'লড়া', 'লড়াই করা'] ,
['কলহ', 'ঝগড়া', 'লড়াই'] ,
['কলহপ্রিয়', 'খিটখিটে', 'ঝগড়াটে', 'লড়াকু'] ,
['কলহারা', 'চক', 'নাচনী'] ,
['কলা', 'কাজ', 'তন্ত্র', 'বংশপুরক', 'বিদ্যা', 'ভাস্কর্য', 'শিল্প প্রতিভা', 'শৈলী'] ,
['কলাকার', 'শিল্পী'] ,
['কলাকার্য', 'কলাত্মকতা'] ,
['কলাত্মক', 'কলাপূর্ণ', 'কলাময়'] ,
['কলাপ', 'কলাপক'] ,
['কলাপিনী', 'ময়ূরী'] ,
['কলাপী', 'কেকী', 'গোনর্দ', 'তাউস', 'বর্হিণ', 'বর্হী', 'শিখণ্ডী', 'শিখাধর', 'শিখাবল', 'শিখী', 'সর্পহিংসক', 'সিতাপাঙ্গ'] ,
['কলাপ্রেমী', 'কলারসিক'] ,
['কলাবাজ', 'বাজিকর', 'মাদারী'] ,
['কলি কাল', 'কলিযুগ'] ,
['কলি', 'কোরক', 'মুকুল'] ,
['কলি-সণ্টারণ', 'কলি-সণ্টারণ উপনিষদ'] ,
['কলিজা', 'মর্ম স্থল', 'হৃদয়'] ,
['কলিযুগাদ্ধ্যা', 'মাঘী'] ,
['কলিল', 'কোলাইড', 'শ্লেষ্মী পদার্থ'] ,
['কলেজ', 'মহাবিদ্যালয়'] ,
['কলেরা', 'বিসূচিকা'] ,
['কলোনি', 'বস্তি'] ,
['কলোম্বিয়ান পেসো', 'পেসো'] ,
['কলোম্বিয়ান', 'কলোম্বিয়াবাসী', 'কলোম্বিয়ার'] ,
['কল্ক', 'খইল', 'খোল', 'শিটা'] ,
['কল্কি', 'কল্কি অবতার'] ,
['কল্কিদ্বাদশী', 'শ্রবণদ্বাদশী'] ,
['কল্পনা করা', 'ধরে নেওয়া', 'মেনে নেওয়া'] ,
['কল্পনা', 'কল্পনাশক্তি', 'কল্পিত বস্তু', 'কাল্পনিক বস্তু', 'খেয়াল', 'ফ্যান্সি'] ,
['কল্পিত জায়গা', 'কল্পিত স্থান', 'কাল্পনিক দুনিয়া', 'কাল্পনিক স্থান'] ,
['কল্পিত জীব', 'কাল্পনিক জীব', 'কাল্পনিক প্রাণী'] ,
['কল্মাষপাদ', 'প্রবৃদ্ধ'] ,
['কল্যাণ', 'কল্যাণ রাগ', 'মঙ্গল', 'শুভ', 'হিত'] ,
['কল্যাণকামী', 'শুভচিন্তাকারী', 'শুভাকাঙ্খী', 'শুভেচ্ছেক', 'হৈতেষী'] ,
['কল্যাণকারী', 'কল্যাণময়', 'মঙ্গলকারী', 'হিতকর'] ,
['কল্যাণার্থ', 'হিতার্থ'] ,
['কল্লোলিনী', 'তটিনী', 'তরঙ্গিনী', 'নদী'] ,
['কশাঘাত স্তম্ভ', 'থাম', 'স্তম্ভ'] ,
['কশাড়', 'কাশ', 'কাশতৃণ', 'কাশফুল', 'কেশে', 'সিতপুষ্প'] ,
['কশীপ', 'তারাধিপ', 'তারানাথ', 'তারাপতি', 'তারেশ', 'বালী', 'সুগ্রীবাগ্রজ'] ,
['কশেরুকা দণ্ড', 'মেরুদণ্ড'] ,
['কষা', 'কষালো'] ,
['কষে বাঁধা', 'বাঁধা'] ,
['কষ্ট পাওয়া', 'দুঃখ করা', 'দুঃখ পাওয়া'] ,
['কষ্ট সহ্য করা', 'দুঃখ সহ্য করা'] ,
['কষ্ট', 'ক্লেশ', 'ছটফটানি', 'দুঃখ', 'পীরা', 'ব্যাথা', 'যন্ত্রণা'] ,
['কষ্টকর', 'কষ্টদায়ী', 'দুঃখদায়ী'] ,
['কষ্টপূর্ণ', 'দুঃখময়', 'বিষণ্ণ', 'বিষাদময়'] ,
['কসরত করানো', 'ব্যায়াম করানো'] ,
['কসরত', 'ব্যায়াম', 'ব্যয়াম'] ,
['কসরতবাজের খেলা', 'কসরতি'] ,
['কসাই', 'ক্রূড় ব্যক্তি', 'জল্লাদ', 'নির্দয় ব্যক্তি', 'নির্দয়ী ব্যক্তি', 'নিষ্ঠুর ব্যক্তি'] ,
['কসাইখানা', 'বধ্যভূমি'] ,
['কসারাগোড', 'কসারাগোড শহর'] ,
['কস্তুর', 'কস্তুরী', 'মৃগনাভি', 'মৃগমদ'] ,
['কস্তুরবা', 'কস্তুরবা গান্ধী', 'বা'] ,
['কস্তুরী মৃগ', 'কস্তুরী হরিণ'] ,
['কাঁই কাঁই করা', 'চিলচিত্কার করা'] ,
['কাঁচ সারস', 'বাকরুকা', 'হরিবতক'] ,
['কাঁচা আম রঙ', 'কাঁচা আমের রঙ'] ,
['কাঁচা ফিল্মের দৈর্ঘ্য', 'ফুটেজ'] ,
['কাঁচা রং', 'কাঁচা রঙ', 'যে রঙ টেকে না'] ,
['কাঁচা হলুদ', 'হলুদ'] ,
['কাঁচামিঠে', 'টকমিষ্টি'] ,
['কাঁচুলি', 'বক্ষবন্ধনী'] ,
['কাঁটা', 'পেরেক', 'বরশি', 'মাছের কাঁটা'] ,
['কাঁটাওয়ালা', 'দাড়াওয়ালা'] ,
['কাঁঠাল', 'পুতিকাষ্টক'] ,
['কাঁদা', 'ক্রন্দন করা', 'রোদন করা'] ,
['কাঁপা', 'ফরফর করা', 'লাফানো'] ,
['কাঁসা', 'কাঁসা ধাতু'] ,
['কাঁসারি', 'কাঁসারী'] ,
['কাঁহর', 'কানহর'] ,
['কাঁড়া', 'কান্ডা'] ,
['কাঁড়ী', 'কাড়ী'] ,
['কাংকের', 'কাংকের শহর'] ,
['কাংশী', 'কাংশী নদী'] ,
['কাউন্সিল', 'পরিষদ'] ,
['কাক ভুষুন্ডি', 'কাকভুষুন্ডি', 'ভুষুন্ডি'] ,
['কাককঙ্গু', 'কাকুন', 'জনারি', 'বহুদল'] ,
['কাকচ্ছদি', 'পাপরি'] ,
['কাকতালীয় ব্যাপার', 'মিল', 'সংযোগ', 'সমকালীনতা', 'সমস্থানিকতা'] ,
['কাকনি', 'কাকনি নদী'] ,
['কাকনী', 'কাকিণী', 'কোকিণী'] ,
['কাকলী', 'তৈলস্যন্দা', 'তৈসস্যন্দা', 'রসা', 'শতপাদিকা'] ,
['কাকা', 'তাত'] ,
['কাকাও', 'কোকো'] ,
['কাকিনাড়া', 'কাকিনাড়া শহর'] ,
['কাকেক্ষু', 'খাগ', 'খাগড়া', 'নলখাগড়া', 'পোটগল', 'শর'] ,
['কাগজ', 'কাগজপত্র', 'খবরের কাগজ', 'দস্তাবেজ', 'পত্র', 'পত্রপত্রিকা', 'পত্রিকা', 'পেপার', 'লিখিত প্রমাণ', 'সংবাদপত্র'] ,
['কাগজী', 'কাগজের', 'কাগুজে'] ,
['কাগজের মুদ্রা', 'পেপার মানি'] ,
['কাঙাল', 'গরীব', 'দরিদ্র', 'দীন', 'ধনহীন', 'নির্ধন'] ,
['কাঙ্গরা', 'কাঙ্গরা জেলা', 'কাঙ্গরা শহর'] ,
['কাঙ্গো', 'কাঙ্গো চা'] ,
['কাচলবণ', 'পাংশুক্ষার', 'পাংশুজ', 'বসির', 'মণিমন্থ', 'মাণিবন্ধ', 'সিন্ধুব', 'সৈন্ধ', 'সৈন্ধব লবণ'] ,
['কাচা হওয়া', 'ধোয়া হওয়া'] ,
['কাচানো', 'ধোওয়ানো', 'ধোলাই করানো'] ,
['কাছি', 'দড়ি', 'মোটা দড়ি', 'রজ্জু', 'রশি'] ,
['কাছে', 'পাড়ে', 'পাশে'] ,
['কাছের জমি', 'পার্শ্ববর্তী জমি'] ,
['কাছের', 'নিকট', 'নিকটস্থ', 'সন্নিকট', 'সমীপবর্তী', 'সমীপস্থ', 'সমীপের'] ,
['কাজ করা', 'কাজে লাগা', 'চলা', 'চাকরি করা', 'প্রভাবশালী'] ,
['কাজ চালানো', 'কাজ হওয়া'] ,
['কাজ দেওয়া', 'চাকরি দেওয়া', 'নিযুক্ত করা', 'ভর্তি করা', 'রাখা'] ,
['কাজ না কর', 'খারাপ হওয়া'] ,
['কাজ', 'কৃতি', 'ক্রিয়া', 'মামলা', 'রচনা', 'শ্রম'] ,
['কাজকর্ম', 'রোজগার'] ,
['কাজচালানোর মতো', 'বিশেষত্বহীন', 'মামুলি', 'সাধারণ', 'সাধারণ'] ,
['কাজল', 'নেত্রাঞ্জন', 'সুরমা'] ,
['কাজলের টিপ', 'নজর না লাগার টিকা'] ,
['কাজাক', 'কাজাকবাসী'] ,
['কাজাকস্তান', 'কাজাকিস্তান'] ,
['কাজালাড্ডু', 'কাজালাড্ডু আম', 'কাজালাড্ডু আম গাছ'] ,
['কাজে না আসা', 'ব্যর্থ হওয়া'] ,
['কাজে লাগানো', 'খরচ করা', 'ব্যবহার করা'] ,
['কাজে', 'কারণে', 'প্রয়োজনে'] ,
['কাঞ্চন', 'স্বর্ণ নির্মিত', 'হেম'] ,
['কাঞ্চী জেলা', 'কাঞ্চীপুরম জেলা'] ,
['কাঞ্চী', 'কাঞ্চীপুরম', 'কাঞ্চীপুরম শহর'] ,
['কাটা', 'কামড়ানো', 'কামিয়ে ফেলা', 'কোঁদা', 'ক্ষত', 'খন্ডিত', 'খোদাই করা', 'খোদিত', 'ছাঁটা', 'ছাড়া', 'ছিন্ন', 'তৈরী করা', 'দংশন করা', 'নামা'] ,
['কাটা-ছেঁড়া', 'ছেঁড়া', 'বিদারণ'] ,
['কাটাই করা', 'ফসল কাটা'] ,
['কাটাকাটি', 'দাঙ্গা', 'প্রহার', 'মার-কাট', 'মারদাঙ্গা', 'মারধর', 'মারপিট', 'মারমার কাটকাট', 'মারামারি', 'রক্তগঙ্গা', 'রক্তপাত', 'রক্তারক্তি'] ,
['কাটানো', 'কামানো'] ,
['কাটালান', 'কাটালান ভাষা'] ,
['কাটিম', 'নাটাই', 'লাটিম'] ,
['কাটিহার', 'কাটিহার জেলা', 'কাটিহার শহর'] ,
['কাটু', 'হিজলী'] ,
['কাট্য', 'খণ্ডনীয়'] ,
['কাঠ', 'দারু'] ,
['কাঠ-ব্রীজ', 'কাঠের ব্রীজ'] ,
['কাঠচিনার', 'ফল্গুবাটিকা', 'রাজফল্গু'] ,
['কাঠপিঁপড়ে', 'পিঁপড়ে'] ,
['কাঠবিড়ালী', 'কাঠবেড়ালী'] ,
['কাঠবেড়ালিমার', 'জুমীজ', 'বঘাতী'] ,
['কাঠমিস্ত্রি', 'কাঠের মিস্ত্রি'] ,
['কাঠসেমুল', 'ফিটসেন'] ,
['কাঠামো', 'গঠন', 'ফ্রেম'] ,
['কাঠিন্য', 'বাঁধা', 'মুশকিল'] ,
['কাঠিয়াবাড়ী', 'কাঠিয়াবাড়ের'] ,
['কাঠের খাঁচা', 'কাষ্ঠ খাঁচা'] ,
['কাঠের তৈরী', 'কাষ্ঠীয়'] ,
['কাঠের পায়া', 'পায়া'] ,
['কাঠের পুতুল', 'কাষ্ঠ পুত্তলিকা'] ,
['কাণ্ড', 'স্কন্ধ'] ,
['কাণ্ডব', 'কাণ্ডব ঋষি'] ,
['কাণ্ডারী', 'খেয়ামাঝি', 'দাঁড়ী', 'নাইয়া', 'নেয়ে', 'নৌকাচালক', 'নৌকাবাহক', 'নৌবাহ', 'মাঝি', 'মাঝিমাল্লা', 'মাল্লা', 'হালী'] ,
['কাতার', 'কাতার রাজ্য', 'স্টেট অফ কাতার'] ,
['কাতারবাসী', 'কাতারি'] ,
['কাতারি দিরেম', 'দিরেম'] ,
['কাতারি রিয়াল', 'রিয়াল'] ,
['কাতুকুতু দেওয়া', 'সুড়সুড়ি দেওয়া'] ,
['কাত্য', 'কাত্য ঋষি'] ,
['কাত্যায়ন', 'কাত্যায়ন ঋষি', 'মেধাজিত'] ,
['কাদাময়', 'থকথকে'] ,
['কাদাযুক্ত', 'পঙ্কিল'] ,
['কাদ্মবরী', 'চিত্রপদা', 'পাঠমঞ্জরী', 'ময়না', 'সারি', 'সারিকা'] ,
['কান', 'বাদ্য খুঁটি'] ,
['কানতড়কা', 'তরপত'] ,
['কানপট্টী', 'গণ্ডস্হল', 'গাল'] ,
['কানপুর', 'কানপুর শহর'] ,
['কানা উঁচু', 'কিনারাওয়ালা'] ,
['কানাডবাসী', 'কানাডিয়ান'] ,
['কানাড়া', 'কানাড়া রাগ'] ,
['কানাডিয়ান ডলার', 'ডলার'] ,
['কানাডিয়ান', 'কানাডীয়'] ,
['কানাত', 'চাঁদোয়া', 'পাইল', 'বিতান'] ,
['কানীন', 'কৃষ্ণ দ্বৈপায়ন', 'পারাশর', 'বেদব্যাস', 'মহর্ষি ব্যাস', 'সাত্যবত'] ,
['কানে কানে কথা বলা', 'ফিসফিস করা'] ,
['কানের দুল', 'দুল. কর্ণালংকার', 'প্যাঁচ'] ,
['কান্ড', 'ভাগ'] ,
['কান্ত', 'কামিনীকান্ত', 'জীবনসঙ্গী', 'জীবনসাথী', 'নাথ', 'পতি', 'পুরুষ', 'প্রাণনাথ', 'বর', 'স্বামী'] ,
['কান্তার', 'গহন বন', 'মহারণ্য', 'সঘন বন'] ,
['কান্তি', 'ছটা', 'ঝলক', 'শোভা', 'সৌন্দর্য'] ,
['কান্তিধর', 'কান্তিময়', 'দীপ্তিমান'] ,
['কান্ধামাল', 'কান্ধামাল জেলা', 'কান্ধামাল শহর'] ,
['কান্না পাওয়া', 'গলা বুজে আসা'] ,
['কান্না', 'ক্রন্দন'] ,
['কান্নাকাটি করা', 'বিলাপ'] ,
['কাপড় মেলার বাঁশ', 'দড়ি কাপড় মেলার দড়ি'] ,
['কাপড়', 'জামা', 'পরিধান', 'পোষাক', 'বস্ত্র', 'বেশ'] ,
['কাপড়ের থান', 'থান'] ,
['কাপিশ', 'চামেলি', 'জাতিপুষ্প', 'মাধবি', 'মালতী'] ,
['কাপুরষতা', 'ভীত', 'ভীরুতা'] ,
['কাপুরুষ', 'নপুংসক', 'পলায়িত', 'ভীতু', 'ভীরু'] ,
['কাপ্তান', 'ক্যাপ্টেন'] ,
['কাফল', 'কায়ফল'] ,
['কাফি', 'কাফি রাগ'] ,
['কাফির', 'কাফের'] ,
['কাফেলা', 'কারাভাঁ'] ,
['কাবলি', 'কাবুলি'] ,
['কাবুল', 'কাবুল নদী'] ,
['কাব্যপ্রেমী', 'কাব্যরসিক'] ,
['কাম', 'কাম বাসনা'] ,
['কাম-শর', 'কামবাণ', 'কামশর', 'কামাযুদ্ধ', 'প্রেমশর', 'বাণ', 'স্মর', 'স্মর-বাণ'] ,
['কাম-শাস্ত্র', 'কামশাস্ত্র'] ,
['কাম-সুত্র', 'কামসুত্র'] ,
['কামড়', 'দংশন', 'সর্পদংশন', 'সাপের কামড়'] ,
['কামড়ানো', 'দংশন করা', 'হুল ফোটানো'] ,
['কামদা', 'কামধেনু', 'গোকন্যা', 'সুরধেনু', 'সুরভি'] ,
['কামদেবী', 'প্রীতি'] ,
['কামধেনু', 'কামধেনু নদী', 'চম্বল', 'চম্বলে নদী', 'চর্মাবতী', 'চর্মাবতী নদী'] ,
['কামনা', 'কামোদ্দীপনা', 'কামোদ্বেগ'] ,
['কামনারহিত', 'নিরাসক্ত', 'বিবাগী', 'বিমুখ', 'বৈরাগী', 'সন্ন্যাসী'] ,
['কামবতী', 'কামিনী'] ,
['কামরা', 'যাত্রী যান'] ,
['কামরূপ', 'কামরূপ জেলা'] ,
['কামশক্তি বর্ধক', 'বীর্যবর্ধক'] ,
['কামহীন', 'নিষ্কাম', 'বাসনাহীন'] ,
['কামাক্ষী আম্মা মন্দির', 'কামাক্ষী মন্দির'] ,
['কামাঠী', 'কামাঠী জাতি'] ,
['কামাতুর', 'কামান্ধ'] ,
['কামানি', 'কামানি আম', 'কামানি আম গাছ'] ,
['কামানের গোলা', 'গাদা কামানের গোলা'] ,
['কামার', 'কামার জাতি', 'লোহার', 'লৌহকার'] ,
['কামারের চুল্লি', 'চুল্লি'] ,
['কামায়নী', 'শ্রদ্ধা'] ,
['কামায়ুধ', 'পুরুষ জননেন্দ্রিয়', 'পুরুষেন্দ্রিয়', 'রতিসাধন', 'লাঙ্গুল', 'লিঙ্গ', 'শিশ্ন'] ,
['কামিনী', 'বিলাসিনী', 'রমণী', 'রূপসী', 'ললিতা', 'সুন্দরী', 'সুন্দরী মহিলা'] ,
['কামুক', 'দুশ্চরিত্র', 'ব্যভিচারী', 'ভোগী', 'লম্পট'] ,
['কামেঙ্গ', 'কামেঙ্গ নদী'] ,
['কামোদ', 'কামোদ রাগ'] ,
['কামোদা', 'কামোদী'] ,
['কাম্বোডিয়ানা', 'কাম্বোডিয়ানা আম'] ,
['কার পার্ক', 'পার্কিং লট'] ,
['কারখানা', 'ফ্যাক্টারী', 'মিল'] ,
['কারগিল', 'কারগিল জেলা', 'কারগিল শহর'] ,
['কারণবশতঃ', 'কারণে'] ,
['কারণে', 'জন্য'] ,
['কারণ্ডব', 'মরাল', 'শ্বেতচ্ছদ', 'সিতপক্ষ', 'হংস', 'হাঁস'] ,
['কারবন', 'কার্বন', 'কার্বন পেপার'] ,
['কারবার', 'লেন-দেন'] ,
['কারলোটা', 'কারলোটা আম', 'কারলোটা আমের গাছ'] ,
['কারাগারকর্মী', 'জেলকর্মী'] ,
['কারাগারাধিকারিক', 'জেলর'] ,
['কারাবকাশ', 'প্যারোল', 'শর্তাধীন মুক্তি'] ,
['কারাবাস', 'কয়েদ', 'জেল', 'জেলখানা'] ,
['কারাবাসী', 'কয়েদি', 'বন্দী'] ,
['কারিগর', 'মিস্ত্রী'] ,
['কারিগরি', 'হস্তশিল্প'] ,
['কারীগর', 'মিস্ত্রী'] ,
['কারীগরী', 'শিল্পকারী', 'হস্ত শিল্প', 'হস্তকলা', 'হস্তশিল্প'] ,
['কারুকাজ করা', 'কারুকার্য করা', 'সুতোর কাজ করা'] ,
['কারুকার্য', 'ফুল'] ,
['কারেন্ট অ্যাকাউন্ট', 'চালু খাতা'] ,
['কারেন্ট', 'বিদ্যুত্ প্রবাহ'] ,
['কারৈকল', 'কারৈকল শহর'] ,
['কারোর দৃষ্টিকোণ থেকে', 'কারোর বিচারে', 'কারোর মতে', 'কারোর হিসাবে'] ,
['কারোর দ্বারা', 'কারোর মারফত্', 'মাধ্যমে'] ,
['কার্টুন', 'ব্যঙ্গ চিত্র'] ,
['কার্ড', 'তাস'] ,
['কার্ডিয়ো', 'কার্ডিয়ো ব্যায়াম'] ,
['কার্তবীর্য অর্জুন', 'সহস্রার্জুন'] ,
['কার্তিক-কৃষ্ণ একাদশী', 'রমা একাদশী'] ,
['কার্তুজ', 'টোটা'] ,
['কার্ত্তিক', 'কার্ত্তিক মাস'] ,
['কার্পেট', 'গালচে', 'গালিচা', 'মখমল'] ,
['কার্বন ডাই অক্সাইড', 'কার্বনডাইঅক্সাইড'] ,
['কার্বি আংগলাংগ', 'কার্বি আংগলাংগ জেলা', 'কার্বি আঙ্গলাঙ্গ'] ,
['কার্য উপলব্ধি', 'কার্যোপলব্ধি'] ,
['কার্য কলাপ', 'কার্যকলাপ', 'ক্রিয়া-কলাপ', 'ক্রিয়াকলাপ', 'গতিবিধি'] ,
['কার্য নিবৃত্তি', 'কার্য সমাপ্তি', 'কার্য সিদ্ধি', 'কার্যপূর্তি'] ,
['কার্য বিধি', 'কার্য শৈলী', 'কার্য-বিধি', 'পদ্ধতি'] ,
['কার্য সমাপন', 'কার্য সম্পূরণ', 'পরিসমাপন', 'পরিসমাপ্তি', 'সমাপ্তি'] ,
['কার্য সমিতি', 'কার্যকারী সমিতি', 'ব্যবস্থাপক সমিতি'] ,
['কার্য সূচী', 'কার্যসূচী'] ,
['কার্য-কাল', 'কার্যকাল'] ,
['কার্য-পদ্ধতি', 'কার্য-প্রণালী', 'কার্যপদ্ধতি', 'কার্যপ্রণালী'] ,
['কার্যকরী', 'প্রভাবশালী'] ,
['কার্যকারী', 'কার্যবাহক'] ,
['কার্যক্রম', 'প্রোগ্রাম'] ,
['কার্যক্রমসূচী', 'সময়তালিকা', 'সময়সূচী'] ,
['কার্যরত', 'জড়ো হওয়া লোক', 'নিযুক্ত', 'প্রবৃত্ত'] ,
['কার্যাঙ্ক', 'তকমা', 'পদচিহ্ন', 'ব্যাজ'] ,
['কার্যালয়', 'দফতর', 'দফ্তর'] ,
['কার্যালয়সংক্রান্ত', 'সরকারী'] ,
['কার্শ্য', 'কৃশতা', 'ক্ষীণতা'] ,
['কার্সার', 'পয়েণ্টার'] ,
['কাল দেবতা', 'মৃত্যুদেবতা', 'যম', 'যমদেব', 'যমরাজ'] ,
['কাল ভৈরব', 'কালনাথ', 'পাপভক্ষণ'] ,
['কাল মাপ', 'সময়ের একক'] ,
['কাল মুর্ঘ', 'কালমুর্ঘ', 'গোবর শকুন', 'গোবরশকুন', 'সাদাশকুন'] ,
['কাল সর্প', 'কালসাপ'] ,
['কাল সীমা', 'সময় সীমা'] ,
['কাল', 'গতকাল', 'জমানা', 'দিন', 'বেলা', 'যুগ', 'সময়'] ,
['কাল-রাত্রী', 'কালনিশা', 'কালরাত্রী'] ,
['কালকন্ঠ', 'খঞ্জনী', 'খন্ডরিচ', 'তাত', 'ভদ্র', 'মদনপাখি', 'মামোলা'] ,
['কালকা', 'কালকা শহর'] ,
['কালকূট', 'সিন্ধুবিষ', 'হলাহল'] ,
['কালক্রম', 'কালানুক্রম', 'কালানুক্রমিক', 'কালান্তর', 'যুগযুগান্ত', 'যুগান্তর', 'সময়ানুসার'] ,
['কালচে লাল', 'মেরুন'] ,
['কালনাগ', 'কালসাপ', 'কৃষ্ণসাপ', 'কেউটে', 'গোখরা', 'গোখুরা'] ,
['কালপর্ণী', 'কালমল্লিকা', 'কৃষ্ণ তুলসী', 'পাপনাশিনী', 'শ্যাম তুলসী'] ,
['কালপ্রমেহ', 'কালপ্রমেহ রোগ'] ,
['কালবিলম্ব', 'বিলম্বন'] ,
['কালমাপক ঘড়ি', 'কালমাপী ঘড়ি', 'মেরিন ক্রোনোমিটার', 'সময়নির্ধারনকারী সুক্ষ্ম ঘড়ি'] ,
['কালমেঘ', 'সবুজ চিরতা'] ,
['কালসিরী', 'গুল্দুম', 'বুলবুল'] ,
['কালা পানি', 'কালাপানি'] ,
['কালা', 'কৃষ্ণ', 'বধির', 'শ্যাম'] ,
['কালাগ্নিরুদ্র', 'কালাগ্নিরুদ্র উপনিষদ', 'কালাগ্নিরুদ্রোপনিষদ'] ,
['কালান্তরে', 'সময়ান্তরে'] ,
['কালাহাণ্ডী', 'কালাহাণ্ডী জেলা'] ,
['কালি', 'মসি'] ,
['কালিমা', 'মলীনতা'] ,
['কালিয়া', 'কালিয়া নাগ'] ,
['কালী সিন্ধু', 'কালী সিন্ধু নদী'] ,
['কালী', 'কালী নদী'] ,
['কালীদাস', 'মহাকবি কালীদাস'] ,
['কালীয়ক', 'কালো ধূপ', 'কেশ্য'] ,
['কালেক্টরেট', 'জেলাধিকারী কার্যালয়'] ,
['কালো কাঁক পাখি', 'কালো সারস পাখি'] ,
['কালো কান বিশিষ্ট সাদা ঘোড়া', 'সাদা ঘোড়া'] ,
['কালো গরুড়', 'কৃষ্ণ সুপর্ণ', 'দ্রোণক', 'ভল্লক'] ,
['কালো ছিদ্র', 'ব্যাল্ক হোল', 'ব্যাল্কহোল'] ,
['কালো ঝান্ডা', 'কালো ধ্বজা', 'কালো পতাকা'] ,
['কালো টাকা', 'ব্যাল্ক মানি'] ,
['কালো তিতির', 'চিত্রপক্ষ'] ,
['কালো নুন', 'সৈন্ধব লবণ'] ,
['কালো পাপিয়া', 'চাতক', 'শৈশির', 'সারঙ্গ', 'সারঙ্গ চাতক'] ,
['কালো বাজার', 'কালো বাজারী', 'কালোবাজার', 'কালোবাজারী'] ,
['কালো ভৃঙ্গরাজ', 'কেশরাজ', 'ভৃঙ্গরাজ'] ,
['কালো সড়ষে', 'কালো সড়িষা'] ,
['কালো', 'কালো রঙ', 'কৃষ্ণ বর্ণ', 'কৃষ্ণবর্ণ', 'কৃষ্ণাঙ্গ', 'শ্যামবর্ণ'] ,
['কালোচিত', 'সময়ানুকূল', 'সময়োচিত', 'সময়োপযোগী'] ,
['কাশি বিশ্বনাথ', 'বাবা বিশ্বনাথ', 'বিশ্বনাথ', 'বিশ্বনাথ বাবা', 'বিশ্বনাথ মন্দির'] ,
['কাশী', 'কাশী নগর', 'বারাণসী', 'বারাণসী জেলা', 'মুক্তিক্ষেত্র', 'শিবপুরী'] ,
['কাশীর', 'বারাণসীর'] ,
['কাশ্মরী', 'গম্ভারী', 'দ্বিতীয় ত্রিফলা', 'ভদ্রা', 'মুকুন্দ', 'সিধুপর্ণী', 'সিন্ধুবেষণ'] ,
['কাশ্মীর', 'জম্মু এবং কাশ্মীর', 'জম্মু কাশ্মীর'] ,
['কাশ্মীরি', 'কাশ্মীরি ভাষা'] ,
['কাশ্যপ', 'কাশ্যপ ঋষি', 'ভূতাঙ্কুশ', 'সুর-তাত'] ,
['কাশ্যপেয়', 'খগপতি', 'খগরাজ', 'খগাধিপ', 'খগেন্দ্র', 'গরুড়', 'গরুত্মান', 'গৃধ্র', 'তার্ক্ষ্য', 'পক্ষীন্দ্র', 'পক্ষীরাজ', 'পতগ', 'পতত্রীরাজ', 'পন্নগাশন', 'বিনতানন্দন', 'বৈনতেয়', 'সর্পভুক', 'সর্পাশন', 'সিতানন', 'সূপর্ণ', 'সৌপর্ণ', 'স্বর্ণপক্ষ'] ,
['কাষ্ঠ শুক', 'রাজশুক'] ,
['কাসনি', 'কাসনি রঙ'] ,
['কাস্তে', 'ঝপাব'] ,
['কায়-চিকিত্সা', 'কায়চিকিত্সা'] ,
['কায়দা করে', 'কায়দা মেরে'] ,
['কায়দা', 'ঢঙ', 'ধরণে', 'বিধি', 'রীতি'] ,
['কায়স্থ', 'কায়স্থ জাতি'] ,
['কায়স্থা', 'কায়স্থিনী'] ,
['কায়া কল্প', 'কায়া-কল্প', 'কায়াকল্প'] ,
['কায়া-বদল', 'কায়াপরিবর্তণ'] ,
['কায়াপরিবর্তণ', 'কায়াবদল'] ,
['কায়িক', 'দৈহিক', 'শারীরির'] ,
['কি কারণে', 'কিসের জন্য', 'কেন', 'কেন নদী'] ,
['কি প্রকারে', 'কিভাবে'] ,
['কি প্রকারের', 'কিরকম', 'কেমন'] ,
['কি', 'চাবি', 'পেণ্ট'] ,
['কি.মি', 'কিলোমিটার'] ,
['কিংকর্তব্য-বিমূঢ়', 'দ্বিধাগ্রস্ত'] ,
['কিংকর্তব্যবিমূঢ়', 'ভ্যাবাচ্যাকা', 'হকচকিয়ে যাওয়া', 'হতবাক'] ,
['কিংবদন্তি', 'জনরব', 'জনশ্রুতি', 'প্রবাদ', 'লোককথা', 'লোকগাঁথা'] ,
['কিংশাসা', 'লিওপোল্ডবিল'] ,
['কিংশুক', 'পলাশ', 'পলাশফুল'] ,
['কিউই', 'নিউজিল্যান্ড বাসী', 'নিউজিল্যান্ডি'] ,
['কিউব', 'ঘনফল'] ,
['কিউবান পেসো', 'পেসো'] ,
['কিকর', 'বাবুল'] ,
['কিকরে', 'কিপ্রকারে', 'কিভাবে'] ,
['কিঙ্কির', 'লালডানা বিশিষ্ট চাতক', 'স্তোতক'] ,
['কিঙ্গ', 'বি বি কিঙ্গ', 'বিলি জিন কিঙ্গ', 'রিলে বি কিঙ্গ'] ,
['কিছু একটা', 'কেউকেটা'] ,
['কিছুরকারোর নামে পুরস্কার ঘোষণা করা হয়েছে এমন', 'পুরস্কার', 'পুরস্কার সম্বন্ধীয়'] ,
['কিঞ্চুলক', 'কেঁচো', 'গণ্ডুপদ', 'ভূলতা', 'মহীলতা', 'শিলীন্ধ্রী'] ,
['কিডনি', 'বৃক্ক'] ,
['কিণ', 'গোখরু', 'ঘট্ঠা'] ,
['কিনার', 'ধার'] ,
['কিনারা বানানো', 'বর্ডার বানানো'] ,
['কিনারা', 'কোনা', 'তট', 'তীর', 'ধার', 'প্রান্ত', 'প্রান্তভাগ'] ,
['কিনারায় থাকা', 'সীমান্তে থাকা'] ,
['কিন্তু-কিন্তু করা', 'চলচিত্ততা', 'দ্বিধাগ্রস্ত হওয়া'] ,
['কিন্নর', 'কিন্নর জাতি', 'কিন্নর জেলা', 'গন্ধর্ব', 'দেবগায়ন'] ,
['কিপ্টে', 'কৃপণ'] ,
['কিরগিজ', 'খিরগিজ'] ,
['কিরগিজস্তান বাসী', 'কিরগিজস্তানি'] ,
['কিরগিজস্তানি সোম', 'সোম'] ,
['কিরন্ডি', 'কিরুন্ডি'] ,
['কিরাঞ্চী', 'গরুর গাড়ি'] ,
['কিরিবাটী', 'কিরিবাটী গণরাজ্য', 'কিরিবাটী জনতন্ত্র'] ,
['কিরৌলা', 'লহতোরা'] ,
['কির্রা', 'চেতা', 'পটারি'] ,
['কিল', 'ঘুষি', 'থাপ্পর', 'থাবরা'] ,
['কিলকিলা কপর্দিক', 'চিতরা কোরিয়াল', 'চিতলা কিলকিলা', 'মাছরাঙা'] ,
['কিলকৈয়া', 'কিলকৈয়া রোগ'] ,
['কিলাঙ্গ শহর', 'কেলাঙ্গ শহর'] ,
['কিলো', 'কিলোগ্রাম'] ,
['কিশমিশ', 'দ্রাক্ষা'] ,
['কিশলয়', 'নতুন পাতা', 'নব পল্লব'] ,
['কিশোর অপরাধ বিচারালয়', 'জুভেনাইল কোর্ট'] ,
['কিষানগঞ্জ', 'কিষানগঞ্জ জেলা', 'কিষানগঞ্জ শহর'] ,
['কিষ্কিন্ধ', 'কিষ্কিন্ধা'] ,
['কিষ্কিন্ধ্যা কাণ্ড', 'কিষ্কিন্ধ্যাকাণ্ড'] ,
['কিসমিস', 'মনাক্কা'] ,
['কিসহিলি', 'কিসহিলি ভাষা', 'সহিলি'] ,
['কিস্তিতে', 'দফায় দফায়'] ,
['কীচক', 'খাগ', 'খাগড়া', 'নল', 'শর'] ,
['কীট', 'কীট আম', 'পোকা'] ,
['কীটভোজী', 'কীটভোজী জীব', 'কীডভক্ষী'] ,
['কীটো', 'কীয়োটো'] ,
['কীমোথেরাপি', 'রসায়ন-উপাচার', 'রসায়ন-চিকিত্সা', 'রসায়ন-চিকিত্সা'] ,
['কীর্তন', 'সংকীর্তন'] ,
['কীর্তি', 'কীর্তিকলাপ'] ,
['কীর্তিমান', 'বিখ্যাত', 'যশস্বী'] ,
['কীলক', 'নাগদন্ত'] ,
['কু কু করা', 'কুহু কুহু করা'] ,
['কুঁকড়ি', 'কুক্কুটী', 'মুরগি', 'রামপাখি', 'শিখন্ডিক'] ,
['কুঁকড়ে যাওয়া', 'কুঁচকানো', 'কুঁচকে যাওয়া', 'সঙ্কুচিত হওয়া'] ,
['কুঁচকানো', 'ভাঁজ করে ফেলা'] ,
['কুঁচকে যাওয়া', 'বলিরেখা পড়া', 'ভাঁজ পড়া', 'সংকুচিত হওয়া'] ,
['কুঁচি', 'কুটি', 'ছাঁট', 'টুকরো', 'ফালি'] ,
['কুঁজ', 'কুঁজা', 'কুঁজো', 'কুব্জ', 'গড়ু'] ,
['কুঁজি', 'কুব্জা'] ,
['কুঁজো', 'কুব্জ', 'ভগ্নপৃষ্ঠ'] ,
['কুঁড়েঘর', 'কুটির', 'কুটীর'] ,
['কুঁদ', 'কুঁদ কর্ম', 'কুন্দ', 'কুন্দ পর্বত'] ,
['কুঁদকল', 'লেদ মেশিন'] ,
['কুঁদন করা', 'কোঁদন করা'] ,
['কুঁদরু', 'কুঁদলী'] ,
['কুক', 'পাচক', 'মহারাজ', 'রাধুনি', 'রান্নার ঠাকুর'] ,
['কুকরোদ', 'তাম্রচূড়'] ,
['কুকার', 'প্রেশার কুকার'] ,
['কুকীর্তি', 'দুষ্কর্ম', 'দুষ্কৃতি', 'দুষ্কৃত্য'] ,
['কুকুভ', 'কুকুভ রাগ', 'কুকুভরাগ', 'প্রসেবক'] ,
['কুকুর', 'কুকুর জাতি', 'কুকুর প্রদেশ', 'কুত্তা', 'মদ্দা কুকুর'] ,
['কুকুর-কাশি', 'কুকুরকাশি'] ,
['কুকুরের বাচ্চা', 'বাচ্চা'] ,
['কুক্রিয়াসক্তা', 'কুলটা', 'ছিনাল', 'ব্যভিচারিণী', 'ভ্রষ্টা'] ,
['কুখ্যাত', 'কুপ্রসিদ্ধ'] ,
['কুচ', 'স্তন'] ,
['কুচকাওয়াজ', 'মার্চ'] ,
['কুচিন্তা', 'বাজে চিন্তা'] ,
['কুচিপুড়ি', 'কুচিপুড়ি নৃত্য'] ,
['কুচো চিংড়ি', 'ছোটো চিংড়ি'] ,
['কুচ্ছ', 'কুমুদ', 'শ্বেতকমল', 'শ্বেতপদ্ম', 'সিতাব্জ', 'সিতাম্ভোজ'] ,
['কুঞ্চিত হওয়া', 'জমে যাওয়া'] ,
['কুঞ্চিত', 'কোঁচকানো', 'সঙ্কুচিত'] ,
['কুঞ্জকানন', 'কুঞ্জবন', 'ছত্বর', 'নিকুঞ্জ'] ,
['কুঞ্জলতা', 'তরুলতা', 'বল্লর', 'বল্লরী', 'বল্লী', 'বীরুধ্', 'ব্রততী', 'লতা', 'লতাগুল্ম', 'লতাতরু', 'লতানে গাছ', 'লতিকা'] ,
['কুট', 'কুট পদ'] ,
['কুটকচালী', 'নালিশ'] ,
['কুটনাই', 'কুটনাপনা'] ,
['কুটনি', 'রঙ্গমাতা'] ,
['কুটিলা', 'বেদগর্ভা', 'ব্রহ্মনদী', 'ব্রহ্মপুত্রী', 'ব্রহ্মসতী', 'সরস্বতী', 'সিন্ধুমাতা'] ,
['কুটু', 'কোটু', 'ফাফরা'] ,
['কুট্টা', 'পরকটা-পাখি'] ,
['কুঠার', 'কুঠারিকা', 'কুঠারী', 'কুড়াল', 'কুড়ুল', 'টাঙ্গি', 'পরশু', 'পর্শ্বধ', 'স্বধিতি'] ,
['কুড়া', 'কুড়ি কাঠা', 'বিঘা'] ,
['কুড়ি তারিখ', 'বিশ তারিখ,'] ,
['কুড়ি', 'কুড়ি বছর', '২০'] ,
['কুড়িতম', 'বিংশতিতম'] ,
['কুড়ুপ', 'বগলেস', 'বন্ধনাঙ্গুরি'] ,
['কুডাল', 'কুডাল শহর'] ,
['কুণবী', 'কুণবী জাতি'] ,
['কুণ্ঠিত', 'লজ্জিত'] ,
['কুণ্ডি', 'কুনি'] ,
['কুণ্ডিক', 'কুণ্ডিক উপনিষদ', 'কুণ্ডিকোপনিষদ'] ,
['কুতসিত', 'কুরূপা', 'কুরূপা মহিলা', 'দানবী'] ,
['কুতার', 'কুলেসির', 'সাদা মাথা'] ,
['কুতূপ', 'কুপী'] ,
['কুত্সিত্ বুড়ি', 'কুরূপা বুড়ি'] ,
['কুদিন', 'খারাপ দিন', 'দুর্দিন'] ,
['কুদৃষ্টি', 'খারাপ নজর', 'নজর'] ,
['কুনকে', 'কুনিকা'] ,
['কুন্ডলী', 'জন্মপত্র', 'জন্মপত্রিকা'] ,
['কুন্তল', 'বহুরূপী', 'রূপধারী', 'লাঙল', 'সারঙ্গ', 'হল'] ,
['কুন্তী', 'পৃথা', 'সূর্যপ্রিয়া'] ,
['কুন্দন', 'খাঁটি সোনা', 'শুদ্ধ সোনা', 'শুদ্ধ স্বর্ণ'] ,
['কুন্দনসাজ', 'জড়িয়া'] ,
['কুন্দু', 'রজনবিশেষ'] ,
['কুন্ধী', 'কুন্ধী মোষ'] ,
['কুপওয়াড়া', 'কুপওয়াড়া জেলা', 'কুপওয়াড়া শহর'] ,
['কুপথ', 'বিপথ', 'ভুলপথ'] ,
['কুপবাহ', 'ফুফু', 'সাদা কোকিল'] ,
['কুপরামর্শ', 'কুমন্ত্রনা'] ,
['কুপি', 'চুঙ্গী', 'ফানেল', 'ফোঁদল'] ,
['কুপিত', 'ক্রুদ্ধ'] ,
['কুপ্পক', 'কুপ্পক রোগ'] ,
['কুপ্পি', 'খোকলি', 'হরিত্ মঞ্জরী'] ,
['কুবর', 'ধরা'] ,
['কুবলযাশ্ব', 'ধুন্ধুমার'] ,
['কুবুদ্ধি', 'দুর্বুদ্ধি'] ,
['কুবুদ্ধিসম্পন্ন', 'কুস্বভাবী', 'দুর্জন'] ,
['কুবেরাচল', 'কুবেরাদ্রি', 'কৈলাশ', 'রজতপ্রস্থ', 'রজতাচল', 'রজতাদ্রি', 'শঙ্কারবাস', 'শঙ্কারালয়', 'শম্ভুগিরি', 'শম্ভুলোক', 'শিবধাম', 'শিবলোক', 'শিবশৈল', 'শ্বেতাদ্রি'] ,
['কুমকুম', 'কেশর', 'কেসর', 'জাফরান', 'রোলী'] ,
['কুমড়ো', 'কুষ্মান্ড'] ,
['কুমাল', 'পিবরি', 'সুনকপাশি'] ,
['কুমীর', 'মকর'] ,
['কুমোর', 'কুম্ভকার'] ,
['কুমোরগিরি', 'কুমোরের কাজ', 'কুম্ভকৃতি'] ,
['কুম্ভ', 'কুম্ভ রাশি', 'কুম্ভ রাশি বিশিষ্ট', 'কুম্ভরাশি'] ,
['কুম্ভলগড়', 'কুম্ভলগড় দুর্গ', 'কুম্ভলগড় শহর'] ,
['কুম্ভীরাশ্রু', 'নকল', 'লোকদেখানো'] ,
['কুরগি', 'কুর্গি', 'কোডাগু ভাষা'] ,
['কুরন্টক', 'সুরমই', 'সুরমাল'] ,
['কুরব', 'কুরবক'] ,
['কুরাজ্য', 'কুশাসন'] ,
['কুরুক্ষেত্র', 'কুরুক্ষেত্র জেলা', 'কুরুক্ষেত্র শহর', 'ব্যাপক যুদ্ধ', 'মহা যুদ্ধ', 'মহাযুদ্ধ'] ,
['কুরুঙ্গ কুর্মে', 'কুরুঙ্গ কুর্মে জেলা', 'কুরুঙ্গ কুর্মে শহর'] ,
['কুরুবংশীয়', 'কৌরব'] ,
['কুরুস্তত', 'কুরুস্তত ঋষি'] ,
['কুরেড', 'পুণ্ডরিক', 'শরভ'] ,
['কুর্তা', 'পাঞ্জাবী'] ,
['কুর্তি', 'পাজ্ঞাবী'] ,
['কুর্নুল', 'কুর্নুল জেলা', 'কুর্নুল শহর'] ,
['কুর্ম', 'কুর্ম ঋষি'] ,
['কুল নাম', 'বংশ নাম'] ,
['কুল-তারণ', 'কুলতারণ'] ,
['কুলকুচি', 'গণ্ডূষ'] ,
['কুলক্ষণযুক্ত', 'কুলক্ষণে'] ,
['কুলতারণ', 'কুলত্রাতা'] ,
['কুলফা', 'খুরফ'] ,
['কুলু', 'কুলু জেলা', 'কুল্লু', 'কুল্লু জেলা', 'কোটু', 'ফাফরা'] ,
['কুলুঙ্গী', 'তাক'] ,
['কুশ', 'কুশ ঘাস'] ,
['কুশধ্বজ', 'দর্ভকেতু'] ,
['কুশমুদ্রিকা', 'পবিত্রী'] ,
['কুশলতা', 'দক্ষতা', 'নৈপুণ্য', 'পটুতা', 'প্রবীণতা', 'বিচক্ষণতা', 'সুরক্ষা'] ,
['কুশলতাপূর্বক', 'কুশলভাবে', 'ঠিক-ঠাক', 'ঠিকঠাক', 'ঠিকভাবে', 'বেশ', 'ভালো', 'সুরক্ষিতভাবে'] ,
['কুশাগ্রবুদ্ধি', 'তীক্ষ্ণবুদ্ধি', 'তীব্রবুদ্ধি', 'প্রখরবুদ্ধি'] ,
['কুশারণি', 'দুর্বাসা'] ,
['কুশাসন', 'কুশের আসনে'] ,
['কুশীনগর', 'কুশীনগর জেলা'] ,
['কুষাণ বংশ', 'কুষাণ রাজবংশ'] ,
['কুষ্মাণ্ডা', 'কুষ্মাণ্ডিনী', 'কুষ্মাণ্ডী'] ,
['কুসুমরেণু', 'পরাগকণা', 'পরাগরেণু', 'পুষ্পরেণু'] ,
['কুসুমরোহিত', 'কুসুমহীন', 'পুষ্পরোহিত', 'পুষ্পহীন'] ,
['কুসুমসৌরভ', 'পরিমল', 'মনোহর গন্ধ'] ,
['কুসুমাগ্রজ', 'বিষ্ণু বামন শিরওড়কর কুসুমাগ্রজ'] ,
['কুসুমালয়', 'কুসুমোদ্দ্যান', 'পুষ্প উপবন', 'পুষ্প বাটিকা', 'পুষ্পবাটিকা'] ,
['কুসুমিত', 'পুষ্পযুক্ত', 'পুষ্পিত', 'প্রস্ফুটিত', 'ফোটা', 'বিকশিত', 'মঞ্জরিত'] ,
['কুসুম্ব', 'কুসুম্বিয়া'] ,
['কুসেবা', 'দুঃসেবা'] ,
['কুস্তি করা', 'কুস্তি লড়া', 'কুস্তিবাজি করা'] ,
['কুস্তিগীর', 'পালোয়ান', 'মল্লযোদ্ধা'] ,
['কুস্তী', 'মল্লযুদ্ধ'] ,
['কুহি বাজ', 'কোহিলা', 'শাহীন'] ,
['কুয়াশাচ্ছন্ন', 'ঝাপসিয়ে যাওয়া'] ,
['কুয়েত', 'কুয়েত সিটি'] ,
['কুয়েত-বাসী', 'কুয়েতি'] ,
['কুয়েতি দিনার', 'দিনার'] ,
['কুয়েতি দিরেম', 'দিরেম'] ,
['কুয়ো', 'কূপ', 'সোপান কূপ'] ,
['কূজন', 'গুঞ্জন'] ,
['কূর্ম অবতার', 'কূর্মাবতার'] ,
['কূর্ম পুরাণ', 'কূর্মপুরাণ'] ,
['কূর্ম', 'কূর্ম নাড়ি', 'মহাপথ', 'সুষুম্না', 'সুষুম্না নাড়ি'] ,
['কূল পরম্পরা', 'কূল রীতি', 'কূলাচার', 'বংশ পরম্পরা'] ,
['কূল', 'পুরো', 'পূর্ণ', 'বংশ', 'মোট. সব', 'সকল', 'সম্পূর্ণ'] ,
['কূলপ্রদীপ', 'বংশপ্রদীপ'] ,
['কূলহীন', 'পরিবারহীন'] ,
['কৃকলাস', 'গিরগিটি', 'বহুরূপী', 'সরট'] ,
['কৃত', 'নির্মিত', 'নিষ্পন্ন', 'প্রণীত', 'বিরচিত', 'রচিত', 'সংরচিত', 'সম্পাদিত', 'সৃষ্ট'] ,
['কৃতঙ্ক জন্তু', 'কৃতঙ্ক জীব'] ,
['কৃতার্থ', 'ধন্য'] ,
['কৃতিত্ব', 'রের্কড'] ,
['কৃতিস্বত্ব', 'পেটেন্ট'] ,
['কৃত্তিকা', 'কৃত্তিকা নক্ষত্র'] ,
['কৃত্রিম উপগ্রহ', 'স্যাটেলাইট'] ,
['কৃত্রিম ভাবে', 'কৃত্রিম রুপে'] ,
['কৃপ', 'কৃপাচার্য'] ,
['কৃপা করে', 'কৃপাপূর্বক', 'দয়া করে', 'দয়াপূর্বক'] ,
['কৃপাণ', 'খঞ্জর', 'ছুড়ি', 'ছুরিকা', 'ছোরা', 'ভোজালি'] ,
['কৃপানিধি', 'কৃপাসিন্ধু', 'দয়ানিধি', 'দয়াসাগর'] ,
['কৃপাপূর্বক', 'দয়া করে', 'মহতভাবে'] ,
['কৃপায়', 'দৌলতে', 'দয়ায়'] ,
['কৃমি ভোজন', 'কৃমিভোজন'] ,
['কৃশ', 'কৃশোদর', 'রোগা', 'রোগা-পাতলা'] ,
['কৃশকায়', 'ক্ষীণ', 'দুর্বল', 'রোগা'] ,
['কৃশোদরা', 'কৃশোদরী', 'তনুমধ্যা'] ,
['কৃষক', 'চাষী'] ,
['কৃষকদল', 'কৃষকবর্গ', 'কৃষিদল'] ,
['কৃষি', 'কৃষিকাজ', 'চাষ-বাস'] ,
['কৃষি-বিভাগ', 'কৃষিবিভাগ'] ,
['কৃষিজমি', 'ক্ষেত', 'চাষযোগ্য জমি', 'চাষের জমি', 'জমি'] ,
['কৃষিবিজ্ঞানী', 'কৃষিবিদ'] ,
['কৃষ্ণ মৃগ', 'কৃষ্ণমৃগ'] ,
['কৃষ্ণগিরি', 'কৃষ্ণগিরি জেলা', 'কৃষ্ণগিরি শহর'] ,
['কৃষ্ণচৈতন্য', 'গৌরাঙ্গ মহাপ্রভু', 'চৈতন্য', 'চৈতন্য প্রভু', 'চৈতন্য মহাপ্রভু'] ,
['কৃষ্ণসার হরিণ', 'সামবার'] ,
['কৃষ্ণসারিকা', 'শ্যামা'] ,
['কৃষ্ণা', 'কৃষ্ণা উপনিষদ', 'কৃষ্ণা জেলা', 'কৃষ্ণা নদী', 'কৃষ্ণোপনিষদ', 'ত্রিহায়নী', 'দ্রৌপদী', 'পাঞ্চালী', 'বেদিজা', 'মুক্তবেণী', 'যাজ্ঞসেনী', 'সৈরন্ধ্রী'] ,
['কেউ', 'যে কেউ', 'যে কোনো'] ,
['কেকা', 'কেকাধ্বনি'] ,
['কেটজল', 'কেটসল'] ,
['কেটে পড়া', 'চলে যাওয়া'] ,
['কেটে যাওয়া', 'ফাটা', 'ফেটে যাওয়া'] ,
['কেতকী', 'ক্যাওড়া'] ,
['কেতন', 'ধ্বজা', 'পতাকা'] ,
['কেতা', 'গোছা', 'সেট'] ,
['কেতাদুরস্ত', 'ফ্যাশন অনুসরণকারী', 'সুসজ্জিত'] ,
['কেতু', 'কেতু গ্রহ'] ,
['কেদার', 'কেদার রাগ'] ,
['কেদারা', 'কেদারী'] ,
['কেন', 'কেনোপনিষদ'] ,
['কেনসিঙ্গটন প্রাইড', 'কেনসিঙ্গটন প্রাইড আম', 'কেনসিঙ্গটন প্রাইড আম গাছ', 'বোবন', 'বোবন আম'] ,
['কেনা গোলাম', 'বাঁধা শ্রমিক'] ,
['কেনা', 'ক্রীত', 'ক্রয় করা'] ,
['কেনা-বেচা করা', 'বেচা-কেনা করা'] ,
['কেনিয়া সম্পর্কিত', 'কেনিয়ার', 'কেনীয়'] ,
['কেনিয়া', 'কেনিয়া গণরাজ্য', 'কেনিয়া প্রবত'] ,
['কেনিয়ান', 'কেনিয়াবাসী'] ,
['কেন্ট', 'কেন্ট আম'] ,
['কেন্দুঝর', 'কেন্দুঝর জেলা', 'কেন্দুঝর শহর'] ,
['কেন্দ্র', 'কেন্দ্র বিন্দু', 'কেন্দ্রবিন্দু', 'কেন্দ্রস্থল', 'কেন্দ্রীয়', 'কেন্দ্রীয় ভবন', 'কেন্দ্রীয় সরকার', 'নাভি', 'মধ্যবর্তী স্থান', 'মাঝখানে', 'সেণ্টার'] ,
['কেন্দ্রক', 'কোষিকা কেন্দ্রক'] ,
['কেন্দ্রপাড়া', 'কেন্দ্রপাড়া জেলা', 'কেন্দ্রপাড়া শহর'] ,
['কেন্দ্রীকরণ করা', 'কেন্দ্রীভূত করা'] ,
['কেন্দ্রীত', 'কেন্দ্রীভূত'] ,
['কেন্দ্রীয় কার্যালয়', 'প্রধান কার্যালয়', 'মুখ্য কার্যালয়', 'সদর'] ,
['কেন্দ্রীয় গোপন সংবাদ সংস্থা', 'সিআইএ', 'সেন্ট্রাল ইন্টেলিজেন্স এজেন্সি'] ,
['কেন্দ্রীয় তদন্ত বিভাগ', 'সিবিআই'] ,
['কেন্দ্রীয় রিজার্ভ পুলিস ফোর্স', 'কেন্দ্রীয় রিজার্ভ পুলিস বাহিনী', 'সিআরপিএফ'] ,
['কেন্দ্রীয় সতর্কতা কমিশনার', 'সিবিসি', 'সেন্ট্রাল ভিজিলেন্স কমিশনার'] ,
['কেন্দ্রীয় সর্তকতা কমিশন', 'সেন্ট্রাল ভিজিলেন্স কমিশন'] ,
['কেন্দ্রীয় সাংখিকী সংগঠন', 'সেন্ট্রাল স্ট্যাটিসটিক্যাল অর্গানাইজেশন'] ,
['কেপ ভের্ডে', 'কেপ ভের্ডে গণতন্ত্র', 'রিপাব্লিক অফ কেপ ভের্ডে'] ,
['কেবটীমোথা', 'শীতপুষ্পক'] ,
['কেমিস্ট্রি', 'রসায়ন', 'রসায়ন বিজ্ঞান', 'রসায়ন শাস্ত্র', 'রসায়নশাস্ত্র'] ,
['কেমেন দ্বীপীয় ডলার', 'ডলার'] ,
['কেরমুটিয়া', 'নারঝি', 'নারঝিনক'] ,
['কেরল', 'মালাবার'] ,
['কেরাবাও', 'কেরাবাও আম', 'কেরাবাও আমের'] ,
['কেলপ্', 'জিব্রালটর'] ,
['কেলি', 'কৌতুক', 'ক্রীড়া', 'খেলা', 'বিনোদ'] ,
['কেল্লা', 'কোর্ট', 'দূর্গ'] ,
['কেশ কর্তনালয়', 'নাপিতালয়', 'সেলুন'] ,
['কেশ প্রসাধক', 'কেশ সজ্জাকার', 'হেয়ারস্টাইলিস্ট'] ,
['কেশ মুন্ডন', 'মুন্ডন', 'মুন্ডন সংস্কার'] ,
['কেশগুচ্ছ', 'চুলের গুচ্ছ'] ,
['কেশব প্রয়াগ', 'কেশবপ্রয়াগ'] ,
['কেশবপ্রিয়া', 'বৃন্দাবনেশ্বরী', 'রাধা', 'রাধারাণী', 'রাধিকা', 'শ্যামা'] ,
['কেশর', 'নাগকেশর', 'নাগপুষ্প', 'পুষ্পলোচন', 'রাজপুষ্প', 'স্ত্রীকেশর', 'হেমপুষ্প'] ,
['কেশরঞ্জন', 'ভৃঙ্গরাজ'] ,
['কেশরাজ', 'কোতওয়াল', 'ভুজঙ্গা'] ,
['কেশরাশি', 'চুল'] ,
['কেশরী', 'পশুরাজ', 'মৃগেন্দ্র', 'সিংহ', 'সিংহ রাগ'] ,
['কেশরীনন্দন', 'পবন তনয়', 'পবন পুত্র', 'হনুমান'] ,
['কেশি', 'তুরগদানব'] ,
['কেসর রঙ', 'জাফরানী রঙ'] ,
['কেসর রঙের', 'জাফরান রঙের'] ,
['কেসর', 'কেসর আম', 'নাগকেসর', 'নাগপুষ্প', 'ফণিকেসর', 'রাজপুষ্প', 'হেমপুষ্প'] ,
['কেসীপুরা', 'কেসীপুরা আম', 'কেসীপুরা আমের গাছ'] ,
['কেয়ূর', 'বাজু', 'বাজুবন্ধ'] ,
['কৈথল', 'কৈথল জেলা', 'কৈথল শহর'] ,
['কৈথি', 'কৈথি লিপি'] ,
['কৈবল্য', 'কৈবল্য উপনিষদ', 'কৈবল্যোপনিষদ'] ,
['কৈমুর', 'কৈমুর জেলা'] ,
['কৈরাত', 'কৈরাত রাগ'] ,
['কৈরি আম', 'কৈরি আম গাছ'] ,
['কোক-শাস্ত্র', 'কোকশাস্ত্র'] ,
['কোকব', 'কোকব রাগ'] ,
['কোকরই', 'তাল সারস', 'নিশা বক'] ,
['কোকরাঝাড়', 'কোকরাঝাড় জেলা', 'কোকরাঝাড় শহর'] ,
['কোকো', 'কোকোবাবা'] ,
['কোঙ্কনী লবা', 'কোঙ্কনী লাবা'] ,
['কোঙ্কান', 'কোঙ্কান পট্টি'] ,
['কোচ', 'খেলা প্রশিক্ষক'] ,
['কোচবিহার', 'কোচবিহার জেলা', 'কোচবিহার শহর'] ,
['কোচি', 'কোচি শহর', 'কোচিন'] ,
['কোঝিকোড', 'কোঝিকোড জেলা', 'কোঝিকোড শহর'] ,
['কোটর', 'খোঁড়ল', 'খোদল', 'খোন্দল', 'গর্ত', 'বিবর', 'সাঁধি', 'সিঁধ', 'সুড়ঙ্গ'] ,
['কোটা শাড়ি', 'কোটাচেক'] ,
['কোটা', 'কোটা জেলা', 'কোটা শহর', 'কোটার', 'নির্ধারিত অংশ'] ,
['কোটি', 'বর্গ', 'শ্রেণী', 'সমূহ', 'স্তর', '১০০০০০০০'] ,
['কোট্টায়াম', 'কোট্টায়াম জেলা', 'কোট্টায়াম শহর'] ,
['কোঠি', 'মহাজনের বাড়ি'] ,
['কোড', 'সংহিতা'] ,
['কোড়ানী', 'ঝাঁঝরি'] ,
['কোডারমা', 'কোডারমা জেলা', 'কোডারমা শহর'] ,
['কোডেগু', 'কোডেগু জেলা'] ,
['কোণ', 'চোঙ', 'বিবিক্ত স্থান'] ,
['কোণবিশিষ্ট', 'কৌণিক'] ,
['কোণাকুনি', 'তির্যক ভাবে'] ,
['কোণ্ডাই', 'কোণ্ডারী'] ,
['কোতোয়াল', 'ডিএসপি'] ,
['কোদানো', 'ছেনা'] ,
['কোন', 'কোন আইসক্রিম', 'শঙ্কু', 'শাঙ্কবাকার বস্তু'] ,
['কোনোমতে করা', 'যা হোক করে করা'] ,
['কোন্দল', 'যুদ্ধ', 'রণ', 'লড়াই', 'সমর', 'সসংগ্রাম'] ,
['কোপদৃষ্টি', 'ক্রুদ্ধ দৃষ্টি', 'ভ্রূকুটি'] ,
['কোপেশ্বর', 'কোপেশ্বর মন্দির'] ,
['কোপ্পল', 'কোপ্পল জেলা', 'কোপ্পল শহর'] ,
['কোবারি', 'ছোট বুজ্জা'] ,
['কোবেলমিন', 'ভিটামিন বি ', 'সায়নোকোবালামিন'] ,
['কোমল গান্ধার', 'কোমলগান্ধার'] ,
['কোমল রোঁয়া', 'মোলায়েম রোঁয়া', 'মোলায়েম রোম'] ,
['কোমল স্বভাবী', 'সৌম্য'] ,
['কোমল', 'নরম', 'মৃদু', 'সুকুমার'] ,
['কোমলহৃদয়যুক্ত', 'হৃদয়বান'] ,
['কোমলাঙ্গিনী', 'কোমলাঙ্গী', 'তন্বী'] ,
['কোমোরিয়ান', 'কোমোরোসি', 'কোমোরোসীয়'] ,
['কোমোরোজ বাসী', 'কোমোরোজবাসী', 'কোমোরোজি'] ,
['কোমোরোজ', 'কোমোরোস'] ,
['কোম্পানি', 'সমবায়'] ,
['কোম্বুজ', 'কোম্বুজ জন্তু'] ,
['কোরবা', 'কোরবা শহর'] ,
['কোরা', 'শূণ্য', 'সাদা'] ,
['কোরাইগড়', 'কোরীগড়'] ,
['কোরান', 'কোরান মাজিদ', 'কোরান শরিফ'] ,
['কোরাপুট', 'কোরাপুট জেলা', 'কোরাপুট শহর'] ,
['কোরিয়া', 'কোরিয়া জেলা'] ,
['কোরিয়ান', 'কোরিয়ান লিপি', 'কোরিয়াবাসী', 'কোরিয়ার'] ,
['কোরুনা', 'স্লোভাকিয়ান কোরুনা'] ,
['কোর্ট কাটা', 'রেখাঙ্কন করা'] ,
['কোর্ট মার্শাল', 'সেনাবাহিনির বিচারালয়', 'সৈনিক আদালত'] ,
['কোর্ট', 'রাজদরবার'] ,
['কোলকাতা', 'কোলকাতা জেলা', 'কোলকাতা শহর'] ,
['কোলন', 'কোস্টা রিকা কোলন'] ,
['কোলনিয়া', 'কোলোনিয়া'] ,
['কোলম', 'কোলম জাতি'] ,
['কোলহাপুর', 'কোলহাপুর জেলা'] ,
['কোলাপুর', 'কোলাপুর শহর'] ,
['কোলার', 'কোলার জেলা', 'কোলার শহর'] ,
['কোলাসিব', 'কোলাসিব জেলা', 'কোলাসিব শহর'] ,
['কোলাহল', 'কোলাহল রোগ', 'চিল্লামিল্লি', 'শোরগোল', 'হল্লা', 'হাঙ্গামা'] ,
['কোলাহলমুখর নিমন্ত্রণ সভা', 'কোলাহলমুখর পার্টি'] ,
['কোলী', 'কোলী জাতি'] ,
['কোলেস্টেরল', 'কোলেস্ট্রল'] ,
['কোলোবাস', 'কোলোবাস বাঁদর'] ,
['কোল্লম', 'কোল্লম জেলা', 'কোল্লম শহর'] ,
['কোশল', 'কোশল রাগ'] ,
['কোশী', 'কোশী নদী'] ,
['কোষ আবরণ', 'কোষ-ভিত্তি'] ,
['কোষ', 'জৈব একক', 'ভান্ডার'] ,
['কোষাধ্যক্ষ', 'খাজাঞ্চি'] ,
['কোষিকা অঙ্গ', 'কোষিকা ভাগ'] ,
['কোষিকা দ্রব্য', 'সাইটোপ্লাজম্'] ,
['কোষ্টা', 'জুট', 'নলিতা', 'নালতে', 'পাট', 'পাটশণ'] ,
['কোষ্ঠি', 'জন্মকুণ্ডলী', 'জন্মপত্রিকা', 'রাশিচক্র'] ,
['কোস্টা রিকা', 'কোস্টারিকা'] ,
['কোহাসা', 'সাপমার', 'সামুদ্রিক উকাব'] ,
['কোহিমা', 'কোহিমা জেলা'] ,
['কোয়ার্টার', 'কোয়ার্টার ফাইনাল', 'পোয়া'] ,
['কোয়েম্বাতুর', 'কোয়েম্বাতুর জেলা', 'কোয়েম্বাতুর শহর'] ,
['কৌডিন্য', 'কৌডিন্য ঋষি'] ,
['কৌতিল্য', 'চানক্য'] ,
['কৌতুক', 'মজা', 'হাসি মজা', 'হাস্য', 'হাস্য পরিহাস'] ,
['কৌতুহল', 'জিজ্ঞাসা'] ,
['কৌতুহলোদ্দীপক', 'বিচিত্র', 'বিস্ময়কারী', 'বিস্ময়জনক'] ,
['কৌত্স', 'কৌত্স ঋষি'] ,
['কৌম', 'জাতি', 'জাতিগত'] ,
['কৌমারিক', 'কৌমারিক রাগ'] ,
['কৌমুদ', 'রাসপূর্ণিমা'] ,
['কৌশল', 'টেকনিক'] ,
['কৌশাম্বী', 'কৌশাম্বী জেলা', 'কৌশাম্বী শহর'] ,
['কৌশিকী-কানাড়া', 'কৌশিকীকানাড়া'] ,
['কৌশীতকী', 'কৌশীতকী উপনিষদ'] ,
['কৌষীতাকি', 'কৌষীতাকি উপনিষদ'] ,
['কৌষ্ঠকাঠিন্য', 'কৌষ্ঠবদ্ধতা', 'মলাবরোধ'] ,
['কৌসীদ', 'জীবক', 'সুদখোর'] ,
['কৌস্তুভ', 'কৌস্তুভ মণি', 'দেবমানক', 'দৈবমণি'] ,
['ক্বাইকাম', 'ক্বাইকাম মোষ'] ,
['ক্বাইজ্বান', 'ক্বাইজ্বান মোষ'] ,
['ক্বাইতুই', 'ক্বাইতুই মোষ'] ,
['ক্যাঁচক্যাঁচ', 'মটমট'] ,
['ক্যাট', 'শট'] ,
['ক্যাটারাক্ট', 'চোখের ছানি', 'ছানি'] ,
['ক্যাণ্ডি', 'মিঠাই'] ,
['ক্যানভাস', 'পটভূমি', 'পশ্চাদ্ভূমি', 'প্রেক্ষাপট'] ,
['ক্যানেস্তারা', 'টিন', 'পিপে'] ,
['ক্যাপসিকাম', 'শিমলা মরিচ'] ,
['ক্যাপসুল', 'বড়ি'] ,
['ক্যাপুচীন', 'ক্যাপুচীন বাঁদর'] ,
['ক্যামেরা ম্যান', 'ফটোগ্রাফার'] ,
['ক্যাম্প', 'শিবির'] ,
['ক্যালকুলেটর', 'পরিকলক'] ,
['ক্যালেন্ডার', 'দিনপঞ্জিকা', 'দিনপঞ্জী'] ,
['ক্যাসেট', 'টেপ'] ,
['ক্রতু', 'ক্রতু ঋষি'] ,
['ক্রম সংখ্যা', 'ক্রমাঙ্ক', 'নম্বর'] ,
['ক্রমবদ্ধ', 'ক্রমানুসার', 'ক্রমিক', 'শৃঙ্খলাবদ্ধ'] ,
['ক্রমবর্ধমান', 'বাড়তে থাকা'] ,
['ক্রমভঙ্গ', 'বিপর্যয়'] ,
['ক্রমরহিত', 'ক্রমহীন'] ,
['ক্রমসূচী', 'রেঙ্কিং'] ,
['ক্রমাগত', 'নিয়ম করে', 'নিয়মানুসারে', 'নিয়মিতভাবে', 'যথানিয়মে'] ,
['ক্রান্তিবাদী', 'বিপ্লবী', 'বিপ্লবী ব্যাক্তি'] ,
['ক্রাস্ট প্লেট', 'প্লেট'] ,
['ক্রিকেট কন্ট্রোল বোর্ড', 'ক্রিকেট নিয়ন্ত্রক পরিষদ', 'ক্রিকেট পরিষদ', 'ক্রিকেট বোর্ড', 'ক্রিকেট সংঘ'] ,
['ক্রিকেট খেলোয়াড়', 'ক্রিকেটার'] ,
['ক্রিকেট টুর্নামেন্ট', 'ক্রিকেট প্রতিযোগীতা'] ,
['ক্রিমিনাল ল', 'দন্ডবিধাণ', 'দন্ডবিধি'] ,
['ক্রিয়া বিশেষণ', 'ক্রিয়া-বিশেষণ', 'ক্রিয়াবিশেষণ'] ,
['ক্রিয়া', 'ক্রিয়াপদ', 'পদ্ধতি', 'প্রক্রিয়া', 'প্রণালী'] ,
['ক্রীড়া উপকরণ', 'খেলার উপকরণ'] ,
['ক্রীড়া প্রতিযোগীতা', 'খেলা প্রতিযোগীতা', 'টুর্নামেন্ট'] ,
['ক্রীড়া বিষয়ক', 'ক্রীড়া সংক্রান্ত', 'খেলা সম্পর্কিত', 'খেলা সম্পর্কিত'] ,
['ক্রীড়া মন্ত্রী', 'ক্রীড়ামন্ত্রী'] ,
['ক্রীড়া', 'খেলা', 'নগনিকা', 'নগনিকাছন্দ', 'নগন্নিকা ছন্দ'] ,
['ক্রীড়াঙ্গন', 'ক্রীড়াস্থল', 'খেলার মাছ', 'খেলার ময়দান', 'প্রাঙ্গন'] ,
['ক্রুজ', 'সাগর বিহার'] ,
['ক্রুদ্ধ করা', 'ক্রোধিত করা', 'প্ররোচনা দেওয়া', 'রাগানো'] ,
['ক্রুদ্ধ নারী', 'ক্রুদ্ধা নারী', 'ভামা', 'ভামিনী', 'রাগি মহিলা'] ,
['ক্রুদ্ধ হওয়া', 'রাগ করা'] ,
['ক্রূরতা', 'দয়াহীনতা', 'নিঠুর', 'নির্দয়তা', 'নিষ্ঠুরতা', 'নৃশংসতা', 'হিংস্রতা', 'হৃদয়হীনতা'] ,
['ক্রেতা', 'গ্রাহক'] ,
['ক্রেতাগণ', 'গ্রাহকগণ', 'গ্রাহকরা'] ,
['ক্রোধী', 'রাগী'] ,
['ক্রোনা', 'ক্রোনার'] ,
['ক্রোশ', 'হুমকি'] ,
['ক্রোয়েশিয়ান ভাষা', 'ক্রোয়েশীয় ভাষা'] ,
['ক্রোয়েশিয়ান', 'ক্রোয়েশিয়ার'] ,
['ক্রোয়েশিয়াবাসী', 'ক্রোয়েশীয়'] ,
['ক্রৌঞ্চাদন', 'নলিনীরূহ', 'নালীক', 'পদ্মনাল', 'পদ্মপলাশ', 'বিস', 'মৃণাল'] ,
['ক্রৌন্চ দ্বীপ', 'ক্রৌন্চদ্বীপ'] ,
['ক্র্যাশ হওয়া', 'ধ্বংস হওয়া'] ,
['ক্রয় কেন্দ্র', 'শপিং মল', 'শপিং সেন্টার'] ,
['ক্লমল', 'ক্লমল ঋষি'] ,
['ক্লান্ত হওয়া', 'হেরে যাওয়া'] ,
['ক্লান্ত', 'পরিশ্রান্ত', 'বিতৃষ্ণ', 'শ্রান্ত'] ,
['ক্লান্তিকর', 'ক্লান্তিব্যঞ্জক'] ,
['ক্লার্ক', 'বাবু', 'লিপিকা'] ,
['ক্লাস', 'ঘন্টা', 'শ্রেণী', 'স্তর'] ,
['ক্লিটোরেস', 'ভগাঙ্কুর', 'যোনিলিঙ্গ'] ,
['ক্লিন বোল্ড', 'বোল্ড'] ,
['ক্লোরোফিল', 'পত্রহরিত্'] ,
['ক্ষ', 'ব্যঞ্জবর্ণ ক্ষ'] ,
['ক্ষণ', 'মুহূর্ত', 'যোগ', 'সেকেন্ড'] ,
['ক্ষণে ক্ষণে', 'প্রতি ক্ষণ', 'সবসময়'] ,
['ক্ষতি করা', 'দেওয়া', 'লোকসান করা'] ,
['ক্ষতি ভরা', 'ক্ষতিপূরণ করা', 'ক্ষতিপূর্তি করা'] ,
['ক্ষতি হওয়া', 'শুকনা লাগা'] ,
['ক্ষতি', 'লোকসান', 'হানি'] ,
['ক্ষতিপূরণ করা', 'পূরণ করা'] ,
['ক্ষতিপূরণ', 'প্রতিদান'] ,
['ক্ষত্রিয়', 'ক্ষাত্র'] ,
['ক্ষত্রিয়া', 'ক্ষত্রিয়াণী', 'ক্ষত্রিয়ানী'] ,
['ক্ষপণক', 'জীবক'] ,
['ক্ষমতা', 'ক্ষমতাপূর্ণতা', 'দম', 'ধারণ ক্ষমতা', 'বল', 'শক্তি', 'শক্তিপূর্ণতা', 'সক্ষমতা', 'সামর্থ্য', 'হাত'] ,
['ক্ষমতাবান', 'সক্ষম', 'সমর্থ'] ,
['ক্ষমা করা', 'মাফ করা'] ,
['ক্ষমা', 'দোষক্ষালন', 'মাফ', 'মার্জন', 'মার্জনা'] ,
['ক্ষমা-যাচনা', 'ক্ষমাযাচনা'] ,
['ক্ষমাযোগ্য', 'মর্ষণীয়'] ,
['ক্ষমাশীল', 'ক্ষমী'] ,
['ক্ষরণ', 'নিঃস্রাব', 'স্রাব'] ,
['ক্ষরিত', 'নিঃসৃত'] ,
['ক্ষার', 'যবক্ষার', 'সোডা'] ,
['ক্ষালন', 'ধোয়া', 'ধৌতকরণ', 'প্রক্ষালন'] ,
['ক্ষিতিজ', 'ভূমিজ'] ,
['ক্ষিতিজা', 'জনক দুহিতা', 'জানকী', 'ধরণীজা', 'মৈথিলী', 'সীতা', 'সীতা উপনিষদ'] ,
['ক্ষীণকায় হওয়া', 'রোগা হওয়া'] ,
['ক্ষীর-নিধি', 'ক্ষীর-সাগর', 'ক্ষীরসাগর'] ,
['ক্ষুণ্ণিবৃত্তিকারী', 'ক্ষুধা নিবৃত্তির জন্য কাজ করা'] ,
['ক্ষুদ্র প্রয়াস', 'ছোট চেষ্টা', 'ছোটখাটো চেষ্টা'] ,
['ক্ষুদ্র', 'সূক্ষ্ম'] ,
['ক্ষুদ্রতা', 'নীচতা', 'নীচত্ব'] ,
['ক্ষুধা', 'খিদে'] ,
['ক্ষুধাতুর', 'ক্ষুধার্ত', 'ক্ষুধিত'] ,
['ক্ষুধাবর্ধক', 'রুচিকর', 'রুচিকারক'] ,
['ক্ষুন্ন হওয়া', 'রেগে যাওয়া'] ,
['ক্ষুব্ধ', 'দণ্ড', 'মন্থনের দণ্ড', 'রতিবন্ধবিশেষ'] ,
['ক্ষুর', 'খুর', 'নাল'] ,
['ক্ষুরিক', 'ক্ষুরিক উপনিষদ', 'ক্ষুরিকোপনিষদ'] ,
['ক্ষেত', 'জমি'] ,
['ক্ষেত্র', 'প্রদেশ', 'ফিল্ড', 'রাজ্য', 'শক্তি ক্ষেত্র', 'সেক্টর'] ,
['ক্ষেত্রফল', 'বর্গফল'] ,
['ক্ষেপণাস্ত্র', 'মিসাইল'] ,
['ক্ষয় করা', 'নাশ করা'] ,
['ক্ষয় রোগ', 'টি.বি.', 'যক্ষ্মা', 'যক্ষ্মা রোগ'] ,
['ক্ষয়', 'হ্রাস'] ,
['ক্ষয়রোগী', 'যক্ষারোগী'] ,
['ক্ষয়শীল', 'পচনশীল'] ,
['ক্ষয়ী', 'মারক'] ,
['কয়েদ বেল', 'দধিফল', 'নীলমল্লিকা', 'পুষ্পফল', 'বিশালক', 'শিরাপত্র', 'হেম'] ,
['খ', 'ব্যঞ্জনবর্ণ খ', 'ব্যোম', 'ব্রহ্মাণ্ড', 'মহাকাশ', 'মহাজাগতিক ক্ষেত্র'] ,
['খঁড়সার', 'খন্ডসার'] ,
['খআঁটি লাভ', 'নীট লাভ'] ,
['খগ', 'খগম', 'খেচর', 'গ্রহ', 'চিড়িয়া', 'পক্ষিণী', 'পাখি', 'বিহগ', 'বিহঙ্গ', 'মাদি পাখি'] ,
['খগরিয়া', 'খগরিয়া জেলা', 'খগরিয়া শহর'] ,
['খচিয়ে দেওয়া', 'রাগিয়ে দেওয়া'] ,
['খজরী', 'খজরী আম'] ,
['খজাকা', 'চামচ চঞ্চু', 'দাবিল'] ,
['খঞ্জত্ব', 'খোঁড়া হওয়া', 'পঙ্গুতা', 'ল্যংড়া'] ,
['খঞ্জর', 'খড্গ', 'খাঁড়া'] ,
['খটখটিয়া', 'খড়ম'] ,
['খটাখটি', 'তর্কাতর্কি'] ,
['খট্টি', 'খাটুলি', 'শবযান', 'শবাধার'] ,
['খড়', 'ঘাস', 'জাবনা', 'বিচালি'] ,
['খড়কই', 'খড়কই নদী'] ,
['খড়ি মাটি', 'চুনা-পাথর'] ,
['খড়ি', 'চক্'] ,
['খণিজ জল', 'মিনারেল ওয়াটার'] ,
['খণিজ', 'খণিজ পদার্থ'] ,
['খণ্ড', 'টুকরো', 'পিণ্ড'] ,
['খণ্ড-কাব্য', 'খণ্ডকাব্য'] ,
['খণ্ডন', 'প্রতিবাদ', 'বিরোধিতা'] ,
['খণ্ডপুরি', 'মিষ্টি লুচি'] ,
['খণ্ডবা', 'খণ্ডবা জেলা', 'খণ্ডবা শহর', 'পূর্ব নিমার', 'পূর্ব নিমার জেলা'] ,
['খণ্ডসর', 'খাঁড়', 'খাঁড় চিনি'] ,
['খণ্ডিত হওয়া', 'ফাটা;১', 'ভগ্ন হওয়া', 'ভাঙ্গা;১', 'ভেঙ্গে যাওয়া'] ,
['খতম হওয়া', 'শেষ হওয়া', 'সমাপ্ত হওয়া'] ,
['খতিয়ান বই', 'জমাখরচের বই', 'লেজার'] ,
['খদির', 'খদির ঋষি', 'খয়ের'] ,
['খদ্দর', 'খাদি'] ,
['খনন করা', 'গর্ত করা'] ,
['খনিজ কয়লা', 'পাথুরে কয়লা'] ,
['খনিজ বিজ্ঞান', 'খনিজবিজ্ঞান'] ,
['খনিজলবণ মিশ্রিত জল', 'খরজল'] ,
['খন্ড কথা', 'খন্ড-কথা', 'খন্ডকথা'] ,
['খন্ডন', 'ভাঙা'] ,
['খবর দেওয়া', 'রিপোর্ট করা'] ,
['খবর', 'খোঁজ', 'খোঁজ-খবর', 'নোটিশ', 'পূর্বাভাস', 'বার্তা', 'মৌখিক খবর', 'সংকেত', 'সংবাদ', 'সন্দেশ', 'সন্ধান', 'সমাচার', 'সূত্র'] ,
['খবরের কাগজ', 'পেপার'] ,
['খবরের কাগজের', 'সংবাদপত্রের'] ,
['খম্মম', 'খম্মম জেলা', 'খম্মম শহর'] ,
['খর', 'ঘাস', 'তৃণ'] ,
['খরগোন', 'খরগোন জেলা', 'খরগোন শহর', 'পশ্চিম নিমার', 'পশ্চিম নিমার জেলা'] ,
['খরগোশ', 'খরগোশের মাংস', 'খরা', 'শশক'] ,
['খরচ হওয়া', 'ব্যয় হওয়া', 'লাগা'] ,
['খরচ', 'খরচা', 'ব্যয়'] ,
['খরজ', 'ষড়জ', 'ষড়জ স্বর', 'সা'] ,
['খরবাস', 'চুলকানি'] ,
['খরমুজ', 'ফুটি'] ,
['খরোষ্ঠী', 'খরোষ্ঠী লিপি', 'গান্ধার লিপি'] ,
['খর্জুর', 'খুর্মা', 'খেজুর', 'খোর্মা', 'ছোহারা', 'ছোয়ারা'] ,
['খর্ব', 'লঘু', 'হ্রস্ব', 'হ্রস্ব স্বর'] ,
['খল', 'দিস্তা', 'দুরাত্মা', 'দুর্জন', 'দুষ্ট ব্যক্তি', 'দুষ্টচেতা', 'দুষ্টাত্মা', 'পাজী', 'শঠ', 'হারামজাদা', 'হারামী'] ,
['খলতা', 'নিকৃষ্টতা', 'নীচতা'] ,
['খসড়া', 'পাটওয়ারি', 'প্রস্তাবনা', 'ভূমি অভিলেখ', 'ভূমি বিবরণ'] ,
['খাঁ', 'খান'] ,
['খাঁচ', 'খাঁচা'] ,
['খাঁচা', 'পিঞ্জর'] ,
['খাঁটি লাভ', 'বিশুদ্ধ মুনাফা'] ,
['খাইজ্বর', 'খাতজ্বর'] ,
['খাওয়া', 'খেয়ে নেওয়া', 'খেয়ে ফেলল', 'গোগ্রাসে খাওয়া', 'ভক্ষণ', 'ভক্ষণ করা', 'ভক্ষিত', 'ভোজন করা', 'লাগানো'] ,
['খাওয়ানো', 'খাবার খাওয়ানো', 'ভোজন করানো'] ,
['খাকরা', 'খাখরা'] ,
['খাকী রঙ', 'মেটে রঙ'] ,
['খাট বুনা', 'খাটবুনা'] ,
['খাটো', 'বামন', 'বেঁটে'] ,
['খাড়া উঁচু পাহাড় বা পাথর', 'দুরারোহ পর্বতগাত্র'] ,
['খাত', 'গভীর খাত', 'গভীর গর্ত'] ,
['খাদক', 'ভক্ষক', 'ভক্ষণকারী', 'ভোজনকারী', 'যারা খেতে এসেছে'] ,
['খাদ্য মিশ্রণ', 'মিশ্রিত খাদ্যবস্তু'] ,
['খাদ্য', 'খাবার', 'ব্যঞ্জন', 'রান্না', 'সুখাদ্য'] ,
['খাদ্যগ্রহণ', 'ভোজন', 'ভোজন কর্ম'] ,
['খাদ্যজ এ', 'ভিটামিন এ'] ,
['খাদ্যজ এইচ', 'বায়োটিন', 'ভিটামিন এইচ'] ,
['খাদ্যজ এম', 'খাদ্যজ বি সি', 'ফেলিক অ্যাসিড', 'ফোলেট', 'ভিটামিন বি সি'] ,
['খাদ্যজ কে ', 'ভিটামিন কে '] ,
['খাদ্যজ ডি ', 'ভিটামিন ডি '] ,
['খাদ্যজ পি', 'বায়োফ্লেবিনোইড', 'ভিটামিন পি', 'সিট্রিন'] ,
['খাদ্যজ বি', 'থাইমিন হাইড্রোক্লোরাইড', 'নিকোটিনিক অ্যাসিড', 'ভিটামিন বি', 'ভিটামিন বি '] ,
['খাদ্যজ', 'ভিটামিন'] ,
['খাদ্যনালি', 'নলি'] ,
['খাদ্যসূচী', 'ব্যঞ্জনসূচী', 'মেনু'] ,
['খানদানি', 'পিতৃপুরুষের', 'পৈতৃক', 'বংশগত', 'বংশীয়', 'মৌরুসি'] ,
['খানা', 'নরদমা', 'নালা'] ,
['খাপা', 'ছোটো হয়ে যাওয়া'] ,
['খাবার কক্ষ', 'খাবারঘর'] ,
['খাবার তৈরি করা', 'খাবার বানানো', 'রসুইতে কাজ করা', 'রাঁধা', 'রান্না করা'] ,
['খাবার বাসন', 'ভোজনপাত্র'] ,
['খাবার', 'ভাত'] ,
['খামখেয়ালিপনা', 'যথেচ্ছাচার'] ,
['খামসামা', 'ঠকুর', 'পাচক', 'বাবুর্চি'] ,
['খাম্বাজ', 'খাম্বাবতী'] ,
['খাম্বাজ-কানাড়া', 'খাম্বাবতী-কানাড়া'] ,
['খাম্বাত', 'খাম্বাত খাঁড়ি'] ,
['খারাপ অক্ষর', 'খারাপ হাতের লেথা'] ,
['খারাপ করা', 'নষ্ট করা', 'পথভ্রষ্ট করা', 'বিগড়ানো', 'বিগড়ে দেওয়া', 'ভুল রাস্তা দেখানো'] ,
['খারাপ গুণ', 'দোষ'] ,
['খারাপ থেকে খারাপতর', 'খুব খারাপ'] ,
['খারাপ পরিণাম', 'বাজে পরিণাম'] ,
['খারাপ বাহন', 'খারাপ যান'] ,
['খারাপ সময়', 'ভাগ্যের ফের', 'সময়ের ফের'] ,
['খারাপ', 'দূষিত', 'দোষযুক্ত'] ,
['খারি', 'খারি নদী'] ,
['খারিজ', 'বহিষ্কৃত'] ,
['খালি করা', 'ছাড়া', 'স্থান ত্যাগ করা'] ,
['খালি জায়গা', 'খালি স্থান', 'রিক্ত স্থান', 'শুণ্য স্থান'] ,
['খালি', 'ফাঁকা', 'ফাঁপা', 'ফাঁপা অংশ', 'রিক্ত', 'শূণ্য'] ,
['খাস', 'খাস জমি', 'বিশেষ'] ,
['খাসী', 'খাসী ভাষা'] ,
['খাস্তা', 'মুচমুচে'] ,
['খিচুড়ী', 'মিলিজুলি'] ,
['খিটখিট', 'ঝগড়া-ঝাটি'] ,
['খিটখিটে স্বভাব', 'রোষপ্রবণতা'] ,
['খিড়কি', 'গবাক্ষ', 'জানলা'] ,
['খুঁট', 'খুঁটি'] ,
['খুঁটি', 'ঠেক', 'ঠেকনা', 'ঠেকা', 'ঠেস'] ,
['খুঁটিনাটি', 'নাড়ীনক্ষত্র', 'বিশদ বিবরণ'] ,
['খুঁটে খাওয়া', 'খোঁটা'] ,
['খুচরো দোকান', 'মুদি দোকান'] ,
['খুচরো', 'রিটেল'] ,
['খুদিত', 'খোঁড়া', 'খোদিত'] ,
['খুন', 'বধ', 'হত্যা', 'হনন'] ,
['খুনি', 'ঘাতক', 'হত্যাকারী'] ,
['খুনী', 'হত্যাকারী'] ,
['খুব ঠান্ডা', 'প্রচন্ড ঠান্ডা'] ,
['খুব বড়', 'বড়', 'মহান'] ,
['খুব বড়ো', 'বিশাল বড়ো', 'বৃহত্'] ,
['খুব বেশী', 'ভয়ঙ্কর'] ,
['খুব হওয়া', 'প্রচুর হওয়া'] ,
['খুবানি', 'খুমানি'] ,
['খুমী', 'খুম্ভী'] ,
['খুরন', 'খুরন রোগ'] ,
['খুরি', 'বাটি'] ,
['খুর্দা', 'খুর্দা জেলা', 'খুর্দা শহর'] ,
['খুর্রম', 'শাহজাহাঁ'] ,
['খুলি', 'ভগালি'] ,
['খুলে যাওয়া', 'ঝড়ে পড়া', 'পৃথক হওয়া', 'বেরোনো. আলাদা হওয়া'] ,
['খুশকি', 'মরামাস', 'রূসী'] ,
['খুশির সঙ্গে', 'প্রসন্নতাপূর্বক', 'সহর্ষ'] ,
['খুশী হওয়া', 'প্রসন্ন হওয়া'] ,
['খেঁদিয়ে দেওয়া', 'তাড়িয়ে দেওয়া'] ,
['খেচর', 'পাখী', 'বিহগ', 'বিহঙ্গ', 'বিহঙ্গম'] ,
['খেড়া', 'খেড়া জেলা', 'খেড়া শহর'] ,
['খেপে যাওয়া', 'পাগল হওয়া'] ,
['খেমকারী', 'ধোবিয়া চিল', 'শঙ্কর চিল'] ,
['খেমের', 'খেমের ভাষা'] ,
['খেরুয়া', 'খেরো'] ,
['খেলনা গাড়ী', 'টয়ট্রেন'] ,
['খেলনা', 'পুতুল'] ,
['খেলা', 'গেম', 'তামাশা', 'প্রগলতা', 'বাঁ হাতের খেলা', 'ম্যাচ', 'সহজ কাজ'] ,
['খেলো', 'ফালতু', 'বাজে', 'রদ্দি'] ,
['খেলোয়াড়দের দল', 'দল'] ,
['খেয়া পারানি', 'পারানি'] ,
['খেয়াল করতে পারা', 'মনে পরা'] ,
['খেয়াল করা', 'নজর দেওয়া'] ,
['খেয়াল না করা', 'ছেড়ে দেওয়া', 'নজর না দেওয়া'] ,
['খেয়াল', 'ধ্যান', 'মনে পড়া', 'সুধি', 'স্মৃতি'] ,
['খেয়ে ফেলা', 'ধ্বংস করা', 'নষ্ট করা', 'বরবাদ করা', 'শেষ করা', 'শেষ করে ফেলা', 'সাফ করে দেওয়া'] ,
['খো-খো', 'খোখো'] ,
['খোঁ ইনজিন', 'সার্চ ইনজিন'] ,
['খোঁচা', 'খোঁচার দাগ'] ,
['খোঁচানো', 'প্ররোচিত করা'] ,
['খোঁজ করা', 'খোঁজা', 'দেখা'] ,
['খোঁজ', 'তল্লাশ'] ,
['খোঁজ-খবর', 'নাম-ঠিকানা'] ,
['খোঁজাখুজি করা', 'খোঁড়া', 'তছনছ করা'] ,
['খোঁড়া', 'পঙ্গু', 'ল্যাঙ্গরা'] ,
['খোঁসা', 'খোঁসা শহর'] ,
['খোঁয়াড়', 'পিঁজড়াপোল'] ,
['খোই', 'খোইয়া'] ,
['খোকা', 'সোনা'] ,
['খোখর', 'খোখর রাগ'] ,
['খোড়ানো', 'ল্যাংড়ানো'] ,
['খোদক', 'খোদাইকারী', 'ত্বষ্টা'] ,
['খোর', 'খোর গাছ'] ,
['খোরা', 'বাটি'] ,
['খোলশা করা', 'প্রকাশ করা'] ,
['খোলা ছেড়া রাখা', 'খোলা রাখা'] ,
['খোলা জায়গা', 'খোলা ময়দান'] ,
['খোলা', 'খোসা', 'চালু', 'চালু করা', 'চালু হওয়া', 'ছাড়া', 'জন্ম দেওয়া', 'দেওয়া', 'পর্দা ফাঁস করা', 'প্রদত্ত', 'প্রদান করা', 'ফাঁস করা', 'বিমোচন', 'মুখোশ খুলে দেওয়া', 'শুরু করা', 'সমাধান করা'] ,
['খোলাখুলিভাবে', 'পরিষ্কীর করে', 'রাখ ঢাক না করে', 'সবার সামনে', 'স্পষ্টতঃ', 'স্পষ্টভাবে'] ,
['খোশমেজাজী', 'মিশুকে', 'সদাশয়', 'সৌর্হার্দ্যপূর্ণ'] ,
['খোশামদী', 'চাটুকারী'] ,
['খোসা ছাড়ানো', 'ছাল ছাড়ানো'] ,
['খোয়া ক্ষীর', 'মাওয়া'] ,
['খোয়া যাওয়া', 'হারানো', 'হারিয়ে যাওয়া'] ,
['খ্যাঁচখ্যাঁচানি', 'বক বক'] ,
['খ্যাত', 'খ্যাতি প্রাপ্ত', 'চেনা-জানা', 'নামকরা', 'নামী', 'নামী-দামি', 'প্রখ্যাত', 'বিখ্যাত'] ,
['খ্যাপা', 'বাতিকগ্রস্ত'] ,
['খ্রিসমাস', 'খ্রিসমাস ডে', 'বড় দিন'] ,
['খ্রীশ্চান', 'খ্রীষ্ট ধর্মাবলম্বী', 'খ্রীষ্টান'] ,
['খ্রীষ্ট ধর্ম', 'খ্রীষ্ট ধর্মীয়', 'খ্রীষ্টিয়'] ,
['খ্রীষ্টান চার্চ', 'চার্চ'] ,
['খয়রাত', 'দান'] ,
['খয়রাতি', 'সাহায্যপ্রাপ্ত'] ,
['গ', 'গান্ধার', 'তৃতীয় স্বর', 'ব্যঞ্জনবর্ণ গ'] ,
['গওয়ালা জাতি', 'গো পালক', 'ঘোষ', 'যাদব'] ,
['গগল্স', 'রোদ চশমা'] ,
['গঙ্গরা', 'রাম গঙ্গরা', 'রামগঙ্গরা'] ,
['গঙ্গা সাগর', 'গঙ্গাসাগর'] ,
['গঙ্গাজল', 'গঙ্গোদক'] ,
['গঙ্গাজলিয়া', 'বববেলিয়া'] ,
['গঙ্গাদত্ত', 'তালকেতু', 'দেবব্রত', 'পুরাবসু', 'ভীষ্ম', 'ভীষ্ম পিতামহ'] ,
['গঙ্গাধর তিলক', 'বাল গঙ্গাধর তিলক', 'লোকমান্য তিলক'] ,
['গঙ্গার', 'গাঙ্গেয়'] ,
['গচ্ছিত', 'জমা'] ,
['গজ', 'দিগ্গজ', 'মহাগজ', 'হাতি'] ,
['গজগজ করা', 'গুজগুজ করা', 'বিড়বিড় করা'] ,
['গজচর্ম', 'হাতির চামড়া'] ,
['গজচ্রম', 'গজচ্রম রোগ'] ,
['গজদন্ত', 'গজদাঁত', 'নাগদন্ত', 'হস্তীদন্ত', 'হাতি-দাঁত', 'হাতির দাঁত'] ,
['গজপতি', 'গজপতি জেলা', 'গজপতি বর্ণবৃত্ত'] ,
['গজপিপ্পলী', 'পিপুল', 'পিপ্পলী'] ,
['গজপুর', 'হস্তিনাপুর'] ,
['গজমতি', 'গজমুক্তা'] ,
['গজশালা', 'পিলখানা', 'হস্তিশালা'] ,
['গজসেনা', 'হাতিসেনা'] ,
['গজাল', 'তারকাঁটা', 'পেরেক'] ,
['গঞ্জন', 'গঞ্জন তাল'] ,
['গঞ্জাম', 'গঞ্জাম জেলা'] ,
['গঠন থাকা', 'সংরচনা থাকা'] ,
['গঠন', 'ডিজাইন', 'নির্মাণ', 'সংরচনা', 'সংস্থাপন', 'সেটিং', 'স্থাপন'] ,
['গঠনশৈলীর', 'স্হাপত্যসংক্রান্ত'] ,
['গড ফাদার', 'ধর্ম পিতা', 'ধর্মপিতা'] ,
['গড মাদার', 'ধর্ম মাতা', 'ধর্মমাতা'] ,
['গডগ', 'গডগ শহর'] ,
['গডচিরোলি', 'গডচিরোলি জেলা'] ,
['গডচিরোলী', 'গডচিরোলী শহর'] ,
['গড়খাই', 'পরিখা'] ,
['গড়গড় শব্দ', 'গর্জন'] ,
['গড়বড়', 'দোষ'] ,
['গড়ানো', 'গড়িয়ে পড়া', 'গড়িয়ে যাওয়া'] ,
['গণ', 'দল', 'পল্টন', 'ফৌজ', 'বর্ণিক গণ', 'বৃন্দ', 'মণ্ডলী', 'সমূহ'] ,
['গণক', 'গণত্কার', 'ভবিষ্যদ্দ্রষ্টা', 'ভবিষ্যদ্বক্তা'] ,
['গণগৌর', 'মনোরথ তৃতীয়া'] ,
['গণতন্ত্র দিবস', 'প্রজাতন্ত্র দিবস'] ,
['গণতন্ত্র', 'গণরাজ্য', 'জনতন্ত্র', 'প্রজাতন্ত্র', 'প্রজাসত্তা', 'লোকতন্ত্র', 'লোকসত্তা'] ,
['গণতান্ত্রিক', 'প্রজাতান্ত্রিক', 'লোকতান্ত্রিক'] ,
['গণনা করা', 'গোনা', 'সংখ্যা জানা'] ,
['গণনীয়', 'গণ্য'] ,
['গণপতি', 'গণপতি উপনিষদ'] ,
['গণসংহার', 'গণহত্যা'] ,
['গণেশ উত্সব', 'গণেশোত্সব'] ,
['গণ্ডক', 'গণ্ডক নদী'] ,
['গণ্ডগোল', 'গোলমাল', 'ঘোটালা', 'তছরূপ'] ,
['গণ্ডূষ', 'তালু'] ,
['গত পরশু', 'পরশু'] ,
['গত সাল', 'পরসাল'] ,
['গতি বিজ্ঞান', 'ডাইনামিক্স'] ,
['গতি মাপক', 'স্পীডোমিটার'] ,
['গতি', 'গতিবেগ', 'চলন', 'বেগ'] ,
['গতিনির্ধারক যন্ত্র', 'পেসমেকার'] ,
['গতিময়', 'গতিশীল', 'প্রবাহমান', 'প্রবাহিত', 'বহমান'] ,
['গতিশীল', 'দ্রুত'] ,
['গতিহীন', 'থামা', 'থেমে থাকা', 'বন্ধ', 'বিশ্রান্ত', 'স্থির'] ,
['গতু', 'গতু ঋষি'] ,
['গথিক ফণ্ট', 'গথিক লিপি'] ,
['গথিক ভাষার', 'গথিক ভাষায়'] ,
['গথিক', 'গথিক ভাষা', 'গথিক লিপি', 'গথিক স্থাপত্যরীতি'] ,
['গদর্ভবাহিনী', 'মাতা', 'শীতলা', 'শীতলা দেবী'] ,
['গদাধর', 'গদাধারী'] ,
['গদি', 'জাহাজ গদি', 'পদ'] ,
['গদি. গোল বালিশ', 'তাকিয়া'] ,
['গদিচ্যূত', 'সিংহাসনচ্যূত'] ,
['গদিধারী', 'সরকার'] ,
['গধূলী', 'গধূলীবেলা', 'সূর্যাস্তকাল'] ,
['গন্তব্য', 'গন্তব্য স্থান', 'লক্ষ্য', 'লক্ষ্য স্থান', 'লক্ষ্যমাত্রা', 'লক্ষ্যস্থান'] ,
['গন্ধ কালিকা', 'দশোয়ী', 'দাসেয়ী', 'মছোদরী', 'মত্স্যগন্ধা', 'মীনগন্ধা', 'যোজনগন্ধা', 'শালঙ্কাযনজা', 'সত্যবতী', 'সত্যা'] ,
['গন্ধ নেওয়া', 'শোঁকা'] ,
['গন্ধ বেড়াল', 'ভাম বেড়াল'] ,
['গন্ধ-পত্র', 'ত্রীফল', 'বিল্ব', 'বেল'] ,
['গন্ধকাম্ল', 'তুঁতে'] ,
['গন্ধকাল্ম', 'ধাতুশেখর'] ,
['গন্ধজাত', 'তমালক', 'তেজপত্র', 'তেজপাতা', 'পাকরঞ্জন', 'সুপত্র'] ,
['গন্ধদ্রব্য', 'সুগন্ধী'] ,
['গন্ধপ্রসারিণী', 'সুপ্রসরা'] ,
['গন্ধবিরোজা', 'দারুগন্ধা'] ,
['গন্ধমূষিক', 'ছুঁচো'] ,
['গন্ধলেবু', 'জম্বির', 'টাবা', 'বড় লেবু'] ,
['গন্ধহীন', 'নির্গন্ধ'] ,
['গবাক্ষ', 'জানলা', 'ঝরোকা', 'বাতায়ন'] ,
['গবাদনী', 'গামলা'] ,
['গবাদি পশু চোর', 'গরু-চোর'] ,
['গবিষ্ঠর', 'গবিষ্ঠর ঋষি'] ,
['গবুনিস', 'গাবানিস', 'গাবার'] ,
['গবেষক-ছাত্র', 'গবেষকছাত্র'] ,
['গবেষণা পত্র', 'রিসার্চ পেপার'] ,
['গবেষণা বিষয়ক প্রবন্ধ', 'গবেষণাপত্র'] ,
['গবোরোন', 'গাবোরোন', 'গৈবোরোন'] ,
['গবয়', 'গবয় ছন্দ'] ,
['গভর্নর', 'রাজ্যপাল'] ,
['গভীর চাহিদা', 'প্রবল অভিলাষা'] ,
['গভীর দুঃখ', 'গভীর শোক'] ,
['গভীর রাত', 'রাতদুপুর'] ,
['গভীরতা', 'গম্ভীরতা', 'গহনতা', 'গুরুত্ব'] ,
['গভীরতায়', 'গভীরে'] ,
['গমন', 'চলে যাওয়া', 'প্রস্থান', 'প্রস্থান করা'] ,
['গমনীয়', 'গম্য'] ,
['গমের সিদ্ধ দানা', 'জোয়ারের সিদ্ধ দানা'] ,
['গম্বুজ', 'গুম্বজ'] ,
['গম্ভিরি', 'গম্ভিরি নদী'] ,
['গরজ', 'স্বার্থ'] ,
['গরবা', 'গরবা জেলা', 'গরবা শহর'] ,
['গরম করা', 'তপ্ত করা'] ,
['গরম কাল', 'গরমের সময়', 'গ্রীষ্মকাল'] ,
['গরম', 'গরম গরম', 'টাটকা', 'তাজা'] ,
['গররাজি', 'দ্বিমতপোষণকারী'] ,
['গরল', 'বিষ'] ,
['গরিমা', 'গৌরব', 'মর্যাদা', 'মহিমা', 'মাহাত্ম্য'] ,
['গরিমাহীন', 'গৌরবহীন'] ,
['গরিলা', 'বনমানুষ'] ,
['গরীব', 'গরীব ব্যাক্তি', 'দরিদ্র', 'দীন', 'নির্ধন', 'নির্ধন ব্যাক্তি', 'ফকির', 'সর্বহারা'] ,
['গরু দান', 'গোদান'] ,
['গরু', 'গাভী', 'ধেনু', 'রেবতী', 'রোহিনী'] ,
['গরুড় পুরাণ', 'গরুড়পুরাণ', 'গারুড়'] ,
['গরুড়াস্ত্র', 'গারুড়'] ,
['গরুর গাড়ী', 'ছ্যাকরা গাড়ী'] ,
['গরুর মাংস', 'গো মাংস', 'গোমাংস'] ,
['গর্গ', 'গর্গ ঋষি'] ,
['গর্জন করা', 'গর্জে ওঠা', 'চিত্কার করা', 'হুঙ্কার দেওয়া'] ,
['গর্জন', 'হুংকার'] ,
['গর্ত', 'গহ্বর', 'ছিদ্র', 'জলভরা গর্ত', 'বিবর', 'শারীরিক কক্ষ'] ,
['গর্দভ', 'গাধা'] ,
['গর্দভিকা', 'গর্দভিকা রোগ'] ,
['গর্দভী', 'গাধী'] ,
['গর্ব দেখানো', 'ডাঁট দেখানো', 'বড়াই করা'] ,
['গর্ভ', 'গর্ভ উপনিষদ', 'গর্ভগৃহ', 'গর্ভথলি', 'গর্ভস্থ জীব', 'গর্ভাবস্থা', 'গর্ভাশয়', 'গর্ভোপনিষদ', 'জরায়ু', 'দেবকক্ষ', 'পেট', 'ভ্রূণ', 'যোনি', 'স্ত্রী জননাঙ্গ'] ,
['গর্ভকাল', 'গর্ভাবস্হা'] ,
['গর্ভজ প্রাণী', 'জরায়ুজ জীব', 'জরায়ুজ প্রাণী'] ,
['গর্ভজ', 'জরায়ুজ'] ,
['গর্ভদংশ', 'সন্দংশ'] ,
['গর্ভধারণ', 'গর্ভধারণ সংস্কার', 'গর্ভাধান', 'গর্ভাধান সংস্কার'] ,
['গর্ভনালি', 'নাভি'] ,
['গর্ভবতী', 'গর্ভবতী মহিলা'] ,
['গর্মপাই', 'গুগরল', 'লাদ্দিম'] ,
['গলগণ্ড', 'ঘেগ'] ,
['গলন', 'গলা', 'বিগলন'] ,
['গলা সাধা', 'রেওয়াজ'] ,
['গলা', 'গলিত', 'গলে যাওয়া', 'গ্রীবা'] ,
['গলাদ্ধকরণ', 'গেলা'] ,
['গলানী', 'গলাসী'] ,
['গলাবন্ধ', 'গলাবন্ধনী', 'মাফলার'] ,
['গলাভাত', 'ফেনাভাত'] ,
['গলার ফোঁড়া', 'ফোঁড়া'] ,
['গলিত-কুষ্ট', 'গলিতকুষ্ট'] ,
['গল্ডেন', 'গিল্ডর', 'ফ্লোরিন'] ,
['গহন', 'ঘন', 'নিবিড়', 'সঘন'] ,
['গহ্বর', 'গুহা'] ,
['গাঁ', 'গ্রাম'] ,
['গাঁজা', 'মারিজুয়ানা'] ,
['গাঁট', 'গিঁট', 'গ্রন্থন', 'জোড়ে', 'ট্যাঁক', 'সন্ধি'] ,
['গাঁটওলা', 'গাঁটযুক্ত'] ,
['গাঁটযুক্ত মূল', 'গাঁটযুক্ত শেখর'] ,
['গাঁঠকাটা', 'চোর', 'ঠগ', 'দোকান-চোর', 'হাতটান স্বভাবের লোক'] ,
['গাঁথা', 'গ্রন্থন', 'গ্রন্থন করা', 'গ্রন্থিত'] ,
['গাংচিল', 'জলকুক্কুটি'] ,
['গাইড', 'মানে বই', 'মার্গদর্শক'] ,
['গাওয়া', 'গীত'] ,
['গাছ', 'গুল্ম', 'তরু', 'তরুবর', 'দ্রুম', 'পাদপ', 'বনস্পতি', 'বিটপ', 'বিটপী', 'বৃক্ষ'] ,
['গাছ-পালা', 'বনস্পতি', 'বৃক্ষ'] ,
['গাছের মূল', 'মূল'] ,
['গাজর ঘাস', 'গাজরঘাস'] ,
['গাজর', 'পীতমূলক'] ,
['গাজিয়াবাদ', 'গাজিয়াবাদ জেলা', 'গাজিয়াবাদ শহর'] ,
['গাজীপুর', 'গাজীপুর জেলা', 'গাজীপুর শহর'] ,
['গাড়ি', 'মোটরগাড়ি'] ,
['গাড়িওয়ালা', 'গাড়োয়ান'] ,
['গাড়ী পার্কিং', 'পার্কিং'] ,
['গাড়ু', 'জগ', 'বদনা'] ,
['গাঢ় করা', 'ঘন করা'] ,
['গাঢ় লাল', 'রক্তবর্ণ'] ,
['গাদা', 'পুঞ্জ', 'সমষ্টি', 'সমূহ'] ,
['গাদি', 'জমিদারি', 'জমিদারিআনা', 'জোতদারি'] ,
['গান', 'গীত', 'সঙ্গীত'] ,
['গান্ধার', 'গান্ধার রাগ', 'গান্ধার রাজ্য'] ,
['গান্ধারী', 'ধৃতরাষ্ট্রী', 'সৌবলী'] ,
['গান্ধিপোকা', 'ছারপোকা'] ,
['গান্ধী নগর', 'গান্ধীনগর'] ,
['গান্ধী', 'গান্ধীজী', 'বাপু', 'মহাত্মা গান্ধী', 'মোহনদাস করমচাঁদ গান্ধী'] ,
['গান্ধীগিরি', 'গান্ধীবাদ'] ,
['গান্ধীনগর', 'গান্ধীনগর জেলা'] ,
['গাবা বাসী', 'গাবানিস', 'গাবাবাসী', 'গাবুন বাসী'] ,
['গাবা', 'গাবান'] ,
['গামছা', 'তোয়ালে'] ,
['গাম্বিয়া বাসী', 'গাম্বিয়ান'] ,
['গাম্বিয়া সম্পর্কিত', 'গাম্বিয়ান', 'গাম্বিয়ার'] ,
['গাম্বিয়া', 'গাম্বিয়া গণতন্ত্র'] ,
['গারস্থ', 'গৃহস্থাশ্রম'] ,
['গারুড়', 'গারুড় উপনিষদ', 'গারুড় বূহ্য', 'গারুড় মন্ত্র', 'গারুড়োপনিষদ', 'পান্না', 'পান্না শহর', 'মরকত'] ,
['গারুড়ি', 'গারুড়ি তাল', 'গারুড়িক'] ,
['গারুড়িক', 'জীবক', 'সাপুড়ে'] ,
['গার্ডেন পিঙ্ক', 'পিঙ্ক'] ,
['গাল দেওয়া', 'বাজে কথা বলা'] ,
['গাল-মন্দ', 'বকা-ঝকা', 'বকা-বকি'] ,
['গালচে', 'গালিচা'] ,
['গালব', 'গালব ঋষি'] ,
['গালিচা', 'জালবন্দ'] ,
['গায়ক পক্ষী', 'গায়ক পাখি'] ,
['গায়কী', 'মূল রস'] ,
['গায়ানা', 'গিয়ানা', 'গুয়ানা', 'ব্রিটিশ গায়ানা'] ,
['গায়ে ব্যাথা', 'পেশীতে ব্যাথা'] ,
['গায়েব হওয়া', 'হারিয়ে যাওয়া'] ,
['গায়েব হয়ে যাওয়া', 'চম্পট দেওয়া', 'চলে যাওয়া', 'পালিয়ে যাওয়া'] ,
['গিগাবাইট', 'জিবি'] ,
['গিনি বিসাউ', 'গিনি বিসাউ গণতন্ত্র', 'পর্তুগালী গিনি'] ,
['গিনি', 'গিনি গণরাজ্য', 'ফ্রেঞ্চ গিনি'] ,
['গিনী-বিসোব পেসো', 'পেসো'] ,
['গিবন', 'গিবন বাঁদর'] ,
['গিরগিটিমার', 'দস্তমল', 'পত্তই', 'সাদা গিরগিটিমার'] ,
['গিরমিটি', 'গিরমিটি শ্রমিক'] ,
['গিরি শিখর', 'চূড়া', 'পর্বত শিখর', 'পাহাড়ের চূড়া', 'শিখর', 'শৃঙ্গ'] ,
['গিরি', 'গিরি সন্ন্যাসী'] ,
['গিরিজা', 'গির্রী', 'গুরগুরা', 'পার্বতী', 'শৈলজা'] ,
['গিরিডি', 'গিরিডি জেলা', 'গিরিডি শহর'] ,
['গিরিপতি', 'গিরিরাজ', 'গিরীশ', 'শৈলাধীপ', 'শৈলেন্দ্র', 'হিমাচল', 'হিমাচল প্রদেশ', 'হিমালয়'] ,
['গিরিপথ', 'পাস'] ,
['গিরিরাজ', 'পর্বতরাজ', 'বড়ো পর্বত'] ,
['গিরিসুত', 'মৈনাক', 'মৈনাক পর্বত', 'সুনাভ', 'হিমালয়াজ'] ,
['গির্জাঘর', 'চার্চ'] ,
['গির্জার পার্শ্ববর্তী স্থান', 'চানসেল'] ,
['গিলে ফেলা', 'গেলা'] ,
['গিল্টী', 'জল করা'] ,
['গীত সঙ্গীত', 'গীত-সঙ্গীত'] ,
['গীতা', 'গীতিকা', 'ভগবদ গীতা', 'শ্রীমদ্ভগবদগীতা'] ,
['গীতিকবিতা', 'গীতিকাব্য'] ,
['গু', 'পায়খানা', 'বিষ্ঠা', 'মল'] ,
['গুঁড়ি', 'টুকরো'] ,
['গুঁড়ো চিনি', 'চিনির গুঁড়ো'] ,
['গুঁড়ো মিষ্টি', 'মিষ্টির গুঁড়ো'] ,
['গুঁড়ো', 'চূর্ণ'] ,
['গুচ্ছ', 'গোছা'] ,
['গুছিয়ে রাখা', 'সুব্যবস্হা করা'] ,
['গুজব', 'রটনা'] ,
['গুজরাত বাসি', 'গুজরাতী'] ,
['গুজরাতী', 'গুজরাতী ভাষা', 'গুজরাতী লিপি'] ,
['গুজ্জর', 'গুজ্জর জাতি', 'গুর্জর'] ,
['গুঞ্জন করা', 'গুনগুন করা'] ,
['গুঞ্জন', 'গুনগুন'] ,
['গুটিবসন্ত', 'মায়ের দয়া'] ,
['গুড়গাঁও', 'গুড়গাঁও জেলা', 'গুড়গাঁও শহর'] ,
['গুড়ের চিট', 'ফদকা'] ,
['গুড়ো করা', 'চূর্ণ করা'] ,
['গুড়ো গুড়ো হয়ে যাওয়া', 'চুরমার হয়ে যাওয়া'] ,
['গুড়ো', 'চূর্ণ'] ,
['গুঢ়', 'রহস্যজনক', 'রহস্যময়'] ,
['গুণ', 'গুণন', 'গুণন কর্ম', 'গুণপনা', 'ছিলা', 'ত্রিগুণ', 'ভালো গুণ', 'লক্ষণ', 'সুগুণ'] ,
['গুণক', 'গুণনাঙ্ক'] ,
['গুণকীর্তন', 'গুণগান'] ,
['গুণকীর্ত্তণ', 'গুণগান'] ,
['গুণকীর্ত্তন করা', 'প্রশংসা করা'] ,
['গুণক্রিয়া', 'গুণগ্রাম', 'গুণাবলি', 'গুণালংকার'] ,
['গুণগ্রাহী', 'সমঝদার'] ,
['গুণনিধি', 'গুণাকর'] ,
['গুণবত্তা স্তর', 'মান', 'মানদণ্ড'] ,
['গুণবত্তারহিত', 'গুণবত্তাহীন'] ,
['গুণবান', 'গুণসম্পন্ন', 'গুণী', 'দক্ষ', 'সদ্গুণসম্পন্ন'] ,
['গুণান্বিত', 'ভালো'] ,
['গুণ্টুর', 'গুণ্টুর জেলা', 'গুণ্টুর শহর'] ,
['গুণ্ডা', 'দাদা', 'মস্তান'] ,
['গুণ্ডু', 'গুণ্ডু আম', 'গুণ্ডু আম গাছ'] ,
['গুত্সমদ', 'গুত্সমদ ঋষি'] ,
['গুদাম', 'ভাঁড়ার ঘর'] ,
['গুন', 'গোণী', 'থলি', 'থলে', 'বোরা'] ,
['গুনগুন করা', 'ভনভন করা'] ,
['গুনগুন', 'গুনগুনানি'] ,
['গুনা', 'গুনা জেলা', 'গুনা শহর'] ,
['গুন্ডাগিরি', 'দাদাগিরি'] ,
['গুপ-চুপ', 'গুপচুপ'] ,
['গুপ্ত অঙ্গ', 'গুপ্তাঙ্গ', 'জনন ইন্দ্রিয়', 'জননাঙ্গ', 'জননেন্দ্রিয়'] ,
['গুপ্ত দ্বার', 'গোপন দরজা', 'চোর দরজা'] ,
['গুপ্ত বংশ', 'গুপ্ত রাজবংশ'] ,
['গুপ্ত স্থান', 'সংবৃত্ত'] ,
['গুপ্ত', 'গোপন', 'লুক্কায়িত', 'সংবৃত'] ,
['গুপ্তপথ', 'চোরা গলি'] ,
['গুম হয়ে যাওয়া', 'চুপচাপ'] ,
['গুমটি', 'পুলিশ চৌকি'] ,
['গুমলা', 'গুমলা জেলা', 'গুমলা শহর'] ,
['গুমসা', 'ভাবসা'] ,
['গুম্পা', 'গুম্পা নৃত্য'] ,
['গুরত্ব', 'গৌরব', 'গৌরবপূর্ণতা', 'মহিমা', 'মাহাত্ম্য', 'শ্রেষ্ঠত্য'] ,
['গুরবাণী', 'গুরু গ্রান্থ সাহেব', 'গুরুগ্রান্থসাহেব', 'গুরুবাণী'] ,
['গুরু গোবিন্দ সিং', 'গোবিন্দ সিং'] ,
['গুরু গোরখনাথ', 'গোরখনাথ'] ,
['গুরু তেগ বাহাদুর', 'তেগ বাহাদুর'] ,
['গুরু নানক', 'নানক', 'নানক দেব'] ,
['গুরু রামদাস', 'রামদাস'] ,
['গুরু হরগোবিন্দ', 'হরগোবিন্দ দেব'] ,
['গুরু হরিকিষণ', 'হরিকিষণ'] ,
['গুরু হয়রায়', 'হয়রায়'] ,
['গুরু', 'ধর্ম শিক্ষক', 'ধর্মগুরু', 'ধর্মাচার্য', 'সদগুরু'] ,
['গুরুঅস্ত্র', 'ঘনবাণ'] ,
['গুরুতর অপরাধ', 'জঘন্যতম অপরাধ'] ,
['গুরুতর', 'ঘোর', 'বিকট', 'ভীষণ', 'ভয়ঙ্কর'] ,
['গুরুত্বহীন', 'তুচ্ছ', 'নগণ্য', 'মহত্বহীন'] ,
['গুরুদাসপুর', 'গুরুদাসপুর জেলা', 'গুরুদাসপুর শহর'] ,
['গুরুপত্নী', 'গুরুমা', 'গুর্বঙ্গনা', 'গুর্বী'] ,
['গুরুপাক', 'দুষ্পাচ্য', 'ভারী'] ,
['গুরুমন্ত্র', 'দিক্ষা'] ,
['গুরুমুখী', 'গুরুমুখী লিপি'] ,
['গুর্জরী', 'গুর্জরী রাগিনী'] ,
['গুল পাপড়ি', 'গুলপাপড়ি'] ,
['গুল বকাবলী', 'গুল-বকাবলী', 'গুলবকাবলী'] ,
['গুল', 'গুল মাজন', 'পায়ের ডিম'] ,
['গুল-নার', 'গুলনার', 'গুলনার রঙ', 'গুলনারি'] ,
['গুলদুপাহারিয়া', 'বন্ধুক', 'বন্ধুজীব', 'বন্ধুজীবক', 'রক্তক', 'রাগপুষ্প', 'রাগপ্রসব'] ,
['গুলফ্', 'গোড়ালির গাঁট', 'পাদগ্রন্থি'] ,
['গুলবার্গ জেলা', 'গুলবার্গ শহর'] ,
['গুলবার্গ', 'গুলবার্গ শহর'] ,
['গুলমেহেন্দি', 'গুলমেহেন্দির গাছ'] ,
['গুলাবাঁস', 'গুলাবাঁস গাছ'] ,
['গুলি ডান্ডা', 'ডাংগুলি'] ,
['গুলি দিয়ে ঝাঁঝরা করা', 'ঝাঁঝরা করা'] ,
['গুলি', 'ট্যাবলেট', 'পিল', 'বটিকা', 'বটী', 'বড়ি', 'ভাঙ', 'রিল', 'লাচি', 'লাছি', 'লোহার গুলি'] ,
['গুলু', 'গুলুবৃক্ষ'] ,
['গুলে যাওয়া', 'গোলা', 'দ্রবীভূত হওয়া', 'দ্রবীভূত হয়ে যাওয়া'] ,
['গুল্ম', 'গুল্ম রোগ', 'গুল্মরোগ', 'ঝাড়', 'ঝোপ', 'ঝোপ ঝাড়'] ,
['গুহানিবাসী', 'গুহাবাসী'] ,
['গুহ্য', 'গুহ্য দ্বার', 'পায়ু', 'মল দ্বার', 'মলদ্বার'] ,
['গুয়াতেমালান', 'গুয়াতেমালার'] ,
['গুয়ানা বাসী', 'ব্রিটিশ গুয়ানা বাসী'] ,
['গুয়ানার', 'গুয়ানীয়'] ,
['গুয়ানিয়ান মুদ্রা', 'ডলার'] ,
['গুয়াহাটী', 'গৌহাটী'] ,
['গূডতৃণ', 'গোনরা', 'নীলপত্র'] ,
['গূণ্ড', 'গূণ্ড রাগ'] ,
['গৃত্সমদ', 'গৃত্সমদ ঋষি'] ,
['গৃহ নির্মাণ', 'বাড়ি নির্মাণ'] ,
['গৃহ প্রবেশ', 'গৃহ-প্রবেশ', 'গৃহপ্রবেশ'] ,
['গৃহ বিজ্ঞান', 'হোম সায়েন্স'] ,
['গৃহ মন্ত্রী', 'গৃহমন্ত্রী'] ,
['গৃহ-যুদ্ধ', 'গৃহযুদ্ধ'] ,
['গৃহ-রাজ্যমন্ত্রী', 'রাজ্য মন্ত্রী'] ,
['গৃহ-সম্পর্কিত', 'ঘরের', 'ঘরোয়া'] ,
['গৃহকর্তা', 'গৃহস্বামী', 'পরিবার প্রধান'] ,
['গৃহনির্মিত', 'ঘরে তৈরী', 'ঘরোয়া'] ,
['গৃহরক্ষক', 'হোম গার্ড'] ,
['গৃহরক্ষাকারী বাহিনী', 'হোম গার্ড'] ,
['গৃহলক্ষ্মী', 'গৃহিনী', 'ঘরনী'] ,
['গৃহস্থ', 'গৃহী'] ,
['গৃহস্থী', 'ঘরের কাজ'] ,
['গৃহোপযোগী', 'ঘরোয়া'] ,
['গেঁটে বাত', 'সন্ধি শূল'] ,
['গেজিঙ্গ', 'গেজিঙ্গ শহর'] ,
['গেজেট', 'ঘোষপত্র', 'সরকারি সংবাদপত্র', 'সাময়িক পত্র'] ,
['গেরিলা বাহিনী', 'গেরিলা সেনা'] ,
['গেরুয়া বস্ত্র', 'গৈরিক বস্ত্র'] ,
['গেলাস', 'গ্লাস'] ,
['গো-ধন', 'গোধন'] ,
['গো-শাবক', 'বাছুর'] ,
['গোঁদা', 'ছোলা'] ,
['গোছগাছ করা', 'বাঁধা'] ,
['গোটা', 'মুখশুদ্ধি'] ,
['গোটানো', 'পাকানো'] ,
['গোঠ', 'গোব্রজ', 'গোষ্ঠ', 'ব্রজ'] ,
['গোড্ডা', 'গোড্ডা জেলা', 'গোড্ডা শহর'] ,
['গোণ্ডা', 'গোণ্ডা জেলা', 'গোণ্ডা শহর'] ,
['গোত্র প্রবর্তক', 'গোত্র-প্রবর্তক', 'গোত্রকার'] ,
['গোত্র', 'গোত্রীয়', 'সগোত্রীয়'] ,
['গোদরোগী', 'শোথরোগী'] ,
['গোদা', 'গোদাবরি', 'গোমতি', 'দক্ষিণগঙ্গা'] ,
['গোধরা', 'গোধরা শহর'] ,
['গোধিকা', 'টিকটিকি'] ,
['গোনর্দ', 'নীর গাং', 'বাজ'] ,
['গোনি', 'ছোটো বস্তা'] ,
['গোনোরিয়া', 'প্রমেহ', 'যোন্যব্যাধিবিশেষ'] ,
['গোন্দিয়া', 'গোন্দিয়া জেলা', 'গোন্দিয়া শহর'] ,
['গোন্স', 'তিলিত্সা'] ,
['গোপন কক্ষ', 'ব্যাক রুম'] ,
['গোপন কথা', 'মর্ম', 'রহস্য'] ,
['গোপন করা', 'লুকোনো'] ,
['গোপনে', 'লুকিয়ে', 'লুকিয়ে চুরিয়ে'] ,
['গোপপাণি', 'গোপপাণি ঋষি'] ,
['গোপাঙ্গনা', 'গোপি', 'গোপিকা', 'গোপিনী'] ,
['গোপাল-তপণি', 'গোপাল-তপণি উপনিষদ'] ,
['গোপালগঞ্জ', 'গোপালগঞ্জ জেলা'] ,
['গোপিকা', 'গোপী', 'গোয়ালিনী'] ,
['গোপী চন্দন', 'গোপীচন্দন', 'তালক'] ,
['গোপুর', 'গোপুরাম', 'বিমানম'] ,
['গোপেশ্বর', 'গোপেশ্বর শহর'] ,
['গোবধ', 'গোহত্যা'] ,
['গোবর', 'গোময়'] ,
['গোবর্ধন', 'গোবর্ধন পর্বত'] ,
['গোভিল', 'গোভিল ঋষি'] ,
['গোমতী', 'গোমতী নদী', 'ধেনুমতি'] ,
['গোমুখ', 'গোমুখাসন', 'গোমুখী'] ,
['গোমুখী', 'জপথলে', 'জপমালী'] ,
['গোমুত্র', 'লাল-ঘাস'] ,
['গোমেদ', 'পীতমণি', 'রাহুরত্ন'] ,
['গোমেধ', 'গোমেধ যজ্ঞ'] ,
['গোরখপন্থ', 'নাথ পন্থ', 'নাথ সম্প্রদায়'] ,
['গোরখপন্থি', 'নাথপন্থি'] ,
['গোরখপুর', 'গোরখপুর জেলা', 'গোরখপুর শহর'] ,
['গোরখা তেঁতুল', 'দীর্ঘদণ্ডী'] ,
['গোরচন', 'রুচি', 'শোভা', 'সুনন্দা'] ,
['গোরা তিতির', 'রাম তিতির', 'সাদা তিতির'] ,
['গোরা', 'ফিরিঙ্গি'] ,
['গোরাডু', 'চুপ্রি আলু'] ,
['গোল মরিচ', 'গোলমরিচ'] ,
['গোল', 'চক্র', 'চক্রাকার', 'চন্দ্রাকার', 'বৃত্ত', 'বৃত্তাকার', 'মন্ডলাকার'] ,
['গোলক', 'গোলক আম', 'গোলক আম গাছে'] ,
['গোলকিপার', 'গোলরক্ষক'] ,
['গোলগাল', 'মোটাসোটা'] ,
['গোলন্দাজ', 'তোপচি'] ,
['গোলমরিচ', 'মরিচ'] ,
['গোলাকার বিজকোষ', 'পোস্তো'] ,
['গোলাঘড়', 'গোলাবাড়ি', 'শস্যাগাড়'] ,
['গোলাঘর', 'গোলাবাড়ি', 'শস্যাগার'] ,
['গোলাঘাট', 'গোলাঘাট জেলা', 'গোলাঘাট শহর'] ,
['গোলাপ জল', 'গোলাপজল'] ,
['গোলাপখাস', 'গোলাপখাস আম'] ,
['গোলাপি', 'গোলাপি রঙ'] ,
['গোলাপী শহর', 'জয়পুর', 'জয়পুর জেলা', 'পিঙ্ক সিটি'] ,
['গোলাবর্ষণ', 'ফায়ারিং', 'বোমাবর্ষণ'] ,
['গোলাম পুত্র', 'দাস পুত্র'] ,
['গোলামী', 'দাসত্ব', 'দাস্য', 'পরাধীনতা'] ,
['গোলোক', 'বিধবার সন্তান', 'বেদুয়া', 'বেদো', 'বেধুয়া'] ,
['গোল্ড কোস্ট', 'ঘানা', 'ঘানা গণতন্ত্র'] ,
['গোশালা', 'গোয়াল', 'গোয়ালঘর'] ,
['গোষুক্তি', 'গোষুক্তি ঋষি'] ,
['গোষ্ঠী', 'দল', 'পঞ্চায়েত', 'বর্গ', 'বাহিনী', 'মণ্ডলী', 'সমষ্টি', 'সমাজ'] ,
['গোসলখানা', 'স্নানগৃহ', 'স্নানঘর', 'স্নানাগার'] ,
['গোস্বামী তুলসীদাস', 'তুলসীদাস'] ,
['গোয়া-আল্ফান্সো আম', 'গোয়া-আল্ফান্সো আম গাছ'] ,
['গোয়াবন্দর', 'গোয়াবন্দর আম', 'গোয়াবন্দর আম গাছ'] ,
['গোয়ালপাড়া', 'গোয়ালপাড়া জেলা', 'গোয়ালপাড়া শহর'] ,
['গোয়ালিয়র', 'গোয়ালিয়র জেলা', 'গোয়ালিয়র শহর'] ,
['গোয়ি', 'গোয়ি রাগ'] ,
['গোয়েটেমালা বাসী', 'গোয়েটেমালান'] ,
['গোয়েটেমালা', 'গোয়েটেমালা গণতন্ত্র', 'গোয়েটেমালা গণরাজ্য'] ,
['গোয়েনান', 'গোয়েনান বাঁদর'] ,
['গৌণ্ড', 'গৌণ্ড জাতি'] ,
['গৌতম বুদ্ধ নগর', 'গৌতম বুদ্ধ নগর জেলা'] ,
['গৌতম বুদ্ধ', 'তথাগত', 'বুদ্ধ', 'ভগবান বুদ্ধ'] ,
['গৌতম', 'গৌতম ঋষি'] ,
['গৌতমবুদ্ধ নগর', 'গৌতমবুদ্ধ নগর জেলা'] ,
['গৌরবময়', 'গৌরবযুক্ত', 'গৌরবশালী', 'গৌরবান্বিত'] ,
['গৌরবর্ণ', 'গৌরবর্ণা', 'গৌরী', 'ফর্সা'] ,
['গৌরিশঙ্কর', 'গৌরিশঙ্কর শৃঙ্গ'] ,
['গৌরী', 'মহাগৌরী'] ,
['গ্যাংটক', 'গ্যাংটক শহর'] ,
['গ্যাংস্টার', 'গ্যাঙ্গস্টার'] ,
['গ্যারাজ', 'গ্যারেজ'] ,
['গ্যারান্টি', 'জবাবদিহি', 'জিম্মা', 'ঠিকা', 'দায়িত্ব', 'ভার'] ,
['গ্যালারি', 'প্যাভিলিয়ন', 'প্রেক্ষণিকা'] ,
['গ্যাস সিলিণ্ডার', 'সিলিণ্ডার'] ,
['গ্যাস', 'গ্যাস উনুন', 'গ্যাসোলিন', 'পাদা', 'রান্নার গ্যাস'] ,
['গ্যাসোলিন', 'পেট্রোল'] ,
['গ্রন্থাগার', 'গ্রন্থালয়', 'পাঠাগার', 'পুস্তকালয়'] ,
['গ্রন্হি', 'জট'] ,
['গ্রস্ত', 'পীড়িত', 'ব্যথিত'] ,
['গ্রহণ করা', 'ধারণ করা', 'নেওয়া', 'পাওয়া', 'প্রাপ্ত করা', 'স্বীকার করা'] ,
['গ্রহণ', 'গ্রাস'] ,
['গ্রহণযোগ্যতা', 'গ্রাহ্য'] ,
['গ্রহণীয়', 'গ্রাহ্য', 'স্বীকার্য্য'] ,
['গ্রহদশা', 'দশা'] ,
['গ্রহন ছাড়া', 'গ্রহনান্ত'] ,
['গ্রহপীড়া', 'গ্রহবাধা'] ,
['গ্রহাকযন্ত্র', 'রিসিভার', 'হ্যান্ডসেট'] ,
['গ্রহিতা', 'প্রাপক', 'প্রাপ্তকর্তা'] ,
['গ্রাজুয়েট', 'স্নাতক'] ,
['গ্রান্ড স্লাম', 'গ্রান্ডস্লাম'] ,
['গ্রাম দেবতা', 'গ্রামদেবতা'] ,
['গ্রাম পঞ্চায়েত', 'গ্রাম পরিষদ', 'গ্রামপঞ্চায়েত'] ,
['গ্রাম পতি', 'গ্রাম প্রধান', 'গ্রাম সভাপতি', 'গ্রাম-প্রধান'] ,
['গ্রামপ্রধান', 'পঞ্চায়েতপ্রধান'] ,
['গ্রামবাসী', 'গ্রামের লোক'] ,
['গ্রামসহায়ক', 'গ্রামসেবক'] ,
['গ্রিনউইচ ভিলেজ', 'ভিলেজ'] ,
['গ্রিফনশকুন', 'মটিয়া শকুন', 'মটিয়াশকুন'] ,
['গ্রীক', 'য়ুনানবাসি', 'য়ুনানি', 'য়ুনানী', 'য়ুনানী ভাষা'] ,
['গ্রীনল্যাণ্ডীয়', 'গ্রীনল্যাণ্ডের'] ,
['গ্রীবাস্থি', 'হাঁসুলি'] ,
['গ্রেট লেক স্টেট', 'মিশিগান'] ,
['গ্রেন সেন্টিয়াগো', 'সেন্টিয়াগো', 'সেন্টিয়াগো ডি চিলী'] ,
['গ্রেনেড', 'হাতবোমা'] ,
['গ্রেনেডিয়ান ডলার', 'ডলার'] ,
['গ্রেপ্তার করা', 'ধরা', 'বন্দী বানানো'] ,
['গ্রেফতার হওয়া', 'ধরা পড়া'] ,
['গ্রেফতার', 'বন্দী'] ,
['গ্র্যাচুইটি', 'পারিতোষিক'] ,
['গ্লুকোজ', 'গ্লুকোস'] ,
['গ্লুসিনিয়াম', 'বেরিলিয়াম'] ,
['গ্লেসিয়র্', 'হিমবাহ', 'হিমানী'] ,
['গ্লোব', 'ভূগোলক'] ,
['গ্লোবাল পোজিশনিং সিস্টেম', 'জীপীএস'] ,
['গয়া', 'গয়া জেলা', 'গয়া শহর'] ,
['ঘ', 'ব্যঞ্জনবর্ণ ঘ'] ,
['ঘগ্গর', 'ঘগ্গর নদী'] ,
['ঘটনাক্রম', 'ঘটনাচক্র'] ,
['ঘটা', 'ঠিক হওয়া', 'সত্য প্রমাণিত হওয়া', 'হওয়া'] ,
['ঘড়া', 'জলপূর্ণ ঘড়া'] ,
['ঘড়ি', 'সময়লেখী', 'সময়লেখী যন্ত্র', 'হাত ঘড়ি'] ,
['ঘড়িঘর', 'ঘন্টাঘর'] ,
['ঘড়ী তৈরীর কাজ', 'ঘড়ী বানানোর কাজ', 'ঘড়ী মোরামতের কাজ', 'ঘড়ীর কাজ'] ,
['ঘণ্টা', 'দণ্ড'] ,
['ঘন মেঘ', 'মেঘমালা', 'মেঘরাজি'] ,
['ঘন', 'সঘন'] ,
['ঘনকাকার', 'ঘনকাকৃতি বিশিষ্ট'] ,
['ঘনত্ব', 'নিবিড়তা', 'সঘনতা'] ,
['ঘনীভবন', 'শীতলীকরণ', 'শীতলীভবন'] ,
['ঘনীভূত', 'জমা'] ,
['ঘন্টা', 'ঘুঙুর', 'নূপুর', 'ম়ঞ্জীর'] ,
['ঘর জামাই', 'ঘরজামাই'] ,
['ঘর', 'ঘুঁটির ঘর', 'দেশ', 'বাড়ী', 'স্বদেশ', 'স্বরাষ্ট্র'] ,
['ঘর-বাড়ি', 'সর্বস্ব'] ,
['ঘরোয়া', 'পারিবারিক'] ,
['ঘর্ঘরা', 'ভবনাশিনী', 'সরায়ু', 'সরায়ু নদী'] ,
['ঘর্ম', 'ঘাম', 'শ্রমজল', 'শ্রমবারি', 'স্বেদ'] ,
['ঘর্ষণ', 'ঘষা', 'রগড়', 'রগড়ানো', 'সংঘর্ষণ'] ,
['ঘষা', 'মাজা', 'মাজা ঘষা করা', 'রগড়ানো'] ,
['ঘা', 'চোট', 'জখম'] ,
['ঘাঘ', 'ঘাঘ কবি'] ,
['ঘাট', 'নৌকাঘাট'] ,
['ঘাটবার', 'পাটুনি'] ,
['ঘাতক', 'দাশুরি', 'নৃশংস', 'বর্বর', 'হিংসক', 'হিংসাত্মক', 'হিংসাপরায়ণ', 'হিংসারু', 'হিংসালু', 'হিংস্রক'] ,
['ঘাতকতা', 'দ্রোহীতা'] ,
['ঘান্টিয়ার', 'ঘান্টিয়ার রোগ'] ,
['ঘাবড়ানো', 'ঘাবড়ে যাওয়া'] ,
['ঘাবড়ে যাওয়া', 'চমকে যাওয়া'] ,
['ঘাম নিঃসরণ', 'স্বেদন'] ,
['ঘাস', 'বারী', 'রাসাল্ভক'] ,
['ঘি', 'ঘৃত'] ,
['ঘুঁঙুর', 'ঘুঁঙ্গুর', 'ঘুঁমুর'] ,
['ঘুঁটের গাদা', 'ঘুঁটের রাশি', 'ঘুঁটের স্তুপ'] ,
['ঘুম', 'নিদ্রা'] ,
['ঘুমন্ত', 'নিদ্রাগত', 'নিদ্রাচ্ছন্ন', 'নিদ্রামগ্ন', 'নিদ্রিত', 'সুপ্ত'] ,
['ঘুরঘুর করা', 'ঘোরা', 'চক্কর কাটা'] ,
['ঘুরতে থাকা', 'ঘূর্ণায়মান'] ,
['ঘুষ খাওয়ানো', 'ঘুষ দেওয়া'] ,
['ঘূম্র', 'ধোঁয়া', 'শিশিরধ্বজ'] ,
['ঘূর্ণণ', 'পাক'] ,
['ঘূর্ণন', 'ঘোরা'] ,
['ঘূর্ণিঝড়', 'ঘূর্ণিবায়ু', 'চক্রবাত', 'সাইক্লোন'] ,
['ঘৃণা করা', 'ঘেন্না করা'] ,
['ঘৃত-পুর', 'ঘেওর'] ,
['ঘেটাল', 'ঘেতলা'] ,
['ঘেরা', 'বেষ্টিত'] ,
['ঘোঁচী', 'ঘোঁচী গাভী'] ,
['ঘোগুর', 'মহাজলকাক'] ,
['ঘোঙ্ঘিল', 'ঘোনঘীলা'] ,
['ঘোড়া', 'ট্রিগার'] ,
['ঘোড়ানিম', 'মহানিম'] ,
['ঘোড়াবেল', 'সারওয়ালা', 'সুরাল'] ,
['ঘোড়ার দল', 'ফিল্ড'] ,
['ঘোড়ী', 'ঘোড়ী গান'] ,
['ঘোর', 'ঘোর ঋষি', 'দারুণ', 'নিদারুণ', 'ভীষণ'] ,
['ঘোরা', 'পরিভ্রমণ', 'পর্যটন', 'পর্যটন করা', 'পিছনে তাকানো', 'ফিরে আসা', 'ফেরা', 'ভ্রমণ', 'যাওয়া'] ,
['ঘোরা-ফেরা', 'বিচরণ', 'ভ্রমণ'] ,
['ঘোরানো', 'চক্কর লাগানো', 'নাচানো', 'হাঁটানো'] ,
['ঘোল', 'মিশ্রণ'] ,
['ঘোষ', 'ঘোষবর্ণ'] ,
['ঘোষণা করা', 'বলা'] ,
['ঘোষণা', 'ডুগডুগি'] ,
['ঘ্রাণেন্দ্রিয়', 'নাক', 'নাসা', 'নাসিকা'] ,
['ঙ', 'ব্যঞ্জনবর্ণ ঙ'] ,
['চ', 'ব্যঞ্জনবর্ণ চ'] ,
['চক', 'বাগ', 'বাজার'] ,
['চকচক', 'ঝকঝক', 'ঝকমক'] ,
['চকচকে হওয়া', 'পরিষ্কার হওয়া'] ,
['চকচকে', 'চকমকে'] ,
['চকবঁড়', 'শুকনাশন'] ,
['চকবড়', 'চাকুদা', 'পামাড়'] ,
['চকমকে', 'চটকদার'] ,
['চকমা দেওয়া', 'চুক্কি দেওয়া'] ,
['চকরি', 'ফিরকি'] ,
['চকোতরী', 'চকোত্রী', 'ছোট বনমুর্গি', 'লোহিত কুক্কুট'] ,
['চকোরি', 'মাদি চকোর'] ,
['চক্কর কাটা', 'পরিক্রমা'] ,
['চক্কর', 'চক্র'] ,
['চক্র', 'চাকা'] ,
['চক্রদন্তী', 'জমালগোটা', 'জামালগোটা', 'দন্ত-মূলিকা', 'দন্তী', 'বিষভদ্রা', 'বিষভদ্রিকা', 'বীজাক্ষ', 'শীঘ্র'] ,
['চক্রধর', 'চক্রধর রাগ'] ,
['চক্রবর্তী রাজা', 'মহারাজা'] ,
['চক্ষু', 'চক্ষু ঋষি'] ,
['চক্ষুর প্রীতিকর', 'নয়নাভিরাম'] ,
['চঞ্চলতা', 'চপলতা', 'চাঞ্চল্য'] ,
['চঞ্চলা', 'চিত্রা'] ,
['চঞ্চু', 'ঠোঁট'] ,
['চট করে', 'চিন্তা ভাবনা না করে', 'ফট করে'] ,
['চটচট করা', 'চিটচিট করা'] ,
['চটচটে ভাব', 'চিটচিটে', 'চ্যাটচ্যটে'] ,
['চটি', 'চপ্পল', 'স্যান্ডেল'] ,
['চটুল', 'চাটু', 'বাচাল'] ,
['চটে যাওয়া', 'জীর্ণ হওয়া'] ,
['চটের চাদর', 'পাখরি'] ,
['চট্টান', 'পাষাণ শিলা', 'প্রস্তর খণ্ড', 'শিলাখণ্ড'] ,
['চড় মারা', 'থাপ্পড় মারা'] ,
['চড়', 'চাঁটা', 'থাপ্পড়'] ,
['চড়কা কাটা', 'সুতো কাটা'] ,
['চড়া', 'নেশা হওয়া', 'সওয়ার হওয়া'] ,
['চড়াই', 'চড়াইপাখি'] ,
['চড়ানো', 'চাপানো', 'বসানো'] ,
['চণক', 'চণক ঋষি', 'চানা', 'ছোলা', 'বুট'] ,
['চণ্ডকৌশিক', 'চণ্ডকৌশিক ঋষি'] ,
['চণ্ডাল', 'ডোম', 'দাহকারি', 'বৈণ', 'শবদাহক'] ,
['চণ্ডাল-বীণা', 'চণ্ডালিকা'] ,
['চণ্ডালিনী', 'দুষ্টা'] ,
['চণ্ডীকুসুম', 'চণ্ডীপুষ্প', 'রক্তকরবী', 'রক্তমঞ্জরী'] ,
['চণ্ডীগড়', 'চণ্ডীগড় কেন্দ্রশাসিত প্রদেশ', 'চণ্ডীগড় শহর'] ,
['চণ্ডেল', 'চণ্ডেল জেলা', 'চণ্ডেল শহর'] ,
['চতরভঙ্গ', 'চতরভঙ্গ রোগ'] ,
['চতরা জেলা', 'চত্রা জেলা'] ,
['চতরা', 'চতরা শহর', 'চত্রা'] ,
['চতুর ব্যক্তি', 'বুদ্ধিমান', 'বুদ্ধিমান ব্যক্তি', 'সমঝদার'] ,
['চতুর', 'চালাক', 'পটু', 'সতর্ক', 'সেয়ানা'] ,
['চতুরঙ্গিনী', 'চতুরঙ্গিনী সৈন্য'] ,
['চতুরতা', 'চাতুরী', 'চাতুর্য', 'চাতুর্য্য', 'চালাকি', 'বুদ্ধিমত্তা'] ,
['চতুরানন', 'জগদ্ধাতা', 'পঙ্কজাসন', 'পিতামহ', 'প্রজাপতি', 'বিধাতা', 'ব্রহ্মা', 'শতপত্র-নিবাস', 'হংসবাহন', 'হিরণ্ময়গর্ভ'] ,
['চতুর্গুণ', 'চার গুণ'] ,
['চতুর্থ গিয়ার', 'ফোর্থ গিয়ার'] ,
['চতুর্থ জর্জ', 'জর্জ'] ,
['চতুর্থ ভাগ', 'চতুর্থাংশ', 'সওয়া'] ,
['চতুর্থ স্বর', 'মধ্যম', 'মধ্যম স্বর'] ,
['চতুর্থ', '৪র্থ'] ,
['চতুর্থপাণ্ডব', 'নকুল'] ,
['চতুর্দশ', 'চোদ্দ', 'চৌদ্দ'] ,
['চতুর্দিকে', 'চার দিকে', 'সব দিকে', 'সর্বত্র'] ,
['চতুর্ভুজ', 'চতুর্ভুজা'] ,
['চতুর্মাস ব্যাপী', 'চাতুর্মাসিক'] ,
['চতুর্মাস', 'চৌমাসা'] ,
['চতুষ্পদ', 'জানোয়ার', 'পশু'] ,
['চতুস্তম্ভ', 'স্মৃতিস্তম্ভ'] ,
['চনেঠ', 'চনেষ্ঠ'] ,
['চন্ডিকা', 'চন্ডী'] ,
['চন্দকপুষ্প', 'ত্রিদশপুষ্প', 'পদ্মগুণা', 'পদ্মা', 'বটুক', 'বরাল', 'বরালক', 'মাদন', 'রুচির', 'লবঙ্গ', 'শ্রীপুষ্প'] ,
['চন্দন', 'মালয়', 'সিত'] ,
['চন্দনগিরি', 'মলায়াচল', 'মলয়', 'মলয় পর্বত', 'মলয়গিরী', 'মালাবার'] ,
['চন্দেল', 'চন্দেলা'] ,
['চন্দৌলি', 'চন্দৌলি জেলা'] ,
['চন্দৌলী', 'চন্দৌলী শহর'] ,
['চন্দ্র গ্রহণ', 'চন্দ্রগ্রহণ', 'সোমগ্রহ', 'সোমগ্রহণ'] ,
['চন্দ্র জ্যোত্স্না', 'চাঁদের আলো', 'জ্যোত্স্না'] ,
['চন্দ্র দিবস', 'তিথি'] ,
['চন্দ্র বংশ', 'চন্দ্র রাজবংশ'] ,
['চন্দ্র শেখর', 'চন্দ্রশেখর'] ,
['চন্দ্র-বিন্দু', 'চন্দ্রবিন্দু'] ,
['চন্দ্রকান্ত', 'চন্দ্রকেতু'] ,
['চন্দ্রজ', 'বুধ', 'বুধ গ্রহ', 'মারক্যুরি', 'শশাঙ্কসূত', 'সোমজ'] ,
['চন্দ্রপুর', 'চন্দ্রপুর জেলা', 'চন্দ্রপুর শহর'] ,
['চন্দ্রবংশীয়', 'সোমবংশীয়'] ,
['চন্দ্রবল্লরী', 'চন্দ্রহাঁস', 'সোমবল্লরী', 'সোমলতা'] ,
['চন্দ্রবার', 'সোম', 'সোমবার'] ,
['চন্দ্রবিজয়', 'রাজা চন্দ্রবিজয়'] ,
['চন্দ্রভবন', 'চন্দ্রভবন রাগ'] ,
['চন্দ্রভাগা', 'চন্দ্রভাগা নদী'] ,
['চন্দ্রমাস', 'চান্দ্রমাস'] ,
['চন্দ্রশেখর', 'চন্দ্রশেখর তাল'] ,
['চন্দ্রসূর', 'হালিম'] ,
['চন্দ্রসেন', 'রাজা চন্দ্রসেন'] ,
['চন্দ্রালোকিত', 'চাঁদনি', 'জ্যোত্স্না'] ,
['চন্দ্রায়ণ', 'চন্দ্রায়ণ ছন্দ'] ,
['চপলতা', 'তীব্রতা', 'ত্বরণ', 'ত্বরা', 'বেগ', 'শীঘ্রতা'] ,
['চব্বিশ', 'চব্বিশ বছর', '২৪'] ,
['চমক', 'চমকে যাওয়া', 'পালিশ'] ,
['চমকে যাওয়া', 'ভ্যাবাচ্যাকা খাওয়া'] ,
['চমরোধা', 'চমাউ', 'চমোয়া'] ,
['চম্পক', 'চম্পক রাগ', 'চম্পা', 'চাঁপা'] ,
['চম্পা কলা', 'চাঁপা কলা', 'চাঁপা-কদলী', 'রক্তকদলী'] ,
['চম্ফাই', 'চম্ফাই জেলা', 'চম্ফাই শহর'] ,
['চম্বাবত', 'চম্বাবত জেলা', 'চম্বাবত শহর'] ,
['চরক', 'চরক মাছ'] ,
['চরচরানি', 'শুকনো ভাব'] ,
['চরণ চিহ্ন', 'ছাপ', 'পদচিহ্ন', 'পা'] ,
['চরণ সিং', 'চৌধুরি চরণ সিং'] ,
['চরণ স্পর্শ করা', 'পা ছোঁয়া', 'প্রণাম করা'] ,
['চরণ', 'পদ', 'পা', 'পাদ'] ,
['চরণধূলি', 'পদধূলি', 'পদরজ'] ,
['চরণামৃত', 'চরণোদক', 'পাদ্য'] ,
['চরম আনন্দ', 'পরম আনন্দ'] ,
['চরম সীমা', 'চরমাবস্থা'] ,
['চরাচরব্যাপী', 'সর্বত্র বিরাজমান', 'সর্বব্যাপী'] ,
['চরানোর কারণে ছাড়া', 'চরার জন্য ছাড়া'] ,
['চরিত', 'চরিত্র', 'চাল-চলন', 'রঙঢঙ'] ,
['চরিত্র', 'পাত্র'] ,
['চরিত্রবতী', 'সচ্চরিত্রা', 'সদাচারিণী', 'সাধ্বী'] ,
['চরিত্রহীন', 'দুরাচারী', 'দুশ্চরিত্র'] ,
['চরিত্রহীনা', 'ব্যভিচারিণী'] ,
['চর্চা', 'মিটিঙ'] ,
['চর্তুগুণ', 'চার গুণ', 'চারগুণ'] ,
['চর্তুমাস', 'জলার্ণব', 'বর্ষা', 'বর্ষা ঋতু', 'বর্ষা কাল', 'বর্ষাকাল', 'মনসুন'] ,
['চর্বন করা', 'চিবানো'] ,
['চর্বি', 'ফ্যাট', 'মেদ'] ,
['চর্বিত চর্বণ করা', 'পণ্ডশ্রম করা'] ,
['চর্বিতচর্বন করা', 'জাবর কাটা', 'রোমন্থন করা'] ,
['চর্বিদার', 'চর্বিযুক্ত'] ,
['চর্ম রোগ', 'চর্মরোগ'] ,
['চর্ম', 'চামড়া', 'ছাল'] ,
['চর্মকার', 'চামার', 'চামার জাতি', 'মুচি'] ,
['চর্মজ', 'চামড়ার'] ,
['চলচিত্র', 'ফিল্ম', 'সিনেমা'] ,
['চলচিত্রগৃহ', 'চলচিত্রাল', 'টকিজ', 'থিয়েটার', 'সিনেমা-ঘর', 'সিনেমাঘর', 'সিনেমাহল'] ,
['চলচ্চিত্র প্রদর্শন', 'ফিল্ম প্রদর্শন'] ,
['চলচ্চিত্র-নির্মাতা', 'প্রোডিউসার'] ,
['চলচ্চিত্রায়িত করা', 'চিত্রায়িত করা'] ,
['চলন', 'প্রচলন', 'ফ্যাশান', 'সঞ্চালন'] ,
['চলভাষ', 'চলমান দূরভাষ যন্ত্র', 'মোবাইল ফোন'] ,
['চলা', 'জারি থাকা', 'টেকা', 'টেকে', 'থাকা', 'দৌড়ানো', 'প্রচলিত হওয়া', 'বয়ে যাওয়া', 'যাওয়া'] ,
['চলাতঙ্ক', 'চলাতঙ্ক রোগ'] ,
['চলিষ্ণু', 'জঙ্গম', 'সচল'] ,
['চলে যাওয়া', 'হাত থেকে চলে যাওয়া'] ,
['চলোতরা', 'ধনমার', 'ধনেশ', 'ধনেশ পাখী', 'বগমা ধনেশ'] ,
['চল্লিশ', '৪০'] ,
['চষানো', 'জোতানো'] ,
['চা তৈরী করার পাত্র', 'চা তৈরীর পাত্র', 'চায়ের পাত্র'] ,
['চাঁদোয়া', 'ছাউনি', 'শামিয়ানা'] ,
['চাঁপা রঙা', 'চাঁপা রঙের'] ,
['চাইনিজ', 'চাইনিজ ভাষা', 'চিনা', 'চীনা', 'বোপোমাফো'] ,
['চাইবাসা', 'চাইবাসা শহর'] ,
['চাউল', 'চাল', 'তণ্ডুল'] ,
['চাকচিক্য', 'ঝকমকি', 'দীপ্ততা'] ,
['চাকর', 'দাস', 'ভৃত্য'] ,
['চাকরানি', 'ঝি', 'পরিচারিকা', 'বাড়ির কাজের লোক', 'সেবিকা'] ,
['চাকরি', 'পরিচর্যা', 'সেবা'] ,
['চাকা লাগানো চেয়ার', 'হুইল চেয়ার'] ,
['চাকার দণ্ড', 'স্পোক'] ,
['চাকার পাখি', 'স্পোক'] ,
['চাক্ষুষ', 'দৃশ্য', 'দৃষ্টিগোচর', 'নেত্রীয়'] ,
['চাঙ্গলাঙ্গ', 'চাঙ্গলাঙ্গ জেলা', 'চাঙ্গলাঙ্গ শহর'] ,
['চাঙ্গা করা', 'তাজা বানানো', 'সুস্থ বানানো'] ,
['চাঙ্গা', 'নিরোগ', 'ফিট', 'ভালো', 'রোগরহিত', 'সুস্থ'] ,
['চাটুকার', 'তোষামদকারী', 'মোশায়েব'] ,
['চাতুর্জাত', 'চাতুর্জাতক'] ,
['চাতুর্ভদ্র', 'চাতুর্ভদ্রক'] ,
['চাতুর্মাস্য', 'চাতুর্মাস্য যজ্ঞ'] ,
['চাদ সম্বন্ধীয়', 'চাদীয়', 'চাদের'] ,
['চাদ', 'চাদ গণতন্ত্র'] ,
['চাদবাসী', 'চাদের নিবাসী'] ,
['চান', 'স্নান'] ,
['চানক', 'চীনা তিতির'] ,
['চান্দ্রায়ণ', 'চান্দ্রায়ণ ব্রত'] ,
['চাপ দেওয়া', 'টেপা', 'ধাক্কা দেওয়া'] ,
['চাপ', 'টেনশন', 'নিয়ন্ত্রণ'] ,
['চাপটাই', 'চাপটাই আম'] ,
['চাপদণ্ড', 'পিস্টন'] ,
['চাপা পড়া', 'থেতলে যাওয়া'] ,
['চাপা', 'চেপে যাওয়া', 'ছোটো'] ,
['চাপাকল', 'নল', 'হ্যান্ডপাম্প'] ,
['চাবি', 'দম'] ,
['চামচিকা', 'চামচিকে'] ,
['চামড়া', 'ত্বক'] ,
['চামরাজনগর জেলা', 'চামরাজানগর', 'চামরাজানগর জেলা', 'চামারাজনগর'] ,
['চামরাজনগর', 'চামরাজানগর'] ,
['চামারনি', 'চামারনী'] ,
['চামুণ্ডী', 'চামুণ্ডেশ্বরী দেবী'] ,
['চামেলী', 'মাধবিকা', 'মালতী'] ,
['চামোলি', 'চামোলি জেলা', 'চামোলি শহর'] ,
['চাম্বা', 'চাম্বা জেলা', 'চাম্বা শহর'] ,
['চার তারিখ,', 'চৌঠা', 'চৌঠা তারিখ'] ,
['চার তোলা', 'চার ভরি'] ,
['চার মাথা', 'চৌরাস্তা'] ,
['চার রঙ বিশিষ্ট', 'চাররঙা'] ,
['চারকোণা', 'চৌকোণা'] ,
['চারখানা', 'চেক'] ,
['চারচাকাবিশিষ্ট', 'চারচাকার'] ,
['চারণভূমি', 'পশুচারণভূমি'] ,
['চারদেওয়াল', 'প্রাচীর', 'ব্যারিকেড'] ,
['চারশো', '৪০০,'] ,
['চারা', 'চারাগাছ', 'টোপ', 'মাছের টোপ'] ,
['চারিদিকে', 'ভিতরে বাইরে'] ,
['চারু', 'মনোহর', 'রুপবান', 'রুপমান', 'ললিত', 'লাবণ্যময়', 'সুন্দর'] ,
['চার্লস পার্সি স্নো', 'সি পি স্নো', 'স্নো'] ,
['চার্লস ফ্রান্সিস হল', 'হল'] ,
['চার্লস ফ্রেডরিক', 'বার্থ'] ,
['চার্লস মার্টিন হল', 'হল'] ,
['চাল', 'ছল', 'ছলচাতুরি', 'টিনের চাল', 'দান', 'প্যাঁচ'] ,
['চালক টিম', 'চালকদল'] ,
['চালক', 'ড্রাইভার'] ,
['চালনি', 'ঝাঁঝরি'] ,
['চালাই', 'ঝাড়াই'] ,
['চালাক', 'ধড়িবাজ', 'ধূর্ত', 'প্রতারক', 'প্রবঞ্চক'] ,
['চালাকী', 'ছল', 'ছল-কপট', 'ছলনা', 'প্রতারণা', 'বঞ্চনা'] ,
['চালান', 'রসিদ'] ,
['চালানো', 'চালিত করা', 'চালু করা', 'পরিচালনা', 'মার্চ করানো', 'সঞ্চালন করা'] ,
['চালিত', 'পরিচালিত'] ,
['চালিসা', 'চাহলুম'] ,
['চালিয়ে নেওয়া', 'নির্বাহ করা', 'মানিয়ে নেওয়া'] ,
['চালু করা', 'চালু হওয়া', 'জারি করা', 'প্রকাশ করা', 'বলবত্ করা', 'বার করা'] ,
['চালু রাখা', 'বজায় রাখা'] ,
['চালু', 'জারি', 'প্রচলিত'] ,
['চালুনি', 'ঝাঁঝরি'] ,
['চাষ', 'চাষ করা', 'চাষবাস করা', 'ফসল ফলানো', 'বোনা'] ,
['চাষযোগ্য জমি', 'জোত'] ,
['চাহনি', 'দৃষ্টি', 'নজর'] ,
['চায়ের আসর', 'টি পার্টি'] ,
['চিঁ হিঁ', 'চিঁহিঁ'] ,
['চিঁড়া', 'চিঁড়ে'] ,
['চিংড়ি', 'চিঙ্গট', 'চিঙ্গড়', 'জলবৃষ্চিক', 'নলমীন', 'বৃহচ্ছক'] ,
['চিক পর্দা', 'ঝাপ'] ,
['চিকনের কাজ করা', 'নকশাকাটা', 'নকশাদার'] ,
['চিকমাগালুর', 'চিকমাগালুর জেলা', 'চিকমাগালুর শহর'] ,
['চিকিত্সক', 'ডাক্তার'] ,
['চিকিত্সা বিজ্ঞান', 'চিকিত্সা শাস্ত্র'] ,
['চিকিত্সা', 'ডাক্তারি', 'প্রতিকার', 'রোগোপচার', 'হাকিমি'] ,
['চিকিত্সালয়', 'হাসপাতাল'] ,
['চিকিত্স্য', 'নিবার্য'] ,
['চিজ', 'পনির'] ,
['চিট', 'পর্চা'] ,
['চিটচিটে ভাব', 'চ্যাটচ্যাটে ভাব'] ,
['চিটমিটা', 'পশ্যা'] ,
['চিঠি-পত্র', 'পত্র-ব্যবহার', 'পত্রব্যবহার', 'পত্রাচার'] ,
['চিড় খাওয়া', 'ফেটে যাওয়া'] ,
['চিড়ি', 'চিড়িতন'] ,
['চিত', 'সিধা', 'সোজা'] ,
['চিতরা সতভৈয়া', 'সতবাহিনী'] ,
['চিতরোখ', 'চিতরোয়া'] ,
['চিতল', 'রঙবেরঙের'] ,
['চিতা', 'চিতাবাঘ', 'পুণ্ডরিক', 'শার্দুল'] ,
['চিতাগ্নি', 'মুখাগ্নি'] ,
['চিতোড় গড়', 'চিতোরগড় জেলা'] ,
['চিতোরগড়', 'চিতোরগড় শহর'] ,
['চিত্কার', 'চিল্লানো'] ,
['চিত্ত চাঞ্চল্য', 'চিত্তবৈকল্য', 'বিহ্বলতা'] ,
['চিত্তাকর্ষক', 'মনোহর', 'হৃদয়গ্রাহী'] ,
['চিত্তুর', 'চিত্তুর জেলা', 'চিত্তুর শহর'] ,
['চিত্র', 'ছবি', 'পিক্চার', 'পেন্টিং', 'ফোটা', 'ভিডিও'] ,
['চিত্রকারী', 'চিত্রণ', 'চিত্রাঙ্কন'] ,
['চিত্রকূট', 'চিত্রকূট জেলা', 'চিত্রকূট শহর'] ,
['চিত্রক্ষেপক', 'প্রোজেক্টর'] ,
['চিত্রগন্ধ', 'হরিতাল'] ,
['চিত্রগ্রহণ', 'দৃশ্যগ্রহণ', 'শুটিং'] ,
['চিত্রদূর্গ', 'চিত্রদূর্গ জেলা', 'চিত্রদূর্গ শহর'] ,
['চিত্রপটমহর্ষি দাদা সাহেব ফালকে', 'দাদা ফালকে', 'দাদা সাহেব ফালকে'] ,
['চিত্রপত্রিকা', 'চিত্রপর্ণী', 'দ্রোণপুষ্পী'] ,
['চিত্রপলশিল্প', 'পচ্চিকারি'] ,
['চিত্রবিচিত্র নকশা-খচিত ঢাকনা', 'চিত্রবিচিত্র নকশা-খচিত পর্দা'] ,
['চিত্ররেখা', 'চিত্রলেখা'] ,
['চিত্রা', 'চিত্রা নক্ষত্র', 'চিত্রা রাগিনী', 'সাত্বতী', 'সুভদ্রা'] ,
['চিত্রাঙ্কন করা', 'ছবি আঁকা'] ,
['চিত্রাঙ্গদ', 'রাজা চিত্রাঙ্গদ'] ,
['চিত্রাবর্তী', 'চিত্রাবর্তী নদী'] ,
['চিত্রিত', 'নিরুপিত', 'বর্ণিত'] ,
['চিদাম্বরম পদ্মনাভম রামানুজম', 'রামানুজম', 'সি পি রামানুজম'] ,
['চিনচিন করা', 'চিরচির করা'] ,
['চিনতে পারা', 'জানা', 'বোঝা'] ,
['চিনি', 'শর্করা'] ,
['চিনেবাদাম', 'চিনেবাদামের দানা'] ,
['চিন্তন', 'চিন্তন-মনন', 'চিন্তা-ভাবনা', 'মনন'] ,
['চিন্তনীয়', 'চিন্তাজনক', 'চিন্ত্য', 'ভাবনাজনক'] ,
['চিন্তা হওয়া', 'পড়া'] ,
['চিন্তা', 'দুশ্চিন্তা'] ,
['চিন্তাগ্রস্ত', 'চিন্তাযুক্ত', 'চিন্তিত'] ,
['চিন্তাজনক', 'শোচনীয়'] ,
['চিন্তামণি', 'নক্ষত্র চিন্তামণি', 'বিভূ', 'ব্রহ্ম', 'সচ্চিদানন্দ'] ,
['চিন্তামুক্ত হয়ে', 'চিন্তাহীন হয়ে', 'নিশ্চিন্ত হয়ে'] ,
['চিন্তামুক্ত', 'চিন্তারহিত', 'নিশ্চিন্ত'] ,
['চিন্তাশীল', 'দূরদর্শী', 'বিচারশীল', 'মননশীল'] ,
['চিপ', 'মাইক্রো চিপ', 'মাইক্রোচিপ', 'সিলিকন চিপ'] ,
['চিপকা', 'চীপক', 'শিকরা'] ,
['চিপকানো', 'জুড়ে যাওয়া', 'সাঁটানো', 'সেঁটে যাওয়া'] ,
['চিবানো', 'চোষা'] ,
['চিবুক সম্পর্কিত', 'চিবুকের'] ,
['চিবুক', 'থুতনি', 'হনু'] ,
['চিমটে', 'সাঁড়াশি'] ,
['চিরগামী', 'দীর্ঘগামী', 'দীর্ঘসূত্রী'] ,
['চিরচির করা', 'ফেটে যাওয়া'] ,
['চিরঞ্জী', 'পিয়াল', 'মহাবীজ'] ,
['চিরস্হায়ী', 'চীরকালীন'] ,
['চিরহরিত্ অরণ্য', 'চিরহরিত্ কানন', 'চিরহরিত্ জঙ্গল', 'চিরহরিত্ বন'] ,
['চিরাগ', 'দীপ', 'দীপক', 'প্রদীপ', 'বাতি', 'লম্ফ'] ,
['চিরাচরিত', 'বংশপরম্পরা', 'সনাতনী'] ,
['চিরুনি', 'প্রসাধণী'] ,
['চিল', 'চিল্ল', 'চিল্লক'] ,
['চিলিবাসী', 'চিলিয়ান'] ,
['চিলির', 'চিলিয়ান', 'চিলীয়'] ,
['চিলিয়ান পেসো', 'পেসো'] ,
['চিলে কুঠুরি', 'চিলে ঘর', 'চিলেকোঠা'] ,
['চিল্লীকা', 'ঝিঁঝিঁ পোকা', 'ঝিঙুর', 'ঝিঞ্ঝী', 'ঝিল্লি', 'ভৃঙ্গারিকা'] ,
['চিহ্ন', 'ছাপ', 'নিশান', 'লক্ষণ'] ,
['চিহ্নিত করা', 'মার্কিং'] ,
['চিহ্নিতকরণ', 'নিশানদিহি', 'সনাক্তকরণ'] ,
['চিহ্নিতকারি বস্তু', 'মার্কার'] ,
['চু', 'চু চু', 'চু চু চু'] ,
['চুঁ চাঁ', 'চুঁ চুঁ', 'চুঁচুঁ'] ,
['চুঁচুড়া', 'চুঁচুড়া শহর'] ,
['চুক', 'চুকা'] ,
['চুকিয়ে দেওয়া', 'মিটিয়ে দেওয়া'] ,
['চুকে যাওয়া', 'মিটে যাওয়া'] ,
['চুচুক', 'চুষি'] ,
['চুড়িওয়ালা', 'মনিহার'] ,
['চুড়িওয়ালী', 'মনিহারিনী'] ,
['চুড়িদার', 'চুড়িদার পাজামা'] ,
['চুনট', 'ঝালর'] ,
['চুনভাটি', 'চুনাভাটি'] ,
['চুনোট দেওয়া', 'ভাঁজ দেওয়া'] ,
['চুপ করে থাকা', 'চেপে থাকা'] ,
['চুপ করে', 'চুপচাপ', 'নিঃশব্দে', 'মৌন হয়ে'] ,
['চুপ হওয়া', 'মৌন হওয়া', 'শান্ত হওয়া'] ,
['চুপ হয়ে যাওয়া', 'নিরুত্তর হয়ে যাওয়া'] ,
['চুপ', 'চুপচাপ', 'মৌন', 'শান্ত'] ,
['চুপচাপ', 'নিস্তব্ধতা'] ,
['চুপড়ি', 'চুবড়ি', 'চ্যাঙারি', 'ঝাঁকা', 'ঝুড়ি', 'ঝোড়া', 'টুকরি', 'টোকরা', 'বাজরা'] ,
['চুপি চুপি', 'লুকিয়ে লুকিয়ে'] ,
['চুমু খাওয়া', 'চুম্বন', 'চুম্বন করা'] ,
['চুমু', 'চুম্বন'] ,
['চুম্বকীয় পার্থক্য', 'ম্যাগনেটিক ভ্যারিয়েসন'] ,
['চুম্বকীয় লৌহ আকর', 'ম্যাগনেটাইট'] ,
['চুরচুর', 'চুরমার'] ,
['চুরমা', 'মলীদা'] ,
['চুরমার করা', 'নষ্ট করা'] ,
['চুরাচাঁদপুর', 'চুরাচাঁদপুর জেলা', 'চুরাচাঁদপুর শহর'] ,
['চুরানব্বই', '৯৪', '৯৪,'] ,
['চুরাশি', '৮৪', '৮৪,'] ,
['চুরি করা', 'হরণ করা'] ,
['চুরি পা', 'সরু পা'] ,
['চুরি হওয়ার যোগ্য', 'হরণীয়.আহরণীয়'] ,
['চুরুট', 'সিগার'] ,
['চুল কাটা', 'চুল সেট করা'] ,
['চুল', 'দাড়ি'] ,
['চুলকানি হওয়া', 'চুলকানো'] ,
['চুয়াত্তর', '৭৪', '৭৪,'] ,
['চুয়ান্ন', '৫৪', '৫৪,'] ,
['চুয়াল্লিশ', '৪৪,'] ,
['চূচক', 'বৃন্ত', 'বোঁটা'] ,
['চূচী', 'পয়োধর', 'বোটা', 'স্তন'] ,
['চূড়', 'বালা'] ,
['চূড়া', 'শিখর'] ,
['চূণী', 'পদ্মরাজ', 'বৈক্রান্তমণি', 'মণি', 'মাণিক', 'রুবি', 'শোণিতপল'] ,
['চূর্ণ', 'পাচক'] ,
['চূর্ণন', 'দলন'] ,
['চূর্ণিত', 'দলিত', 'পেষিত', 'মর্দিত'] ,
['চেঁচ', 'নির্চা', 'মুক্তচন্দা'] ,
['চেঁচানো', 'ডাকা', 'ভোঁ-ভোঁ করা'] ,
['চেঁচামেচি', 'শোরগোল'] ,
['চেক ভাষা', 'চেকীয় ভাষা'] ,
['চেক', 'চেক গণতন্ত্র'] ,
['চেকপয়েন্ট', 'নজরদারী চৌকি'] ,
['চেখে দেখা', 'স্বাদ নেওয়া'] ,
['চেতন', 'চেতনাসম্পন্ন', 'জাগ্রত', 'সংজ্ঞাযুক্ত'] ,
['চেতনা', 'চৈতন্য', 'সুধি'] ,
['চেদিরাজ', 'শিশুপাল', 'সুনীথ'] ,
['চেন', 'বেড়ী', 'শিকল', 'শৃঙ্খল', 'শেকল'] ,
['চেনা', 'জানা'] ,
['চেনা-পরিচিত', 'পরিচিত'] ,
['চেন্নাই', 'চেন্নাই জেলা', 'মাদ্রাস'] ,
['চেম্বার', 'সভা ভবন', 'সভাগৃহ', 'সভাঘর'] ,
['চেরাই করা', 'ছেদ করা', 'ভেদ করা'] ,
['চেলা', 'শিষ্য'] ,
['চেহারা', 'রঙ-রূপ', 'রূপ'] ,
['চেয়ে', 'ভিক্ষা করে', 'যাচনা করে', 'যেচে'] ,
['চৈকিত', 'চৈকিত ঋষি'] ,
['চৈতন', 'টিকি', 'শিখা'] ,
['চৈত্য', 'বিহার', 'বৌদ্ধ বিহার', 'বৌদ্ধ মঠ'] ,
['চৈত্র একাদশী', 'পাপমোচনি একাদশী'] ,
['চৈত্র', 'চৈত্র মাস'] ,
['চৈত্ররথ', 'চৈত্ররথ বন'] ,
['চোকানো', 'শোধ করা'] ,
['চোখা', 'ভর্তা'] ,
['চোখে ধুলো দেওয়া', 'ঠকানো', 'প্রতারণা করা'] ,
['চোখের কাঁটা', 'চোখের কুটো'] ,
['চোখের পলক পড়া', 'চোখের পাতা পড়া'] ,
['চোখের পাতা', 'নয়ন পট', 'নয়নপট', 'পলক'] ,
['চোখের পীড়া', 'চোখের ব্যাথা', 'চোখের যন্ত্রণা'] ,
['চোখের ময়লা', 'পিচুটি'] ,
['চোঙা', 'নল', 'নালি', 'বাঁশের নল'] ,
['চোর', 'তস্কর'] ,
['চোর-পুষ্পী', 'ভূতলতা', 'শঙ্কপুষ্পী', 'শঙ্খানাম্বী', 'শঙ্খাহুলী'] ,
['চোরাকারবারি', 'স্মাগলার'] ,
['চোরাকারবারী', 'চোরাবাজারী'] ,
['চোল', 'চোলবাসী'] ,
['চোলাই', 'পচুই', 'রামদানা'] ,
['চোষ কাগজ', 'ব্লোটিং পেপার'] ,
['চোসা', 'চোসা আম'] ,
['চোয়াল', 'হনু'] ,
['চৌকাঠ', 'দরজা'] ,
['চৌকি', 'ডেস্ক', 'তক্তাপোষ', 'তক্তি', 'নজর-ঘাঁটি', 'পাহারা বুরুজ', 'ফাঁড়ি', 'মেজ'] ,
['চৌকিদার', 'দারোয়ান', 'পাহারাদার', 'প্রহরী'] ,
['চৌকো করে', 'বর্গাকারে'] ,
['চৌকো বানানো', 'বর্গাকার বানানো'] ,
['চৌকো', 'চৌকোনা'] ,
['চৌখস', 'সচেতন', 'সজাগ', 'সতর্ক'] ,
['চৌত্রিশ', '৩৪,'] ,
['চৌপট', 'তছ নছ', 'ধ্বংস', 'নষ্ট', 'বরবাদ', 'বিনষ্ট', 'সমাপ্ত'] ,
['চৌপাট হওয়া', 'ডোবা', 'নষ্ট হওয়া'] ,
['চৌবাচ্চা', 'জল ভাণ্ডার', 'জলাধার', 'ট্যাঙ্ক'] ,
['চৌষট্টি', '৬৪'] ,
['চ্যবন ঋষি', 'চ্যবনঋষি'] ,
['চ্যাপ্টানাকযুক্ত', 'চ্যাপ্টানাকের'] ,
['চ্যাম্পিয়ন', 'বিজয়ী'] ,
['চ্যাম্পিয়ান', 'জিনিয়াস', 'সুপারস্টার', 'স্টার'] ,
['চ্যালাকাঠ', 'জ্বলন্ত কাঠ'] ,
['চ্যালেঞ্জ করা', 'দ্বন্দ্বযুদ্ধে আহ্বান করা'] ,
['চ্যালেঞ্জপূর্ণ', 'চ্যালেঞ্জযুক্ত'] ,
['চ্যুত হওয়া', 'নড়ে যাওয়া', 'সরে যাওয়া'] ,
['চয়ন করা', 'নির্বাচিত করা', 'পছন্দ করা', 'বেছে নেওয়া', 'বের করা'] ,
['চয়ন', 'পছন্দ'] ,
['চয়নকর্তা', 'নির্বাচক'] ,
['চয়নিত', 'বাছাই করা', 'মনোনীত'] ,
['ছ তারিখ', 'ছয় তারিখ,'] ,
['ছ', 'ব্যঞ্জনবর্ণ ছ'] ,
['ছট', 'ছট মা'] ,
['ছটি বই', 'পুস্তিকা'] ,
['ছড়ানো', 'ছড়ানো-ছিটানো', 'ছিটানো', 'ছেটানো', 'পৌঁছে যাওয়া', 'বিস্তারলাভ করা', 'বিস্তৃত হওয়া'] ,
['ছড়ানো-ছিটানো', 'বিক্ষিপ্ত'] ,
['ছড়ি', 'ধোঁটি', 'যষ্টি', 'লগুড়', 'লাঠি', 'লোহাযুক্ত ছড়ি', 'শলাকা'] ,
['ছড়িয়ে দেওয়া', 'প্রসারিত করা', 'বিস্তৃত করা'] ,
['ছড়িয়ে পড়া', 'প্রসারিত হওয়া'] ,
['ছড়িয়ে বসা', 'প্রসারিত হওয়া'] ,
['ছত্তরপুর', 'ছত্তরপুর জেলা', 'ছত্তরপুর শহর'] ,
['ছত্তিশগড়ী', 'ছত্রিশগড়ি', 'ছত্রিশগড়ী'] ,
['ছত্র', 'ছাতা'] ,
['ছত্রধর', 'ছত্রধারী'] ,
['ছত্রধারী', 'ছত্রপতি'] ,
['ছত্রপতি শিবাজী', 'ছত্রপতি শিবাজী মহারাজ', 'ছত্রপতি শিবাজী রাজ ভোঁসলে', 'শিবাজী'] ,
['ছত্রপুর', 'ছত্রপুর শহর'] ,
['ছত্রাক', 'ভুঁইফোড়'] ,
['ছত্রিশ', '৩৬,'] ,
['ছত্রিশগড়', 'ছত্রিশগড় রাজ্য'] ,
['ছত্রিশগড়ী', 'ছত্রিশগড়ের'] ,
['ছন্দ', 'ছন্দালঙ্কার'] ,
['ছন্দপতন', 'ব্যাঘাত হওয়া'] ,
['ছন্দশাস্ত্র', 'পিঙ্গল'] ,
['ছন্দশাস্ত্রজ্ঞ', 'ছন্দশাস্ত্রী'] ,
['ছন্নছাড়া', 'ভবঘুরে', 'যাযাবর'] ,
['ছবি তোলা', 'তোলা'] ,
['ছবি', 'ছায়া-চিত্র', 'প্রতিকৃতি', 'ফটো', 'ফোটো'] ,
['ছরিলা', 'পাথর ফুল', 'স্থবির'] ,
['ছলকে পড়া', 'ছিটকে পড়া'] ,
['ছলনা', 'তামাশা', 'ধোঁকা', 'ধোঁকাবাজি', 'ভেলকি'] ,
['ছলাকলা', 'ঢং', 'ভাবভঙ্গিমা'] ,
['ছাঁইচ', 'ছাদের প্রান্তভাগ'] ,
['ছাঁচ', 'ফরমা'] ,
['ছাই', 'ছাইভস্ম', 'ভস্ম', 'ভস্ম উপনিষদ', 'ভস্মোপনিষদ'] ,
['ছাউনি', 'শিবির'] ,
['ছাগলী', 'ছাগী'] ,
['ছাছ', 'মাঠা'] ,
['ছাড় দেওয়া', 'বাদ দেওয়া'] ,
['ছাড়', 'স্বাধীনতা'] ,
['ছাড়া পাওয়া', 'মুক্ত হওয়া'] ,
['ছাড়া', 'ছেড়ে দেওয়া', 'ছেড়ে যাওয়া', 'ত্যাগ', 'ত্যাগ করা', 'দেওয়া', 'পরিত্যাগ করা', 'প্রদান করা', 'ফেলা', 'ফেলে দেওয়া', 'বাঁধনমুক্ত', 'বার হওয়া', 'বিদায় জানানো', 'বিনা', 'ব্যতিত', 'মুক্ত করা', 'যাত্রা করা'] ,
['ছাড়ানো', 'ছাড়িয়ে দেওয়া', 'ছাড়িয়ে নেওয়া', 'বন্ধনমুক্তি', 'সরে যাওয়া'] ,
['ছাতু', 'সক্তু'] ,
['ছাত্র উপদেষ্টা', 'ছাত্র পরামর্শদাতা', 'স্টুডেন্ট কাউন্সিলর'] ,
['ছাত্র', 'বিদ্যার্থী'] ,
['ছাত্রবৃত্তি', 'বৃত্তি'] ,
['ছাত্রাবাস', 'ছাত্রালয়', 'হস্টেল'] ,
['ছাত্রী', 'বিদ্যার্থিনী', 'শিষ্যা'] ,
['ছানা', 'পশু শাবক', 'পাখির ছানা', 'শাবক'] ,
['ছান্দোগ্য', 'ছান্দোগ্য উপনিষদ'] ,
['ছাপ লাগানো', 'মোহর লাগানো'] ,
['ছাপ', 'ছাপা', 'দাগ', 'প্রভাব', 'মোহর', 'সিলমোহর', 'স্ট্যাম্প'] ,
['ছাপরা', 'ছাপরা শহর'] ,
['ছাপা', 'মুদ্রণ', 'মুদ্রণ করা', 'মুদ্রিত', 'মুদ্রিত হওয়া'] ,
['ছাপাই', 'মুদ্রণমূল্য'] ,
['ছাপাখানা', 'মুদ্রণালয়'] ,
['ছাপানো', 'প্রকাশ করানো'] ,
['ছাপান্ন', '৫৬', '৫৬,'] ,
['ছাপ্পা', 'শিলমোহর', 'স্ট্যাম্প'] ,
['ছাব্বিশ', '২৬'] ,
['ছাল', 'বল্কল', 'বাকল'] ,
['ছায়া যন্ত্র', 'রোদঘড়ি'] ,
['ছায়া', 'জিন', 'পিশাচ', 'প্রতিবিম্ব', 'প্রেত', 'বিম্ব', 'ভূত', 'ভূত-প্রেত'] ,
['ছায়া-গ্রাহিণী', 'সিংহিকা'] ,
['ছি-ছি', 'ছিছি'] ,
['ছিছি করা', 'থুত্কার', 'থুথু করা'] ,
['ছিটা', 'ছিটে'] ,
['ছিদ্র', 'মুখ', 'রন্ধ্র'] ,
['ছিদ্রযুক্ত', 'রন্ধ্রযুক্ত', 'সছিদ্র', 'সরন্ধ্র'] ,
['ছিদ্রহীন', 'নিশ্ছিদ্র'] ,
['ছিন্দওয়াড়া', 'ছিন্দওয়াড়া জেলা', 'ছিন্দওয়াড়া শহর'] ,
['ছিন্নভিন্ন হওয়া', 'টুকরো টুকরো হওয়া'] ,
['ছিন্নমস্তা', 'ছিন্নমস্তা দেবী'] ,
['ছিবড়া', 'ছিবড়ে', 'সারহীন পদার্থ', 'সারহীন বস্তু'] ,
['ছিলিম-বরদার', 'ছিলিমবরদার'] ,
['ছিলিম-বরদারী', 'ছিলিমবরদারী'] ,
['ছিয়াত্তর', '৭৬', '৭৬,'] ,
['ছিয়ানব্বই', '৯৬', '৯৬,'] ,
['ছিয়াশি', '৮৬', '৮৬,'] ,
['ছু মন্তর', 'ছুমন্তর'] ,
['ছুঁচানো', 'মলদ্বার প্রক্ষলন'] ,
['ছুঁড়ে ফেলানো', 'ছোঁড়ানো'] ,
['ছুতোর পত্নী', 'ছুতোরনি'] ,
['ছুতোর', 'ছুতোর জাতি'] ,
['ছুতোরগিরি', 'ছুতোরের কাজ'] ,
['ছুরি', 'ছুরিকা'] ,
['ছেঁড়া কাপড়', 'ছেঁড়া বস্ত্র'] ,
['ছেঁড়া', 'তোলা'] ,
['ছেচল্লিশ', '৪৬', '৪৬,'] ,
['ছেড়ে দেওয়া', 'পৌঁছে দেওয়া', 'মুক্তি দেওয়া', 'লেলিয়ে দেওয়া'] ,
['ছেড়ে যাওয়া', 'পরিত্যক্ত'] ,
['ছেদক', 'ভেদক'] ,
['ছেদনীয়', 'ছেদ্য'] ,
['ছেদিত', 'বিদারিত', 'ভেদিত'] ,
['ছেলে', 'ছোকরা', 'বালক'] ,
['ছেলেবেলা', 'ছোটবেলা', 'বাল্যকাল', 'শৈশব'] ,
['ছেষট্টি', 'ষষ্ঠদশ', '৬৬', '৬৬,'] ,
['ছোঁয়া', 'লাগা', 'স্পর্শ করা', 'স্পর্শিত'] ,
['ছোঁয়াচে রোগ', 'সংক্রামক রোগ', 'স্পর্শজ রোগ'] ,
['ছোঁয়ানো', 'স্পর্শ করানো'] ,
['ছোট দেহাতি গাড়ী', 'হাল্কা'] ,
['ছোট পাখা', 'বেনিয়া'] ,
['ছোট পানকৌড়ি', 'জোগ্রীবা'] ,
['ছোট পেরেক', 'বিরঞ্জী'] ,
['ছোট ফোড়া', 'ফুসকুড়ি'] ,
['ছোট ফ্যাশানেবল সমাজ', 'ছোট শৌখিন সমাজ'] ,
['ছোট মাপ', 'ছোট সাইজ'] ,
['ছোট মূর্তি', 'মূর্তি'] ,
['ছোট', 'ছোটখাটো'] ,
['ছোটবেলা', 'বাল্যাবস্হা', 'শৈশব'] ,
['ছোটো খাট', 'দড়ির খাট', 'শিশুদের ঘের দেওয়া শয্যা'] ,
['ছোটো ঘর', 'ছোটো বাড়ি'] ,
['ছোটো ডাক', 'ছোটো ডাহুক'] ,
['ছোটো পাখি', 'বিহঙ্গীকা'] ,
['ছোটো বংশী', 'ছোটো বাঁশি', 'মুরলী'] ,
['ছোটো বাক্স', 'ঝাঁপি'] ,
['ছোটো', 'পুঁচকে', 'লঘুত্ব', 'সাধারণ'] ,
['ছোটো-খাটো', 'লঘুকায়'] ,
['ছোটোবেলার বন্ধু', 'বালবন্ধু', 'সখী', 'সঙ্গীনী'] ,
['ছোড়া', 'দাগা'] ,
['ছোপওয়ালা', 'দাগওয়ালা'] ,
['ছোলাভাজা', 'মটরভাজা'] ,
['জ', 'ব্যঞ্জনবর্ণ জ'] ,
['জং', 'মরচে', 'মরিচা'] ,
['জংলী জানোয়ার', 'বন্য জীব', 'বন্য পশু', 'বন্যপ্রাণী'] ,
['জংলী', 'বন্যতাপূর্ণ'] ,
['জই', 'জয়ন্তী', 'শিবানী'] ,
['জওহরলাল নেহেরু', 'নেহেরু', 'পণ্ডিত জওহরলাল নেহেরু'] ,
['জগতজয়ী', 'দিগ্বিজয়ী', 'বিশ্ব বিজয়ী', 'বিশ্বজয়ী'] ,
['জগতসিংহপুর', 'জগতসিংহপুর জেলা', 'জগতসিংহপুর শহর'] ,
['জগত্ গুরু', 'জগদগুরু', 'বিশ্বগুরু', 'মহাগুরু'] ,
['জগত্', 'দুনিয়া', 'পৃথিবী', 'বিশ্ব', 'বিশ্বজগত্', 'সংসার'] ,
['জগন্নাথ-পুরী', 'জগন্নাথপুরী', 'জগন্নাথপুরী ধাম'] ,
['জগমোহন', 'মণ্ডপ', 'সভামণ্ডপ'] ,
['জঙ্গলী ক্ষেত্র', 'বন্য ক্ষেত্র', 'বন্য প্রান্তর'] ,
['জঙ্গলী ফুল', 'বুনো ফুল'] ,
['জঙ্গলী মোষ', 'বুনোমোষ'] ,
['জঙ্গলী', 'বন্য', 'বুনো'] ,
['জঙ্ঘাস্থি', 'শিন বোন'] ,
['জজ', 'ন্যায়াধিকারী', 'ন্যায়াধীশ'] ,
['জট ছাড়ানো', 'জটমুক্ত'] ,
['জট পড়া', 'জট পাকানো'] ,
['জটা', 'জটাজুট'] ,
['জটিলক', 'জটিলক ঋষি'] ,
['জড়', 'জীবনহীন', 'নিষ্প্রাণ'] ,
['জড়তা', 'জড়ত্ব', 'প্রাণহীনতা', 'বিরাম', 'স্থিরতা'] ,
['জড়নো', 'পাকানো'] ,
['জড়ানো', 'পাকানো'] ,
['জড়ি-বুটি', 'জড়িবুটি'] ,
['জড়িয়ে পড়া', 'ফেঁসে যাওয়া'] ,
['জড়িয়ে যাওয়া', 'ফেঁসে যাওয়া'] ,
['জণ্ডিস', 'পাণ্ডুরোগ', 'পিত্তরোগ'] ,
['জতুকা লতা', 'নিশান্ধী', 'লম্বা দানার আঙুর'] ,
['জন আর মেজর', 'জন মেজর', 'জন রয় মেজর', 'মেজর'] ,
['জন এল এইচ ডাউন', 'ডাউন'] ,
['জন কল্যাণ বিভাগ', 'লোক কল্যাণ বিভাগ'] ,
['জন কল্যাণ', 'জন সেবা', 'পরোপকার', 'লোকহিত'] ,
['জন গণনা', 'জনগণনা'] ,
['জন চিকিত্সালয়', 'সার্বজনীন্ চিকিত্সালয়', 'সিবিল হসপিটাল'] ,
['জন', 'জনগণ', 'জনতা', 'জনমানস', 'পাবলিক', 'বান্দা', 'ব্যক্তি', 'মানস', 'লোক'] ,
['জন-', 'জনগণের'] ,
['জন-জাতি', 'জনজাতি'] ,
['জন-হিত', 'জনহিত'] ,
['জনক', 'জন্মদাতা', 'নিমিরাজ', 'পিতা', 'বিদেহ', 'মিথিল', 'মিথিলেশ', 'মৈথিল', 'রাজা জনক'] ,
['জনকপুর', 'বিদেহপুর'] ,
['জনগণ', 'জনসাধারণ', 'প্রজা'] ,
['জনডিস', 'ন্যাবা', 'পাণ্ডুরোগ', 'পিত্তরুদ্ধ কামলা'] ,
['জনতা দল ইউনাইটেড', 'জনতাদল ইউনাইটেড'] ,
['জনতা', 'জনসমষ্টি', 'ভিড়'] ,
['জনন কোষিকা', 'জননিকা'] ,
['জননী', 'জন্মদাত্রী', 'মা', 'মাতা', 'মাতৃকা'] ,
['জননেতা', 'জনপ্রতিনিধি'] ,
['জনপদ', 'জেলা'] ,
['জনপোযোগী', 'লোকোপোযোগী'] ,
['জনপ্রিয়', 'লোকপ্রিয়', 'সর্বপ্রিয়'] ,
['জনমত', 'ভোট', 'লোকমত'] ,
['জনমেজয়', 'পারিক্ষিত'] ,
['জনযুদ্ধ', 'জনসংগ্রাম'] ,
['জনসংহার', 'নরসংহার'] ,
['জনসেবক', 'সরকারি কর্মচারী'] ,
['জনসেবা', 'লোকসেবা'] ,
['জনসেবায়', 'লোকসেবায়'] ,
['জনার', 'ভুট্টা', 'মকাই'] ,
['জনাশ্রয়', 'ধর্ম-শালা', 'ধর্মশালা', 'ধর্মশালা শহর', 'পথিকালয়', 'পথিকাশ্রয়', 'পান্থশালা', 'মুসাফিরখানা', 'সরাইখানা'] ,
['জনিত', 'বাহিত'] ,
['জন্তু', 'জানোয়ার', 'জীব', 'জীবজন্তু', 'প্রাণী', 'প্রাণীকুল'] ,
['জন্ত্রী', 'তিথিপত্রস পঞ্জিকা', 'পঞ্চাঙ্গ'] ,
['জন্ম তিথি', 'জন্ম-তিথি', 'জন্মতিথি'] ,
['জন্ম নেওয়া', 'জন্মগ্রহণ করা', 'জন্মানো'] ,
['জন্ম রাশি', 'রাশি'] ,
['জন্ম সংস্কার', 'জাতক সংস্কার'] ,
['জন্ম-ঘুট্টী', 'জন্মঘুট্টী'] ,
['জন্মকাল', 'জন্মলগ্ন', 'জন্মসময়'] ,
['জন্মগত', 'জন্মজাত'] ,
['জন্মজয়ন্তী', 'জন্মোত্সব', 'জয়ন্তী'] ,
['জন্মদিন', 'জন্মদিবস', 'বার্থডে'] ,
['জন্মভূমি', 'জন্মস্থান', 'মাতৃভূমি'] ,
['জন্মান্তর', 'পরজন্ম'] ,
['জপনীয়', 'জপ্য'] ,
['জপমালা', 'তসবী'] ,
['জবরদস্তি', 'জোর', 'বলপূর্বক'] ,
['জবাস', 'তাম্রমূলা', 'বালপত্র-অধিকন্টক', 'সিংহনাদিকা'] ,
['জবাহ', 'প্রবাল'] ,
['জব্বলপুর', 'জব্বলপুর জেলা', 'জব্বলপুরম'] ,
['জমকালো প্রবেশদ্বার', 'রাজকীয় প্রবেশদ্বার'] ,
['জমা ধন', 'জমা-পুঁজি', 'জমানো টাকা'] ,
['জমা', 'জমে যাওয়া'] ,
['জমাট', 'জমাটবদ্ধ'] ,
['জমাদার', 'মেথর', 'সাফাই কর্মী'] ,
['জমাদারনি', 'মেতরানী'] ,
['জমানো', 'বসানো'] ,
['জমি', 'টপ্পা', 'প্লট', 'ভূ-ভাগ', 'ভূমি', 'ভূমিখণ্ড', 'ভূস্হল', 'স্হল', 'স্হলভাগ'] ,
['জমিদার', 'জোতদার'] ,
['জমুই', 'জমুই জেলা', 'জমুই শহর'] ,
['জমে ওঠা', 'জমে যাওয়া'] ,
['জমে যাওয়া', 'ঠিক হয়ে যাওয়া', 'ধরে যাওয়া', 'নিশ্চিত হওয়া', 'পাকা হওয়া'] ,
['জম্বুখন্ড', 'জম্বুদ্বীপ', 'দ্বীপ'] ,
['জম্মু', 'জম্মু জেলা', 'জম্মু শহর'] ,
['জরত্কারু', 'জরত্কারু ঋষি', 'নাগভগিনী'] ,
['জরদা', 'পিলু', 'লৌরি'] ,
['জরাকুমার', 'জরাসন্ধ', 'মগহপতি', 'মাগধ'] ,
['জরাথ্রুষ্ট প্রবর্তিত ধর্ম', 'পারসী ধর্ম'] ,
['জরিদার', 'জরিযুক্ত', 'জরির'] ,
['জর্জ স্যাণ্ড', 'ব্যারোনেস দুদেভ্যান্ত', 'স্যাণ্ড'] ,
['জর্জ', 'তৃতীয় জর্জ', 'দ্বিতীয় জর্জ', 'পঞ্চম জর্জ', 'প্রথম জর্জ', 'ষষ্ঠ জর্জ', 'সেন্ট জর্জ'] ,
['জর্জর', 'জীর্ণ', 'জীর্ণ-শীর্ণ', 'ভাঙ্গা-চোড়া'] ,
['জর্ডনবাসী', 'জর্ডনিয়ান'] ,
['জর্ডান', 'জর্ডান নদী'] ,
['জল জীব', 'জল প্রাণী', 'জলচর', 'জলীয় জীব'] ,
['জল নিকাষি', 'জলনিকাষি'] ,
['জল বর্ষণ করা', 'বর্ষণ করা'] ,
['জল', 'জলভাগ'] ,
['জল-ক্রীড়া', 'জল-বিহার', 'জলকেলি', 'জলক্রীড়া', 'জলবিহার'] ,
['জল-ধারা', 'জলধার জলপ্রবাহ', 'জলধারা'] ,
['জল-পরী', 'জলকন্যা', 'জলপরী', 'মত্সকন্যা', 'মত্সনারী', 'মত্সাঙ্গনা'] ,
['জল-বৃষ্টি', 'বর্ষা', 'বাদলা', 'বৃষ্টি'] ,
['জল-মানুষ', 'জলমনুষ্য', 'জলমানুষ'] ,
['জল-সেনা', 'জলসেনা', 'নেভি', 'নৌসেনা'] ,
['জলকণা', 'শীকর', 'সীকর'] ,
['জলকপোত', 'ফেসান্ট টেলড জাকানা'] ,
['জলকল', 'জলকল বিভাগ'] ,
['জলকাক', 'বুজ্জা', 'মুণ্ড'] ,
['জলকুল্তল', 'জলঘাস', 'জলনীলিকা', 'জলনীলী', 'ভূকেশ', 'শিহালা', 'শেওলা', 'শেহালা', 'শেয়ালা', 'শৈবাল', 'সলিলকুন্তল'] ,
['জলগাঁও', 'জলগাঁও জেলা', 'জলগাঁও শহর'] ,
['জলচর পাখি', 'জলের পাখি'] ,
['জলজ গাছ', 'জলজ পাদপ', 'জলজ বনস্পতি', 'হাইড্রোফাইটা'] ,
['জলজ', 'জলীয়', 'জলের'] ,
['জলজাহাজ', 'জলপোত', 'জাহাজ'] ,
['জলদস্যু', 'নৌদস্যু', 'সামুদ্রিক ডাকাত'] ,
['জলদেবতা', 'জলাধিপ', 'জলাধিপতি', 'তোয়েশ', 'পাশপাণি', 'পাশি', 'প্রচেতস', 'প্রচেতা', 'বরুন', 'বরুনদেবতা', 'যাদঃপতি', 'সাগরালয়'] ,
['জলধর', 'মেঘ'] ,
['জলধর-কেদারা', 'জলধর-কেদারা রোগ'] ,
['জলন্ধর', 'জলন্ধর ঋষি', 'জলন্ধর জেলা', 'জালান্ধর', 'সিন্ধুসুত'] ,
['জলপতি', 'পূর্বাষাঢ়া', 'পূর্বাষাঢ়া নক্ষত্র'] ,
['জলপাইগুড়ী', 'জলপাইগুড়ী জেলা', 'জলপাইগুড়ী শহর'] ,
['জলপিপুল', 'রক্তারি'] ,
['জলবাহিত মৃত্তিকা', 'পলি', 'পলি মৃত্তিকা'] ,
['জলবিন্দুজ', 'জলবিন্দুজা', 'যাবনাল'] ,
['জলবিল্ব', 'স্বল্প জলের জায়গা'] ,
['জলমগ্ন', 'ডুবে যাওয়া', 'নিমজ্জিত', 'প্লাবিত'] ,
['জলযন্ত্র', 'পাম্প', 'বারিযন্ত্র'] ,
['জলসেনা অধক্ষ্য', 'জলসেনাধক্ষ্য', 'নৌসেনা অধক্ষ্য', 'নৌসেনাধক্ষ্য'] ,
['জলস্তর উঁচু হওয়া', 'বেড়ে যাওয়া'] ,
['জলহস্তী', 'হিপ্পো'] ,
['জলহীন', 'নির্জলা'] ,
['জলাধার', 'ট্যাংক'] ,
['জলাভিষেক', 'স্নানাভিষেক'] ,
['জলাশয়', 'ঝিলে', 'দিঘি', 'পুকুর', 'পুষ্করিণী', 'সর', 'সরোবর'] ,
['জলীয় জন্তু', 'জলীয় প্রানী'] ,
['জলুস', 'জেল্লা', 'দীপ্তি', 'রূপ'] ,
['জলোদর', 'জলোদর রোগ'] ,
['জশপুর', 'জশপুর জেলা', 'জশপুর শহর'] ,
['জহর', 'রতন', 'রত্ন'] ,
['জহ্নু', 'জহ্নু ঋষি'] ,
['জাঁতাকল', 'জাঁতাশাল'] ,
['জাখোম', 'জাখোম নদী'] ,
['জাগরণ', 'জাগা', 'জাগৃতি'] ,
['জাগা', 'সজাগ থাকা', 'সতর্ক থাকা', 'সাবধান থাকা'] ,
['জাগানো', 'সচেতন করা'] ,
['জাঘী', 'বোডাল', 'সিংহমোনাল'] ,
['জাজপুর', 'জাজপুর জেলা'] ,
['জাজলি', 'জাজলি ঋষি'] ,
['জাজ্জ্বল্যমান', 'তেজ পূর্ণ', 'তেজোমণ্ডিত', 'দিব্য', 'দেদীপ্যমান', 'প্রজ্জ্বলিত'] ,
['জাঞ্জগীর', 'জাঞ্জগীর শহর'] ,
['জাঞ্জগীর-চাঁপা', 'জাঞ্জগীর-চাঁপা জেলা'] ,
['জাতক', 'বৌদ্ধ ভিক্ষুক', 'বৌদ্ধ সাধু'] ,
['জাতভাই', 'সহজাতি'] ,
['জাতি নির্বাসিত', 'জাতি বহিষ্কৃত', 'জাতিচ্যূত'] ,
['জাতি', 'জাতিত্ব', 'ধরণ', 'প্রকার'] ,
['জাতি-সম্বন্ধীয়', 'জাতির', 'জাতিসংক্রান্ত', 'নৃকুলসংক্রান্ত'] ,
['জাতিকোষ', 'জাতিপত্রী', 'জাবিত্রী', 'জায়পত্রী'] ,
['জাতীয় ধ্বজা', 'জাতীয় পতাকা'] ,
['জাতীয়', 'দেশীয়'] ,
['জাতীয়তাবাদ সম্পর্কিত', 'জাতীয়তাবাদ সম্বন্ধীয়'] ,
['জাতুক', 'হিং', 'হিঙ্গ'] ,
['জাদু', 'মন্ত্র', 'মন্ত্রতন্ত্র'] ,
['জান', 'জীবন', 'প্রাণ'] ,
['জানা যাওয়া', 'জ্ঞাত হওয়া'] ,
['জানা', 'দেখা', 'পূর্ব পরিচিত'] ,
['জানা-শোনা', 'পরিচিতি', 'পরিচয়'] ,
['জানানো', 'প্রকাশ করা', 'বলা'] ,
['জানালা', 'বাতায়ন'] ,
['জানাশোনা', 'পরিচিতি', 'সম্পর্ক'] ,
['জানু', 'হাঁটু'] ,
['জানুকর্ণ', 'জানুকর্ণ ঋষি'] ,
['জানুয়াঁ', 'জানুয়াঁ রোগ'] ,
['জান্তব', 'প্রাণী'] ,
['জাপানবাসী', 'জাপানী'] ,
['জাপানী', 'জাপানী লিপি', 'জ্যাপানিস্'] ,
['জাফরাবাদী', 'জাফরাবাদী মোষ'] ,
['জাব', 'জাবনা'] ,
['জাবাই', 'জাবাই লিপি'] ,
['জাবাল', 'জাবাল উপনিষদ', 'জাবালোপনিষদ'] ,
['জাবালি', 'জাবালি ঋষি'] ,
['জাবেদা খাতা', 'হিসাবের খাতা'] ,
['জাভা', 'জাভা দ্বীপ'] ,
['জাভানিস', 'জাভানিস ভাষা'] ,
['জাম গাছ', 'শফতালু'] ,
['জাম রঙ', 'বেগুনি রঙ'] ,
['জাম', 'ট্রাফিক জাম', 'যানজট'] ,
['জামতারা', 'জামতারা জেলা', 'জামতারা শহর'] ,
['জামদগ্নি', 'জামদগ্নি ঋষি'] ,
['জামনগর', 'জামনগর জেলা'] ,
['জামশেদপুর', 'টাটানগর'] ,
['জামা', 'বাগা'] ,
['জামাই', 'জামাইবাবু', 'জামাতা'] ,
['জামাইকান ডলার', 'ডলার'] ,
['জামাইকান', 'জামাইকাবাসী', 'জামাইকার'] ,
['জামিন', 'জামিনদার', 'জামীন'] ,
['জাম্বিয়া', 'জাম্বিয়া গণরাজ্য'] ,
['জাম্বিয়ান', 'জাম্বিয়াবাসী', 'জাম্বিয়ার'] ,
['জার্মান', 'জার্মান ভাষা', 'জার্মান-বাসী', 'জার্মানবাসী'] ,
['জার্সি', 'জার্সি প্রজাতি'] ,
['জাল', 'জালি', 'তন্তু', 'নকল', 'নেট', 'পাশ', 'লাগাম'] ,
['জালজীবি', 'জেলে', 'ধীবর'] ,
['জালনা', 'জালনা জেলা', 'জালনা শহর'] ,
['জালি', 'ঝাঁঝরি'] ,
['জালিদার সসার', 'তারজালি'] ,
['জালোর', 'জালোর জেলা', 'জালোর শহর'] ,
['জালৌন', 'জালৌন জেলা', 'জালৌন শহর'] ,
['জাহাঙ্গীর', 'নুরুদ্দীন জাহাঙ্গীর', 'সলীম'] ,
['জাহাজ সম্পর্কিত', 'জাহাজের'] ,
['জাহাজের খাজাঞ্চী', 'পার্সার'] ,
['জাহানাবাদ', 'জাহানাবাদ জেলা', 'জাহানাবাদ শহর'] ,
['জাহান্নম', 'দোজখ', 'নরক', 'নাগলোক', 'পাতাল', 'পাতাললোক', 'রসাতল'] ,
['জাহিরুদ্দীন মহম্মদ বাবর', 'বাবর'] ,
['জায়গা', 'প্রদেশ', 'ফাঁক', 'বদলে', 'স্থল', 'স্থান', 'স্হান'] ,
['জায়গির', 'দেবত্র জমি'] ,
['জায়ফল', 'পুন্নাগ'] ,
['জি স্ট্যানলি হল', 'হল'] ,
['জিগিন', 'জিঙ্গনী', 'জিঙ্গিনী'] ,
['জিঙ্ক', 'দস্তা'] ,
['জিজিয়া', 'জিজিয়া কর'] ,
['জিজীবিষা', 'জীবনেচ্ছু'] ,
['জিজ্ঞাসা করা', 'প্রশ্ন করা'] ,
['জিজ্ঞাসা', 'জিজ্ঞাসাবাদ'] ,
['জিতাষ্টমী', 'জিতাষ্টমী ব্রত', 'জীমূতাষ্টমী'] ,
['জিদ', 'জেদ'] ,
['জিন', 'পর্যাণ'] ,
['জিনিস', 'দ্রব্য', 'পদার্থ', 'বস্তু'] ,
['জিনিসপত্র', 'দ্রব্যসামগ্রী', 'মাল'] ,
['জিন্দ', 'জিন্দ জেলা', 'জিন্দ শহর'] ,
['জিপসি', 'জিপসি ভাষা', 'রোমানি ভাষা'] ,
['জিপ্সী', 'যাযাবর'] ,
['জিব', 'জিহ্বা'] ,
['জিবাউটি', 'জিবাউটি গণতন্ত্র'] ,
['জিভ', 'জিহ্বা'] ,
['জিম', 'জিমনাশিয়াম'] ,
['জিম্বাবোয়ান ডলার', 'ডলার'] ,
['জিম্বাবোয়ে', 'জিম্বাবোয়ে গণরাজ্য'] ,
['জিরো', 'জিরো শহর'] ,
['জিল', 'জিল আম'] ,
['জিহাদ', 'জেহাদ'] ,
['জিহাদী', 'জেহাদী'] ,
['জিহ্বাপ', 'জিহ্বাপ প্রাণী'] ,
['জীব বর্গ', 'জীব সম্প্রদায়', 'জীবকুল'] ,
['জীব বিজ্ঞান', 'বায়োলজি'] ,
['জীব', 'প্রাণী'] ,
['জীবক', 'দিব্যা', 'দিব্যা', 'প্রস্তরণী', 'ভূতকেশ', 'শতগ্রন্থি', 'শীতদূর্বা', 'সাদা দূর্বা', 'স্বল্পকেশী'] ,
['জীবন অতিবাহিত করা', 'জীবন যাপন করা', 'জীবিত থাকা', 'বাঁচা'] ,
['জীবন কথা', 'জীবন চরিত', 'জীবন বৃত্তান্ত', 'জীবনী'] ,
['জীবন চরিত', 'জীবনবৃত্তান্ত', 'জীবনী'] ,
['জীবন', 'প্রাণ'] ,
['জীবনকাল', 'সময়'] ,
['জীবনচক্র', 'জীবনযাত্রা'] ,
['জীবনচর্যা', 'জীবনশৈলী'] ,
['জীবনদায়ী', 'সঞ্জীবনী'] ,
['জীবনবিমুখ', 'পলায়নবাদী'] ,
['জীবনবিমুখতা', 'পলায়নী মনোবৃত্তি'] ,
['জীবনভর', 'সারাজীবন'] ,
['জীবনহরণকারী', 'প্রাণহন্তা', 'প্রাণহরণকারী'] ,
['জীবনাশক', 'রক্তনাল', 'শিরিয়ারী', 'সুসনা'] ,
['জীবন্ত জীবাশ্ম', 'জীবন্ত ফসিলস্'] ,
['জীবন্ত মানুষের সমান মাপের', 'পূর্ণাবয়ব'] ,
['জীবন্ত', 'জীবিত', 'সজীব', 'সবুজ'] ,
['জীবন্তী', 'জীবন্তী লতা', 'জীবা', 'মৃগরাটিকা', 'রক্তাঙ্গী', 'শাকশ্রেষ্ঠা'] ,
['জীবাণু জনিত', 'ব্যাকটেরিয়া জনিত'] ,
['জীবাণু সংক্রমণ', 'ব্যাকটিরিয়াল ইন্ফেকশন', 'ভাইরাল ইন্ফেকশন'] ,
['জীবাণু', 'ব্যাক্টিরিয়া', 'ভাইরাস'] ,
['জীবাণুঘটিত', 'ভাইরাসঘটিত'] ,
['জীবাণুনাশ', 'বিসংক্রমণ'] ,
['জীবাণুবিজ্ঞান', 'ভাইরোলজি'] ,
['জীবাণুবিজ্ঞানী', 'ভাইরোলজিস্ট'] ,
['জীবিকা', 'বৃত্তি'] ,
['জীবিকাহীন', 'বেকার', 'রোজগারহীন'] ,
['জীবিত করা', 'বাঁচিয়ে দেওয়া'] ,
['জীবীত রাখা', 'পালিত করা', 'পুষ্ট করা', 'বজায় রাখা'] ,
['জীরা', 'জীরে'] ,
['জীরিকা', 'বংশপত্রী'] ,
['জীর্ণ', 'ফাটা', 'বিদীর্ণ'] ,
['জীর্ণ-শীর্ণ', 'ফুটিফাটা', 'ভাঙাচোরা'] ,
['জীর্ণোদ্ধার', 'পুনরুদ্ধার'] ,
['জীল্যাণ্ড', 'সীল্যাণ্ড'] ,
['জুঁই', 'পারিজাত', 'পুষ্পগন্ধা', 'যুথিকা', 'যূথি', 'যূথিকা', 'যূথী'] ,
['জুআঠ', 'জোত'] ,
['জুগজুগি', 'শকরখোরা পাখি'] ,
['জুট', 'পাট', 'শন'] ,
['জুটি', 'যুগল', 'সঙ্গী', 'সহচর'] ,
['জুড়ি', 'জোড়া', 'জোড়া লাগানো', 'যুগল'] ,
['জুডিশিয়ারি', 'ন্যায়পালিকা'] ,
['জুতা', 'জুতো'] ,
['জুতাখোর', 'জুতোখোর', 'লাতখোর'] ,
['জুনাগড়', 'জুনাগড় জেলা', 'জুনাগড় শহর'] ,
['জুন্হেবোটো', 'জুন্হেবোটো শহর'] ,
['জুপিটার', 'বৃহস্পতি', 'বৃহস্পতি গ্রহ'] ,
['জুবলী', 'জুবলী আম'] ,
['জুমীজ', 'মরুভূমি গরুড়'] ,
['জুম্বলি', 'জুম্বলি ভেড়া'] ,
['জুরি', 'নির্ণায়ক সভা', 'বিচারক মণ্ডলী'] ,
['জুলপি', 'জুলফি'] ,
['জুলি', 'জুলি আম'] ,
['জুহার', 'লব্বা', 'লব্বা পাখি'] ,
['জুয়া চোর', 'জুয়াচোর'] ,
['জুয়া', 'দ্যূতক্রীড়া'] ,
['জুয়াখানা', 'জুয়াঘর', 'জুয়ার আড্ডা', 'দ্যুতশালা', 'দ্যূতগৃহ'] ,
['জুয়াড়ী', 'জুয়ারি'] ,
['জুয়াবাজ', 'জুয়ারি', 'ধুর্ত'] ,
['জেট', 'জেট বিমান'] ,
['জেঠী', 'জেঠীমা', 'জ্যাঠাইমা'] ,
['জেতব্য', 'জেয়', 'জয় যোগ্য'] ,
['জেতা', 'বিজয় লাভ করা', 'বিজয়ী হওয়া', 'সফল হওয়া', 'সফলতা প্রাপ্ত করা', 'সফলতা লাভ করা'] ,
['জেদ করা', 'জেদ ধরা'] ,
['জেদ', 'বদজেদ', 'হঠ'] ,
['জেদী', 'বিগড়ানো', 'বেয়াড়া'] ,
['জেনানা', 'মেয়েদের', 'স্ত্রী-সংক্রান্ত', 'স্ত্রী-সম্পর্কিত'] ,
['জেনিভা ঝিল', 'জেনিভা লেক'] ,
['জেপি', 'জয়প্রকাশ নারায়ণ'] ,
['জেপিসি', 'সংযুক্ত সংসদীয় সমিতি'] ,
['জেরক্স', 'জেরক্স কপি', 'নকল', 'প্রতিলিপি', 'প্রতিলিপিকরণ'] ,
['জেলা প্রশাসক', 'জেলাধিকারিক'] ,
['জেলা শাসক', 'জেলাধীশ', 'ডিস্ট্রিক্ট ম্যাজিস্ট্রেট'] ,
['জেলাম', 'জেলাম নদী'] ,
['জেলে', 'ধীবর'] ,
['জেষ্ঠ্যা', 'জেষ্ঠ্যা নক্ষত্র'] ,
['জৈন মুনি', 'জৈন সাধু'] ,
['জৈন', 'জৈন ধর্ম', 'জৈন সম্প্রদায়', 'জৈনধর্মালম্বী'] ,
['জৈব দ্রব্য', 'জৈব পদার্থ', 'প্রোটোপ্লাজম'] ,
['জৈব', 'জৈবিক'] ,
['জৈবপ্রযুক্তি', 'বায়োটেকনোলজি'] ,
['জৈবিক প্রক্রিয়া', 'প্রাণীয় প্রক্রিয়া'] ,
['জৈমিনী', 'জৈমিনী ঋষি'] ,
['জৈষ্ঠ্য', 'জৈষ্ঠ্য মাস'] ,
['জোকার', 'বিদূষক', 'ভাঁড়'] ,
['জোঙ্কা', 'ভুটানি'] ,
['জোচ্চোর', 'ঠক', 'ধাপ্পাবাজ'] ,
['জোড় খাওয়া', 'ঠাপানো'] ,
['জোড়', 'জোড়া', 'বল'] ,
['জোড়া অংশ', 'সন্ধিস্হল'] ,
['জোড়া', 'জোড়া লাগানো', 'জোড়া লেগে যাওয়া', 'যুক্ত করা', 'যুক্ত হওয়া', 'যুগল', 'যোগ করা', 'লাগানো', 'সংবদ্ধ করা', 'সংলগ্ন করা', 'সেঁটে দেওয়া'] ,
['জোতগাড়ি', 'পশুযান'] ,
['জোতা', 'হাল চালানো'] ,
['জোনাক', 'জোনাকি'] ,
['জোবাই', 'জোবাই শহর'] ,
['জোর হাওয়া', 'ঝড়'] ,
['জোর', 'বল', 'শক্তি'] ,
['জোরহাট', 'জোরহাট জেলা', 'জোরহাট শহর'] ,
['জোরালো', 'শক্তিশালী'] ,
['জোসেফ স্টেলিন', 'স্টেলিন'] ,
['জোহর', 'জোহর প্রথা'] ,
['জোয়ান', 'তীব্রগন্ধা'] ,
['জোয়ার', 'যব'] ,
['জৌনপুর', 'জৌনপুর জেলা', 'জৌনপুর শহর'] ,
['জ্ঞ', 'ব্যঞ্জনবর্ণ জ্ঞ'] ,
['জ্ঞাতব্য', 'জ্ঞানগম্য', 'জ্ঞেয়', 'বোধগম্য', 'বোধ্য'] ,
['জ্ঞাতযৌবনা', 'যৌবনপ্রাপ্তা'] ,
['জ্ঞাতা', 'জ্ঞানী', 'পণ্ডিত', 'বিজ্ঞ', 'বিদ্বান'] ,
['জ্ঞান', 'বিদ্যা', 'বোধ', 'বোধি', 'শিক্ষা', 'সংজ্ঞা', 'সংজ্ঞান'] ,
['জ্ঞানদেবী', 'জ্ঞানেশ্বরী', 'ভাবার্থদীপিকা'] ,
['জ্ঞানপূর্ণ', 'জ্ঞানময়', 'বোধপূর্ণ'] ,
['জ্ঞানবৃক্ষ', 'ট্রী অফ নলেজ', 'বুদ্ধিবৃক্ষ', 'বোধবৃক্ষ'] ,
['জ্ঞানলাভ', 'বোধপ্রাপ্তি'] ,
['জ্ঞানের তল পাওয়া', 'সম্যক জ্ঞান পাওয়া'] ,
['জ্ঞানেশ্বর', 'জ্ঞানেশ্বর মহারাজ', 'সাধু জ্ঞানেশ্বর'] ,
['জ্ঞাপক', 'পরিচায়ক', 'সূচক'] ,
['জ্ঞাপিত', 'বিজ্ঞাপিত', 'বিদিত'] ,
['জ্ঞেয় অপরাধ', 'বোধগম্য অপরাধ'] ,
['জ্বর কমাবার ওষুধ', 'তাপনাশক', 'তাপহারী'] ,
['জ্বলা', 'জ্বলে যাওয়া', 'দগ্ধ', 'দগ্ধ হওয়া', 'পোড়া'] ,
['জ্বলুনি', 'দাহ'] ,
['জ্বলে যাওয়া', 'পুড়ে যাওয়া'] ,
['জ্বালানো', 'প্রজ্বলিত করা', 'বাষ্পীভূত করা'] ,
['জ্যাকলিন', 'জ্যাকলিন আম'] ,
['জ্যাঠা', 'জ্যেঠু'] ,
['জ্যামিতিক', 'রেখাগাণিতিক'] ,
['জ্যেষ্ঠ', 'জ্যেষ্ঠ নক্ষত্রে', 'বড়'] ,
['জ্যেষ্ঠাম্বু', 'তন্ডুরণ', 'তন্ডুল-জল'] ,
['জ্যোতি', 'জ্যোতি তাল'] ,
['জ্যোতিবা ফুলে নগর', 'জ্যোতিবা ফুলে নগর জেলা'] ,
['জ্যোতির্বিদ', 'জ্যোতিষী'] ,
['জ্যোতিষ', 'জ্যোতিষ শাস্ত্র', 'জ্যোতিষ-বিদ্যা', 'জ্যোতিষবিদ্যা', 'জ্যোতিষশাস্ত্র'] ,
['জ্যোতিষ-চক্র', 'জ্যোতিষচক্র', 'রাশি মণ্ডল', 'রাশি-চক্র', 'রাশিচক্র', 'রাশিমণ্ডল'] ,
['জয় পরাজয়', 'হার জিত', 'হার-জিত'] ,
['জয়', 'বশীকরণ', 'বিজয়', 'মহাভারত', 'মহাভারত গ্রন্থ', 'সাফল্য'] ,
['জয়দ্রথ', 'সিন্ধুরাজ'] ,
['জয়ন্ত', 'পাকশাসনি', 'যাগসন্তান'] ,
['জয়ন্তী', 'শারণী'] ,
['জয়মল্লার', 'জয়মল্লার রাগ'] ,
['জয়মালা', 'মালা'] ,
['জয়মাল্য', 'বরমালা', 'বরমাল্য'] ,
['জয়সল', 'রাজা জয়সল'] ,
['জয়সলমীর', 'জয়সলমীর জেলা', 'জয়সলমীর শহর'] ,
['জয়স্তম্ভ', 'বিজয়স্তম্ভ'] ,
['জয়াবহা', 'ভদ্রদন্তী'] ,
['জয়ী', 'বিজয়ী'] ,
['জয়েত্', 'জয়েত্ রাগ'] ,
['জয়েন্ট ভেঞ্চার', 'সংযুক্ত উদ্যম'] ,
['ঝ', 'ব্যঞ্জনবর্ণ ঝ'] ,
['ঝঁপানী', 'ঝপ্পানী'] ,
['ঝগড়া করা', 'বিতণ্ডা করা', 'বিবাদ করা'] ,
['ঝগড়ুটে', 'ঝমেলাবাজ'] ,
['ঝজ্জর', 'ঝজ্জর জেলা', 'ঝজ্জর শহর'] ,
['ঝঝুঝুবী', 'ঝবঝবী'] ,
['ঝঞ্ঝা', 'ঝড়', 'প্রচন্ড'] ,
['ঝঞ্ঝাট', 'ঝামেলা', 'প্রপঞ্চ'] ,
['ঝড়', 'ঝড় তুফান', 'ঝোড়ো', 'তুফান'] ,
['ঝড়া', 'পড়া'] ,
['ঝনকবাত', 'ঝনকবাত রোগ'] ,
['ঝম-ঝম', 'ঝমঝম'] ,
['ঝরনা কলম', 'ফাউনটেন পেন'] ,
['ঝরা', 'পড়া'] ,
['ঝর্ণা', 'ঝোরা', 'প্রপাত', 'ফোয়ারা'] ,
['ঝর্সুগুডা', 'ঝর্সুগুডা শহর', 'ঝারসুগুডা', 'ঝারসুগুডা জেলা', 'ঝারসুগুডা শহর', 'ঝার্সগুড জেলা'] ,
['ঝলসানো লাল', 'রোদে পোড়া লাল'] ,
['ঝলসানো', 'পোড়ানো', 'রান্না করা', 'স্যাঁকা'] ,
['ঝাঁকড়া চুলওয়ালা', 'লোমওয়ালা'] ,
['ঝাঁকানো', 'নাড়ানো'] ,
['ঝাঁঝরা করা', 'ফাঁক করা'] ,
['ঝাঁট দেওয়া', 'ঝাড়ু দেওয়া'] ,
['ঝাঁটা', 'ঝাড়ু'] ,
['ঝাঁড়া', 'ঝাড়-ফুঁক', 'ঝাড়ফুঁক'] ,
['ঝাঁপ দরজা', 'হ্যাচ'] ,
['ঝাঁপ দেওয়া', 'লাফ দেওয়া', 'লাফানো'] ,
['ঝাঁপান', 'পালকি'] ,
['ঝাঁসি', 'ঝাঁসি জেলা', 'ঝাঁসি শহর'] ,
['ঝাঁসী', 'ঝাঁসী পোকা'] ,
['ঝাড় মারা', 'বকা', 'ভয় দেখানো'] ,
['ঝাড়', 'ঝোপ ঝাড়', 'মূনা'] ,
['ঝাড়-ফুঁক করা', 'ঝাড়া'] ,
['ঝাড়খণ্ড', 'ঝাড়খণ্ড রাজ্য'] ,
['ঝাড়নণ্ঠন', 'ঝুমুর'] ,
['ঝাড়াই করানো', 'ঝাড়ানো'] ,
['ঝাড়ু', 'বুরুশ', 'ব্রাশ'] ,
['ঝাবুয়া', 'ঝাবুয়া জেলা', 'ঝাবুয়া শহর'] ,
['ঝামুমো', 'ঝারখণ্ড মুক্তি মোর্চা'] ,
['ঝালাবাড়', 'ঝালাবাড় জেলা', 'ঝালাবাড় শহর'] ,
['ঝিঙ্গিনী', 'ঝিঙ্গী'] ,
['ঝিনঝিন', 'টনটনানি'] ,
['ঝিলমিল', 'ঝিলমিল কাপড়'] ,
['ঝিল্লী', 'মধ্যচ্ছদা'] ,
['ঝিল্লীযুক্ত', 'ঝিল্লীসমন্বিত'] ,
['ঝুঁকে থাকা', 'ঝোঁকা', 'নুইয়ে পড়া'] ,
['ঝুড়ি', 'টোকরি', 'ডালা', 'ধামা'] ,
['ঝুনঝুনি', 'ঝুমঝুমি'] ,
['ঝুপড়ি', 'টিনের চালযুক্ত ঝুপড়ি'] ,
['ঝুমর', 'ঝুমর গান', 'ঝুমর নৃত্য', 'হাতুড়ি'] ,
['ঝুলন্ত', 'ঝুলে থাকা'] ,
['ঝুলন্ত-পুল', 'ঝুলন্ত-সাঁকো'] ,
['ঝোড়ো', 'দ্রুত'] ,
['ঝোলদার', 'রসালো'] ,
['ঞ', 'ব্যঞ্জনবর্ণ ঞ'] ,
['ট', 'ব্যঞ্জনবর্ণ ট'] ,
['টং টং করা', 'ঢং ঢং করা'] ,
['টক চাটনি', 'টোকো'] ,
['টকা-তোপ', 'টকাতোপ'] ,
['টক্কর দেওয়া', 'পাল্লা দেওয়া'] ,
['টক্কর', 'বিতণ্ডা', 'লড়াই'] ,
['টক্র', 'টাকু', 'টাকুর', 'টাকুয়া', 'তকলি', 'তর্কু', 'মাকু'] ,
['টগর', 'তগর', 'নবমল্লিকা', 'বর্হি', 'শীতপুষ্প', 'সগর'] ,
['টঙ্কণ', 'টঙ্কণ ঘোড়া'] ,
['টঙ্কা', 'টঙ্কা রাগ'] ,
['টঙ্কার তোলা', 'টঙ্কার দেওয়া'] ,
['টনটনানি', 'ব্যথা'] ,
['টনসিল', 'টন্সিল'] ,
['টপ', 'প্রথম'] ,
['টপটপ', 'টিপটিপ'] ,
['টপার', 'প্রথম স্হানাধিকারী'] ,
['টপ্পা', 'টপ্পা গান'] ,
['টমকী', 'টুমকী'] ,
['টমি অ্যাটকিন্স', 'টমি অ্যাটকিন্স আম'] ,
['টরাবা', 'তরাবা', 'বাইরিকী', 'বায়রিকী'] ,
['টর্চ', 'দীপযোষ্ঠী', 'দীপিকা', 'ব্যাটারী'] ,
['টলমল', 'টালমাটাল'] ,
['টলমলা অবস্থা', 'টলমলানি'] ,
['টহল', 'রোঁদ'] ,
['টাঁক', 'সেলাই'] ,
['টাইগ্রিস', 'টাইগ্রিস নদী', 'দিজ্লা'] ,
['টাইপ', 'টাইপ করা', 'টাইপিং'] ,
['টাইপরাইটার', 'মুদ্রলেখক'] ,
['টাইফ-রাইটার', 'মুদ্রাক্ষরযন্ত্র'] ,
['টাইম', 'সময়'] ,
['টাইমটেবল', 'সময়সারণী'] ,
['টাউন', 'টাউনশিপ'] ,
['টাকওলা ব্যাক্তি', 'টাকলা', 'টোকো'] ,
['টাকওয়ালা', 'টাকলা', 'টেকো'] ,
['টাকা লাগানো', 'পুঁজি-নিবেশ'] ,
['টাকা', 'টাকা-পয়সা', 'পয়সা', 'মুদ্রা'] ,
['টান দেওয়া', 'দম মারা'] ,
['টান', 'টানা'] ,
['টানা', 'টানাটানি', 'টেনে নামানো', 'বার করা', 'শোষণ করা', 'সারি'] ,
['টানানো', 'প্রসারিত করানো'] ,
['টানেল', 'সুড়ঙ্গ'] ,
['টারবাইন', 'টারবাইন মেশিন'] ,
['টি এইচ হোয়াইট', 'হোয়াইট'] ,
['টিউনিসিয়ান', 'টিউনিসীয়'] ,
['টিউনীশিয়া বাসী', 'টিউনীশিয়াই', 'টিউনীশিয়ান'] ,
['টিউনীশিয়া', 'টিউনীশিয়া গণরাজ্য'] ,
['টিউনেশিয়ান দিনার', 'দিনার'] ,
['টিউব', 'টিউব লাইট', 'মারকারি লাইট'] ,
['টিউবওয়েল', 'নলকূপ'] ,
['টিকমগড়', 'টিকমগড় শহর'] ,
['টিকল', 'বাত', 'বাত রোগ', 'বাতরোগ'] ,
['টিকলি', 'টিপ'] ,
['টিকা', 'টিকাকরন', 'তিলক'] ,
['টিকিট চেকার', 'টিসি'] ,
['টিকিয়া', 'বাটি', 'লিট্টী'] ,
['টিকে থাকা', 'স্থিত'] ,
['টিক্কা', 'মাংসের টুকরো'] ,
['টিঙ্কচার-ওপিয়াই', 'টিঙ্কচার-কার্ডিমাম'] ,
['টিচিঙ এইড', 'শিক্ষণ সামগ্রী'] ,
['টিটি', 'টিটি বাঁদর'] ,
['টিটেনাস', 'ধনুষ্টংকার'] ,
['টিপ', 'বকশিশ', 'বখশিশ'] ,
['টিপু', 'টিপু গাছ', 'হলুদ জ্যাকরেণ্ডা'] ,
['টিপ্পণী করা', 'ব্যঙ্গ করা'] ,
['টিপ্পনি', 'নোট'] ,
['টিভি', 'টিভি চ্যানেল', 'টেলিভিশন চ্যানেল', 'দূরদর্শন চ্যানেল'] ,
['টিলা', 'ঢিবি'] ,
['টিয়া রঙের', 'ধানী'] ,
['টিয়াপাখি', 'তোতাপাখি'] ,
['টীকা টিপ্পনী', 'নোট'] ,
['টীকা', 'নোট', 'ভ্যাকসিন', 'সমালোচনা'] ,
['টীকাযুক্ত', 'ব্যাখ্যাযুক্ত'] ,
['টীটী', 'ফেডরেটেড স্টেট অফ মাইক্রনেশিয়া', 'ফেডরেটেড স্টেট অফ মাইক্রোনেশিয়া', 'মাইক্রনেশিয়া', 'মাইক্রনেসিয়া', 'মাইক্রোনেশিয়া', 'মাইক্রোনেসিয়া'] ,
['টুকরো করা', 'ভাঙা'] ,
['টুকলিবাজ', 'নকলকারী'] ,
['টুথ পেস্ট', 'টুথপেস্ট', 'পেস্ট'] ,
['টুথপাউডার', 'টুথপাউডার', 'দন্তমাজন', 'দাঁত মাজন', 'দাঁতমাজন', 'মাজন'] ,
['টুনীশিয়ান টিরেম', 'ডিরেম'] ,
['টুপি পরানো', 'ঠকানো'] ,
['টুপি', 'স্কালক্যাপ', 'হ্যাট'] ,
['টুবেলিয়ান ডলার', 'ডলার'] ,
['টেকনিকাল', 'প্রযুক্তি'] ,
['টেকনিশিয়ান', 'প্রযুক্তিবিদ'] ,
['টেক্স্ট ফাইল', 'ডকিউমেন্ট', 'ফাইল'] ,
['টেণ্ডার', 'দরপত্র'] ,
['টেনিস', 'লন চেনিস'] ,
['টেনে আনা', 'বের করা'] ,
['টেনে বাড়ানো', 'প্রলম্বিত করা', 'প্রসারিত করা'] ,
['টেপ করা', 'রেকর্ড করা'] ,
['টেপ', 'টেপ-রেকর্ডার', 'ফিতে', 'মাপার ফিতে', 'সেলোটেপ', 'স্কেল'] ,
['টেলিকম বিভাগ', 'দূরসঞ্চার বিভাগ'] ,
['টেলিগ্রাফ বা টেলিফোন তার', 'টেলিগ্রাফ লাইন', 'টেলিফোন লাইন'] ,
['টেলিগ্রাফ', 'তারবার্তা প্রেরণযন্ত্র', 'দূরলিখ'] ,
['টেলিগ্রাম', 'তার'] ,
['টেলিফান লাইন', 'ফোন লাইন', 'লাইন'] ,
['টেলিফোন নম্বর', 'দূরভাষ ক্রমাঙ্ক', 'ফোন নম্বর'] ,
['টেলিফোন', 'দূরভাষ', 'দূরাভাস', 'ফোন'] ,
['টেলিভিজন', 'টেলিভিজন সিস্টেম', 'দূরদর্শন-তন্ত্র', 'দূরদর্শন-প্রণালী'] ,
['টেলিস্কোপ', 'দুরবীন'] ,
['টেস্ট করানো', 'পরীক্ষা করানো'] ,
['টেস্ট শৃঙ্খলা', 'টেস্ট সিরিজ'] ,
['টেস্ট', 'টেস্ট ম্যাচ', 'পরীক্ষা', 'মানসিক বিকাশের পরীক্ষা'] ,
['টেস্টার', 'পরখিত্র'] ,
['টোংক', 'টোংক জেলা', 'টোংক শহর'] ,
['টোকা', 'নকল করা'] ,
['টোগো বাসী', 'টোগোলিস'] ,
['টোন্স', 'টোন্স নদী'] ,
['টোল', 'টোল রাগ'] ,
['ট্বেনসাঙ্গ', 'ট্বেনসাঙ্গ জেলা', 'ট্বেনসাঙ্গ শহর'] ,
['ট্যাঁকশাল', 'ট্যাঁকশাল ঘর'] ,
['ট্যাংক', 'যুদ্ধযান'] ,
['ট্যাংরা', 'ট্যাংরা মাছ'] ,
['ট্যাক্স আধিকারীক', 'শুল্ক আধিকারীক'] ,
['ট্যাক্সোন', 'বর্গীকরণ ভিত্তিক বর্গ'] ,
['ট্যানিন', 'ট্যানিন অ্যাসিড'] ,
['ট্রপোস্ফিয়ার', 'ভূ-পৃষ্ঠ সংলগ্ন বায়ুস্তর'] ,
['ট্রাঙ্ক', 'পেটি', 'বক্স', 'বাক্স', 'সিন্দুক'] ,
['ট্রান্সফর্মার', 'পরিণামিত্র'] ,
['ট্রাম', 'ট্রাম গাড়ি'] ,
['ট্রাম্প', 'তুরুপ'] ,
['ট্রেক করা', 'লম্বা কঠিন যাত্রা করা'] ,
['ট্রেক', 'ট্রেকিং'] ,
['ট্রেগ লি', 'লি'] ,
['ট্রেন', 'রেল', 'রেল-গাড়ি', 'রেলগাড়ি', 'লৌহপথগামিনী'] ,
['ট্রেনার', 'প্রশিক্ষক'] ,
['ট্রেনিং নেওয়া', 'প্রশিক্ষণ পাওয়া', 'প্রশিক্ষণ লাভ করা'] ,
['ট্র্যাক', 'রেলপথ', 'রেললাইন', 'লাইন'] ,
['ট্র্যাকিওফাইট', 'সংবাহিনী উদ্ভিদ'] ,
['ট্র্যাজিক', 'দুঃখান্তিক নাটক'] ,
['ঠ', 'ব্যঞ্জনবর্ণ ঠ'] ,
['ঠক-ঠক', 'ঠকঠক'] ,
['ঠকানো', 'প্রতারণা করা'] ,
['ঠকে যাওয়া', 'প্রতারিত হওয়া'] ,
['ঠগ', 'প্রবঞ্চক'] ,
['ঠগীনি', 'মায়াবিনী'] ,
['ঠঠবা', 'লমগজা'] ,
['ঠাকুমা', 'পিতামহী', 'প্রমাতা'] ,
['ঠাকুর বাড়ি', 'দেব-মন্দির', 'দেবগৃহ', 'দেবতার থান', 'দেবমন্দির', 'দেবস্থান', 'দেবালয়'] ,
['ঠাকুরপো', 'দেওর', 'দেবর', 'শ্বশুর্য'] ,
['ঠাকুর্দা', 'দাদু', 'পিতামহ'] ,
['ঠাণা', 'ঠাণে জেলা', 'থানা', 'থানে'] ,
['ঠাণ্ডা করা', 'শীতল করা'] ,
['ঠাণ্ডা হওয়া', 'নিভে যাওয়া', 'মরে যাওয়া'] ,
['ঠাণ্ডা', 'শান্ত', 'শীত'] ,
['ঠান্ডা', 'শরবত', 'শীত', 'শীত ঋতু', 'শীত কাল', 'শীতঋতু', 'শীতল', 'শীতলতা', 'হিম ঋতু', 'হেমঋতু'] ,
['ঠাসা', 'ঠেসে দেওয়া'] ,
['ঠিক করা', 'নির্ণয় নেওয়া', 'পটানো', 'পাকা করা', 'বেঁকে বসা', 'ভালো করা', 'ভেবে নেওয়া', 'মেরামত করা', 'স্থির করা'] ,
['ঠিক মনে করা', 'বিশ্বাস করা', 'ভরসা করা'] ,
['ঠিক', 'ঠিক ভাবে', 'নির্দিষ্ট', 'নির্ধারিত', 'নিশ্চিত', 'ফিট', 'ভালো ভাবে', 'যথার্থ', 'সত্য'] ,
['ঠিকঠাক', 'ফিট', 'ভালো', 'সোজাপথে'] ,
['ঠুঁটো', 'হস্তবিহীন', 'হাতবিহীন'] ,
['ঠেলা', 'ঠেলা গাড়ি', 'হাতঠেলা'] ,
['ঠেলাঠেলি', 'ধাক্কাধাক্কি'] ,
['ঠেলে দেওয়া', 'সঁপে দেওয়া', 'সমর্পণ করা'] ,
['ঠোঁটকাটা', 'দুর্মুখ', 'স্পষ্টবাদী'] ,
['ঠোকর', 'ধাক্কা'] ,
['ঠোক্কর লাগা', 'ধাক্কা লাগা'] ,
['ঠোক্কর', 'ধাক্কা'] ,
['ঠ্যাকা দেওয়া', 'দাঁড় করানো'] ,
['ড', 'ব্যঞ্জনবর্ণ ড়'] ,
['ডংগ', 'ভিয়েতনামি ডংগ'] ,
['ডঃ আম্বেদকার', 'ডঃভীমরাও আম্বেদকার'] ,
['ডপোরিজো', 'ডপোরিজো শহর'] ,
['ডব্লু এইচ ও', 'বিশ্ব স্বাস্থ্য সংস্থা', 'হু'] ,
['ডমরু', 'ডুগডুগি'] ,
['ডমিনিক ডলার', 'ডলার'] ,
['ডমিনিকান পেসো', 'পেসো'] ,
['ডলার', 'তাইওয়ানি ডলার', 'ত্রিনিদাদ ও টোবাগোর ডলার', 'নিউজিল্যান্ডী ডলার', 'ফিজি ডলার', 'বারমুডার ডলার', 'বাহামার ডলার', 'লিবেরিয়ান ডলার', 'সিঙ্গাপুরি ডলার', 'হংকং ডলার'] ,
['ডহোম', 'বেনিন'] ,
['ডা. মনমোহন সিং', 'মনমোহন সিং'] ,
['ডাঁশ', 'বড় মশা', 'বনমাছি'] ,
['ডাঁয়া', 'তবলা'] ,
['ডাঁয়ে-বাঁয়ে', 'ডানদিক-বাঁদিক'] ,
['ডাই', 'রঙ'] ,
['ডাইনি', 'ডাকিনী', 'দজ্জাল', 'পিশাচিনী', 'পেত্নী'] ,
['ডাউনলোড', 'ডাউনলোড করা', 'ডাউনলোডিং'] ,
['ডাউরাউকাউলী', 'ডাউরাউকাউলী বাঁদর'] ,
['ডাক খরচা', 'ডাক ব্যয়', 'ডাক-ব্যয়'] ,
['ডাক', 'শূণ্য', 'হাঁক', 'হাঁকা'] ,
['ডাক-টিকিট', 'ডাকটিকিট', 'স্ট্যাম্প'] ,
['ডাকগাড়ী', 'মেল'] ,
['ডাকঘর', 'পোস্ট-অফিস', 'পোস্ট-আপিস'] ,
['ডাকা', 'বলা', 'সম্বোধন', 'সম্বোধিত'] ,
['ডাকাত', 'দস্যু'] ,
['ডাঙ্গ', 'ডাঙ্গ জেলা'] ,
['ডাচ্ গায়ানা', 'নীদরল্যাঁণ্ড গুয়েনা', 'সুরিনাম'] ,
['ডাটাফাইল', 'ডেটাফাইল', 'ফাইল'] ,
['ডাণ্ডা', 'লাঠি'] ,
['ডানা', 'পাখনা'] ,
['ডানাওলা', 'ডানাযুক্ত'] ,
['ডানাবিহীন', 'পাখাবিহীন'] ,
['ডান্ডিয়া', 'ডান্ডিয়া রাস', 'দান্ডিয়া'] ,
['ডান্স পার্টি', 'নাচের আসর'] ,
['ডাফ', 'ডাফলি'] ,
['ডাল', 'ডাল ঝিল', 'ডাল লেক', 'শাখা'] ,
['ডাল-পিঠা', 'ডাল-পিঠে'] ,
['ডালা', 'ডালি'] ,
['ডায়টিং', 'মিতাহার'] ,
['ডায়বেটোলজিস্ট', 'মধুমেহ বিশেষজ্ঞ'] ,
['ডায়রেক্টর অফিস', 'নির্দেশালয়'] ,
['ডায়রেক্টোরেট', 'নির্দেশক মণ্ডলী', 'নির্দেশালয়', 'সঞ্চালক-মণ্ড'] ,
['ডায়াফ্রাম', 'তনুপট'] ,
['ডায়াবেটিক', 'মধুমেহ রোগী', 'মধুমেহী'] ,
['ডায়াবেটিস', 'মধুমেহ'] ,
['ডায়ামিটার', 'ব্যাস'] ,
['ডায়েরি', 'দৈনন্দিনী', 'দৈনিকী', 'রোজনামচা'] ,
['ডি এন এ', 'ডিঅক্সিরাইবোনিউক্লিক অম্ল', 'ডিঅক্সিরাইবোনিউক্লিক অ্যাসিড'] ,
['ডি-ব্যাঙ্ক', 'বিকাশ ব্যাঙ্ক'] ,
['ডিআডিও', 'রক্ষা অনুসন্ধান এবং বিকাশ সংগঠন'] ,
['ডিকেন্স', 'ডিকেন্স আম', 'ডিকেন্স আম গাছ'] ,
['ডিগ্রী', 'ডিগ্রী সেলসিয়াস'] ,
['ডিঙানো', 'লঙ্ঘন করা'] ,
['ডিঙ্গল', 'ডিঙ্গল ভাষা'] ,
['ডিঙ্গোচ', 'সীঙ্কপার'] ,
['ডিজাইন', 'নকশা', 'নমুনা', 'প্রতিরূপ', 'মডেল', 'রূপরেখা'] ,
['ডিজাইনার', 'পরিকল্পক'] ,
['ডিজিক্যাম', 'ডিজিটাল ক্যামেরা'] ,
['ডিটেক্টর', 'সূচক'] ,
['ডিনার', 'নৈশ ভোজ', 'নৈশভোজ'] ,
['ডিপার্টমেন্ট', 'বিভাগ'] ,
['ডিপ্লোমা', 'ডিপ্লোমা প্রমাণপত্র'] ,
['ডিফুসান', 'ব্যাপন'] ,
['ডিফেন্স', 'প্রতিরক্ষামূলক টিম', 'প্রতিরক্ষামূলক দল'] ,
['ডিবান', 'তক্তা'] ,
['ডিব্বা', 'ডিব্বে'] ,
['ডিব্রুগড়', 'ডিব্রুগড় জেলা', 'ডিব্রুগড় শহর'] ,
['ডিভোর্সী', 'বিবাহবিচ্ছিন্ন পতি বা পত্নী'] ,
['ডিম', 'ডিম্ব'] ,
['ডিমওয়ালা', 'ডিমভরা'] ,
['ডিম্বাকার', 'ডিম্বাকৃতি'] ,
['ডিম্বাণু', 'স্ত্রী জনন কোষ'] ,
['ডিরেক্টার', 'নির্দেশক'] ,
['ডিল্লা', 'তিলকা', 'বনিতা'] ,
['ডিস্ক', 'রেকর্ড'] ,
['ডুংগরপুর', 'ডুংগরপুর জেলা', 'ডুংগরপুর শহর'] ,
['ডুবতে থাকা', 'পিছিয়ে থাকা'] ,
['ডুবানো', 'ডুবিয়ে দেওয়া', 'ডোবানো'] ,
['ডুবে যাওয়া', 'ডোবা'] ,
['ডুমুর', 'ডুমুর গাছ'] ,
['ডুলি', 'পাল্কী'] ,
['ডেগ', 'হাঁড়ি'] ,
['ডেট করা', 'মিলিত হওয়া'] ,
['ডেড সি', 'মৃত সাগর'] ,
['ডেনমার্কবাসী', 'ডেনমার্কীয়'] ,
['ডেনমার্কীয় ভাষা', 'ডেনিশ'] ,
['ডেনমার্কীয়', 'ডেনিশ'] ,
['ডেভিল ডগ', 'মেরিন', 'সীপবোর্ড সোলজার'] ,
['ডেভিস-হেডন', 'ডেভিস-হেডন আম', 'ডেভিস-হেডন আমের গাছ'] ,
['ডেরা জমানো', 'থাকা'] ,
['ডেলটা', 'ডেল্টা'] ,
['ডেলা', 'ঢিল'] ,
['ডেলাওয়ার', 'ডেলাওয়ার নদী'] ,
['ডেল্টা', 'ব-দ্বীপ'] ,
['ডেয়ারি', 'দুগ্ধজাত', 'দুগ্ধশালা'] ,
['ডোজ', 'মাত্রা'] ,
['ডোডা', 'ডোডা জেলা', 'ডোডা শহর'] ,
['ডোবা', 'ডোয়া'] ,
['ডোমিনিকা বাসী', 'ডোমিনিকান'] ,
['ডোমিনিকান গণতন্ত্র', 'ডোমিনিকান গণরাজ্য', 'ডোমিনিকান রিপাবলিক'] ,
['ডোসা', 'দোসা'] ,
['ড্রপ খাওয়া', 'লাফানো'] ,
['ড্রাইভ', 'যানবাহনে ভ্রমণ', 'রাইড'] ,
['ড্রাফ্ট', 'ব্যাঙ্ক-হুন্ডি'] ,
['ড্রিল', 'ড্রিলিঙ্গ মেশীন'] ,
['ড্রয়ার', 'দেরাজ'] ,
['ঢ', 'ব্যঞ্জনবর্ণ ঢ়'] ,
['ঢং', 'পাঁয়তারা', 'ভঙ্গি', 'মুদ্রা'] ,
['ঢাকা', 'ঢেকে রাখা', 'পাতা', 'বিছানো'] ,
['ঢাল', 'পটা'] ,
['ঢালা', 'পোরা', 'ভরা', 'রাখা'] ,
['ঢালানো', 'পোরানো', 'রাখানো'] ,
['ঢালু ছাত', 'বরাসাতি ছাত'] ,
['ঢালু', 'প্রবণ'] ,
['ঢিমে', 'মিহি', 'হাল্কা'] ,
['ঢিল', 'ঢিলি'] ,
['ঢিলা', 'ঢিলে', 'ঢিলেঢালা'] ,
['ঢিলে', 'শিথিল'] ,
['ঢুঁঢলা', 'ঢুঁঢা'] ,
['ঢুকিয়ে দেওয়া', 'ঢোকানো', 'প্রবেশ করানো'] ,
['ঢুলি', 'ঢোলবাদক'] ,
['ঢেউ তোলা', 'দোলা'] ,
['ঢেউ', 'তরঙ্গ'] ,
['ঢেলা', 'পিন্ড', 'মন্ড'] ,
['ঢোকা', 'প্রবিষ্ট হওয়া', 'প্রবেশ করা'] ,
['ঢোকানো', 'পোঁতা'] ,
['ণ', 'ব্যঞ্জনবর্ণ ণ'] ,
['ত', 'ব্যঞ্জনবর্ণ ত'] ,
['তক্তা', 'পাটা', 'পাটাতন', 'পাল্লা'] ,
['তক্ষক', 'তক্ষক নাগ'] ,
['তছ-নছ করা', 'বিক্ষিপ্ত করা'] ,
['তট-রেখা', 'তটরেখা'] ,
['ততপশ্চাত্', 'তদোপরান্ত', 'তারপর'] ,
['ততসম', 'ততসম শব্দ'] ,
['তত্ত্ব', 'ভূত', 'মূল দ্রব্য', 'রাসায়নিক তত্ত্ব', 'সত্ত্ব'] ,
['তত্ত্বগত', 'তাত্ত্বিক', 'পাণ্ডিত্যপূর্ণ'] ,
['তত্ত্বজ্ঞ', 'তত্ত্বদর্শী', 'তাত্ত্বিক', 'দর্শন শাস্ত্রী', 'দর্শনশাস্ত্রী', 'দার্শনিক'] ,
['তত্ত্বাবধান', 'প্রহরা', 'রক্ষণাবেক্ষন', 'হেফাজত'] ,
['তত্পুরুষ', 'তত্পুরুষ সমাস'] ,
['তত্বজ্ঞান', 'দর্শন', 'মতবাদ'] ,
['তথ্য', 'প্রমাণ', 'সাক্ষ্য'] ,
['তথ্যপূর্ণ', 'প্রামাণিক', 'সারপূর্ণ'] ,
['তথ্যান্বেষণ', 'তদন্ত'] ,
['তদনুকূল', 'তদনুরূপ', 'তদনুসার', 'তদনুসারে'] ,
['তদর্থক', 'তদর্থে'] ,
['তদারকি', 'দেখাশুনো', 'নজর', 'নিরীক্ষণ', 'পর্যবেক্ষণ'] ,
['তদ্ভব', 'তদ্ভব শব্দ'] ,
['তনক', 'তনক রাগিনী'] ,
['তনুধারী', 'দেহধারী', 'দেহবান', 'শরীরধারী', 'শরীরী', 'সশরীরী'] ,
['তন্ডি', 'তন্ডি ঋষি'] ,
['তন্ডুলী', 'নকুলী', 'নাকুল', 'বিশ্বা', 'যবতিক্তা', 'শঙ্খিনী'] ,
['তন্তু বাদ্য', 'তন্ত্রী বাদ্য', 'তার বাদ্য'] ,
['তন্তু', 'সুতা', 'সুতো'] ,
['তন্তুবাদক', 'তন্ত্রী'] ,
['তন্ত্র ক্রিয়া', 'ষষ্টকর্ম'] ,
['তন্ত্র', 'তন্ত্র বিদ্যা', 'তন্ত্র শাস্ত্র', 'তন্ত্রবিদ্যা', 'তন্ত্রশাস্ত্র', 'ব্যবস্হা', 'রাজতন্ত্র', 'রাজ্য তন্ত্র', 'রাজ্য-তন্ত্র', 'রাজ্যতন্ত্র', 'শাসন তন্ত্র', 'শাসন-তন্ত্র', 'শাসনতন্ত্র'] ,
['তন্ত্রি', 'তন্রিকা', 'নাড়ী', 'রক্ত বাহিকা', 'রক্ত বাহিনী', 'স্নায়ু'] ,
['তন্ত্রিকা কোষিকা', 'নিউরন'] ,
['তন্ত্রী', 'তাঁত', 'তার', 'বাদ্য তার'] ,
['তন্দ্রালু', 'নিদ্রালু'] ,
['তন্দ্রিলসন্নিপাত', 'তন্দ্রিলসন্নিপাত রোগ'] ,
['তন্ময় হওয়া', 'বিলীন হওয়া'] ,
['তন্ময়', 'নিমগ্ন', 'বিনিষ্ট', 'মশগুল', 'লিপ্ত', 'লীন'] ,
['তপ', 'তপস্যা'] ,
['তপস্বিনী', 'তাপসী', 'যোগিনী'] ,
['তপস্বী', 'তাপস', 'ত্যাগী', 'যোগী', 'সন্ন্যাসী'] ,
['তপস্বীনি', 'তাপসী'] ,
['তফন', 'লুঙ্গী'] ,
['তফাত্ বোঝা', 'পার্থক্য বোঝা'] ,
['তবক', 'পরত', 'স্তর'] ,
['তবক্ষীর', 'বংশলোচন'] ,
['তবলচী', 'তবলা-বাদক', 'তবলাবাদক'] ,
['তবা', 'তবা নদী'] ,
['তবাঙ্গ', 'তবাঙ্গ জেলা', 'তবাঙ্গ শহর'] ,
['তবু', 'তা সত্ত্বেও', 'তাও'] ,
['তম', 'তমোগুণ'] ,
['তমাল', 'তমাল গাছ'] ,
['তমালপাতা', 'তেজপাতা'] ,
['তমেঙ্গলাঙ্গ', 'তমেঙ্গলাঙ্গ জেলা', 'তমেঙ্গলাঙ্গ শহর'] ,
['তমোগুণযুক্ত', 'তামসিক', 'তামসী'] ,
['তম্বুর', 'তম্বুরা', 'তানপুরা'] ,
['তম্বুরাবাদক', 'তানপুরাবাদক'] ,
['তরকারি', 'সব্জি'] ,
['তরঙ্গ', 'স্রোত'] ,
['তরণি', 'নৌকা'] ,
['তরফদারি', 'পক্ষপাত', 'ভেদভাব'] ,
['তরবর', 'তরোতা'] ,
['তরল আহার', 'তরল খাদ্য পদার্থ'] ,
['তরল-গতিবিজ্ঞান', 'তরল-গতিশক্তি'] ,
['তরাজু', 'তুলাদণ্ড', 'দাঁড়িপাল্লা', 'নিক্তি'] ,
['তরী', 'বনহটী'] ,
['তরুণ', 'যুবক', 'যুবা'] ,
['তরুণী', 'যুবতী'] ,
['তরুশালা', 'নার্সারি', 'পুষ্পগৃহ'] ,
['তর্ক বিতর্ক করা', 'বাত বিতণ্ডা করা', 'বিবাদ করা'] ,
['তর্ক বিতর্ক', 'বাদ বিবাদ', 'বিবাদ বিসম্বাদ', 'সওয়াল জবাব'] ,
['তর্ক', 'যুক্তি'] ,
['তর্ক-শাস্ত্রী', 'তর্কশাস্ত্রজ্ঞ', 'তর্কশাস্ত্রী', 'তার্কিক'] ,
['তর্কক', 'তর্কচঞ্চু', 'তর্কপটু', 'তর্কী', 'বাদক'] ,
['তর্ককারক', 'তার্কিক'] ,
['তর্কগম্য', 'তর্কসংগত', 'তর্কাধীন'] ,
['তর্কশাস্ত্র', 'হেতুবাদ'] ,
['তর্কহীন', 'যুক্তিহীন'] ,
['তর্পণ', 'পিতৃতর্পণ', 'পিতৃযজ্ঞ'] ,
['তল', 'তলা', 'দিক', 'স্তর'] ,
['তলওয়াড়ী', 'তলওয়াড়ী জেলা', 'তলওয়াড়ী শহর'] ,
['তলা', 'পায়া', 'সোল'] ,
['তলার', 'নীচের'] ,
['তলোয়ার', 'ধোপ'] ,
['তলোয়ারবাজি', 'শমশেরবাজি'] ,
['তল্প', 'বাঙ্ক'] ,
['তল্লাশি', 'তল্লাশী', 'বিবস্ত্র করে তল্লাশি'] ,
['তসরের ধুতি', 'মটকার ধুতি'] ,
['তহবিলদার', 'রেকর্ড কীপার'] ,
['তহসিল', 'মহকুমা'] ,
['তাঁত', 'লুম'] ,
['তাইবানবাসী', 'তাইবানী'] ,
['তাক্ষ্রপ্রসব', 'তাক্ষ্রপ্রসব গাছ'] ,
['তাগড়া', 'মোটা', 'ষণ্ডা', 'হৃষ্টপুষ্ট'] ,
['তাগতুম্বী', 'পাতালতুম্বী'] ,
['তাগা', 'মঙ্গলসূত্র'] ,
['তাজ', 'তাজমহল', 'মুকুট', 'শিরমোর'] ,
['তাজা হাওয়া', 'শুদ্ধ হাওয়া'] ,
['তাজা', 'তাজাভাব'] ,
['তাজিক', 'তাজিক ভাষা'] ,
['তাঞ্জানিয়া নিবাসী', 'তাঞ্জানিয়ান'] ,
['তাঞ্জানিয়া', 'তাঞ্জানিয়া সংঘীয় গণরাজ্য'] ,
['তাঞ্জানিয়ান', 'তাঞ্জানিয়ার', 'তাঞ্জানীয়'] ,
['তাঞ্জাবুর শহর', 'তাঞ্জোর'] ,
['তাঞ্জাবুর', 'তাঞ্জাবুর জেলা', 'তাঞ্জোর'] ,
['তাড়া করা', 'ধাওয়া করা', 'পিছনে যাওয়া'] ,
['তাড়াতাড়ি করে', 'শীঘ্র ভাবে', 'শীঘ্রতঃ'] ,
['তাড়ানো', 'দৌঁড় করানো', 'বার করা', 'বিতাড়িত করা'] ,
['তাড়াহুড়ো', 'হড়বড়'] ,
['তাড়ি', 'তালরস'] ,
['তাড়ী আবাবিল', 'তাল চটক'] ,
['তাড়ু', 'দর্বি', 'দর্বিক', 'হাতা'] ,
['তাণ্ডব', 'তাণ্ডব নৃত্য'] ,
['তাতার ভাষা', 'তাতারীয় ভাষা'] ,
['তাতার', 'তাতার দেশ'] ,
['তাতারীয়', 'তাতারের'] ,
['তাত্ক্ষণিক বুদ্ধি', 'হঠাত্ এসে যাওয়া দারুণ কোনো বুদ্ধি'] ,
['তাপ-প্লীহা', 'প্লীহা'] ,
['তাপজনিত', 'রৌদ্রজনিত'] ,
['তাপমাপক যন্ত্র', 'তাপমাপার যন্ত্র', 'থার্মোমিটার'] ,
['তাপ্পি লাগানো', 'রিফু করা'] ,
['তামাক', 'তাম্বাকু', 'নাগবল্লরী', 'পাতাবাসিনী', 'পান', 'পান করা', 'রঙ্গবল্লিকা', 'শুকনো তামাক', 'সর্পলতা'] ,
['তামার', 'তাম্র'] ,
['তামিল', 'তামিল ভাষা', 'তামিল লিপি'] ,
['তামিস্ত্র', 'তামিস্ত্র নরক'] ,
['তাম্বুল', 'পান'] ,
['তাম্বুলিনী', 'তাম্বুলীনি'] ,
['তাম্র ফলক', 'তাম্রপত্র'] ,
['তাম্রপুষ্পী', 'ধাই', 'ধাবরা', 'ধৌ', 'নন্দীতরু', 'শিজওয়া', 'শুক্লবৃক্ষ', 'সিধুপুষ্পী', 'সিন্দুরী'] ,
['তাম্রবর্ণ', 'পিঙ্গল'] ,
['তার উপর', 'তার ওপর'] ,
['তার উপরে', 'তার সঙ্গে'] ,
['তার কবজ', 'শেকল কবজ'] ,
['তার', 'তারক', 'তারবৃত্ত'] ,
['তারক', 'তারক মন্ত্র', 'তারকব্রহ্ম'] ,
['তারকা', 'তারা', 'তারা দেবী', 'নক্ষত্র'] ,
['তারণ', 'তারণকর্তা'] ,
['তারনা', 'বীরনি'] ,
['তারপীন', 'তারপীন তেল'] ,
['তারসার', 'তারসার উপনিষদ', 'তারসারোপনিষদ'] ,
['তারা ভরা', 'তারাঙ্কিত', 'তারাযুক্ত'] ,
['তারা', 'তারা চিহ্ন', 'তারাচিহ্ন', 'নক্ষত্র', 'স্টার'] ,
['তারানা', 'স্বর মাধুর্য'] ,
['তারাবিহীন', 'তারাহীন'] ,
['তারাভ', 'নারদ'] ,
['তারামণ্ডল', 'নক্ষত্রমণ্ডল', 'প্ল্যানেটরিয়াম'] ,
['তারারন্ধ্র', 'লেন্স'] ,
['তারুণ্য', 'যুবাবস্থা', 'যৌবন'] ,
['তার্ক্ষ্য', 'তার্ক্ষ্যশৈল', 'রসরাজ', 'রসাগ্য', 'রসাগ্রজ', 'রসাঞ্জন'] ,
['তাল কারী', 'লয় কারী'] ,
['তাল বাদ্য', 'তালবাদ্য'] ,
['তাল মাত্রা', 'মাত্রা'] ,
['তাল', 'তাল গাছ', 'তালবৃক্ষ', 'মণ্ড', 'মদাঢ্য'] ,
['তাল-বন', 'তালবন'] ,
['তালকন্দ', 'তালপত্রিকা', 'তালমূলিকা', 'তালমূলী', 'মুসলী'] ,
['তালগোণ্ডা', 'তালগোণ্ডা জেলা', 'তালগোণ্ডা শহর'] ,
['তালবিহীন', 'বেতালা'] ,
['তালব্য', 'তালব্য বর্ণ'] ,
['তালমিল রাখা', 'মানিয়ে নেওয়া'] ,
['তালাক', 'বিবাহ-বিচ্ছেদ', 'বিবাহবিচ্ছেদ'] ,
['তালিকা', 'লগ', 'সারণী'] ,
['তালিকা-পুস্তক', 'নিবন্ধগ্রন্থ', 'পঞ্জি-পুস্তক', 'রেজিস্টার'] ,
['তালিকাবদ্ধ', 'সূচীবদ্ধ'] ,
['তালিকাভুক্ত', 'নথীভুক্ত'] ,
['তালিম', 'পড়াশোনা', 'শিক্ষা', 'শিক্ষা-দিক্ষা', 'শিক্ষাগত যোগ্যতা'] ,
['তালু', 'পদতল', 'পাঞ্জা', 'পাতা'] ,
['তালের', 'পুকুরের'] ,
['তাল্বর্বুদ', 'তাল্বর্বুদ রোগ'] ,
['তাসের ফোঁটা', 'ফোঁটা', 'বুটি'] ,
['তিউনিশিয়ার', 'তিউনিশীয়'] ,
['তিক্ত', 'তিতা', 'তেতো'] ,
['তিতিক্ষ', 'তিতিক্ষ ঋষি'] ,
['তিত্তিরি', 'তিত্তিরি ঋষি'] ,
['তিথি', 'দিন', 'দিবস'] ,
['তিন দিন', 'ত্রিবাসর'] ,
['তিন মাথার মোড়', 'ত্রীমার্গী'] ,
['তিন', 'তিন তারিখ', 'ত্রয়', '৩,'] ,
['তিনচাকাবিশিষ্ট', 'তিনচাকার'] ,
['তিনদিক থেকে', 'তিনদিকের'] ,
['তিনদিনের বাসি', 'বাসি'] ,
['তিনপায়া', 'তেপায়া'] ,
['তিনবেলা', 'সারাদিন'] ,
['তিনরঙা', 'তিনরঙা পতাকা', 'ত্রিবর্ণ রঞ্জিত', 'ত্রিবর্ণ রঞ্জিত পতাকা'] ,
['তিনশ', '৩০০'] ,
['তিনসুকিয়া', 'তিনসুকিয়া জেলা', 'তিনসুকিয়া শহর'] ,
['তিনিশ', 'রথদ্রু'] ,
['তিনেক', 'প্রায় তিনটে'] ,
['তিনের দুই ভাগ', 'দুই তৃতীয়াংশ'] ,
['তিপান্ন', '৫৩'] ,
['তিফলিস', 'ত্বিলিসী'] ,
['তিব্বতী', 'তিব্বতী লিপি'] ,
['তিমি', 'রাতকানা', 'রাতকানা রোগ'] ,
['তিমিধ্বজ', 'শম্বর'] ,
['তিরঙ্গা', 'ভারতীয় ধ্বজা', 'ভারতীয় পতাকা'] ,
['তিরপ', 'তিরপ জেলা'] ,
['তিরপল', 'তেরপল', 'ত্রিপল'] ,
['তিরস্কিরিণী', 'তিরস্কিরিণী বিদ্যা'] ,
['তিরানব্বই', '৯৩', '৯৩,'] ,
['তিরাশি', '৮৩', '৮৩,'] ,
['তিরিশ', 'ত্রিশ', '৩০'] ,
['তিরুনেল্লবেলি', 'তিরুনেল্লবেলি জেলা', 'তিরুনেল্লবেলি শহর'] ,
['তিরুবনন্তপুরম', 'তিরুবনন্তপুরম জেলা'] ,
['তিরুবন্তপুরম', 'তিরুবন্তপুরম শহর', 'ত্রিবান্দ্রাম'] ,
['তিরুবন্নামালাই', 'তিরুবন্নামালাই জেলা', 'তিরুবন্নামালাই শহর'] ,
['তিরুবরুর', 'তিরুবরুর জেলা', 'তিরুবরুর শহর'] ,
['তিরুবল্লুর', 'তিরুবল্লুর জেলা', 'তিরুবল্লুর শহর'] ,
['তিরোধান দিবস', 'মৃত্যু বার্ষিকী', 'মৃত্যুদিবস'] ,
['তির্যক', 'র্কণ'] ,
['তিলওয়াসিনী', 'রাজপ্রিয়া'] ,
['তিলক কামোদ', 'তিলককামোদ'] ,
['তিলকুট', 'তিলের নাড়ু'] ,
['তিলপট্টী', 'তিলপাপড়ি'] ,
['তিলপিঞ্জ', 'তৈলপিঞ্জ'] ,
['তিলারী', 'তিলোহরা', 'পাটের তন্তু'] ,
['তিল্ব', 'তৈল্বক', 'বলভদ্র', 'মার্জন', 'লোধ', 'লোধবৃক্ষ', 'শাবর', 'শালক', 'শুক'] ,
['তিল্লর', 'হোভার'] ,
['তিষ্ঠা', 'তিষ্ঠা নদী'] ,
['তিসমার খাঁ', 'তিসমার খান'] ,
['তিসি', 'মসিনা'] ,
['তিস্তা', 'তিস্তা নদী'] ,
['তিহরি', 'তিহরি গাড়োয়াল জেলা', 'তিহরি শহর'] ,
['তিয়াত্তর', '৭৩', '৭৩,'] ,
['তীক্ষ্ণ', 'তীব্র', 'ধারালো', 'প্রখর', 'বিষম'] ,
['তীক্ষ্ণক', 'মুষ্ক', 'মুষ্কক', 'মোখা'] ,
['তীক্ষ্ণগন্ধা', 'রাই'] ,
['তীক্ষ্ণতা', 'তীব্রতা', 'তেজী', 'প্রখরতা', 'প্রচন্ডতা', 'বেগ'] ,
['তীজ', 'তৃতীয়া', 'তৃতীয়া তিথি'] ,
['তীব্র করা', 'দ্রুত করা', 'বাড়িয়ে দেওয়া'] ,
['তীব্র গতি', 'দ্রুত গতি'] ,
['তীব্র গতিতে', 'দ্রুত গতিতে'] ,
['তীব্রতা', 'প্রবলতা'] ,
['তীর', 'বাণ', 'শর'] ,
['তীরন্দাজ', 'ধনুর্ধর', 'ধনুর্ধরী', 'ধনুর্ধারী'] ,
['তীরন্দাজী', 'ধনুর্বিদ্যা'] ,
['তীর্থ যাত্রা', 'তীর্থযাত্রা', 'তীর্থাটন', 'যাত্রা'] ,
['তীর্থ স্থল', 'তীর্থস্থান'] ,
['তীর্থ', 'তীর্থ সন্ন্যাসী'] ,
['তীর্থ-যাত্রী', 'তীর্থযাত্রী', 'তীর্থসেবক', 'তীর্থাটক'] ,
['তীর্থপাদীয়', 'বিষ্ণুভক্ত', 'বৈষ্ণব'] ,
['তীসা', 'শ্বেতনেত্র গরুড়'] ,
['তুইবাই', 'তুইবাই নদী'] ,
['তুকারাম', 'তুকোবা', 'সন্ত তুকারাম'] ,
['তুগ্র', 'তুগ্র ঋষি'] ,
['তুঙ্গ', 'তুঙ্গা'] ,
['তুঙ্গনাথ', 'তুঙ্গনাথ মহাদেব', 'তুঙ্গনাথ শিখর'] ,
['তুঙ্গভদ্রা', 'তুঙ্গভদ্রা নদী'] ,
['তুচ্ছতা', 'নগণ্যতা', 'হীনতা'] ,
['তুতিকোরিন শহর', 'তুতুকুরি', 'তুতুকুরি শহর'] ,
['তুতিকোরিন', 'তুতুকুরি', 'তুতুকুরি জেলা'] ,
['তুবড়ানো', 'মুচড়ানো'] ,
['তুবরা', 'বিনা'] ,
['তুমকুর', 'তুমকুর জেলা', 'তুমকুর শহর'] ,
['তুমারিয়া সুতা', 'তুমারিয়া সুতো'] ,
['তুম্বরু', 'তুম্বুরু'] ,
['তুরা', 'তুরা শহর'] ,
['তুরী', 'তুর্য্য'] ,
['তুরী-বাদক', 'তুরীবাদক'] ,
['তুরীয়াতীত', 'তুরীয়াতীত উপনিষদ', 'তুরীয়াতীতোপনিষদ'] ,
['তুর্কমেনিস্তানবাসী', 'তুর্কমেনিস্তানী'] ,
['তুর্কমেনিস্তানী মনেট', 'মনেট'] ,
['তুর্কি লীরা', 'লীরা'] ,
['তুর্কি', 'তুর্কি ভাষা', 'তুর্কিস্তানবাসী'] ,
['তুর্বশ', 'তুর্বসু'] ,
['তুলতুলে', 'নরম'] ,
['তুলনীয়', 'তুল্য'] ,
['তুলসী পত্র', 'তুলসী-পত্র', 'তুলসীপত্র', 'তুলসীপাতা'] ,
['তুলসী', 'শ্রীমঞ্জরী'] ,
['তুলসীতলা', 'তুলসীমণ্ডপ'] ,
['তুলা', 'তুলা রাশি', 'তুলা রাশিবিশিষ্ট', 'তুলারাশি'] ,
['তুলাযন্ত্র', 'দাড়িপাল্লা'] ,
['তুলি', 'তুলি কলম', 'তুলিকা', 'ব্রাশ'] ,
['তুলু', 'তুলু ভাষা'] ,
['তুলে নেওয়া', 'ফিরিয়ে নেওয়া', 'ফেরত্ নেওয়া'] ,
['তুলো লাগানো কাঠি', 'ফুরেরি'] ,
['তুষ', 'ধান্যাস্থি', 'ভুসি'] ,
['তুষার', 'তুহিন', 'হিম'] ,
['তুষারকণা', 'বরফকণা', 'হিমকণা'] ,
['তুষারপাত', 'হিমপাত'] ,
['তুষারাবৃত', 'বরফযুক্ত', 'বরফাবৃত'] ,
['তুষিত', 'ভদ্র'] ,
['তুষ্ট করা', 'সন্তুষ্ট করা'] ,
['তুষ্ট হওয়া', 'তৃপ্ত হওয়া', 'সন্তুষ্ট হওয়া'] ,
['তুষ্ট', 'তৃপ্ত', 'সন্তুষ্ট'] ,
['তূণ', 'তূণীর'] ,
['তূরী', 'তূর্য', 'রোশনচৌকী', 'সানাই'] ,
['তৃণকর্ণ', 'তৃণকর্ণ'] ,
['তৃণকুটির', 'পর্ণ-শালা', 'পর্ণকুটিকা', 'পর্ণকুটির', 'পর্ণশালা'] ,
['তৃণকেতকী', 'তৃণকেতু'] ,
['তৃণগ্রন্থী', 'স্বর্ণজীবন্তী'] ,
['তৃণজীবী', 'তৃণভোজী'] ,
['তৃণপত্রী', 'তৃণপ্রত্রিকা'] ,
['তৃণভোজী', 'শাকাহারী'] ,
['তৃণমণি', 'তৈলস্ফটিক', 'পীতাভ বাদামী মণি'] ,
['তৃতীয় গিয়ার', 'থার্ড গিয়ার'] ,
['তৃতীয় বন্ধনী', 'তৃতীয় বন্ধনী চিহ্ন'] ,
['তৃতীয়', '৩য়'] ,
['তৃপপ্রিয়া', 'পিন্ড-খেজুর', 'পিন্ডখেজুর', 'ফলপুষ্পা', 'ফলপুষ্পী'] ,
['তৃষা', 'তৃষ্ণা', 'তেষ্টা', 'পিপাসা'] ,
['তৃষ্ণার্ত', 'পিপাসিত', 'পিপাসী'] ,
['তেঁতুল', 'তেঁতুল গাছ'] ,
['তেইশ', 'তেইশ বছর', '২৩'] ,
['তেঙ্গা', 'থবন'] ,
['তেজস্বিতা', 'প্রভাবশালিতা'] ,
['তেজারতি', 'পণ', 'বাণিজ্য', 'বিপণন', 'ব্যবসা', 'ব্যাপার', 'রোজগার', 'রোজগারী'] ,
['তেজু', 'তেজু শহর'] ,
['তেজো-বিন্দু', 'তেজো-বিন্দু উপনিষদ'] ,
['তেতাল্লিশ', '৪৩', '৪৩,'] ,
['তেত্রিশ', '৩৩', '৩৩,'] ,
['তেনি', 'তেনি জেলা', 'তেনি শহর'] ,
['তেপায়া', 'ত্রিপাদিকা'] ,
['তেরঙ্গা', 'ত্রিবর্ণরঞ্জিত'] ,
['তেরছা চাল', 'বাঁকা ধরণ'] ,
['তেরো', '১৩'] ,
['তেলতেলে', 'তৈলাক্ত'] ,
['তেলতেলেভাব', 'তৈলাক্ততা', 'স্নিগ্ধতা'] ,
['তেলী', 'তেলী জাতি', 'তৈলিক'] ,
['তেলুগু', 'তেলেগু'] ,
['তেলে বেগুনে জ্বলে ওঠা', 'রেগে যাওয়া'] ,
['তেলেগু', 'তেলেগু লিপি'] ,
['তেল্লুর', 'তেল্লুর জেলা', 'তেল্লুর শহর'] ,
['তেষট্টি', '৬৩', '৬৩,'] ,
['তৈত্তিরীয়', 'তৈত্তিরীয় উপনিষদ'] ,
['তৈরি করা', 'নির্মাণ করা', 'বানানো', 'রচনা'] ,
['তৈরি করানো', 'নির্মাণ করানো', 'বানানো'] ,
['তৈরী করা', 'নির্মাণ করা', 'পাকানো', 'বানানো'] ,
['তৈরী করানো', 'বানানো'] ,
['তৈলাক্ত পদার্থ', 'স্নেহ পদার্থ'] ,
['তৈলাঞ্চী', 'মলিয়া'] ,
['তোঙ্গ আম', 'তোঙ্গ দম', 'ব্যাল্ক গোল্ড আম'] ,
['তোতপুরী', 'তোতপুরী আম'] ,
['তোতাপুরি', 'তোতাপুরি আম'] ,
['তোপ খানা', 'তোপখানা'] ,
['তোপান্ন', '৫৩,'] ,
['তোবরুক', 'তোবরুক শহর'] ,
['তোলা', 'রাখা'] ,
['তোল্লাই দেওয়া', 'বাড়ানো'] ,
['ত্বক', 'নির্মোক', 'শল্ক'] ,
['ত্বকের বাইরের আবরণ', 'বাহ্যত্বক'] ,
['ত্বরিত', 'দ্রুত'] ,
['ত্যক্ত', 'পরিত্যক্ত'] ,
['ত্যজনীয়', 'ত্যাজ্য', 'পরিত্যাজ্য', 'বর্জনীয়', 'বর্জ্য'] ,
['ত্যাগ করা', 'পরিত্যাগ করা', 'প্রস্থান করা', 'ব্যাক আউট', 'সরে যাওয়া'] ,
['ত্যাগ', 'ভোগত্যাগ'] ,
['ত্র', 'ব্যঞ্জনবর্ণ ত্র'] ,
['ত্রসদস্যু', 'ত্রসদস্যু'] ,
['ত্রাটক', 'ত্রাটক ছন্দ'] ,
['ত্রাণ পাওয়া', 'সদ্গতি প্রাপ্ত হওয়া'] ,
['ত্রাণ-কার্য', 'ত্রাণকার্য'] ,
['ত্রাণকর্তা', 'ত্রাতা', 'পরিত্রাতা'] ,
['ত্রাস', 'ভীতি', 'ভয়', 'সন্ত্রাস'] ,
['ত্রি-ষিখি', 'ত্রি-ষিখি উপনিষদ'] ,
['ত্রিকালজ্ঞ', 'ত্রিকালদর্শী'] ,
['ত্রিকুট', 'ত্রিমুকুট', 'ত্রিশীর্ষ'] ,
['ত্রিকোণ', 'ত্রিকোণাকার', 'ত্রিভূজ'] ,
['ত্রিকোণা', 'ত্রিকোণীয়', 'ত্রিভূজাকার', 'ত্রিভূজীয়'] ,
['ত্রিগুণাতীত', 'নির্গুণ'] ,
['ত্রিচিরাপল্লি', 'ত্রিচিরাপল্লি জেলা', 'ত্রিচিরাপল্লি শহর'] ,
['ত্রিত', 'ত্রিত ঋষি'] ,
['ত্রিদেব', 'ত্রিমূর্তি', 'দেবত্রয়ী', 'হরিহরপিতামহ'] ,
['ত্রিদোষ', 'সন্নিপাত', 'সন্নিপাত রোগ'] ,
['ত্রিনিদাদ ও টোবাগো', 'ত্রিনিদাদ ও টোবাগো গণরাজ্য'] ,
['ত্রিনিদাদিয়ান', 'ত্রিনিদাদের'] ,
['ত্রিপুর', 'ত্রিপুর উপনিষদ', 'ত্রিপুরোপনিষদ'] ,
['ত্রিপুরমল্লিকা', 'মুক্তাতাভা'] ,
['ত্রিপুরাতপনি', 'ত্রিপুরাতপনি উপনিষদ'] ,
['ত্রিপুরাসুর', 'বক্র', 'বাণ', 'বাণাসুর'] ,
['ত্রিবর্গ', 'ত্রিবর্ণ', 'ত্রিহণ'] ,
['ত্রিবেণী', 'ত্রিবেণী রাগ', 'বেণী'] ,
['ত্রিবেদী', 'ত্রৈবিদ্য'] ,
['ত্রিভুবন', 'ত্রিলোক', 'ত্রৈলোক্য'] ,
['ত্রিভূজাকার', 'ত্রিভূজাকৃতি'] ,
['ত্রিমাসীয়', 'ত্রৈমাসিক'] ,
['ত্রিমুণ্ড', 'ত্রিশিরা'] ,
['ত্রিযামা', 'নিশা', 'নিশি', 'রাত', 'রাত্রি'] ,
['ত্রিলোকতি', 'ত্রিলোকনাথ', 'ত্রিলোকেশ'] ,
['ত্রিশ', 'ত্রিশ বছর'] ,
['ত্রিশির', 'ত্রিশীর্ষ'] ,
['ত্রিশীর্ষক', 'ত্রিশূল', 'পিনাক'] ,
['ত্রিশুলধারী', 'ত্রিশুলি'] ,
['ত্রিশোক', 'ত্রিশোক ঋষি'] ,
['ত্রিসন্ধি', 'ত্রিসন্ধ্যকুসুম'] ,
['ত্রিসামা', 'ত্রিসামা নদী'] ,
['ত্রিসুর পুরম', 'পুরম'] ,
['ত্রিসুর', 'ত্রিসুর জেলা', 'ত্রিসুর শহর'] ,
['ত্রুটি', 'বিকার', 'বিকৃতি'] ,
['ত্রেতা', 'ত্রেতাযুগ'] ,
['ত্রৈবলি', 'ত্রৈবলি ঋষি'] ,
['ত্রোটক', 'ত্রোটক রাগ'] ,
['ত্র্যারুণ', 'ত্র্যারুণ ঋষি'] ,
['ত্রয়োদশী', 'ত্রয়োদশী তিথি'] ,
['থ', 'ব্যঞ্জনবর্ণ থ'] ,
['থআন', 'স্থান'] ,
['থমকে যাওয়া', 'স্তব্ধ হওয়া'] ,
['থমাস মোর', 'মোর', 'স্যার থমাস মোর'] ,
['থর মরুভূমি', 'থর মরুস্থল'] ,
['থরথর-কম্পনী', 'থিরথিরকম্পনী'] ,
['থলথলে', 'মাংসল'] ,
['থলি', 'থলে'] ,
['থলে', 'নাপিতের থলে', 'বস্তা'] ,
['থাই', 'থাই ভাষা', 'থাই লিপি', 'থাইল্যান্ডবাসী', 'থাইল্যান্ডীয়'] ,
['থাইমস', 'থাইমসগ্রন্থি'] ,
['থাকা', 'থেকে যাওয়া', 'নিবাস', 'নিবাস করা', 'বসবাস', 'বসবাস করা', 'বাস করা'] ,
['থান', 'বাথান'] ,
['থানা', 'পুলিশথানা'] ,
['থানে', 'থানে শহর'] ,
['থানেলা', 'স্তনের ফোঁড়া'] ,
['থাবা', 'পাঞ্জা', 'হাত'] ,
['থাম', 'স্তম্ভ'] ,
['থামা', 'বন্ধ হওয়া'] ,
['থামানো', 'থামিয়ে দেওয়া', 'ধরা', 'মিটমাট করা', 'শান্ত করা', 'সমাধাণ করা', 'সামলে নেওয়া'] ,
['থালা', 'পরাত', 'বারকোশ'] ,
['থিতানো', 'স্হির হয়ে যাওয়া'] ,
['থিয়েটার হল', 'সিনেমা হল'] ,
['থিয়েটার', 'নাটক গৃহ', 'নাটক ঘর', 'নাটক-শালা', 'নাটকশালা', 'নাট্য মন্দির', 'নাট্য-শালা', 'নাট্যনিকেতন', 'নাট্যশালা', 'নাট্যশালা', 'রঙ মহল', 'রঙগৃহ', 'রঙ্গ ভবন', 'রঙ্গশালা', 'রঙ্গাবয়'] ,
['থু থু করা', 'নিন্দা করা'] ,
['থুতু', 'পিক'] ,
['থুত্কার', 'ধিক্কার'] ,
['থেকে থেকেই কষ্ট দেওয়া', 'থেকে থেকেই ব্যাথা দেওয়া'] ,
['থেকে যাওয়া', 'রয়ে যাওয়া'] ,
['থেতলানো', 'পেষা'] ,
['থেমে থেমে', 'বিরাম নিয়ে', 'বিশ্রাম নিয়ে'] ,
['থেমে যাওয়া', 'দাঁড়িয়ে থাকা', 'বন্ধ হওয়া'] ,
['থোক', 'পাইকারি'] ,
['থৌবল', 'থৌবল জেলা', 'থৌবল শহর'] ,
['দ', 'ব্যঞ্জনবর্ণ দ'] ,
['দংশন', 'হুল ফোটানো'] ,
['দই বড়া', 'দইবড়া'] ,
['দই', 'দধি'] ,
['দক্ষ সাবর্ণি মনু', 'দক্ষসাবর্ণি'] ,
['দক্ষজা', 'দাক্ষায়ণী', 'সতী'] ,
['দক্ষিণ অয়নান্ত দিবস', 'মকর সংক্রান্তি'] ,
['দক্ষিণ আফ্রিকা সম্পর্কিত', 'দক্ষিণ আফ্রিকার', 'দক্ষিণ আফ্রিকীয়'] ,
['দক্ষিণ আফ্রিকা', 'দক্ষিণ আফ্রিকা গণরাজ্য'] ,
['দক্ষিণ আফ্রিকান', 'দক্ষিণ আফ্রিকাবাসী'] ,
['দক্ষিণ আমেরিকা', 'সাউথ আমেরিকা'] ,
['দক্ষিণ আমেরিকার', 'দক্ষিণ আমেরিকীয়'] ,
['দক্ষিণ আমেরীকি দেশ', 'দক্ষিণ আমেরীকি রাষ্ট্র'] ,
['দক্ষিণ এশীয় আঞ্চলিক সহযোগিতা সংস্থা', 'সাউথ এশিয়ান অ্যাসোসিয়েশন ফর রীজনাল কোঅপরেশন', 'সার্ক'] ,
['দক্ষিণ কন্নড়', 'দক্ষিণ কন্নড় জেলা', 'ম্যাঙ্গালোর', 'ম্যাঙ্গালোর জেলা'] ,
['দক্ষিণ কোরিয়া', 'দক্ষিণ কোরিয়া গণরাজ্য'] ,
['দক্ষিণ কোরিয়ান বান', 'বান'] ,
['দক্ষিণ গারো হিল্স', 'দক্ষিণ গারো হিল্স জেলা'] ,
['দক্ষিণ গোয়া', 'দক্ষিণ গোয়া জেলা', 'দক্ষিণ গোয়া জেলা'] ,
['দক্ষিণ চব্বিশ পরগণা', 'দক্ষিণ চব্বিশ পরগণা জেলা'] ,
['দক্ষিণ ত্রিপুরা', 'দক্ষিণ ত্রিপুরা জেলা'] ,
['দক্ষিণ দিনাজপুর', 'দক্ষিণ দিনাজপুর জেলা'] ,
['দক্ষিণ পশ্চিম', 'দক্ষিণ-পশ্চিম', 'নৈঋত', 'নৈঋত কোণ'] ,
['দক্ষিণ সিকিম', 'দক্ষিণ সিকিম জেলা'] ,
['দক্ষিণাবর্ত', 'দক্ষিণাবর্ত শঙ্খ'] ,
['দক্ষিণামূর্তি', 'দক্ষিণামূর্তি উপনিষদ'] ,
['দক্ষিণী প্রিয়ংবদা', 'ভিয়াকুরো পাখি'] ,
['দখল', 'দখলদারি', 'হস্তক্ষেপ'] ,
['দখলকারী', 'বসবাসকারী'] ,
['দড়ি পাকানো', 'সুতো পাকানো'] ,
['দড়ি', 'রসি'] ,
['দণ্ড দেওয়া', 'শাস্তি দেওয়া'] ,
['দণ্ড পাত্র', 'দণ্ডনীয়'] ,
['দণ্ড', 'বল্লম', 'রাজদণ্ড', 'সাজা'] ,
['দণ্ডক ছন্দ', 'দণ্ডকবৃত্ত'] ,
['দণ্ডক', 'দণ্ডক বন', 'দণ্ডকারণ্য'] ,
['দণ্ডাজ্ঞা', 'দণ্ডাদেশ'] ,
['দণ্ডিত', 'দোষী', 'সাজাপ্রাপ্ত'] ,
['দতিয়া', 'দতিয়া জেলা', 'দতিয়া শহর'] ,
['দত্তক', 'দত্তক নেওয়া', 'দত্তক পুত্র', 'দত্তক সন্তান'] ,
['দত্তাত্রয়', 'দত্তাত্রয় উপনিষদ', 'দত্তাত্রয়োপনিষদ'] ,
['দত্তোলি', 'পুলসত্য', 'পুলসত্য ঋষি', 'পুলসত্যঋষি', 'বেদবাহু'] ,
['দধীচি', 'দধীচি ঋষি'] ,
['দনুজা', 'দানবী'] ,
['দন্ডধর', 'শাসক'] ,
['দন্ডবাসী', 'দারোয়ান', 'দ্বারপতি', 'দ্বারপাল', 'দ্বারপালক', 'দ্বারাধ্যক্ষ'] ,
['দন্ডাধিকারী', 'ম্যাজিস্ট্রেট'] ,
['দন্ত চিকিত্সক', 'দন্ত-চিকিত্সক', 'দাঁত চিকিত্সক'] ,
['দন্ত বিষয়ক', 'দন্তীয়', 'দন্ত্য'] ,
['দন্ত', 'দাঁত', 'রদন'] ,
['দন্ত-চিকিত্সা বিজ্ঞান', 'দন্ত-চিকিত্সা শাস্ত্র', 'দন্তচিকিত্সা বিজ্ঞান', 'দন্তচিকিত্সা শাস্ত্র'] ,
['দন্তপংক্তি', 'দাঁতের পাটি'] ,
['দন্তযুক্ত', 'দন্তুর', 'দাঁতওয়ালা', 'দাঁতালো', 'দেঁতো'] ,
['দন্তেওয়াড়া', 'দন্তেওয়াড়া শহর'] ,
['দপ দপ করে জ্বালানো', 'দাউ দাউ করে জ্বালানো'] ,
['দফা', 'ধারা', 'নিয়ম', 'পদ', 'পর্যায়', 'বার', 'বিষয়', 'রাউন্ড', 'সামগ্রী'] ,
['দম বন্ধ করা', 'বদ্ধ'] ,
['দম বন্ধ হওয়া', 'নিশ্বাস আটকানো', 'শ্বাসরোধ হওয়া'] ,
['দম', 'ফুঁ'] ,
['দমন এবং দিউ', 'দমন-দিউ'] ,
['দমন করা', 'দমিয়ে রাখা', 'নিপীড়ন করা'] ,
['দমন', 'দমন জেলা', 'দমন শহর', 'নিবারণ', 'নিয়ন্ত্রণ', 'প্রশমন', 'সংযম'] ,
['দম্বল', 'সাজা'] ,
['দম্ভহীনতা', 'দর্পহীনতা'] ,
['দময়ন্তী', 'ভৈমী'] ,
['দর', 'রেট'] ,
['দরজা', 'দ্বার'] ,
['দরজায় দরজায়', 'দ্বারে-দ্বারে'] ,
['দরদাম', 'মূল্য তুল্য', 'লেনদেন', 'সওদা'] ,
['দরবার', 'রাজ দরবার', 'রাজ-দরবার', 'রাজ-সভা', 'রাজদরবার', 'রাজসভা'] ,
['দরাঙ্গ', 'দরাঙ্গ জেলা'] ,
['দর্জি', 'দর্জি পাখি'] ,
['দর্শক', 'দ্রষ্টা'] ,
['দর্শকগণ', 'দর্শকবৃন্দ', 'দর্শকরা'] ,
['দর্শন করতে', 'দর্শনার্থে'] ,
['দর্শনাভিলাষী', 'দর্শনার্থি'] ,
['দর্শনীয়', 'দেখার যোগ্য'] ,
['দল পাকানো', 'লোক জড়ো করা'] ,
['দল', 'পক্ষ', 'পরিধি', 'পাপড়ি', 'পার্টি', 'বাহিনী', 'বিভাগ', 'বৃত্ত', 'সংঘ', 'সঙ্ঘ', 'সার্কেল'] ,
['দলছুট পশু', 'দলছুট পাখী'] ,
['দলবদলকারী', 'পাল্টিখোর'] ,
['দলবল', 'লোকলস্কর'] ,
['দলবাজ', 'পার্টিবাজ'] ,
['দলিত', 'দলিত ব্যক্তি', 'পদদলিত'] ,
['দলিল', 'দস্তাবেজ', 'সম্পত্তির উইল'] ,
['দলীপ', 'দিলীপ'] ,
['দশ লাখ', 'মিলিয়ন', '১০০০০০,', '১০০০০০০,'] ,
['দশ হাজার', 'দশহাজার'] ,
['দশ', '১০'] ,
['দশকন্ধ', 'দশগ্রীব', 'দশমুণ্ড', 'দশানন', 'দশাস্য', 'বহুবাহু', 'রক্ষোনাথ', 'রক্ষোরাজ', 'রাবণ', 'লঙ্কাধিপতি', 'লঙ্কাপতি', 'লঙ্কেশ', 'লঙ্কেশ্বর'] ,
['দশম', '১০ম'] ,
['দশমাংশ', 'দশাংশ'] ,
['দশমী', 'দশমী তিথি'] ,
['দশলাখ বিলিয়ন', '১০০০০০০০০০০০০০০০,'] ,
['দশহরা', 'বিজয়দশমী', 'বিজয়া'] ,
['দশহরি', 'দশহরি আম'] ,
['দশহাজার বিলিয়ন', '১০০০০০০০০০০০০০,'] ,
['দস্তানা', 'বড় দস্তানা', 'বাহুল'] ,
['দস্তুর', 'দেশাচার', 'প্রথা'] ,
['দাঁড় করানো', 'সামনে আনা'] ,
['দাঁত কিড়মিড় করা', 'দাঁত খিটমিট করা'] ,
['দাঁতের ময়লা', 'পুষ্পিকা'] ,
['দাখিল করা', 'দায়ের করা', 'লিখে রাখা'] ,
['দাগ দিয়ে রাখা', 'লিখে রাখা'] ,
['দাগ', 'রেখা'] ,
['দাড়চিনি', 'নটপর্ণ', 'সলপত্র'] ,
['দাড়ি', 'পূর্ণ বিরাম', 'পূর্ণ বিরাম চিহ্ন', 'শ্মশ্রূ'] ,
['দাতব্য', 'দান', 'দানযোগ্য', 'দানীয়'] ,
['দাতা', 'প্রদানকারী'] ,
['দাদ', 'দাদ রোগ'] ,
['দাদরা ও নগর হাভেলি', 'দাদরা ও নগর হাভেলী'] ,
['দাদা শ্বশুড়', 'দাদাশ্বশুড়'] ,
['দাদা', 'ভাই'] ,
['দাদু', 'দাদুদয়াল', 'মাতামহ'] ,
['দান পত্র', 'দান-পত্র'] ,
['দান পাত্র', 'দান-পাত্র'] ,
['দান', 'বলিদান'] ,
['দানপাত্র', 'দানপেটি'] ,
['দানবিক', 'দানবীয়'] ,
['দানবীর', 'দানশীল', 'দানশৌণ্ড', 'দানী'] ,
['দানা', 'শস্য দানা'] ,
['দানাদার', 'দানাযুক্ত'] ,
['দানিয়ুব', 'দানিয়ুব নদী'] ,
['দানেচ্ছু', 'দিত্সু'] ,
['দান্তেওয়াড়া', 'দান্তেওয়াড়া জেলা'] ,
['দাবনগেরে', 'দাবনগেরে শহর'] ,
['দাম দেওয়া', 'মূল্য দেওয়া'] ,
['দাম বাড়া', 'মূল্যবৃদ্ধি'] ,
['দাম রাখা', 'মূল্য রাখা'] ,
['দাম', 'দামনীতি', 'পণ', 'মূল্য'] ,
['দামি', 'মহার্ঘ্য'] ,
['দামী রত্ন', 'বহুমূল্য রত্ন'] ,
['দামী', 'বেশী দামী', 'মহার্ঘ্য'] ,
['দামোহ', 'দামোহ জেলা', 'দামোহ শহর'] ,
['দারগা', 'মাজার'] ,
['দারভাঙা', 'দারভাঙা জেলা', 'দারভাঙা শহর'] ,
['দারুণ', 'ভালো'] ,
['দারুফল', 'পিস্তা'] ,
['দার্জিলিং', 'দার্জিলিং শহর'] ,
['দার্জিলিঙ টি', 'দার্জিলিঙের চা'] ,
['দার্জিলিঙ', 'দার্জিলিঙ জেলা'] ,
['দালাল খাতা', 'ব্রোকিং অ্যাকাউন্ট'] ,
['দাস', 'দাস্য ভক্তি'] ,
['দাহোদ', 'দাহোদ জেলা', 'দাহোদ শহর'] ,
['দায়', 'দেয়', 'প্রদেয়', 'বকেয়া'] ,
['দায়িত্ব নেওয়া', 'নিজের অধিকারে নেওয়া', 'নিজের হাতে নেওয়া'] ,
['দায়িত্ব', 'রাশ', 'লাগাম'] ,
['দিউ', 'দিউ শহর'] ,
['দিওয়ানি', 'দেওয়ানি'] ,
['দিক', 'দিশা', 'বিষয়', 'মুখ'] ,
['দিকচক্রবাল', 'দিগন্ত'] ,
['দিকনির্ণায়ক', 'দিকসূচক', 'দিগ্দর্শক'] ,
['দিকপতি', 'দিকপাল', 'দিকস্বামী', 'দিগীশ্বর', 'দিগেশ', 'দিগ্গজ', 'দিগ্রাজ', 'দিশাপতি', 'দিশাপাল', 'লোকপাল', 'লোকাধিপতি'] ,
['দিকভ্রষ্ট', 'পথভ্রষ্ট', 'বিচ্যূত', 'ভ্রষ্ট'] ,
['দিকের', 'দুই তরফের'] ,
['দিক্ষাপতি', 'দিক্ষাপাল', 'সোম', 'সোম দেব', 'সোম দেবতা', 'সোমদেব'] ,
['দিখু', 'দিখু নদী'] ,
['দিগদর্শক', 'পথপ্রদর্শক', 'মার্গদর্শক'] ,
['দিগদর্শন', 'দিশা দর্শন', 'মার্গ দর্শন'] ,
['দিগভ্রম করা', 'পথ হারিয়ে ফেলা'] ,
['দিগম্বর', 'দিগম্বর সাধু'] ,
['দিগ্দর্শক', 'পথ-প্রদর্শক', 'পথপ্রদর্শক', 'মার্গ-দর্শক', 'মার্গদর্শক'] ,
['দিগ্ভ্রম', 'দিগ্ভ্রষ্টতা'] ,
['দিগ্ভ্রষ্ট', 'দিশাহীন'] ,
['দিণ্ডকল', 'দিণ্ডকল জেলা', 'দিণ্ডকল শহর', 'দিণ্ডিগুল', 'দিণ্ডিগুল শহর'] ,
['দিদা', 'মাতামহ'] ,
['দিদি শাশুড়ি', 'দিদিশাশুড়ি'] ,
['দিদি', 'বোন'] ,
['দিদিমা', 'প্রমাতামহী'] ,
['দিন', 'দিবস', 'দিবা', 'দৈনিক', 'সময়'] ,
['দিন-দিন', 'দিন-প্রতিদিন'] ,
['দিনকানা', 'নিশাচর'] ,
['দিনচর্চা', 'দৈনিক ক্রিয়াকলাপ', 'দৈনিক গতিবিধি'] ,
['দিনব্যাপী', 'দিনভর'] ,
['দিনভর', 'সারাদিন'] ,
['দিনাবসান', 'দিবসান্ত', 'বৈকাল', 'সন্ধ্যা', 'সন্ধ্যাকাল', 'সন্ধ্যাবেলা', 'সাঁঝ'] ,
['দিনার', 'বাহরিনি দিনার', 'যুগোস্লোভিয়ান দিনার', 'লিবিয়ান দিনার'] ,
['দিনের', 'দিবসীয়'] ,
['দিনোন্ধ', 'দিবস-অন্ধ', 'দিবান্ধ'] ,
['দিফু', 'দিফু শহর'] ,
['দিফ্লু', 'দিফ্লু নদী'] ,
['দিব্য শক্তি', 'সর্বোচ্চ শক্তি', 'সর্বোচ্চ সত্ত্বা'] ,
['দিব্যা', 'পাঙ্শুরাগিনী', 'মধুরা', 'মহামেদা'] ,
['দিব্যি', 'শপথ'] ,
['দিমাপুর', 'দিমাপুর জেলা', 'দিমাপুর শহর'] ,
['দিরাত্র', 'দিরাত্র যজ্ঞ'] ,
['দিরেম', 'মরক্কান দিরেম', 'লিবিয়ার দিরেম'] ,
['দিলপসন্দ', 'দিলপসন্দ আম'] ,
['দিল্ল শহর', 'দিল্লী', 'নয়া দিল্লী'] ,
['দিল্লীওয়াল', 'দিল্লীওয়াল জুতো'] ,
['দিশা নির্দেশ', 'দিশা-নির্দেশ', 'দিশানির্দেশ'] ,
['দিয়লী', 'বাতি'] ,
['দীন ই ইলাহী', 'দীন ই ইলাহী ধর্ম'] ,
['দীনতা', 'দৈন্য'] ,
['দীননাথ', 'দীনবত্সল', 'দীনশরণ', 'দীনেশ'] ,
['দীনবত্সল', 'দীনবন্ধু'] ,
['দীপ শিখা', 'দীপশিখা', 'শিখা'] ,
['দীপক', 'দীপকে অলঙ্কার'] ,
['দীপকমালা', 'দীপকমালা অলংকার', 'দীপকমালা বর্ণবৃত্ত'] ,
['দীপাবলি', 'দেওয়ালী'] ,
['দীপ্ত কেতু', 'দীপ্তকেতু'] ,
['দীর্ঘ অবকাশ', 'লম্বা ছুটি'] ,
['দীর্ঘ', 'দীর্ঘ স্বর', 'লম্বা'] ,
['দীর্ঘকায়', 'বিরাট', 'বিশাল', 'বিশালাকায়', 'বৃহত্'] ,
['দীর্ঘজীবন', 'দীর্ঘায়ু'] ,
['দীর্ঘতমা', 'দীর্ঘতমা ঋষি'] ,
['দীর্ঘতা', 'বিশালতা'] ,
['দীর্ঘদর্শিতা', 'দূরদর্শিতা', 'দূরদৃষ্টি'] ,
['দীর্ঘদর্শী', 'দূরদর্শী', 'দূরদ্রষ্টা'] ,
['দীর্ঘমতা', 'দীর্ঘমতা ঋষি', 'প্রদ্বেষী', 'প্রদ্বেষী ঋষি'] ,
['দীর্ঘরদ', 'বরাহ', 'শুয়োর', 'শূকর'] ,
['দীর্ঘরোম', 'ভালুক', 'ভাল্লুক'] ,
['দীর্ঘশ্রোত্রবিশিষ্ট', 'লম্বকর্ণ'] ,
['দীর্ঘসূত্রী', 'লেট লতিফ'] ,
['দু', 'দু তারিখ', 'দুই', 'দুই তারিখ'] ,
['দু-ধারা', 'দুইধারা', 'দোধারা'] ,
['দু-ধারী', 'দুই-ধারী', 'দুইধারী'] ,
['দুঃখ', 'বিষাদ', 'শোক', 'সন্তাপ'] ,
['দুঃখগাথা', 'দুঃখের কথা', 'রামকথা'] ,
['দুঃখগ্রস্ত', 'দুঃখজনক'] ,
['দুঃখজনক', 'দুঃখপ্রদ'] ,
['দুঃখময় অবস্থা', 'দুঃখের সময়'] ,
['দুঃখান্তক', 'শোকান্তক'] ,
['দুঃখেষ্বনুদ্বিগ্নমনা', 'স্থিতপ্রজ্ঞ'] ,
['দুঃসাহসী', 'বেয়াদপ'] ,
['দুঃস্বপ্ন', 'বাজে স্বপ্ন'] ,
['দুইগুণ', 'দ্বিগুণ'] ,
['দুইচাকার', 'দুচাকাবিশিষ্ট'] ,
['দুএকজন', 'বিরল'] ,
['দুখণ্ড বিশিষ্ট', 'দ্বিখণ্ডিত'] ,
['দুগর্ন্ধ ছড়ানো', 'দুর্গন্ধিত করা'] ,
['দুগাছা', 'দুগাছার মালা'] ,
['দুগুণ', 'দ্বিগুণ'] ,
['দুগ্ধ', 'দুধ'] ,
['দুজ', 'দ্বিতীয়া'] ,
['দুটো', '২'] ,
['দুতরফা', 'দুমুখো'] ,
['দুতিকা', 'দুতী'] ,
['দুধপিঠে', 'দুধপুলি'] ,
['দুধফেনী', 'ফেনদুগ্ধা'] ,
['দুধযুক্ত', 'দুধের'] ,
['দুধরাজ', 'শাহবুলবুল'] ,
['দুধিয়া ঘাস. দুদ্ধী', 'নাগার্জুনী'] ,
['দুধেল গরু', 'দুধেল গাই', 'দুধেল গাভী'] ,
['দুন', 'দেরাদুন', 'দেরাদুন জেলা', 'দেরাদুন শহর'] ,
['দুনিয়াদার', 'ব্যবহার কুশলী'] ,
['দুপুর', 'মধ্যাহ্ণ'] ,
['দুবস্যু', 'দুবস্যু ঋষি'] ,
['দুবে', 'দ্বিবেদি'] ,
['দুমকা', 'দুমকা জেলা', 'দুমকা শহর'] ,
['দুম্বা', 'মেষপুচ্ছ'] ,
['দুরঙা', 'দোরঙা'] ,
['দুরভিপ্রায়ী', 'দুরাশয়'] ,
['দুরাকাঙ্খ', 'দুরাশয়', 'মন্দ অভিপ্রায়যুক্ত'] ,
['দুরাচারিণী', 'দুশ্চরিত্রা', 'পতিতা'] ,
['দুরাত্মা', 'দুষ্টচেতা', 'দুষ্টমতি', 'পাপাশয়'] ,
['দুর্কল', 'বনবকরা'] ,
['দুর্গ', 'দুর্গ জেলা', 'দুর্গ শহর'] ,
['দুর্গতি', 'দুর্দশা'] ,
['দুর্গন্ধপূর্ণ', 'দুর্গন্ধযুক্ত'] ,
['দুর্গ্রাহ্য', 'ভ্রান্ত'] ,
['দুর্দৈব', 'দুর্ভাগ্য', 'ভাগ্যহীনতা'] ,
['দুর্বল', 'হাড়জিরজিরে'] ,
['দুর্বা', 'শতপর্বা', 'শিবজা', 'শিবেষ্টা'] ,
['দুর্মিল', 'মদনমনোরমা'] ,
['দুর্লভ', 'দুষ্প্রাপ্য'] ,
['দুল', 'ফুল'] ,
['দুলকি', 'দুলকি চাল'] ,
['দুলন', 'দুলুনি', 'দোদুল্যমানতা', 'দোলন', 'ললন', 'হিন্দোল', 'হিল্লোল'] ,
['দুলারী', 'দুলারী মাতা'] ,
['দুশো', '২০০,'] ,
['দুশ্চরিত্র', 'দুশ্চরিত্র ব্যক্তি', 'ব্যভিচারী', 'ব্যভিচারী ব্যক্তি'] ,
['দুশ্চরিত্রা', 'পতিতা', 'ব্যভিচারিণী'] ,
['দুশ্চিন্তন', 'দুশ্চিন্তা করা'] ,
['দুষ্টু', 'বদমাশ', 'শয়তান'] ,
['দুষ্টুমি', 'নষ্টামি', 'বদমাইশী'] ,
['দুহিতা', 'নাতনি'] ,
['দুয়া', 'দুয়ো', 'পাছেলা', 'পাছেলি'] ,
['দূত', 'রাষ্ট্রদূত', 'সন্দেশ বাহক', 'সন্দেশবাহক'] ,
['দূতাবাস', 'রাজদূতাবাস'] ,
['দূতি', 'দূতী'] ,
['দূর করা', 'সমাপ্ত করা'] ,
['দূর নিয়ন্ত্রক', 'রিমোট', 'রিমোট কন্ট্রোল'] ,
['দূর', 'দূরবর্তী', 'দূরস্থ'] ,
['দূরকারী', 'লোপকারী'] ,
['দূরীকৃত', 'বহিষ্কৃত'] ,
['দূর্গপতি', 'দূর্গপাল'] ,
['দূর্গা-নবমী', 'রামনবমী'] ,
['দূর্গাষ্ঠমী', 'মহাষ্ঠমী'] ,
['দৃঢ় প্রতিজ্ঞা', 'দৃঢ় সংকল্প'] ,
['দৃঢ়-নেমি', 'দৃঢ়নেমি'] ,
['দৃঢ়তা', 'পাকা ভাব', 'স্থায়ীত্ব', 'স্থিরতা'] ,
['দৃঢ়তাপূর্বক', 'দৃঢ়তার সঙ্গে', 'সঙ্কল্পপূর্বক'] ,
['দৃঢ়তার সঙ্গে', 'সাহসিকতার সঙ্গে', 'সাহসের সঙ্গে'] ,
['দৃশ্য', 'দৃশ্যকাব্য', 'রূপক', 'সিন', 'সীন'] ,
['দৃশ্য-বর্ণণ', 'দৃশ্যবর্ণণ'] ,
['দৃশ্যপট', 'পটভূমি', 'প্রেক্ষাপট', 'সিন', 'সেটিং'] ,
['দৃশ্যান্ত', 'যবনিকা পাত'] ,
['দৃষ্টি পটল', 'দৃষ্টিপটল'] ,
['দৃষ্টিকোণ', 'দৃষ্টিভঙ্গী', 'পরিপ্রেক্ষিত'] ,
['দৃষ্টিগোচর হওয়া', 'দেখা যাওয়া', 'নজরে আসা'] ,
['দৃষ্টিবান', 'দৃষ্টিশক্তিসম্পন্ন'] ,
['দৃষ্টিবিভ্রম', 'দৃষ্টিভ্রম'] ,
['দৃষ্টিসীমা', 'নেত্রসীমা'] ,
['দেওঘর', 'দেওঘর জেলা', 'দেওঘর শহর'] ,
['দেওয়া', 'পড়া', 'প্রদান'] ,
['দেওয়ানি মামলা', 'দেওয়ানি মোকদ্দমা'] ,
['দেওয়াল', 'প্রাচীর'] ,
['দেখা করা', 'দেখা-সাক্ষাত্ করা'] ,
['দেখা যাওয়া', 'ভিসিবিলিটি'] ,
['দেখা হওয়া', 'দেখানো', 'মিলিত হওয়া', 'সাক্ষাত্ হওয়া'] ,
['দেখা', 'দেখা-শোনা করা', 'নজর করা', 'নজর রাখা', 'নিরীক্ষণ', 'নিরীক্ষণ করা', 'পরিচয়', 'পরীক্ষা করা', 'পরীক্ষিত', 'পর্যবেক্ষণ', 'মন দেওয়া', 'যাচাই করা', 'সাক্ষাত্কার', 'সামনাসামনি', 'সামলানো'] ,
['দেখা-শোনা করা', 'পাহাড়া দেওয়া'] ,
['দেখা-শোনা', 'রক্ষণা-বেক্ষণ', 'রক্ষা'] ,
['দেখাদেখি', 'মুখ দেখাদেখি'] ,
['দেখানো', 'নির্দেশিত করা', 'পরীক্ষা করানো', 'প্রদর্শন', 'প্রদর্শন করা', 'বলা', 'ভাব দেখানো', 'লোক দেখানো'] ,
['দেখার মতো', 'প্রদর্শনীয়'] ,
['দেখাশোনা করা', 'পালন করা', 'পালনপোষণ করা'] ,
['দেখাশোনা', 'পালনপোষণ', 'ভরণপোষণ', 'লালন-পালন'] ,
['দেখেশুনে', 'পরীক্ষা করে'] ,
['দেজ', 'দেজ তাল'] ,
['দেড় গুণ', 'দেড়গুণ'] ,
['দেতীবৃক্ষ', 'নিষ্কুম্ভ', 'নিষ্কুম্ভ গাছ'] ,
['দেনা', 'ধার'] ,
['দেব গণ', 'দেবগণ', 'সুর গণ', 'সুরগণ'] ,
['দেব গান্ধার', 'দেবগান্ধার'] ,
['দেব গান্ধারী', 'দেবগান্ধারী'] ,
['দেব প্রতিমা', 'দেব বিগ্রহ', 'দেব মূর্তি'] ,
['দেব-ঋষি', 'দেবর্ষি'] ,
['দেব-নাগরী', 'দেবনাগরী', 'দেবনাগরী লিপি'] ,
['দেবইচ্ছা', 'প্রভুর ইচ্ছা'] ,
['দেবকী', 'বৃকদেবা'] ,
['দেবকুট', 'দেবকুট আশ্রম'] ,
['দেবগড়', 'দেবগড় জেলা', 'দেবগড় শহর'] ,
['দেবচিকিতসক', 'ধন্বন্তরী'] ,
['দেবতাতুল্য', 'দেবতুল্য'] ,
['দেববর্ণিনী', 'বরবর্ণিনী'] ,
['দেবব্রত', 'দেবব্রত ঋষি'] ,
['দেবভাষা', 'সংস্কৃত', 'সংস্কৃত ভাষা'] ,
['দেবরাত', 'দেবরাত ঋষি'] ,
['দেবরিয়া', 'দেবরিয়া জেলা', 'দেবরিয়া শহর'] ,
['দেবল', 'দেবল ঋষি', 'বেবালয়', 'মন্দির'] ,
['দেবশ্রবা', 'দেবশ্রবা ঋষি'] ,
['দেবাঙ্গনা', 'দেবী', 'সুরনারী', 'সুরাঙ্গনা'] ,
['দেবাতিথি', 'দেবাতিথি ঋষি'] ,
['দেবানিক', 'রাজা দেবানিক'] ,
['দেবাস', 'দেবাস জেলা', 'দেবাস শহর'] ,
['দেবি', 'দেবি উপনিষদ'] ,
['দেবী সাবিত্রী', 'সাবিত্রী', 'সাবিত্রী দেবী'] ,
['দেবী-মন্দির', 'দেবীমন্দির', 'দেবীস্থান'] ,
['দেবে যাওয়া', 'ধ্বসে যাওয়া'] ,
['দেরি হওয়া', 'বিলম্ব হওয়া'] ,
['দেরি', 'বিলম্ব'] ,
['দেরী', 'বিলম্ব করে', 'বিলম্ব পূর্বক'] ,
['দেলা', 'দোল খাওয়া'] ,
['দেশ গান্ধার', 'দেশগান্ধার'] ,
['দেশ', 'দেশ রাগ', 'রাষ্ট্র'] ,
['দেশ-প্রেম', 'রাষ্ট্র প্রেম', 'রাষ্ট্রীয়তা'] ,
['দেশকার', 'দেশকার রাগ', 'দেশকাররাগ'] ,
['দেশজ', 'দেশী', 'দেশীয়', 'স্বদেশী', 'স্বদেশীয়', 'স্হানীয়'] ,
['দেশদ্রোহী', 'রাষ্ট্রদ্রোহী'] ,
['দেশদ্রোহীতা', 'রাষ্ট্র বিদ্রোহ'] ,
['দেশভক্ত', 'রাষ্ট্রভক্ত'] ,
['দেশভক্তি', 'রাষ্ট্রভক্তি'] ,
['দেশহিত', 'রাষ্ট্রহিত'] ,
['দেহ ব্যবসা', 'বেশ্যাবৃত্তি'] ,
['দেহলি-দীপক', 'দেহলি-দীপক অলঙ্কার'] ,
['দেহাত্মবাদ', 'ভৌতবাদ'] ,
['দৈনিক ক্রিয়া', 'নিত্যকর্ম', 'নিত্যক্রিয়া'] ,
['দৈব বিধান', 'দৈবী নিয়ম', 'দৈবী বিধান'] ,
['দৈব', 'দৈবিক', 'নিয়তি', 'ভাগ্য'] ,
['দৈবিক', 'দৈবী'] ,
['দৈহিকধর্ম', 'শারীরিকধর্ম'] ,
['দোকান', 'মুদিখানার দোকান', 'স্টল'] ,
['দোতলা', 'দোতলা ভবন', 'দোমহলা'] ,
['দোদুল্যমান', 'দোলায়মান'] ,
['দোনলা', 'দোনালা'] ,
['দোনা', 'মদনক', 'মুনিপুত্র'] ,
['দোভাষী', 'দ্বিভাষিক', 'দ্বিভাষী'] ,
['দোল', 'হোলি'] ,
['দোলক', 'পেণ্ডুলাম'] ,
['দোলনা', 'দোলা'] ,
['দোষ নিবারণ', 'দোষাপনয়', 'পরিহার'] ,
['দোষারপ', 'প্রমাণবিহীণ বিবৃতি'] ,
['দোহন করা', 'দোয়া', 'দোয়ানো'] ,
['দোহন', 'শোষণ'] ,
['দোয়াঁশ', 'দোয়াঁশ মাটি'] ,
['দোয়াঙ্গ', 'দোয়াঙ্গ নদী'] ,
['দোয়াত', 'মসিদানি', 'মসিধান', 'মসিপত্র'] ,
['দৌড়', 'দৌড় প্রতিযোগীতা', 'রেস'] ,
['দৌড়-ঝাঁপ করা', 'দৌড়ানো'] ,
['দৌড়াদৌড়ি', 'ব্যস্ততা'] ,
['দৌহিত্র', 'নাতি'] ,
['দ্বন্দ', 'দ্বন্দ সমাস'] ,
['দ্বন্দযুদ্ধ', 'মল্লযুদ্ধ'] ,
['দ্বন্দ্বহীন', 'সংশয়হীন', 'সন্দেহহীন'] ,
['দ্বাদশ', 'বারো'] ,
['দ্বাপর', 'দ্বাপর যুগ'] ,
['দ্বাবিংশতি', 'বাইশ', '২২,'] ,
['দ্বার', 'সিংহদ্বার'] ,
['দ্বারকা', 'দ্বারিকা', 'দ্বারিকা ধাম', 'দ্বারিকাপুরি'] ,
['দ্বিজ', 'দ্বিজপতি', 'পণ্ডিত', 'বর্ণজ্যেষ্ঠ', 'বিপ্র', 'ব্রাহ্মণ', 'ভূদেব'] ,
['দ্বিজা', 'ব্রাহ্মণী', 'ব্রাহ্মণী নদী'] ,
['দ্বিতীয় গিয়ার', 'সেকেণ্ড গিয়ার'] ,
['দ্বিতীয় বন্ধনী', 'দ্বিতীয় বন্ধনী চিহ্ন', 'সর্পিল বন্ধনী'] ,
['দ্বিতীয়', '২রা'] ,
['দ্বিধা', 'সংকোচ', 'সংশয়'] ,
['দ্বিধাহীন', 'নিঃসঙ্কোচী'] ,
['দ্বিপক্ষ', 'মাস'] ,
['দ্বিপ্রাহরিক ভোজন', 'লাঞ্চ'] ,
['দ্বিবর্ষজীবী', 'দ্বিবর্ষী'] ,
['দ্বিবর্ষীয় গাছ', 'দ্বিবর্ষীয় ফসল'] ,
['দ্বিবাহু', 'দ্বিভুজ'] ,
['দ্বীতিয় স্থানে আসা', 'প্লেস করা'] ,
['দ্বীপ সমূহ', 'দ্বীপপুঞ্জ'] ,
['দ্বৈত', 'দ্বৈতবাদ', 'ভেদভাব'] ,
['দ্ব্যর্থতা', 'দ্ব্যর্থবোধক অলংকার'] ,
['দ্ব্যর্থবোধক', 'শ্লেষযুক্ত'] ,
['দ্ব্যাক্ষায়ণ', 'দ্ব্যাক্ষায়ণ ঋষি'] ,
['দ্যুতমত্', 'দ্যুতিমত'] ,
['দ্যুতান', 'দ্যুতান ঋষি'] ,
['দ্যুতি বোম', 'রেডিও বোমা'] ,
['দ্যুম্ন', 'দ্যুম্ন ঋষি'] ,
['দ্যুম্নিক', 'দ্যুম্নিক ঋষি'] ,
['দ্যূতি', 'লাবণ্য'] ,
['দ্রবণ', 'দ্রবীকরণ'] ,
['দ্রবীকরণ', 'দ্রবীভবন'] ,
['দ্রাঘিমাংশ', 'রেখাংশ', 'লম্বাংশ'] ,
['দ্রুত', 'ফাস্ট'] ,
['দ্রুতগামী মোটরচালিত নৌকা', 'দ্রুতগামী যন্ত্রচালিত নৌকা'] ,
['দ্রুতগামী', 'দ্রুতবেগের'] ,
['দ্রুতবিলম্বিত', 'সুন্দরী'] ,
['দ্রুম', 'দ্রুমেশ্বর', 'পারিজাত', 'পারিজাত বৃক্ষ', 'পারিজাতক'] ,
['দ্রুমিল', 'দ্রুমিল ঋষি'] ,
['দ্রোণ', 'দ্রোণকলস'] ,
['দ্রোণক্ষীরা', 'দ্রোণদুগ্ধা'] ,
['দ্রোণগিরি', 'দ্রোণাচল'] ,
['দয়ার্দ্র', 'দয়াসিক্ত'] ,
['দয়ালু ব্যক্তি', 'সহৃদয় ব্যক্তি'] ,
['ধ', 'ব্যঞ্জনবর্ণ ধ'] ,
['ধংকেনাল', 'ধংকেনাল জেলা', 'ধংকেনাল শহর'] ,
['ধক ধক করা', 'স্পন্দিত হওয়া', 'হৃদস্পন্দন'] ,
['ধন প্রাপ্তি', 'ধন লাভ'] ,
['ধন রাশি', 'ধনরাশি'] ,
['ধনতরস', 'ধনত্রয়োদশী'] ,
['ধনাদেশ', 'পে অর্ডার'] ,
['ধনিষ্টা', 'ধনিষ্টা নক্ষত্র'] ,
['ধনিয়া', 'ধনে', 'ধনে পাতা', 'ধন্যাক', 'ধান্যক', 'ধান্যাক'] ,
['ধনু', 'ধনু রাশি', 'ধনু রাশিবিশিষ্ট', 'ধনুরাশি'] ,
['ধনুষাক্ষ', 'ধনুষাক্ষ ঋষি'] ,
['ধন্য', 'ধান', 'প্রশংসনীয়', 'শ্লাঘনীয়', 'শ্লাঘ্য'] ,
['ধবল বক', 'সাদা বক'] ,
['ধবল', 'ধৌল', 'সাদা', 'সাদা আখ'] ,
['ধমক দেওয়া', 'ধমকানো', 'হুমকি দেওয়া'] ,
['ধমরতী', 'ধমরতী জেলা', 'ধমরতী শহর'] ,
['ধমার', 'ধমার তাল', 'ধমাল'] ,
['ধমারিয়া', 'ধমালিয়া'] ,
['ধর-পাকড়', 'ধরপাকড়'] ,
['ধরণ', 'প্রকার'] ,
['ধরফরানি', 'ধুকপুকানি'] ,
['ধরম', 'ধর্ম'] ,
['ধরা', 'ধরে ফেলা', 'নেওয়া', 'বোঝা'] ,
['ধরাতল', 'ভূতল', 'মহীতল'] ,
['ধরানো', 'লাগানো'] ,
['ধরার কাজ', 'পাকড়ানোর কাজ'] ,
['ধরাশায়ী', 'ভূলন্ঠিত'] ,
['ধরে নেওয়া', 'ধরো'] ,
['ধরে রাখা', 'বজায় রাখা', 'বাঁচিয়ে রাখা'] ,
['ধর্ম উপদেশ', 'ধর্মোপদেশ'] ,
['ধর্ম গ্রন্থ', 'ধর্মগ্রন্থ', 'ধার্মিক গ্রন্থ'] ,
['ধর্ম চক্র', 'ধর্মচক্র'] ,
['ধর্ম ন্যাস', 'ধার্মিক ন্যাস'] ,
['ধর্ম প্রচারক', 'ধর্মপ্রচারক'] ,
['ধর্ম বিধি', 'ধর্ম-বিধি', 'ধার্মিক বিধি', 'ধার্মিক-বিধি', 'ধার্মিকবিধি', 'বিধি-বিধান', 'বিধিবিধান'] ,
['ধর্ম যুদ্ধ', 'ধর্মযুদ্ধ'] ,
['ধর্ম শাস্ত্রজ্ঞ', 'ধর্ম শাস্ত্রী', 'ধর্মগ্রন্থজ্ঞ', 'ধর্মজ্ঞ'] ,
['ধর্ম সাবর্ণি', 'ধর্ম সাবর্ণি মনু'] ,
['ধর্ম স্থান', 'ধর্মস্থল', 'ধার্মিক স্থল', 'ধার্মিক স্থান'] ,
['ধর্ম', 'ধর্ম বিশ্বাস', 'ধর্মনিষ্ঠা', 'নিসর্গ', 'পবিত্র কর্ম', 'পুণ্যকর্ম', 'প্রকৃতি', 'প্রবৃত্তি', 'বৃত্তি', 'মেজাজ', 'স্পিরিট', 'স্বভাব'] ,
['ধর্ম-আচার্যা', 'ধর্ম-উপদেশিকা', 'ধর্মচার্যা', 'ধর্মশিক্ষিকা', 'ধর্মোপদেশিকা'] ,
['ধর্ম-নিষ্ঠতা', 'ধর্ম-পরায়ণতা', 'ধর্মনিষ্ঠা', 'ধর্মশীলতা', 'ধার্মিকতা'] ,
['ধর্ম-যুদ্ধ', 'ধর্মযুদ্ধ', 'ধর্মার্থ যুদ্ধ'] ,
['ধর্মঘট', 'বন্ধ', 'হড়তাল'] ,
['ধর্মচ্যূত', 'ধর্মপথভ্রষ্ট', 'ধর্মভ্রষ্ট', 'নীতিভ্রষ্ট'] ,
['ধর্মজ্ঞানী', 'ধর্মশাস্ত্রজ্ঞ'] ,
['ধর্মধ্বোজী', 'পাখন্ড', 'পাষন্ড'] ,
['ধর্মনিষ্ঠ', 'ধর্মপরায়ণ', 'ধর্মাত্মা', 'ধার্মিক'] ,
['ধর্মপুত্র', 'যুধিষ্ঠির'] ,
['ধর্মপুরি', 'ধর্মপুরি জেলা', 'ধর্মপুরি শহর'] ,
['ধর্মবৃক্ষ', 'নাগবন্ধু', 'পিপুল'] ,
['ধর্মযুগ', 'সত্যযুগ'] ,
['ধর্মশাস্ত্র', 'শাস্ত্র'] ,
['ধর্মাত্মা', 'পুন্য কর্তা', 'পুন্যকর্মা', 'পুন্যবান', 'পুন্যাত্মা', 'পূণ্যবান', 'পূণ্যাত্মা'] ,
['ধর্মানুসারী', 'ধর্মাবলম্বী'] ,
['ধর্ষণ', 'সতীত্ব হরণ', 'সতীত্বহরণ'] ,
['ধর্ষণকারী', 'বলাত্কারী'] ,
['ধলাই', 'ধলাই জেলা'] ,
['ধস নামা', 'পড়ে যাওয়া'] ,
['ধস', 'ভূস্খলন'] ,
['ধা', 'ধৈবত', 'ধৈবত স্বর'] ,
['ধাঁধা', 'প্রহেলিকা'] ,
['ধাই', 'ধাই মা', 'ধাইমা', 'ধাত্রী'] ,
['ধাক্কা দেওয়ানো', 'ভেড়ানো'] ,
['ধাক্কা দেওয়ার লোক', 'ধাক্কা প্রদানকারী'] ,
['ধাক্কা লাগা', 'ভিড়িয়ে দেওয়া'] ,
['ধাক্কাধাক্কি', 'ধাক্কাধুক্কি', 'মারামারি'] ,
['ধাতু কলশ', 'ধাতু-ঘট', 'ধাতুঘট'] ,
['ধাতুপাত্র', 'ধাতুর বাসন'] ,
['ধাতুপুত্র', 'সনতকুমার'] ,
['ধান ক্ষেত', 'ধানের ক্ষেত', 'ধান্য ক্ষেত্র'] ,
['ধান', 'ধান্য'] ,
['ধানবাদ', 'ধানবাদ জেলা', 'ধানবাদ শহর'] ,
['ধানসিড়ি', 'ধানসিড়ি নদী'] ,
['ধান্ধাবাজ', 'সুযোগসন্ধানী'] ,
['ধাপ', 'সিঁড়ি'] ,
['ধাবন করা', 'পলায়ন করা', 'পালিয়ে যাওয়া'] ,
['ধাবিকা', 'মহিলা দৌড়বীর'] ,
['ধার', 'ধার জেলা', 'ধার শহর', 'পান', 'ফলক', 'ফলা'] ,
['ধারওলা', 'ধারালো', 'শাণিত'] ,
['ধারণ করা', 'পরা'] ,
['ধারবাড়', 'ধারবাড় শহর'] ,
['ধারা', 'প্রবাহ', 'বেগ'] ,
['ধারাবাহিক', 'সিরিয়াল'] ,
['ধার্মিক সঙ্ঘ', 'সঙ্ঘ'] ,
['ধিক্কার', 'ভতর্সনা'] ,
['ধীমান', 'বিচক্ষণ', 'বুদ্ধিমান', 'সমঝদার'] ,
['ধীমে', 'মন্থর', 'মন্দ গতি'] ,
['ধীর', 'ধৈর্য্যবান', 'ধৈর্য্যশীল', 'শান্ত'] ,
['ধীরে চলা', 'হামাগুঁড়ি দেওয়া'] ,
['ধুতরা', 'ধুতুরা'] ,
['ধুতার', 'ধুতী', 'মোরাস্মানী'] ,
['ধুতুরা গাছ', 'মদন', 'মদন বৃক্ষ'] ,
['ধুনো', 'সুরাল'] ,
['ধুবরি জেলা', 'ধুব্রি জেলা'] ,
['ধুবরি শহর', 'ধুব্রি শহর'] ,
['ধুম', 'ধুম ঋষি'] ,
['ধুম-পান', 'ধুমপান', 'ধুম্রপান'] ,
['ধুমধাম সহকারে', 'ধুমধামের সঙ্গে'] ,
['ধুরিয়ামল্লার', 'ধুরিয়ামল্লার রাগ'] ,
['ধুলে', 'ধুলে জেলা', 'ধুলে শহর'] ,
['ধুলো', 'ময়লা'] ,
['ধুয়ে মুছে যাওয়া', 'বাজে ভাবে হেরে যাওয়া'] ,
['ধুয়েমুছে দেওয়া', 'সাফ করা'] ,
['ধূপ', 'সঞ্চারি'] ,
['ধূপদান', 'ধূপদানি'] ,
['ধূমপান করা', 'ধূম্রপান করা', 'ফোঁকা'] ,
['ধূমপান', 'ধূর্ম-পান', 'ধূর্মপান', 'স্মোকিং'] ,
['ধূম্রপ্পাঁ', 'বিজয়া'] ,
['ধূলা', 'মাটি.মৃত্তিকা'] ,
['ধূলিধূসরিত', 'ধূলিময়'] ,
['ধূলিবন্দন', 'রঙোত্সব', 'হোলি'] ,
['ধূলোবন্দন', 'হোলি'] ,
['ধূসর কয়লা', 'লিগনাইট'] ,
['ধৃষ্টতা', 'বেয়াদপি'] ,
['ধৃষ্টদ্যুম্ন', 'পার্ষত'] ,
['ধেনুক', 'ধেনুকাসুর'] ,
['ধেমাজী', 'ধেমাজী জেলা', 'ধেমাজী শহর'] ,
['ধৈর্য ধরা', 'সবুর করা'] ,
['ধোঁয়াচ্ছন্ন', 'ধোঁয়াটে'] ,
['ধোঁয়াটে সময়', 'ধোঁয়াশা'] ,
['ধোওয়া', 'ধৌত', 'পরিষ্কার দেওয়া'] ,
['ধোড়', 'ধোড় সাপ'] ,
['ধোতর', 'মোটা কাপড়'] ,
['ধোপা ঘাট', 'ধোপাঘাট'] ,
['ধোপা', 'রজক'] ,
['ধোপাখানা', 'লণ্ড্রি'] ,
['ধোপার ধোলাই', 'ধোবি পাছাড়', 'ধোবিপাট'] ,
['ধোলপুর', 'ধোলপুর জেলা', 'ধোলপুর শহর'] ,
['ধ্বংস করা', 'বিধ্বস্ত করা'] ,
['ধ্বংস হওয়া', 'নষ্ট হওয়া', 'নিশ্চিহ্ন হওয়া'] ,
['ধ্বংস', 'নিপাত', 'পণ্ড', 'পরাভব', 'বিধ্বংস', 'বিনাশ', 'ভাঙচুর', 'সংহার', 'সর্বনাশ'] ,
['ধ্বংসক', 'ধ্বংসকারী'] ,
['ধ্বংসকারী', 'ধ্বংসাত্মক'] ,
['ধ্বংসাবশেষ', 'ভগ্নস্তুপ', 'ভগ্নাবশেষ'] ,
['ধ্বজদণ্ড', 'পতাকার দণ্ড'] ,
['ধ্বজাদন্ড', 'পতাকাদন্ড'] ,
['ধ্বনিগ্রাহী', 'মাইক', 'মাইক্রোফোন'] ,
['ধ্বনিত', 'নিনাদিত'] ,
['ধ্বনির', 'ধ্বনিসংক্রান্ত'] ,
['ধ্বনী-বিস্তারক', 'ভেঁপু', 'লাউডস্পিকার'] ,
['ধ্বান্ত', 'ধ্বান্ত নরক', 'ধ্বান্ত মরুত্'] ,
['ধ্যাণনিষ্ট', 'ধ্যাণমগ্ন', 'ধ্যাণস্থ', 'ধ্যাণী'] ,
['ধ্যান', 'ধ্যান যোগ'] ,
['ধ্যানবিন্দু', 'ধ্যানবিন্দু উপনিষদ'] ,
['ধ্যানাবস্থা', 'প্রণিধান', 'সমাধি'] ,
['ধ্রুপদ', 'ধ্রুবপদ'] ,
['ধ্রুব', 'ধ্রুব তারা', 'মেরু'] ,
['ধ্রুবরেখা', 'বিষুব রেখা', 'বিষ্যুত রেখা', 'ভূমধ্যরেখা'] ,
['ধ্রুবা', 'মরোড়ফলী', 'রঙ্গলতা', 'শিখরা', 'শিখরিণী'] ,
['ন', 'ব্যঞ্জনবর্ণ ন'] ,
['নকল হীরে', 'নিম্ন মানের হীরে'] ,
['নকশা করা', 'ফুলআঁকা'] ,
['নকশা', 'নক্সা', 'ফুলকারি', 'মানচিত্র', 'সূচীকর্ম'] ,
['নকশাল', 'নকশালপন্থী', 'নকশালবাদী'] ,
['নকশালপন্থা', 'নকশালবাদ'] ,
['নকুল', 'নেউল', 'সর্পারি'] ,
['নকুলের', 'নেউলের', 'বেজির'] ,
['নক্শা করা', 'নক্শা বানানো'] ,
['নখ দিয়ে খোঁচানো', 'নখ দিয়ে খোঁটা'] ,
['নখাস', 'নখাস কর', 'পশুহাট'] ,
['নগর নিগম', 'নিগম', 'মহানগরপালিকা'] ,
['নগর নিবাসী', 'নগর বাসী', 'নগর-নিবাসী', 'নগর-বাসী', 'নগরনিবাসী', 'নগরবাসী', 'পুরবাসী', 'শহরবাসী', 'শহুরে'] ,
['নগর প্রশাসক', 'নগরপাল', 'নগরাধিপতি'] ,
['নগর সভা', 'নগর সমিতি', 'নগরপালিকা', 'মহাপালিকা', 'মিউনিসিপালিটি'] ,
['নগর', 'নগরী', 'মমম', 'শহর'] ,
['নগরবাসী', 'শহরবাসী'] ,
['নগরশুল্ক', 'প্রবেশদ্বার', 'প্রবেশদ্বার শুল্ক', 'প্রহরা'] ,
['নগরীকৃত', 'শহরীকৃত'] ,
['নগ্ন হওয়া', 'বিবস্ত্র হওয়া'] ,
['নগ্ন', 'বসনহীন', 'বস্ত্রহীন', 'বিবসন', 'বিবস্ত্র'] ,
['নঙ্গর ফেলা', 'বাঁধা হওয়া'] ,
['নজর', 'পরখ', 'মানুষ চেনার ক্ষমতা'] ,
['নঞর্থক', 'নেতিবাচক'] ,
['নট', 'নট জাতি', 'নট রাগ', 'নাট্যকার', 'পাত্র', 'রঙ্গবিদ্যাধর'] ,
['নটনারায়ণ', 'নটনারায়ণ রাগ'] ,
['নটমল', 'নটমল রাগ'] ,
['নটমল্লার', 'নটমল্লার রাগ'] ,
['নটমল্লারি', 'নটমল্লারি রাগ'] ,
['নট্যা', 'নট্যা রাগিনী'] ,
['নডজামেন', 'ফোর্ট-লেমী'] ,
['নতদ্রুম', 'লতাশাল'] ,
['নতমস্তক', 'নতশির'] ,
['নতুন করা', 'নবায়ণ করা'] ,
['নতুন ভাবে', 'শুরু থেকে'] ,
['নতুনত্ব', 'নবীনতা'] ,
['নথ', 'নাকছাবি', 'নাকের আংটা', 'নোলক'] ,
['নথি', 'ফাইল'] ,
['নথিকরণ', 'লিপিবদ্ধ'] ,
['নথীবদ্ধ', 'রেকর্ডিং'] ,
['নথীভূক্ত করা', 'রেজিস্ট্রি করানো'] ,
['নথীভূক্ত', 'রেকর্ড'] ,
['নদ', 'নদ ঋষি'] ,
['নদিয়া', 'নদিয়া জেলা'] ,
['নদী প্রবাহ', 'শ্রোত'] ,
['নদুলসাই', 'নদুলসাই আম'] ,
['ননদ', 'ননদিনী'] ,
['ননী', 'নবনীত', 'মাখন'] ,
['নন্দ', 'নন্দ রাগ', 'বাবা নন্দ'] ,
['নন্দনতত্ত্ব', 'সৌন্দর্য্য শাস্ত্র'] ,
['নন্দরাণী', 'যশোদা', 'যশোমতি'] ,
['নন্দী', 'নন্দীকেশর'] ,
['নন্দুবার', 'নন্দুবার শহর'] ,
['নন্দুরবার', 'নন্দুরবার জেলা'] ,
['নপুংসক', 'হিজড়া', 'হিজড়ে'] ,
['নপুংসকতা', 'নপুংসত্ব', 'পুরুষত্বহীনতা', 'পৌরুষহীনতা'] ,
['নব পরিণীতা', 'নব বিবাহিতা', 'নববিবাহিতা'] ,
['নব প্রশিক্ষিত ব্যক্তি', 'শিক্ষানবিশ', 'শিক্ষানবিশ ব্যক্তি'] ,
['নব-খন্ড', 'নবখন্ড', 'নয়-খন্ড', 'নয়খন্ড'] ,
['নবগড়', 'নবগড় শহর'] ,
['নবগ্রহী', 'নবগ্রহী মালা'] ,
['নবজাগরণ', 'পুনর্জাগরণ'] ,
['নবজাত শিশু', 'নবজাতক', 'বাচ্চা'] ,
['নবজাত', 'সদ্যোজাত'] ,
['নবতারা', 'নোভা'] ,
['নবনির্মিত', 'নবরচিত', 'নব্য'] ,
['নবপরিণীত', 'নববিবাহিত'] ,
['নববিবাহিতা', 'সদ্যবিবাহিতা'] ,
['নবমী', 'নবমী তিথি'] ,
['নবযুবতী', 'নবযৌবনা'] ,
['নবরঙ্গপুর', 'নবরঙ্গপুর জেলা', 'নবরঙ্গপুর শহর'] ,
['নবরত্ন হার', 'নবরত্নমালা'] ,
['নবরত্ন', 'নবরত্ন চাটনি'] ,
['নবসারি', 'নবসারি জেলা', 'নবসারি শহর'] ,
['নবাঁ', 'নবাঁ শহর', 'নবাঁ শহর জেলা'] ,
['নবাদা', 'নবাদা জেলা', 'নবাদা শহর'] ,
['নবাবজাদা', 'নবাবপুত্র', 'লাটসাহেব'] ,
['নবীনতম', 'নবীনতম আম', 'নবীনতম আম গাছ'] ,
['নব্বই', '৯০'] ,
['নভঃ সেনা', 'বায়ু সেনা'] ,
['নভাক', 'নভাক ঋষি'] ,
['নমনশীলতা', 'নমনীয়তা', 'নম্রতা', 'নম্রভাব', 'বিনমন'] ,
['নমনীয়', 'স্থিতিস্থাপক'] ,
['নমস্কার', 'সেলাম'] ,
['নমুনা', 'স্যাম্পেল'] ,
['নমেরু', 'রুদ্রাক্ষ', 'রুদ্রাক্ষ উপনিষদ', 'রুদ্রাক্ষোপনিষ'] ,
['নম্বর নির্ধারন', 'নম্বর প্রদান'] ,
['নম্বর প্লেট', 'নম্বরপ্লেট'] ,
['নম্র', 'বিনম্র', 'বিনীত'] ,
['নম্রতাপূর্বক', 'বিনয়পূর্বক'] ,
['নর জনন কোষিকা', 'নর জননিকা', 'পুরুষ জনন কোষিকা'] ,
['নর নারায়ণ', 'নর-নারায়', 'নরনারায়ণ'] ,
['নর', 'পুরুষ', 'পুরুষ প্রজাতি', 'মনুজ', 'মনুষ্য', 'মানব', 'মানুষ'] ,
['নরওয়েজিয়ান', 'নরওয়েজিয়ান ভাষা', 'নরওয়েবাসী'] ,
['নরকস্থা', 'বৈতরণী', 'বৈতরণী নদী'] ,
['নরকাসুর', 'বসুধাসুর', 'ভূমিজ', 'ভূমিপুত্র', 'ভূসুত', 'ভৌমাসুর'] ,
['নরখাদক', 'মানুষখেকো'] ,
['নরনাহর', 'নরসিংহ', 'নৃসিংহ', 'নৃসিংহ অবতার', 'নৃহতি', 'ভগবান নরসিংহ'] ,
['নরনৌল', 'নরনৌল শহর'] ,
['নরবলি', 'মানব বলি'] ,
['নরম', 'পথ্য', 'লঘু পাক', 'সহজ পাচ্য', 'সুপাচ্য', 'হাল্কা'] ,
['নরসিংহ রাও', 'পামুলাপর্তি ভেঙ্কট নরসিম্হা রাও', 'পিবি নরসিংহ রাও'] ,
['নরসিংহপুর', 'নরসিংহপুর জেলা', 'নরসিংহপুর শহর'] ,
['নরসিঙ্গা', 'সিংঙ্গা'] ,
['নরেন্দ্র', 'নরেন্দ্রনাথ দত্ত', 'বিবেকানন্দ', 'স্বামী বিবেকানন্দ'] ,
['নর্তক', 'নৃত্যকার'] ,
['নর্তকী', 'নৃত্যাঙ্গনা', 'বারিণী'] ,
['নর্থ', 'ফ্রেডরিক নর্থ'] ,
['নর্দমা', 'নালা', 'নালি', 'প্রণালী'] ,
['নল কুবের', 'নলকুবের'] ,
['নল', 'পাইপ'] ,
['নলিকা', 'নাল', 'নালক'] ,
['নলিনী', 'ভ্রমরবলী', 'মনহরণ'] ,
['নলী', 'পাইপ', 'বন্দুকের নলী'] ,
['নষ্ট করা', 'মুছে দেওয়া', 'হারিয়ে ফেলা'] ,
['নসাউ', 'নাসাউ'] ,
['নস্য', 'নস্যি', 'নাস'] ,
['নহরের', 'নালার'] ,
['নহান', 'নহান শহর'] ,
['নহুষ', 'নহুষ ঋষি'] ,
['না চেয়ে', 'বিনা চেয়ে', 'যাচনা না করে'] ,
['না থাকা', 'ভেঙে পড়া'] ,
['না', 'নয়'] ,
['নাই', 'নাপিতানী', 'নাপিতিনী', 'নাপিতেনি'] ,
['নাইজার', 'নাইজার নদী'] ,
['নাইজিরিয়া', 'নাইজিরিয়া গণরাজ্য', 'নাইজিরিয়া সঙ্ঘীয় গণরাজ্য'] ,
['নাইজিরিয়াবাসী', 'নাইজেরিয়ান'] ,
['নাইল', 'নীল'] ,
['নাক ডাকা', 'নাক বাজা'] ,
['নাক বাঁশি', 'নাকবংশি', 'নাকবাঁশি'] ,
['নাকচ করা', 'নিরস্ত করা', 'বাতিল করা'] ,
['নাকছাবি', 'নোলক'] ,
['নাকশির', 'রক্তপিত্ত'] ,
['নাকের ফুটো', 'নাসারন্ধ্র', 'নাসিকা ছিদ্র'] ,
['নাকের রোগ', 'পুয়রক্ত'] ,
['নাগনায়ক', 'নাগপতি', 'ফনীন্দ্র', 'বাসুকি', 'বাসুকি নাগ', 'সর্পরাজ'] ,
['নাগপদ', 'নাগপদ রতিবন্ধ'] ,
['নাগপুর', 'নাগপুর জেলা', 'নাগপুর শহর'] ,
['নাগপুরী', 'নাগপুরের'] ,
['নাগমণি', 'নাগসম্ভব'] ,
['নাগমাতা', 'পদ্মা', 'পদ্মাদেবী', 'মনসা', 'মনসাদেবী', 'সূরসা'] ,
['নাগরকোইল', 'নাগরকোইল শহর'] ,
['নাগরমোথা', 'বৃষপর্বা', 'শিশিরা', 'স্বল্পকন্দ'] ,
['নাগরা', 'নাগরা জুতো'] ,
['নাগরাজ', 'নারাচ', 'পঞ্চামর'] ,
['নাগরিক', 'শহুরে'] ,
['নাগা', 'নাগা জনজাতি', 'নাগা সন্ন্যাসী', 'নাগা সাধু'] ,
['নাগাপট্টিনম', 'নাগাপট্টিনম জেলা', 'নাগাপট্টিনম শহর'] ,
['নাগেশ্বর', 'নাগেশ্বরনাথ', 'নাগেশ্বরম'] ,
['নাগৌর', 'নাগৌর জেলা', 'নাগৌর শহর'] ,
['নাঙ্গাও', 'নাঙ্গাও জেলা', 'নাঙ্গাও শহর'] ,
['নাচ', 'নৃত্য'] ,
['নাচঘর', 'নৃত্যশালা'] ,
['নাচা', 'নৃত্য করা'] ,
['নাচানো', 'নৃত্য করানো'] ,
['নাট', 'নাট রাগ'] ,
['নাটক', 'নাট্য', 'মহারুপক'] ,
['নাটকীয় ট্যাবলো', 'নাটকীয় দৃশ্য'] ,
['নাটকের সম্বোধন', 'নাট্যোক্তি'] ,
['নাট্যবিদ্যা', 'নাট্যশাস্ত্র'] ,
['নাড়ী', 'পিঙ্গলা', 'পিঙ্গলা নাড়ী', 'সূর্য নাড়ী', 'সূর্যনাড়ী'] ,
['নাতি', 'পৌত্র', 'পৌত্রী', 'প্রপৌত্র'] ,
['নাদ', 'নাদি', 'ন্যাড়', 'লন্ড', 'লন্ডা', 'লাদ', 'লেন্ড'] ,
['নাদ-বিন্দু উপনিষদ', 'নাদবিন্দু'] ,
['নাদিরশাহ', 'মহম্মদ নাদিরশাহ'] ,
['নান-প্লাস-আল্ট্রা আম গাছ', 'নান-প্লাস-আল্ট্রা আম গাছ'] ,
['নান-প্লাস-আল্ট্রা', 'নান-প্লাস-আল্ট্রা আম'] ,
['নানাকন্দ', 'পিণ্ডালু', 'রক্তপত্র'] ,
['নানামতাবলম্বী', 'বহুমার্গাবলম্বী', 'শতপথিক'] ,
['নান্দেড', 'নান্দেড জেলা', 'নান্দেড শহর'] ,
['নাবিক', 'মাঝি', 'হ্যাণ্ড'] ,
['নাবিকের', 'মাল্লার'] ,
['নাভাগ', 'নাভাগ ঋষি'] ,
['নাভিপাক', 'নাভিপাক রোগ'] ,
['নাভিশোথ', 'নাভিশোথ রোগ'] ,
['নাম করা', 'নাম স্মরণ করা', 'সংস্মরণ', 'স্মরণ'] ,
['নাম দেওয়া', 'নামাঙ্কন করা'] ,
['নাম', 'সংজ্ঞা'] ,
['নামক', 'নামধারী', 'নামা', 'নামে', 'নামের', 'নাম্নী'] ,
['নামকরণ', 'নামকরণ সংস্কার'] ,
['নামক্কল', 'নামক্কল জেলা', 'নামক্কল শহর'] ,
['নামচি', 'নামচি শহর'] ,
['নামঠিকানা', 'নামধাম'] ,
['নামদেব', 'সাধু নামদেব'] ,
['নামপট্টী', 'নেমপ্লেট'] ,
['নামমাত্র', 'বিন্দুমাত্র', 'লেশমাত্র'] ,
['নামাঙ্কণ', 'পঞ্জীকরণ'] ,
['নামাঙ্কিত', 'লিখিত'] ,
['নামিবিয়া সম্পর্কিত', 'নামিবিয়ান', 'নামিবিয়াবাসী', 'নামিবিয়ার'] ,
['নামিবিয়া', 'নামিবিয়া গণরাজ্য'] ,
['নামিয়ে ফেলা', 'শেষ করে ফেলা'] ,
['নামী', 'নামীদামী', 'প্রসিদ্ধ', 'বিখ্যাত'] ,
['নারকেল', 'নারকেলের শাঁস'] ,
['নারদ পুরাণ', 'নারদপুরাণ'] ,
['নারদপরিব্রাজক উপনিষদ', 'নারদপরিব্রাজকোপনিষদ', 'পরিব্রাত উপনিষদ', 'পরিব্রাতোপনিষদ'] ,
['নারাচিকা', 'নারাচী'] ,
['নারায়ণ', 'নারায়ণ উপনিষদ', 'নারায়ণ ঋষি', 'নারায়ণোপনিষদ'] ,
['নার্স', 'পরিচারিকা', 'সিস্টার'] ,
['নালন্দা', 'নালন্দা জেলা'] ,
['নালা', 'প্রণালী'] ,
['নালিকা', 'নালী', 'বাহিকা'] ,
['নাশক', 'বিনাশক', 'বিনাশকারক', 'বিনাশকারী', 'বিনায়ক'] ,
['নাসা', 'ন্যাশানাল এয়োরোনটিক্স অ্যান্ড স্পেস অ্যাডমিনিস্ট্রশান', 'রাষ্ট্রীয় বৈমানিকী ও অন্তরিক্ষ প্রবন্ধন'] ,
['নাসা-বিবর', 'নাসারন্ধ্র', 'নাসিকা-গুহা'] ,
['নাসিক', 'নাসিক জেলা', 'নাসিক শহর'] ,
['নাসিকামল', 'পোঁটা', 'সিকনি'] ,
['নাসিরুদ্দিন হুমায়ুন', 'হুমায়ুন'] ,
['নাস্তিক', 'নাস্তিকতাবাদী', 'নিরীশ্বরবাদী'] ,
['নাস্তিকতা', 'নাস্তিকত্ব'] ,
['নাস্তিকতাবাদ', 'নিরীশ্বরবাদ'] ,
['নায়ক', 'নেতা', 'প্রধান চরিত্র', 'হীরো'] ,
['নায়কত্ব', 'নেতৃত্ব'] ,
['নায়িকা', 'হিরোইন'] ,
['নিংড়ানো', 'শোষণ করা'] ,
['নিঃশঙ্কা', 'সংশয়হীন', 'সন্দেহহীন'] ,
['নিঃশব্দ', 'নীরব', 'শান্ত'] ,
['নিঃশুল্ক', 'মুফত'] ,
['নিঃশ্বাস', 'নিশ্বাস'] ,
['নিঃসঙ্কোচে', 'সঙ্কোচহীন ভাবে'] ,
['নিঃসঙ্গ', 'নিঃসঙ্গ সাধু'] ,
['নিঃসন্তান', 'সন্তানহীন'] ,
['নিঃস্বার্থ', 'স্বার্থহীন'] ,
['নিঃস্বার্থতা', 'স্বার্থহীনতা'] ,
['নিউজ এজেন্সি', 'সংবাদ এজেন্সি'] ,
['নিউজিল্যান্ড বাসী', 'নিউজিল্যান্ডীয়', 'নিউজিল্যান্ডের'] ,
['নিউজিল্যান্ড', 'নিউজিল্যান্ড দ্বীপ'] ,
['নিকট কুটুম', 'নিকটাত্মীয়'] ,
['নিকন্দ রোগ', 'নিকন্দ-রোগে'] ,
['নিকানো', 'মাখা', 'লেপা'] ,
['নিকারাগুয়া-বাসী', 'নিকারাগুয়ান'] ,
['নিকাশ', 'নিকাশী', 'নির্গমন'] ,
['নিকৃষ্ট বস্তু', 'নিম্নমানের বস্তু'] ,
['নিকেশ', 'নির্মূল'] ,
['নিকোবর', 'নিকোবর জেলা'] ,
['নিক্ষেপ', 'বিক্ষেপ', 'বিক্ষেপণ'] ,
['নিখুঁত বানানো', 'নিপুণ বানানো'] ,
['নিগম', 'সংঘ', 'সংস্হা'] ,
['নিগুর্ডী', 'নিশিপুষ্পিকা', 'শেফালি', 'শেফালিকা', 'শ্বেতপুষ্প', 'সিন্দুবার'] ,
['নিগ্রহ স্থান', 'নিগ্রহস্থান'] ,
['নিগ্রহী', 'সংযত'] ,
['নিচ', 'নিচু', 'নিম্ন'] ,
['নিচু কুল', 'নিচু বংশ', 'হীন কুল'] ,
['নিচের বার্থ', 'নিচের সিট'] ,
['নিজ বিবেক', 'স্ববিবেক'] ,
['নিজ', 'পারস্পরিক'] ,
['নিজস্ব', 'নিজের', 'ব্যক্তিগত'] ,
['নিজামাবাদ', 'নিজামাবাদ জেলা', 'নিজামাবাদ শহর'] ,
['নিজে নিজেই', 'নিজেই', 'সাক্ষাত্', 'স্বতঃ', 'স্বয়ং'] ,
['নিজের করা', 'স্বকৃত'] ,
['নিজের থেকে', 'স্বতঃ'] ,
['নিজের বোন', 'বোন', 'সহোদরা'] ,
['নিন্দনীয়', 'নিন্দার যোগ্য', 'নিন্দার্হ'] ,
['নিন্দাজনক', 'নিন্দামূলক', 'নিন্দাসূচক'] ,
['নিপাট মুর্খ', 'মহামূর্খ'] ,
['নিপাতযোগ্য', 'বধ্য'] ,
['নিবন্ধ', 'লেখা'] ,
['নিবাস স্থল', 'নিবাস স্থান', 'নিবাস-স্থল', 'নিবাস-স্থান', 'বাসস্থান'] ,
['নিবৃত্ত', 'বিমুখ', 'বিরত'] ,
['নিবেদিত', 'প্রার্থিত'] ,
['নিবেশ করা', 'লাগানো'] ,
['নিভানো', 'নিভিয়ে দেওয়া'] ,
['নিম', 'নিম্ব'] ,
['নিমগ্ন হওয়া', 'মগ্ন হওয়া'] ,
['নিমগ্ন', 'নিমজ্জিত'] ,
['নিমজ্জনযোগ্য', 'সাবমারসিবল'] ,
['নিমণ্ত্রণ', 'পার্টি', 'প্রীতিভোজ'] ,
['নিমি', 'নিমি ঋষি'] ,
['নিম্ন রক্তচাপ', 'লো ব্লাডপ্রেসার', 'হাইপোটেনশন'] ,
['নিম্নকক্ষ', 'লোকসভা'] ,
['নিম্নবংশ', 'নীচকুল', 'নীচবংশ'] ,
['নিম্নলিখিত', 'নিম্নাঙ্কিত'] ,
['নিম্ম বংশীয়', 'নীচ বংশীয়'] ,
['নিযুক্ত করা', 'বানানো'] ,
['নিযুক্ত', 'নিয়োজিত'] ,
['নিযুক্তি', 'নিয়োগ', 'নিয়োজন'] ,
['নিরক্ষরতা', 'স্বাক্ষরহীনতা'] ,
['নিরক্ষীয়', 'বিষুবরেখীয়'] ,
['নিরঙ্কুশ শাসক', 'স্বেচ্ছাচারী শাসক'] ,
['নিরঙ্কুশ', 'সর্বমান্য'] ,
['নিরপরাধ', 'নির্দোষ', 'নিষ্পাপ'] ,
['নিরস্ত', 'বাতিল', 'রদ'] ,
['নিরানব্বই', '৯৯', '৯৯,'] ,
['নিরাপদ', 'সুরক্ষিত'] ,
['নিরামিশাষী প্রাণী', 'নিরামিষভোজী প্রাণী', 'শাকাহারী জীব', 'শাকাহারী প্রাণী'] ,
['নিরামিশাসী', 'শাকজীবি', 'শাকাহারী'] ,
['নিরামিষ আহার', 'বনস্পতীয় আহার', 'মাংসহীন আহার', 'শাকাহার'] ,
['নিরামিষ', 'মাংসরহিত'] ,
['নিরালম্ব', 'নিরালম্ব উপনিষদ', 'নিরালম্বোপনিষদ'] ,
['নিরাশ', 'হতাশ'] ,
['নিরাশা', 'নৈরাশ্য', 'হতাশা'] ,
['নিরাশাবাদী', 'হতাশাবাদী'] ,
['নিরীক্ষণ করা', 'পরীক্ষা করা'] ,
['নিরীহ', 'নিষ্পাপ'] ,
['নিরুদ্দেশ', 'হারানো'] ,
['নিরুদ্ধগুহ্য', 'নিরুদ্ধগুহ্য রোগ'] ,
['নিরুদ্ধপ্রকাশ', 'নিরুদ্ধপ্রকাশ রোগ'] ,
['নিরূড় লক্ষণা', 'নিরূড়লক্ষণা', 'রূড়ি লক্ষণা', 'রূড়িলক্ষণা'] ,
['নির্গত করা', 'বার করা'] ,
['নির্গত হওয়া', 'বেরিয়ে আসা', 'বেরোনো'] ,
['নির্গম', 'নির্গমন', 'নিষ্কাশন'] ,
['নির্গুণ ব্রাহ্মণ', 'নির্বিকার ব্রাহ্মণ'] ,
['নির্জন বনপ্রান্তর', 'নির্জন বনাঞ্চল'] ,
['নির্জীব', 'প্রাণহীন'] ,
['নির্ণায়ক দল', 'নির্ণায়ক বৃন্দ', 'প্যানেল'] ,
['নির্ণায়ক', 'নির্ণয় কর্তা', 'নির্ধারক'] ,
['নির্ণীত', 'মীমাংসিত', 'সুনির্দিষ্ট', 'সুস্পষ্ট'] ,
['নির্ণয়', 'নিশ্চয়', 'বিচার', 'সিদ্ধান্ত', 'সিদ্ধি'] ,
['নির্দষ্টা', 'নির্দেশক', 'নির্দেশী'] ,
['নির্দিষ্ট করা', 'বলি লাগানো'] ,
['নির্দিষ্ট রাস্তা', 'পরিচিত রাস্তা'] ,
['নির্দিষ্ট', 'নির্দেশিত', 'নির্ধারিত', 'পরিকল্পিত'] ,
['নির্দেশ দেওয়া', 'বলা', 'শেখানো'] ,
['নির্দেশক', 'প্রদর্শক'] ,
['নির্ধারিত করুন', 'সুনিশ্চিত করা'] ,
['নির্ধারিত কাল', 'নির্ধারিত সময়', 'নিয়ত অবধি'] ,
['নির্বংশ', 'বংশরহিত'] ,
['নির্বস্তুক', 'বিমূর্ত বস্তু'] ,
['নির্বাচক', 'ভোটার', 'মতদাতা'] ,
['নির্বাচন করা', 'নির্বাচিত'] ,
['নির্বাচিত করা', 'বেছে নেওয়া'] ,
['নির্বাণ', 'নির্বাণ উপনিষদ', 'নির্বাণোপনিষদ', 'মহানির্বাণ', 'মহাপরিনির্বাণ', 'মুক্তি', 'মোক্ষ'] ,
['নির্বাণপ্রাপ্ত', 'মোক্ষপ্রাপ্ত.বন্ধনমুক্ত'] ,
['নির্বাত পাম্প', 'ভ্যাকুয়াম ক্লিনার'] ,
['নির্বাত', 'বাতশূণ্য', 'বায়ুশূণ্য', 'বায়ুহীন'] ,
['নির্বান', 'পরিত্রান', 'মোক্ষ'] ,
['নির্বাসন', 'নিষ্কাসন', 'বেরোনো', 'সরানো'] ,
['নির্বাসিত', 'নির্বাসিত', 'নিষ্কাশিত'] ,
['নির্বাহ', 'ভরণপোষণ নির্বহণ'] ,
['নির্বাহন করা', 'লড়া'] ,
['নির্বীজ করানো', 'নির্বীজকরণ করা'] ,
['নির্বীর', 'বীরশূণ্য', 'বীরহীন'] ,
['নির্ভীক', 'নির্ভয়', 'ভয়হীন'] ,
['নির্ভয়', 'ভয়হীনতা'] ,
['নির্মল', 'পরিষ্কার', 'বিশুদ্ধ', 'শুদ্ধ'] ,
['নির্মলা', 'নির্মলা পন্থা'] ,
['নির্মাণ শিল্প', 'বাস্তুকলা', 'স্থাপত্য কলা', 'স্থাপত্যকলা', 'স্থাপত্যশিল্প'] ,
['নির্মাণ', 'নির্মিতি', 'রচনা', 'সৃজন'] ,
['নির্মাতা', 'বিল্ডার', 'ভবন নির্মাতা'] ,
['নির্যাস', 'রস'] ,
['নির্লজ্জ নারী', 'বেহায়া', 'লজ্জাহীনা'] ,
['নির্লজ্জ', 'নিলাজ', 'বেহায়া', 'লজ্জাহীন', 'লাথখোর'] ,
['নির্লজ্জতা', 'লজ্জাহীনতা'] ,
['নির্লোভ', 'নির্লোভী', 'নিস্পৃহ', 'লালসামুক্ত', 'লালসারহিত', 'লালসাহীন', 'লোভশূণ্য', 'লোভহীন'] ,
['নিলাম', 'নিলাম বিক্রী'] ,
['নিশাচর পাখি', 'নিশাচর বিহঙ্গ'] ,
['নিশাচরী', 'রাক্ষসী'] ,
['নিশাজল', 'মিহিকা', 'শীত', 'হিম', 'হেম'] ,
['নিশাদ', 'নিশাভোজী'] ,
['নিশান', 'প্রতিরূপ', 'প্রতীক'] ,
['নিশানা বানানো', 'লক্ষ্য বানানো'] ,
['নিশানা', 'লক্ষ্য'] ,
['নিশিজাগরণ', 'নিশিপালন'] ,
['নিশিপাল', 'নিশিপালিকা'] ,
['নিশ্চিত', 'পাকা', 'পাক্কা', 'পুরো'] ,
['নিশ্চিরা', 'নিশ্চিরা নদী'] ,
['নিশ্বাস ত্যাগ করা', 'পরলোক গমন', 'মরা', 'মারা যাওয়া'] ,
['নিশ্বাস', 'প্রশ্বাস'] ,
['নিষধাবতী', 'নিষধাবতী নদী'] ,
['নিষাদ', 'নিষাদ জাতি', 'ব্যাধ', 'ব্যাধ জাতি'] ,
['নিষিদ্ধ.মানা', 'বারণ', 'মানা করা হয়েছে এমন'] ,
['নিষেধ করা', 'নিষেধাজ্ঞা জারী করা', 'মানা করা'] ,
['নিষেধ', 'প্রতিবন্ধ', 'বর্জন', 'বারণ'] ,
['নিষ্কপট', 'সত্', 'সাচ্চা'] ,
['নিষ্কম্প', 'নিস্পন্দ'] ,
['নিষ্কাম', 'প্রত্যাশারহিত'] ,
['নিষ্কাশিত', 'পদচ্যূত', 'বরখাস্ত'] ,
['নিষ্কৃতি', 'প্রায়শ্চিত্ত'] ,
['নিষ্ক্রিয়', 'সুপ্ত', 'সুসুপ্ত'] ,
['নিষ্পক্ষতা', 'পক্ষপাতহীনতা'] ,
['নিষ্পত্তি', 'প্রতীকার', 'মীমাংসা', 'সমঝোতা', 'সমাধান'] ,
['নিষ্পাদিত', 'পূর্ণ', 'শেষ', 'সমাপ্ত', 'সম্পন্ন', 'সম্পাদিত', 'সম্পূর্ণ'] ,
['নিষ্পাপ', 'পাপহীন'] ,
['নিষ্পাপতা', 'পাপহীনতা'] ,
['নিষ্পেক্ষ', 'পক্ষপাতহীন'] ,
['নিসর্গ', 'প্রকৃতি', 'মহামায়া'] ,
['নিস্কৃত-ধন', 'পণ'] ,
['নিস্তব্ধ', 'স্তম্ভিত'] ,
['নিস্তব্ধতা', 'নীরবতা', 'প্রশান্তি', 'শান্তি'] ,
['নিস্তার পাওয়া', 'বাঁচা'] ,
['নিস্তেজ', 'ভোঁতা', 'মন্দ'] ,
['নিহঙ্গ', 'নিহঙ্গ পথ', 'ব্রহ্মচারী'] ,
['নিহত', 'হত'] ,
['নিহাই', 'নেহাই'] ,
['নিয়ণ্ত্রণকর্তা', 'পরিচালক', 'সঞ্চালক', 'সঞ্চালনা কর্তা'] ,
['নিয়ত', 'সীমিত'] ,
['নিয়তি', 'ভবিতব্য'] ,
['নিয়তির অধীন', 'পূর্ব নির্ধারিত'] ,
['নিয়ন্ত্রক ও মহা লেখা পরীক্ষক', 'সিএজি'] ,
['নিয়ন্ত্রক', 'নিয়ামক', 'বিধিকারি'] ,
['নিয়ন্ত্রণ করা', 'নিয়ন্ত্রণ রাখা'] ,
['নিয়ন্ত্রণ সমিতি', 'সেন্সর বোর্ড'] ,
['নিয়ন্ত্রণে রাখা', 'বেঁধে রাখা'] ,
['নিয়ম পালক', 'নিয়মানুবর্তী'] ,
['নিয়ম পালন', 'নিয়ম-নিষ্ঠা', 'নিয়ম-পালন', 'বিধি-পালন'] ,
['নিয়ম মতো', 'নিয়মসম্মত', 'বিধিপূর্বক'] ,
['নিয়ম লঙ্ঘন', 'নিয়মভঙ্গ'] ,
['নিয়ম সংকলন', 'বিধি সংকলন'] ,
['নিয়ম', 'নিয়ম-কানুন', 'পরম্পরা', 'প্রোটোকল', 'বিনয়বিধি', 'যোগ-নিয়ম', 'যোগনিয়ম', 'রীতি', 'রীতি-নীতি', 'রেওয়াজ', 'সিদ্ধান্ত'] ,
['নিয়মকানুন', 'প্রনিয়ম', 'প্রবিধান', 'বিধিনিয়ম'] ,
['নিয়ামক', 'প্রবন্ধ-কর্তা', 'প্রবন্ধক', 'প্রবন্ধকর্তা', 'বিধায়ক', 'ব্যবস্থাপক', 'ম্যানেজার', 'রেগুলেটার'] ,
['নিয়ে নেওয়া', 'ফেরত্ নেওয়া'] ,
['নিয়ে যাওয়া', 'বার করা'] ,
['নিয়োগকর্তা', 'মালিক'] ,
['নীচ', 'পতিত', 'পাপাত্মা', 'পাপী'] ,
['নীতি', 'ন্যায়', 'পলিসি'] ,
['নীতিবাদ', 'বিধানবাদ'] ,
['নীতিবিদ', 'নীতিশাস্ত্রী'] ,
['নীমচ জেলা', 'নীমুচ'] ,
['নীমচ', 'নীমচ শহর'] ,
['নীমরোড', 'নীমরোড আম'] ,
['নীমহাকিম', 'হাতুড়ে ডাক্তার'] ,
['নীরগোঙ্গ', 'লাল অঞ্জন'] ,
['নীরস', 'ফিকে', 'বিস্বাদ', 'বেরসিক', 'রসহীন', 'রুক্ষ', 'শুকনো', 'শুষ্ক', 'স্বাদহীন'] ,
['নীল ডেল্টা', 'নীলনদের ব-দ্বীপ'] ,
['নীল প্রজাপতি', 'ব্লু'] ,
['নীল বস্ত্র', 'নীলাম্বর'] ,
['নীল মণি', 'নীলমণি', 'নীলা'] ,
['নীল', 'নীল রঙ'] ,
['নীলকন্ঠ', 'নীলকন্ঠ পাখি'] ,
['নীলক্রান্তা', 'বিষ্ণুক্রান্তা'] ,
['নীলগিরি', 'নীলগিরি জেলা', 'নীলগিরি পর্বত', 'নীলগিরি বৃক্ষ', 'নীলগিরি শহর'] ,
['নীলচক্র', 'শ্রী চক্র', 'শ্রীচক্র'] ,
['নীলনির্যাসক', 'নীলবীজ', 'নীলাসন', 'পিয়াসাল'] ,
['নীলপক্ষ শুক', 'মদনগৌড় টিয়া'] ,
['নীলফল', 'বেগুণ'] ,
['নীলম বনেশান', 'নীলম বনেশান আম', 'নীলম বনেশান আমের গাছ'] ,
['নীলম', 'নীলম আম'] ,
['নীলমেহ', 'নীলমেহ রোগ'] ,
['নীলরু', 'নীলসর', 'লীলগহী'] ,
['নীলশিগ্রু', 'মেচক', 'সজনে', 'সজনে ডাঁটা'] ,
['নুইয়ে পড়া', 'শুকিয়ে যাওয়া'] ,
['নুক্তা', 'বিন্দী', 'বিন্দু'] ,
['নুন', 'লবণ'] ,
['নুনিয়া', 'নোনি'] ,
['নুর জাহান', 'নুরজাহান'] ,
['নুলো', 'প্রতিবন্ধী', 'লুলা ল্যাংড়া'] ,
['নুয়াপাড়া', 'নুয়াপাড়া জেলা', 'নুয়াপাড়া শহর'] ,
['নূপুর', 'পায়েল'] ,
['নৃত্য-নাট্য', 'নৃত্যনাট্য'] ,
['নৃপ কুটুম্ব', 'রাজপরিবার'] ,
['নৃপ বল্লভা', 'বেগম', 'মহিষী', 'রানী'] ,
['নৃপকুমকুম', 'রোহিশ'] ,
['নৃপপ্রিয়া', 'পিন্ড-খেজুর', 'পিন্ডখেজুর', 'ফলপুষ্পা', 'ফলপুষ্পী'] ,
['নৃপোচিত', 'বর্বটি'] ,
['নৃমেধ', 'নৃমেধ ঋষি'] ,
['নৃসিংহতাপনী', 'নৃসিংহতাপনী উপনিষদ'] ,
['নেংটি', 'লেংটি', 'ল্যাঙোট'] ,
['নেওয়া', 'বলা'] ,
['নেওয়াজ', 'নেওয়াজ নদী'] ,
['নেওয়ারী', 'শিখরিণী'] ,
['নেকড়ে', 'নেকড়ে বাঘ'] ,
['নেকলেস', 'হার'] ,
['নেগ', 'নেগাচার'] ,
['নেট ওয়ার্ক', 'নেটওয়ার্ক'] ,
['নেতা', 'প্রধান ব্যক্তি', 'রাজনৈতিক নেতা', 'সর্দার'] ,
['নেতাজী', 'নেতাজী সুভাষচন্দ্র বোস', 'সুভাষ চন্দ্র বোস', 'সুভাষচন্দ্র', 'সুভাষচন্দ্র বোস'] ,
['নেত্তি', 'লেত্তি'] ,
['নেত্র ভঙ্গীমা', 'নেত্র মুদ্রা'] ,
['নেত্র রোগ', 'নেত্ররোগ'] ,
['নেদারল্যান্ড', 'হল্যান্ড'] ,
['নেপচুন', 'নেপচুন গ্রহ'] ,
['নেপথ্য', 'নেপথ্য গৃহ'] ,
['নেপাল বাসী', 'নেপাল-বাসী', 'নেপালবাসী', 'নেপালি'] ,
['নেপালী', 'নেপালী ভাষা'] ,
['নেপোলিয়ান', 'নেপোলিয়ান প্রথম', 'নেপোলিয়ান বোনাপার্ট'] ,
['নেভানো', 'বন্ধ করা'] ,
['নেশা বন্ধ', 'নেশাবন্ধ'] ,
['নেশা', 'নেশার জিনিস', 'মাদক', 'মাদক দ্রব্য'] ,
['নেশাখোর', 'নেশাড়ু'] ,
['নেশাগ্রস্ত', 'পানাসক্ত', 'মদমত্ত', 'মদ্যপ', 'মাদকাসক্ত', 'সুরাসক্ত'] ,
['নেশাদ্রব্য', 'মাদক'] ,
['নৈতিক কাজ', 'ভালো কাজ', 'সত্কার্য'] ,
['নৈনিতাল', 'নৈনিতাল জেলা', 'নৈনিতাল শহর'] ,
['নৈবেদ্য', 'ভোগ'] ,
['নৈসর্গিক প্রক্রিয়া', 'প্রাকৃতিক কার্য', 'প্রাকৃতিক ক্রিয়া', 'প্রাকৃতিক প্রক্রিয়া'] ,
['নৈসর্গিক বস্তু', 'প্রাকৃতিক বস্তু'] ,
['নৈসর্গিক শোভা', 'সিনারি'] ,
['নোংরা করা', 'মলিন করা'] ,
['নোংরা ভাব', 'নোংরামি'] ,
['নোংরা হওয়া', 'মলিন হওয়া', 'ময়লা হওয়া'] ,
['নোংরা', 'ময়লা'] ,
['নোঙ্গপো', 'নোঙ্গপো শহর'] ,
['নোড়া', 'মুষল'] ,
['নোধা', 'নোধা ঋষি'] ,
['নোনা ঘাস', 'লবণতৃণ'] ,
['নোনা', 'লবণাক্ত'] ,
['নৌ সেনা', 'নৌসেনা'] ,
['নৌকা আবাস', 'শিকারা', 'হাউস বোট'] ,
['নৌসেনা', 'নৌসৈনিক', 'নৌসৈন্য'] ,
['ন্যগ্রোধ', 'বটগাছ', 'বটবৃক্ষ', 'মহাচ্ছায়', 'যক্ষতরু', 'শিফাতরু'] ,
['ন্যায় কর্তা', 'ন্যায়কারী'] ,
['ন্যায়-দর্শন', 'ন্যায়-শাস্ত্র', 'ন্যায়দর্শন', 'ন্যায়শাস্ত্র'] ,
['ন্যায়পরায়ণ', 'বিনীত'] ,
['ন্যায়পূর্ণ', 'ন্যায়সংগত', 'ন্যায়োচিত'] ,
['ন্যায়শাস্ত্রজ্ঞ', 'ন্যায়শাস্ত্রবিদ'] ,
['ন্যুজ স্টুডিও', 'স্টুডিও'] ,
['ন্যুমারোলজি', 'সংখ্যাশাস্ত্র'] ,
['নয়ডা', 'নয়ডা শহর'] ,
['নয়াগড়', 'নয়াগড় জেলা', 'নয়াগড় শহর'] ,
['প', 'ব্যঞ্জনবর্ণ প'] ,
['পঁচাত্তর', 'পঁচাত্তর বছর', '৭৫'] ,
['পঁচানব্বই', '৯৫', '৯৫,'] ,
['পঁচাশি', '৮৫', '৮৫,'] ,
['পঁচিশ', 'পঁচিশ বছর'] ,
['পঁয়তাল্লিশ', '৪৫'] ,
['পঁয়ত্রিশ', 'পঁয়ত্রিশ বছর', '৩৫', '৩৫,'] ,
['পঁয়ষট্টি', 'পঁয়ষট্টি বছর', '৬৫', '৬৫,'] ,
['পংক্তি', 'লাইন'] ,
['পকেট বিলিয়ার্ডস', 'পুল'] ,
['পকোরা', 'ফুলুরি', 'বড়া'] ,
['পক্ক', 'পরিপক্ক', 'পাকা'] ,
['পক্ষপাতদুষ্ট', 'পক্ষপাতপূর্ণ'] ,
['পক্ষপাতশূণ্য', 'পক্ষপাতহীন'] ,
['পক্ষী সম্পর্কিত', 'পক্ষী সম্বন্ধায়'] ,
['পক্ষীমাংস', 'পাখির মাংস'] ,
['পঙক্তি', 'পাত পেড়ে খাওয়া'] ,
['পঙ্কতি', 'লাইন', 'শ্রেণী'] ,
['পঙ্কতিবদ্ধ হওয়া', 'লাইনে হওয়া', 'সারিবদ্ধ হওয়া'] ,
['পঙ্গু', 'প্রতিবন্ধী', 'ল্যাংড়া', 'শনৈশ্চর বাত রোগ'] ,
['পচন ধরা', 'পচা'] ,
['পচা', 'পচে যাওয়া'] ,
['পচাত্তর', '৭৫,'] ,
['পচ্চ-ব্রহ্ম', 'পচ্চ-ব্রহ্ম উপনিষদ'] ,
['পচ্চি বতা', 'পচ্চী', 'পাচি', 'পাচী'] ,
['পছন্দ হওয়া', 'পোষানো', 'ভালোলাগা'] ,
['পছন্দমাফিক', 'প্রিয়', 'রুচিকর'] ,
['পছন্দের', 'প্রিয়'] ,
['পঞ্চ তত্ত্ব', 'পঞ্চ ভূত', 'পঞ্চতত্ত্ব', 'পঞ্চভূত'] ,
['পঞ্চ-কোণ', 'পঞ্চকোণ'] ,
['পঞ্চকুলা', 'পঞ্চকুলা জেলা', 'পঞ্চকুলা শহর'] ,
['পঞ্চতন্ত্রী', 'পঞ্চতন্ত্রী বীণা'] ,
['পঞ্চতালেশ্বর', 'পঞ্চতালেশ্বর রাগ'] ,
['পঞ্চদেব', 'পঞ্চদেবতা'] ,
['পঞ্চধাতু', 'পঞ্চরস'] ,
['পঞ্চনদ', 'পাঞ্জাব'] ,
['পঞ্চনামা', 'সালিসনামা'] ,
['পঞ্চপাত', 'পঞ্চোলী'] ,
['পঞ্চপাত্র', 'পার্বণ শ্রাদ্ধ'] ,
['পঞ্চপ্রাণ', 'পঞ্চবায়ু'] ,
['পঞ্চম তার', 'লরজ'] ,
['পঞ্চম', 'পঞ্চম রাগ', 'পঞ্চম সুর', 'পা'] ,
['পঞ্চমহল', 'পঞ্চমহল জেলা'] ,
['পঞ্চমুখ', 'পঞ্চমুখী রুদ্রাক্ষ'] ,
['পঞ্চমূলী', 'স্বল্পপঞ্চমূল'] ,
['পঞ্চরক্ষক', 'পাখৌড়া'] ,
['পঞ্চান্ন', '৫৫', '৫৫,'] ,
['পঞ্চামৃত. চরণামৃত', 'মধুপর্ক'] ,
['পঞ্চাশ', 'পঞ্চাশ বছর'] ,
['পঞ্চায়ত ঘর', 'পঞ্চায়ত ভবন'] ,
['পট', 'ফলক', 'স্লেট'] ,
['পটনী', 'পটোঁহা'] ,
['পটা', 'পটে যাওয়া'] ,
['পটানো', 'রাজী করানো'] ,
['পটারি', 'পিয়াসন', 'ফরিয়া'] ,
['পটু', 'পটুক', 'পটোল', 'পটোলিকা', 'পটোলী', 'পাণ্ডুফল'] ,
['পটোরী', 'পটোল', 'পটোলা', 'পটোলী'] ,
['পট্ট', 'পাটা'] ,
['পট্টি পড়ানো', 'বিপথে চালিত করা'] ,
['পঠনাংশ', 'পাঠ'] ,
['পড়া', 'পড়াশোনা করা', 'পড়ে থাকা', 'পড়ে যাওয়া', 'পাত', 'ফেলা', 'শুরু হওয়া'] ,
['পড়ানো', 'শেখানো'] ,
['পড়িনাতি', 'পুতী', 'প্রপৌত্র'] ,
['পড়ে থাকা', 'ফেলা থাকা'] ,
['পণ করা', 'প্রতিজ্ঞা করা'] ,
['পণ', 'পণ প্রথা', 'প্রতিজ্ঞা', 'বাজি'] ,
['পণজী', 'পণজী শহর'] ,
['পণি', 'পণি ঋষি'] ,
['পণ্ডিচেরি', 'পণ্ডিচেরী', 'পণ্ডিচেরী জেলা'] ,
['পণ্ডিচেরী', 'পণ্ডিচেরী শহর'] ,
['পণ্য', 'পণ্যশালা', 'বাজার হাট'] ,
['পতঙ্গ', 'ফড়িং'] ,
['পতঙ্গভূক', 'পতঙ্গভোজী'] ,
['পতঞ্জলভাষ্য', 'মহাভাষ্য'] ,
['পতঞ্জলি', 'ভোগীন্দ্র'] ,
['পতনমতিট্টা', 'পতনমতিট্টা জেলা', 'পতনমতিট্টা শহর'] ,
['পতিতজমি', 'ফকিরান জমি'] ,
['পতিব্রতা', 'পতিব্রতা স্ত্রী', 'সতী'] ,
['পত্থরচটা', 'পথরচটা'] ,
['পত্নীনিষ্ঠ পুরুষ', 'পত্নীব্রত পুরুষ'] ,
['পত্নীভক্ত', 'স্ত্রীভক্ত', 'স্ত্রৈণ'] ,
['পত্র', 'পত্রক', 'পর্ণ', 'পল্লব', 'পাতা'] ,
['পত্রপুষ্পক', 'ভুজপত্র', 'ভোজ শিল্পী', 'ভোজপত্র', 'যুগ্মপত্র', 'শিতি', 'শিলি'] ,
['পত্রবাহক', 'প্যোস্টম্যান'] ,
['পত্রযুক্ত', 'পর্ণী', 'পাতাযুক্ত'] ,
['পত্রশুক', 'পর্ণশুক', 'ভেদাশি', 'ভোরা টিয়া', 'লাটকান'] ,
['পত্রিকা', 'ম্যাগাজিন'] ,
['পথ চলার', 'পায়ে হাঁটার'] ,
['পথ প্রদর্শক', 'মার্গ প্রদর্শক'] ,
['পথ', 'মার্গ', 'রাস্তা'] ,
['পথ-প্রদর্শন', 'পথপ্রদর্শন', 'মার্গ-দর্শন', 'মার্গদর্শন'] ,
['পথভোলা', 'মার্গচ্যূত'] ,
['পথভ্রষ্ট করা', 'ভুল রাস্তা বলা'] ,
['পথিক', 'পদব্রজী', 'পদযাত্রী', 'যাত্রী'] ,
['পথ্য', 'সুপথ্য আহার'] ,
['পদ আচ্ছাদন', 'পদ পরিধান', 'পদাবরণ'] ,
['পদ পূজা', 'পদ সেবা'] ,
['পদ', 'পা'] ,
['পদক', 'মেডেল'] ,
['পদক্ষেপণ', 'পা ফেলা'] ,
['পদচারী', 'পদাতিক'] ,
['পদদলন', 'মাড়ান'] ,
['পদবীধারী', 'পদাধিকারী'] ,
['পদযাত্রা', 'হাইকিঙ্গ'] ,
['পদাঘাত', 'লাথি'] ,
['পদাতিক সৈন্য', 'পদাতিকবাহিনী'] ,
['পদার্থ', 'বস্তু', 'মাল', 'সামগ্রী'] ,
['পদার্থবিজ্ঞান', 'ভৌতবিজ্ঞান'] ,
['পদার্থবিজ্ঞানী', 'ভৌতবিজ্ঞানী'] ,
['পদ্ম মুল', 'পদ্মকান্ড', 'মৃণাল', 'শালিনী'] ,
['পদ্ম', 'পদ্ম পুরাণ', 'পদ্মপুরাণ', '১০০০০০০০০০০০০০০০০'] ,
['পদ্ম-সমূহ', 'পদ্মাকর'] ,
['পদ্মপ্রভ', 'পদ্মপ্রভনাথ'] ,
['পদ্যকার', 'পদ্যলেখক'] ,
['পনেরো', '১৫'] ,
['পন্ত', 'মত', 'মার্গ', 'শাখা', 'সম্প্রদায়'] ,
['পপ গায়ক', 'পপ সিঙ্গার'] ,
['পপ মিউজিক', 'পপ সঙ্গীত'] ,
['পপুমপারে', 'পপুমপারে জেলা'] ,
['পপুয়া নিউ গিনী', 'পপুয়া নিউ গিনীয়া'] ,
['পবণ বাণ', 'পবণ-বাণ', 'পবণবাণ'] ,
['পবন পরীক্ষা', 'পবন-পরীক্ষা', 'পবনপরীক্ষা'] ,
['পবিত্র স্থান', 'পুণ্য ভূমি', 'পুণ্য স্থান'] ,
['পবিত্র', 'পুণ্য', 'পুত', 'শুদ্ধ'] ,
['পবিত্রতা', 'শুচিতা', 'শুদ্ধতা'] ,
['পবিত্রা', 'পাবিত্রপান একাদশী', 'পুত্রদা একাদশী', 'শ্রাবণ শুক্ল একাদশী'] ,
['পম্পা', 'পম্পাসর'] ,
['পরখ', 'পরিচয়', 'পরীক্ষা'] ,
['পরচর্চাকারী', 'রটন্তী'] ,
['পরজ', 'পরাজিকা'] ,
['পরজীবি', 'পরভোজী'] ,
['পরতযুক্ত', 'স্তরযুক্ত', 'স্তরিত'] ,
['পরদা', 'পর্দা', 'স্ক্রীন'] ,
['পরদাবিশিষ্ট', 'পরদাযুক্ত'] ,
['পরদারগামী', 'পরদারী', 'পরস্ত্রীগামী'] ,
['পরদেশ', 'পররাষ্ট্র', 'বিদেশ', 'বিলেত'] ,
['পরদেশী', 'বিদেশী', 'বিলাতি', 'ভিনদেশী'] ,
['পরনারী', 'পরপত্নী', 'পরস্ত্রী'] ,
['পরনের কাপড়ের ভাগ', 'পরিধান ভাগ', 'পোষাকের ভাগ', 'বস্ত্র ভাগ'] ,
['পরবন', 'পরবন নদী'] ,
['পরবর্তী', 'পরের'] ,
['পরভণী জেলা', 'প্রভাবতীনগর'] ,
['পরভণী', 'পরভণী শহর'] ,
['পরম প্রিয়', 'প্রিয়', 'প্রিয়তম'] ,
['পরমপরাগত', 'পরম্পরা', 'পারম্পরিকতা'] ,
['পরমব্রহ্ম', 'পরমব্রহ্ম উপনিষদ'] ,
['পরমহংস', 'পরমহংস উপনিষদ', 'পরমহংসোপনিষদ'] ,
['পরমহংস-পরিব্রাজক', 'পরমহংস-পরিব্রাজক উপনিষদ', 'পরমহংস-পরিব্রাজকোপনিষদ'] ,
['পরমানন্দ', 'ব্রহ্মানন্দ'] ,
['পরমান্ন', 'পায়েস'] ,
['পরম্পরা অনুসারে', 'পরম্পরানুসারে'] ,
['পরলোকগত', 'মৃত', 'স্বর্গীয়'] ,
['পরশ', 'পরশ পাথর', 'পরশ মণি'] ,
['পরশু', 'পরশু দিন'] ,
['পরশুরাম', 'ভার্গব', 'ভৃগুনন্দন', 'ভৃগুনাথ', 'ভৃগুনায়ক', 'ভৃগুপতি'] ,
['পরসর্গ', 'প্রত্যয়'] ,
['পরহিত', 'পরোপকার'] ,
['পরহিতৈষী', 'পরোপকারী'] ,
['পরা', 'পরিধান', 'পরিধান করা', 'লাগানো', 'সজ্জা'] ,
['পরা-বিদ্যা', 'ব্রহ্ম-বিদ্যা'] ,
['পরাক্রম', 'বাহুবল', 'বীরত্ব', 'ভূজবল', 'শারীরিক শক্তি'] ,
['পরাক্রমী', 'প্রতাপশালী', 'বীর', 'শূর'] ,
['পরাগকেশর', 'পুংকেশর'] ,
['পরাঙ্মুখ', 'বিমুখ'] ,
['পরাজিত করা', 'পরাস্ত করা', 'মাত করা', 'হারানো'] ,
['পরাজিত হওয়া', 'পরাস্ত হওয়া'] ,
['পরাজিত', 'পরাস্ত', 'বিজিত', 'হেরে যাওয়া ব্যক্তি'] ,
['পরানো', 'পরিধান করানো', 'লাগানো'] ,
['পরাবর্তন', 'প্রতিগমন'] ,
['পরামর্শ দেওয়া', 'বোঝানো', 'রায় দেওয়া'] ,
['পরামর্শ', 'প্রতিজল্প', 'বিচার-বিমর্শ', 'মতামত', 'মন্তব্য', 'মন্ত্রণা', 'রায়'] ,
['পরাশর', 'পরাশর ঋষি'] ,
['পরিকল্পনা করা', 'যোজনা বানানো'] ,
['পরিকল্পনা থাকা', 'ভাবনা থাকা'] ,
['পরিক্রমণ', 'পরিক্রমা', 'প্রদক্ষিণ', 'প্রদক্ষীণ'] ,
['পরিক্ষণ স্থল', 'পরিক্ষণ স্থান'] ,
['পরিচর্চা', 'সেবা'] ,
['পরিচয় জ্ঞাপক সংখ্যা', 'সংখ্যা'] ,
['পরিচয় পত্র', 'পরিচয়-পত্র'] ,
['পরিচয়', 'প্রশংসা'] ,
['পরিণতি', 'রুপান্তর'] ,
['পরিণীত', 'বিবাহিত'] ,
['পরিণীতা', 'বিবাহিত মহিলা', 'বিবাহিতা'] ,
['পরিণয়', 'বিবাহ', 'বিয়ে'] ,
['পরিধি', 'বৃত্ত পরিধি', 'বৃত্ত সীমা', 'মন্ডল'] ,
['পরিপক্ক হওয়া', 'পাকা'] ,
['পরিপক্ক', 'বিকশিত'] ,
['পরিপক্কতা', 'বিকাশ'] ,
['পরিপূরক', 'পূরক', 'সম্পূরক'] ,
['পরিপূর্ণ', 'পুরো', 'পূর্ণ', 'ভরা', 'ভর্তি'] ,
['পরিপোষক', 'পুষ্টিকর', 'পুষ্টিকর আহার', 'পুষ্টিকারক', 'পুষ্টিপ্রদ'] ,
['পরিবর্ত', 'বিকল্প'] ,
['পরিবর্তণ আনা', 'পরিবর্তিত হওয়া', 'বদলানো'] ,
['পরিবর্তণ করা', 'বদলানো', 'বদলে দেওয়া'] ,
['পরিবর্তন', 'বদল'] ,
['পরিবর্তনবাদী', 'পরিবর্তনবাদী ব্যক্তি'] ,
['পরিবর্তনশীল', 'পরিবর্তনীয়'] ,
['পরিবর্তিকা', 'পরিবর্তিকা রোগ'] ,
['পরিবর্তিত রূপ', 'পরিবৃত্ত রূপ'] ,
['পরিবর্তিত', 'বদল'] ,
['পরিবর্তে', 'বদলে'] ,
['পরিবার', 'ফ্যামিলি', 'বাড়ী'] ,
['পরিবারহীন', 'স্বজনহীন'] ,
['পরিবৃত্তি', 'পরিবৃত্তি অলঙ্কার'] ,
['পরিবেশ', 'পরিস্থিতি', 'বায়ুমন্ডল'] ,
['পরিবেশন করা', 'প্রতিপাদন করা'] ,
['পরিবেশন', 'বাড়া'] ,
['পরিব্যাপক', 'ব্যাপক'] ,
['পরিব্যাপ্ত', 'ব্যাপী', 'ব্যাপ্ত'] ,
['পরিব্রাজ', 'পরিব্রাজক'] ,
['পরিব্রাজক', 'সন্ন্যাসী'] ,
['পরিভাষা', 'ব্যাখা'] ,
['পরিমল', 'সুগন্ধ', 'সুবাস', 'সুরভি', 'সৌরভ'] ,
['পরিমাণ স্বরূপ', 'পরিমাণস্বরূপ', 'ফলত', 'ফলস্বরূপ'] ,
['পরিমাণ', 'মাত্রা', 'মান'] ,
['পরিমাপ', 'মাপ'] ,
['পরিমাপক', 'পেয়ালা', 'মাপ', 'মাপক', 'মাপা'] ,
['পরিমার্জন', 'পরিশোধণ', 'পরিষ্করণ', 'সংস্কার'] ,
['পরিমার্জিত', 'পরিশোধিত', 'পরিষ্কৃত', 'সংস্কৃত'] ,
['পরিমিতি', 'পার', 'বর্ডার', 'সীমা', 'সীমারেখা'] ,
['পরিযায়ী', 'প্রবাসী', 'ভ্রাম্যমান'] ,
['পরিযোজনা', 'প্রকল্প', 'প্রোজেক্ট'] ,
['পরির দেশ', 'পরীলোক'] ,
['পরিশিষ্ঠ', 'মুখবন্ধ'] ,
['পরিশুদ্ধ', 'পরিশোধিত', 'শোধিত', 'সংশোধিত'] ,
['পরিশোধণ', 'পরিষ্কার', 'বিশোধণ', 'শুদ্ধিকরণ', 'শোধণ'] ,
['পরিশোধিত', 'যান্ত্রিক উপায়ে পরিশোধিত'] ,
['পরিষদ', 'বোর্ড', 'সভা', 'সমিতি'] ,
['পরিষেবা প্রদানকারী সংস্থা', 'সার্ভিস সেণ্টার'] ,
['পরিষ্করণ কেন্দ্র', 'রিফাইনারী'] ,
['পরিষ্কার করানো', 'সাফ করানো'] ,
['পরিষ্কার', 'প্রকট', 'স্পষ্ট'] ,
['পরিসীমিত', 'সসীম', 'সীমাবদ্ধ', 'সীমিত'] ,
['পরিসীমিত. সীমাবদ্ধ', 'সসীম', 'সীমিত'] ,
['পরিস্কার করা', 'রগড়ানো'] ,
['পরিহার করা', 'বিরত থাকা'] ,
['পরিহার', 'বর্জন'] ,
['পরীক্ষা করা', 'যাচাই করা'] ,
['পরীক্ষা করানো', 'বিচার করানো', 'যাচাই করানো'] ,
['পরীক্ষা পত্র', 'পরীক্ষা-পত্র', 'পেপার', 'প্রশ্ন-পত্র', 'প্রশ্ন-পত্রিকা', 'প্রশ্নপত্র', 'প্রশ্নপত্রিকা'] ,
['পরীবন্দ', 'মল'] ,
['পরুচ্ছেয়', 'পরুচ্ছেয় ঋষি'] ,
['পরে', 'পশ্চাত্'] ,
['পরোষ্ণী', 'পরোষ্ণী নদী'] ,
['পরোয়া করা', 'মন দেওয়া', 'মনোযোগ দেওয়া'] ,
['পর্ণকার', 'পানওয়ালা'] ,
['পর্ণসা', 'পর্ণসা নদী', 'বেণা নদী'] ,
['পর্ণসি', 'শাক'] ,
['পর্ণাটক', 'পর্ণাটক ঋষি'] ,
['পর্ণাদ', 'পর্ণাদ ঋষি'] ,
['পর্ণিকা', 'ব্রহ্মপর্ণী'] ,
['পর্দা প্রথা', 'পর্দাপ্রথা'] ,
['পর্দা', 'যবনিকা'] ,
['পর্দাফাঁস হওয়া', 'প্রকাশ পাওয়া', 'রহস্যোদ্ঘাটন হওয়া', 'লিক হওয়া'] ,
['পর্দাফাস', 'রহস্য উদঘাটন', 'রহস্য প্রকাশ', 'রহস্য ফাস করা', 'রহস্য ভাঙা', 'লিক'] ,
['পর্বত নিবাসী', 'পর্বত বাসী', 'পর্বত-বাসী', 'পাহাড়ী'] ,
['পর্বত মালা', 'পর্বত শৃঙ্খলা', 'পর্বত শ্রেণী', 'পর্বতমালা', 'পর্বতশৃঙ্খলা', 'পর্বতশ্রেণী'] ,
['পর্বত', 'পর্বত সন্ন্যাসী'] ,
['পর্যটক', 'পর্যটনপ্রিয়', 'ভ্রমণ-প্রেমী', 'ভ্রমণপিপাসু', 'ভ্রমণপ্রেমী', 'ভ্রমণার্থী', 'যাযাবর'] ,
['পর্যটন স্হল', 'বেড়াবার জায়গা'] ,
['পর্যাপ্ত', 'যথেষ্ট'] ,
['পর্যাপ্ততা', 'যথেষ্টতা'] ,
['পলক্কড', 'পলক্কড জেলা', 'পলক্কড শহর'] ,
['পলল', 'পাললিক'] ,
['পলাণ্ডু', 'পিঁয়াজ', 'পেঁয়াজ', 'রক্তকন্দ', 'শল্ক'] ,
['পলাতক', 'ফেরার'] ,
['পলি', 'পলিমাটি'] ,
['পলিটেকনিক', 'বহুশিল্প'] ,
['পলিসি', 'বীমা নীতি', 'বীমা পলিসি'] ,
['পলেস্তরা', 'প্লাস্টার'] ,
['পল্লবিত হওয়া', 'বিকশিত হওয়া'] ,
['পশম সূতী বা মসলিনের তৈরী এক প্রকারের হাতাবিহীন ছোট জ্যাকেট', 'মিরজই'] ,
['পশম', 'পশমিনা'] ,
['পশমীনা', 'পশ্মীনা'] ,
['পশু চিকিত্সা', 'পশুচিকিত্সা'] ,
['পশু-পালন', 'পশুপালন'] ,
['পশুত্ব', 'পাশবিকতা'] ,
['পশুপক্ষী', 'পশুপাখি'] ,
['পশুপত', 'পশুপত উপনিষদ', 'পশুপতোপনিষদ'] ,
['পশুপতি', 'শঙ্কর', 'শশিভূষণ', 'শিব'] ,
['পশুপালন বিজ্ঞান', 'পশুপালন বিদ্যা', 'পশুপালন শাস্ত্র'] ,
['পশুর', 'পশুসম্বন্ধীয়', 'পাশব'] ,
['পশ্চজল', 'ব্যাকওয়াটর্স'] ,
['পশ্চাত', 'পশ্চাত অংশ', 'পশ্চাত ভাগ', 'পশ্চাদ্ভাগ', 'পিছনে', 'পৃষ্ঠভূমি', 'পেছন', 'পেছনের অংশ', 'পেছনের দিক'] ,
['পশ্চাতে', 'পিছু', 'পেছনে'] ,
['পশ্চাত্', 'পিছন'] ,
['পশ্চাদাগত', 'পিছিয়ে পড়া'] ,
['পশ্চিম কামেঙ্গ', 'পশ্চিম কামেঙ্গ জেলা'] ,
['পশ্চিম খাসি হিল্স', 'পশ্চিম খাসি হিল্স জেলা'] ,
['পশ্চিম গারো হিল্স', 'পশ্চিম গারো হিল্স জেলা'] ,
['পশ্চিম গোদাবরী', 'পশ্চিম গোদাবরী জেলা'] ,
['পশ্চিম চম্পারণ', 'পশ্চিম চম্পারণ জেলা'] ,
['পশ্চিম ত্রিপুরা', 'পশ্চিম ত্রিপুরা জেলা'] ,
['পশ্চিম বাংলা', 'বঙ্গ', 'বাংলা', 'বাংলা লিপি'] ,
['পশ্চিম মধ্য রেলওয়ে', 'পশ্চিমী মধ্য রেলওয়ে'] ,
['পশ্চিম মেদিনীপুর', 'পশ্চিম মেদিনীপুর জেলা'] ,
['পশ্চিম সামোয়া', 'সামোয়া', 'সামোয়া ই সিসিফো'] ,
['পশ্চিম সিংভুম', 'পশ্চিম সিংভুম জেলা'] ,
['পশ্চিম সিকিম', 'পশ্চিম সিকিম জেলা'] ,
['পশ্চিম সিয়াঙ্গ', 'পশ্চিম সিয়াঙ্গ জেলা'] ,
['পশ্চিম-ঘাট', 'পশ্চিমঘাট'] ,
['পশ্চিমি', 'পশ্চিমি হাওয়া'] ,
['পশ্চিমী', 'পাশ্চাত্য'] ,
['পা দান', 'পাদানি'] ,
['পা ফেলা', 'পা রাখা'] ,
['পা-দান', 'রেকাব'] ,
['পাঁচ তারিখ', '৫'] ,
['পাঁচ', '৫'] ,
['পাঁচটি রঙ বিশিষ্ট', 'পাঁচরঙা'] ,
['পাঁচতারা', 'ফাইভ স্টার'] ,
['পাঁচশো', '৫০০'] ,
['পাঁচিল', 'প্রাচীর'] ,
['পাঁজর', 'পাঁজরা'] ,
['পাঁঠার মাংস', 'মটন'] ,
['পাঁয়তা', 'পায়তানা'] ,
['পাইকারী বাজার', 'বাজার'] ,
['পাইলট', 'বায়ুযান-চালক', 'বিমান চালক'] ,
['পাউঁরুটি', 'পাও'] ,
['পাউন্ড', 'ব্রিটিশ পাউন্ড', 'লেবাননী পাউন্ড', 'সাইপ্রাসি পাউন্ড', 'সুদানি পাউন্ড'] ,
['পাউরুটি', 'ব্রেড'] ,
['পাওড়া', 'পৌরিয়া'] ,
['পাওনা', 'বকেয়া'] ,
['পাওয়া', 'পৌঁছানো', 'প্রাপ্ত', 'প্রাপ্ত করা', 'লাভ করা', 'হাসিল করা'] ,
['পাওয়ার প্লান্ট', 'পাওয়ার স্টেশন', 'পাওয়ার হাউস', 'বিদ্যুত্ কেন্দ'] ,
['পাওয়ার', 'বিদ্যুত'] ,
['পাওয়ি', 'ময়না'] ,
['পাক', 'পাকিস্তানি', 'মোচড়', 'রস', 'রান্না'] ,
['পাকশালা', 'ভোজনালয়', 'রান্নাঘর'] ,
['পাকশাস্ত্র', 'রন্ধন শাস্ত্র'] ,
['পাকশৈলী', 'রান্না করার কায়দা'] ,
['পাকা মেঝে', 'মেঝে'] ,
['পাকা রাস্তা', 'মার্গ', 'রাস্তা', 'রোড', 'সড়ক'] ,
['পাকা', 'পেকে যাওয়া', 'সঠিক'] ,
['পাকাতীসার', 'পাকাতীসার রোগ'] ,
['পাকানো', 'বানানো'] ,
['পাকারি গাছ', 'সাদা কচনার'] ,
['পাকিস্তান পিপল্স পার্টি', 'পিপিপি'] ,
['পাকিস্তান মুসলিম লীগ নওয়াজ', 'পিএমএলএন'] ,
['পাকিস্তানবাসী', 'পাকিস্তানি'] ,
['পাকুর', 'পাকুর জেলা', 'পাকুর শহর'] ,
['পাক্ষিক', 'পাক্ষিক পত্রিকা'] ,
['পাখিদের বসার মাচা', 'মাচা'] ,
['পাখির বাসা', 'বাসা'] ,
['পাচন তন্ত্র', 'পাচন-তন্ত্র', 'পাচনতন্ত্র'] ,
['পাচিত', 'হজম'] ,
['পাছুক', 'পাছুক নদী'] ,
['পাজামা', 'পায়জামা'] ,
['পাঞ্চাল', 'পাঞ্চাল দেশ'] ,
['পাঞ্জা', 'হাত'] ,
['পাঞ্জাব ও সিন্ধ ব্যাঙ্ক', 'পিএসবি'] ,
['পাঞ্জাব ন্যাশানাল ব্যাঙ্ক', 'পিএনবি'] ,
['পাঞ্জাববাসী', 'পাঞ্জাবী'] ,
['পাঞ্জাবী', 'পাঞ্জাবী ভাষা'] ,
['পাটওয়ারি', 'লেখপাল'] ,
['পাটন', 'পাটন জেলা', 'পাটন শহর'] ,
['পাটনা', 'পাটনা জেলা', 'পাটনা শহর', 'পাটুলিপুত্র'] ,
['পাটরাণী', 'মহারাণী', 'রাজমহিষী'] ,
['পাটস', 'পাটস বাঁদর'] ,
['পাটিয়ালা স্টেটব্যাংক', 'স্টেট ব্যাংক অফ পাটিয়ালা'] ,
['পাটেল', 'পাটেল জাতি'] ,
['পাঠ করা', 'বলা', 'শুনানো'] ,
['পাঠভেদ', 'পাঠ্যান্তর'] ,
['পাঠশালা', 'বিদ্যালয়', 'স্কুল'] ,
['পাঠশালার', 'বিদ্যালয়ের', 'স্কুলের'] ,
['পাঠান', 'পাঠান জাতি'] ,
['পাঠানো', 'প্রেরণ করা', 'প্রেরিত'] ,
['পাঠানোর মজুরী', 'পৌঁছানোর মজুরী'] ,
['পাঠ্য পুস্তক', 'পাঠ্য-পুস্তক', 'পাঠ্যপুস্তক'] ,
['পাঠ্য বিবরণ পুস্তিকা', 'পাঠ্যক্রম পুস্তিকা'] ,
['পাঠ্য', 'সুপাঠ্য'] ,
['পাঠ্য-ক্রম', 'পাঠ্যক্রম', 'পাঠ্যচর্চা'] ,
['পাণিগ্রহণীয়', 'প্রাণিগ্রাহিক', 'বৈবাহ', 'বৈবাহিক'] ,
['পাণিনি', 'মহর্ষি পাণিনি'] ,
['পাণ্ডা', 'পাণ্ডা বিয়ার', 'ভড্ডর', 'লাল পাণ্ডা'] ,
['পাণ্ডু', 'পাণ্ডু রঙ', 'পৃথাপতি'] ,
['পাণ্ড্য', 'পাণ্ড্য রাজবংশ'] ,
['পাতলা কোমরযুক্ত', 'পাতলা কোমরের'] ,
['পাতলা চাদর', 'স্টোল'] ,
['পাতলা', 'মিহি', 'সুক্ষ্ম'] ,
['পাতলুন', 'প্যান্ট'] ,
['পাতা', 'পাতার থালা', 'বিছানো'] ,
['পাতাল নিবাসী', 'পাতালনিবাসী'] ,
['পাতিয়ালা', 'পাতিয়ালা জেলা', 'পাতিয়ালা শহর'] ,
['পাত্র', 'বাসন', 'ভাঁড়'] ,
['পাথর ভাঙার শ্রমিক', 'শ্রমিক'] ,
['পাথর', 'শিলা খন্ড'] ,
['পাথরচটা', 'পুনর্নবা', 'বিশখিকা', 'বিশাখ', 'বিসখপরা', 'বৃশ্চী', 'বৃশ্চীব', 'রক্তবৃন্তক', 'শশিবাটিকা', 'শাকবীর'] ,
['পাথরবৃষ্টি', 'প্রস্তরবর্ষণ'] ,
['পাদরী', 'ফাদার'] ,
['পানফুল', 'পূগ-পুষ্পিকা'] ,
['পানসে', 'ফিকে'] ,
['পানালয়', 'ভাটিখানা', 'মদিরালয়'] ,
['পানাহারে সংযমী', 'মিতাচারী'] ,
['পানিপথ', 'পানিপথ জেলা', 'পানিপথ শহর'] ,
['পানিফল', 'শৃঙ্গাটক', 'সিঙ্গাড়া'] ,
['পানীয়', 'পেয়', 'পেয় পদার্থ'] ,
['পানের কৌটো', 'পানের ডাবর'] ,
['পানের পিক', 'পিক'] ,
['পান্না রঙের', 'পান্নারঙা'] ,
['পান্না', 'পান্না জেলা'] ,
['পাপাইয়া', 'পেঁপে'] ,
['পাপাঙ্কুশা', 'পাপাঙ্কুশা একাদশী'] ,
['পাপাধন', 'পাপাধন নদী'] ,
['পাপাধম', 'পাপিষ্ঠ', 'মহানীচ', 'মহাপাপী'] ,
['পাপিণী', 'পাপিষ্ঠা', 'পাপীয়সী'] ,
['পাপী', 'পাষণ্ড', 'ভণ্ড'] ,
['পাপোঁছা', 'পাপোশ'] ,
['পাবলিক সেক্টর আন্ডারটেকিং', 'পিএসয়ু'] ,
['পাব্লিক প্রাইভেট পার্টনারশিপ', 'পিপিপি'] ,
['পামর', 'পামর আম', 'পামর আম গাছ', 'বুদ্ধিহীন', 'মন্দবুদ্ধি', 'মূর্খ', 'স্বল্পবুদ্ধিসম্পন্ন'] ,
['পার করা', 'লঙ্ঘন করা'] ,
['পার হয়ে যাওয়া', 'পিছনে রয়ে যাওয়া'] ,
['পারস', 'পারস দেশ'] ,
['পারসিয়ান', 'ফারসি', 'ফারসি ভাষা'] ,
['পারসেন্ট', 'শতাংশ'] ,
['পারস্পারিক নিধি', 'মিউচুয়াল ফান্ড'] ,
['পারিজাত', 'বৃক্ষরাজ'] ,
['পারিতোষিক', 'পুরষ্কার', 'পুরস্কার', 'বকশিশ'] ,
['পার্ক', 'বলপার্ক', 'মুঙ্গো পার্ক'] ,
['পার্কস', 'রোজা পার্কস'] ,
['পার্টস', 'যন্রাংশ'] ,
['পার্টি', 'রাজনৈতিক দল'] ,
['পার্থ', 'পার্থ জাতি', 'পার্থ রাজ্য'] ,
['পার্থক্য', 'বিভেদ'] ,
['পার্থিব শরীর', 'স্থূল শরীর'] ,
['পার্থিব', 'ভৌতিক'] ,
['পার্বতী', 'পার্বতী নদী'] ,
['পার্বত্য', 'পাহাড়ী'] ,
['পার্শ্ব একাদশী', 'পার্শ্বেকাদশী'] ,
['পার্শ্ব ভাগ', 'পাশ', 'পাশ হওয়া'] ,
['পার্শ্ব', 'পাশ'] ,
['পার্শ্ববর্তী', 'পাশের'] ,
['পার্স', 'বটুয়া', 'হাত ব্যাগ'] ,
['পার্সি দেব', 'পার্সি দেবতা'] ,
['পাল', 'পাল বিধি'] ,
['পাল-তোলা নৌকা', 'মাস্তুলী নৌকা'] ,
['পালক', 'পালনকর্তা'] ,
['পালকাপ্য', 'পালকাপ্য ঋষি'] ,
['পালকি', 'শিবিকা', 'শিবীরথ', 'সুরাসন'] ,
['পালন করা', 'পোষা', 'মানা'] ,
['পালনপুর', 'পালনপুর শহর'] ,
['পালামু', 'পালামু জেলা', 'পালামু শহর'] ,
['পালি', 'পালি জেলা', 'পালি ভাষা', 'পালি শহর', 'পালী'] ,
['পালিত হওয়া', 'বড় হওয়া', 'লালিত পালিত হওয়া'] ,
['পাল্টা অভিযোগ', 'পাল্টা আরোপ'] ,
['পাল্টানো বা বদলানো', 'ফেরানো'] ,
['পাল্টে যাওয়া', 'বদলে যাওয়া'] ,
['পাল্লা', 'রেঞ্জ'] ,
['পাশ', 'পাশ যোগ'] ,
['পাশুপত - অস্ত্র', 'পাশুপত অস্ত্র', 'পাশুপতাস্ত্র'] ,
['পাশুপত রস', 'পাশুপতরস'] ,
['পাষাণ', 'প্রস্তর'] ,
['পাস', 'প্রবেশিকা', 'মঞ্জুর', 'সম্মতি প্রাপ্ত', 'স্বীকৃত'] ,
['পাসিঘাট', 'পাসিঘাট শহর'] ,
['পাহাড়ি গরুড়', 'পাহাড়ি তীসা'] ,
['পাহাড়ী মহুয়া', 'স্বল্পপত্রক'] ,
['পাহারাদার', 'সেপাই', 'সৈনিক'] ,
['পায়খানা করা', 'মলত্যাগ করা', 'হাগা'] ,
['পায়চারি করা', 'হাঁটা'] ,
['পায়রা', 'পায়রার মাংস'] ,
['পায়রী', 'পায়রী আম', 'রসপুরী আম'] ,
['পায়ু', 'পায়ু ঋষি'] ,
['পায়ে-চলা পথ', 'ফুটপাত'] ,
['পায়ে-পায়ে', 'পেছনে-পেছনে'] ,
['পায়ের আওয়াজ', 'পায়ের শব্দ'] ,
['পিঁপড়ে', 'পিপিলিকা'] ,
['পিঁয়াজ', 'পেঁয়াজ'] ,
['পিএ', 'প্রাইভেট অ্যাসিসটেন্ট', 'ব্যক্তিগত কর্মচারী'] ,
['পিএম', 'প্রধান-মন্ত্রী', 'প্রধানমন্ত্রী'] ,
['পিএমও', 'প্রধানমন্ত্রীর মন্ত্রক'] ,
['পিএসি', 'লোক লেখা সমিতি'] ,
['পিকো', 'পিকো আম'] ,
['পিঙ্গল', 'পিঙ্গলরাগ'] ,
['পিঙ্গলা', 'লক্ষ্মী'] ,
['পিচ্ছিল', 'হড়কানে'] ,
['পিচ্ছিলকারী', 'মসৃণকারী'] ,
['পিচ্ছিলপাদ', 'পিচ্ছিলপাদ রোগ'] ,
['পিছনে', 'পিছিয়ে'] ,
['পিছু করা', 'পিছু নেওয়া'] ,
['পিট্যুইটারি গ্রন্থি', 'পিট্যুইটারি গ্ল্যাণ্ড'] ,
['পিঠ', 'পৃষ্ঠদেশ'] ,
['পিঠা', 'পিঠে'] ,
['পিঠীনস', 'পিঠীনস ঋষি'] ,
['পিণ্ড', 'শ্রাদ্ধ পিণ্ড'] ,
['পিণ্ডালু', 'রক্তকন্দ', 'রতালু'] ,
['পিতল সম্পর্কিত', 'পিতলের তৈরী'] ,
['পিতা', 'বাপ', 'বাবা'] ,
['পিতা-মাতা', 'বাপ-মা', 'বাবা-মা', 'মাতা-পিতা'] ,
['পিতামহ', 'পিতামহ ঋষি'] ,
['পিতৃ সম্পত্তি', 'বাবার সম্পত্তি'] ,
['পিতৃকুল্যা', 'পিতৃকুল্যা নদী'] ,
['পিতৃঘাতী', 'পিতৃহন্তা'] ,
['পিতৃপুরুষ', 'পূর্বপুরুষ'] ,
['পিতৃহারা', 'পিতৃহীন'] ,
['পিত্ত কোষ', 'পিত্তকোষ', 'পিত্তাশয়'] ,
['পিত্ত', 'পিত্তাগ্নি'] ,
['পিত্তপাথরি', 'পিত্তপাথরি রোগ'] ,
['পিত্তবিদগ্ধ-দৃষ্টি', 'পিত্তবিদগ্ধ-দৃষ্টি রোগ'] ,
['পিত্তলা', 'পিত্তলা রোগ'] ,
['পিত্তস্রাব', 'পিত্তস্রাব রোগ'] ,
['পিত্তাণ্ড', 'পিত্তাণ্ড রোগ'] ,
['পিত্তাতিসার', 'পিত্তাতিসার রোগ'] ,
['পিত্তোদর', 'পিত্তোদর রোগ'] ,
['পিথৌরাগড়', 'পিথৌরাগড় জেলা', 'পিথৌরাগড় শহর'] ,
['পিদড়ী', 'পিদারা', 'পিদ্ধী', 'ফুটকি', 'বাবুনা'] ,
['পিনকুশন', 'পিনদান'] ,
['পিনাক', 'পিনাকি', 'শিবধনু'] ,
['পিনাবু', 'পিনাবু শহর'] ,
['পিনাল কোড', 'পেনাল কোড'] ,
['পিপে', 'ব্যারেল'] ,
['পিপ্পলাদ', 'পিপ্পলাদ ঋষি'] ,
['পিলভিট', 'পিলভিট জেলা', 'পিলভিট শহর'] ,
['পিলু', 'পিল্লু'] ,
['পিল্ল', 'পিল্ল রোগ'] ,
['পিশাচ', 'প্রেত', 'শয়তান'] ,
['পিষ্টপ্রমেহ', 'পিষ্টমেহ'] ,
['পিসতুতো বোন', 'পিসতুতো ভগিনী'] ,
['পিস্টন ছড়ি', 'পিস্টন দণ্ড', 'পিস্টন রড'] ,
['পিস্তল', 'বন্দুক'] ,
['পিয়ার', 'পিয়াল'] ,
['পীতবর্ণ', 'হরিদ্রাবর্ণ', 'হলুদ'] ,
['পীতলের কলশ', 'পীতলের ঘটে'] ,
['পীতাম্বর', 'হলুদ রঙের বস্ত্র'] ,
['পীর', 'পীর বাবা'] ,
['পীলু', 'পীলু রাগ'] ,
['পুঁছ', 'পুঁছ জেলা', 'পুঁছ শহর'] ,
['পুঁজ', 'রস'] ,
['পুঁজি বিনিয়োগকারী', 'বিনিয়োগকারী'] ,
['পুঁথিগত', 'বইয়ের'] ,
['পুংসবন', 'পুংসবন সংস্কার'] ,
['পুচ্ছ', 'লাঙ্গুল', 'লেজ', 'ল্যাজ'] ,
['পুচ্ছকণ্টক', 'বিছা', 'বিছে', 'বৃশ্চিক'] ,
['পুচ্ছদা', 'পুত্রকন্দা', 'বিষাখমূল', 'লক্ষণকন্দ', 'লক্ষণা'] ,
['পুটলি', 'পুটুলি'] ,
['পুডিং', 'পুডিঙ্গ'] ,
['পুণা', 'পুণে', 'পুণে জেলা', 'পুণে শহর'] ,
['পুণ্ডরিক', 'শ্বেত কমল', 'শ্বেত পদ্ম', 'শ্বেতোত্পল'] ,
['পুণ্যরহিত', 'পুণ্যহীন'] ,
['পুতিকর্ণ', 'পুতিকর্ণ রোগ', 'পুতিকর্ণক'] ,
['পুতিযোনি', 'পুতিযোনি রোগ'] ,
['পুতিরক্ত', 'পুতিরক্ত রোগ', 'পুতিরক্তরোগ'] ,
['পুত্র-বধূ', 'পুত্রবধূ', 'বউ', 'বধূ'] ,
['পুত্রকামী', 'পুত্রাভিলাষী'] ,
['পুত্রকামেষ্ঠি', 'পুত্রেষ্ঠি', 'পুত্রেষ্ঠি যজ্ঞ'] ,
['পুত্রতুল্য', 'পুত্রবত্'] ,
['পুত্রদা একাদশী', 'পৌষ-শুক্ল একাদশী', 'সুনন্দা একাদশী'] ,
['পুথিকা', 'পোই', 'মুকুন্দ'] ,
['পুদুকোট্টে', 'পুদুকোট্টে জেলা', 'পুদুকোট্টে শহর'] ,
['পুননির্মাণ', 'পুনর্রচনা'] ,
['পুনপ্রদর্শন', 'রিপ্লে'] ,
['পুনরাগমন', 'পুনরাবর্তন', 'প্রত্যাগমন', 'প্রত্যাবর্তন'] ,
['পুনরাবির্ভাব', 'পুনর্জন্ম', 'পুনর্জীবন'] ,
['পুনরাবৃত্তি করা', 'পুনরায় করা', 'পুনরায় বলা'] ,
['পুনরাবৃত্তি', 'পূর্বকথা'] ,
['পুনরায় পেষণ করা', 'পুনরায় পেষাই করা'] ,
['পুনরায় ফিরে পাওয়া', 'পুনরায় লাভ করা'] ,
['পুনরুক্তি করা', 'বার বার বলা'] ,
['পুনর্নিযুক্ত করা', 'বহাল করা'] ,
['পুনর্নিযুক্ত', 'বহাল'] ,
['পুনর্বাস', 'পুনর্বাসন'] ,
['পুনা অধিবাসী', 'পুনা নিবাসী', 'পুনাবাসী'] ,
['পুনুপুন', 'পুনুপুন নদী'] ,
['পুন্ডরিয়া', 'পুন্ডরী', 'পুন্ডর্য', 'মূলশোধন'] ,
['পুপ্পুট', 'পুপ্পুট রোগ'] ,
['পুরনপুরি', 'পুরনপুলি'] ,
['পুরন্দর', 'পুরন্দর কেল্লা'] ,
['পুরাতত্ত্ব', 'পুরাবিদ্যা', 'পুরাশাস্ত্র', 'প্রত্ন-বিজ্ঞান', 'প্রত্নতত্ত্ব', 'প্রত্নবিজ্ঞান'] ,
['পুরাতত্ত্ববিদ', 'প্রত্নতত্ত্ববিদ'] ,
['পুরাতন ও ভাঙ্গা জিনিসের বিক্রেতা', 'রদ্দিওয়ালা'] ,
['পুরাতন', 'পুরানো', 'পূর্বকালীন', 'প্রাচীন'] ,
['পুরাতাত্ত্বিক বস্তু', 'প্রত্নতাত্ত্বিক বস্তু'] ,
['পুরাতাত্ত্বিক', 'প্রত্নতাত্ত্বিক'] ,
['পুরী', 'পুরী জেলা', 'পুরী সন্ন্যাসী'] ,
['পুরু বংশজাত', 'পৌরব'] ,
['পুরুমিল্ল', 'পুরুমিল্ল ঋষি'] ,
['পুরুরবা', 'বিশ্বদেব'] ,
['পুরুলিয়া', 'পুরুলিয়া জেলা', 'পুরুলিয়া শহর'] ,
['পুরুষ গুপ্তাঙ্গ', 'পুরুষ জননাঙ্গ'] ,
['পুরুষ সিংহ', 'বলবান', 'বাহাদুর', 'বীর', 'বীর পুরুষ', 'শূর', 'শূরবীর'] ,
['পুরুষ', 'বংশ'] ,
['পুরুষ-সংক্রান্ত', 'পুরুষালি'] ,
['পুরুষত্ব', 'পৌরষ'] ,
['পুরুষদন্তিকা', 'বরা', 'মেদা', 'রসা', 'শল্যদা', 'শল্যা', 'স্বল্পপর্ণী'] ,
['পুরুহন', 'পুরুহন ঋষি'] ,
['পুরো করা', 'শেষ করা', 'সমাপ্ত করা'] ,
['পুরোহিত', 'যজমানী'] ,
['পুর্ণবসু', 'পুর্ণবসু নক্ষত্র', 'বাসু'] ,
['পুর্ণিয়া', 'পুর্ণিয়া জেলা', 'পুর্ণিয়া শহর'] ,
['পুল', 'সেতু'] ,
['পুলক', 'রোমাঞ্চ'] ,
['পুলকিত', 'রোমহর্ষিত', 'রোমাঞ্চিত'] ,
['পুলবামা', 'পুলবামা জেলা', 'পুলবামা শহর'] ,
['পুলহ', 'পুলহ ঋষি'] ,
['পুলিশ দ্বারা অনুসন্ধেয়', 'পুলিশ দ্বারা অভিপ্রেত', 'পুলিশের কাছে কাঙ্খিত'] ,
['পুলিশ', 'সেপাই'] ,
['পুলিস অধীক্ষক', 'সুপার', 'সুপারিন্টেণ্ডেন্ট'] ,
['পুলোম', 'পুলোমা'] ,
['পুষণ', 'পুষা'] ,
['পুষে রাখা', 'পোষণ করা'] ,
['পুষ্কল', 'মেরু', 'মেরুপর্বত', 'হেমাঙ্গ'] ,
['পুষ্ট', 'সংবর্ধিত'] ,
['পুষ্টি সম্প্রদায়', 'পুষ্টিমার্গ'] ,
['পুষ্টিকর', 'বলবর্ধক', 'শক্তিবর্ধক'] ,
['পুষ্প রস', 'পুষ্পসার'] ,
['পুষ্প', 'পুষ্পক', 'প্রসূন', 'ফুল'] ,
['পুষ্পক', 'পুষ্পক বিমান'] ,
['পুষ্পকৃচ্ছ', 'পুষ্পকৃচ্ছ ব্রত'] ,
['পুষ্পবর্ষা', 'পুষ্পবৃষ্টি'] ,
['পুষ্পভাগ', 'পুষ্পাঙ্গ'] ,
['পুষ্পমালা', 'পুষ্পমাল্য', 'ফুলের মালা'] ,
['পুষ্পিকা', 'লিঙ্গের ময়লা', 'শিশ্ন ময়লা'] ,
['পুষ্পিত করা', 'ফোটানো'] ,
['পুষ্পিত হওয়া', 'ফুল ফোটা'] ,
['পুষ্পিত', 'ফুলযুক্ত'] ,
['পুস্তক আলমারি', 'বই-য়ের আলমারি'] ,
['পুস্তক', 'বই'] ,
['পূজনীয়', 'পূজিতব্য', 'পূজ্যমান', 'বন্দনীয়'] ,
['পূজারী', 'সেবক'] ,
['পূণ্য', 'ভালো', 'মঙ্গলজনক', 'শুভ'] ,
['পূতদক্ষ', 'পূতদক্ষ ঋষি'] ,
['পূননিরীক্ষণে', 'পূনরীক্ষণ'] ,
['পূরণ', 'পূর্তি'] ,
['পূরিয়া', 'পূরিয়া রাগ'] ,
['পূর্ণ আশা', 'পূর্ণাশা'] ,
['পূর্ণ কোণ', 'পূর্ণকোণ'] ,
['পূর্ণকাম', 'সফল মনোরথ'] ,
['পূর্ণকায়', 'পূর্ণাঙ্গ', 'সর্বাঙ্গ'] ,
['পূর্ণগ্রাস', 'সর্বগ্রাস'] ,
['পূর্ণতা', 'সম্পূর্ণতা'] ,
['পূর্ণবসু', 'পূর্ণবসু নক্ষত্র'] ,
['পূর্ণহোম', 'পূর্ণাহুতি'] ,
['পূর্ণাঙ্গ কক্ষসমষ্টি', 'সুইট'] ,
['পূর্ণাশা', 'পূর্ণাশা নদী'] ,
['পূর্ণিমা', 'পূর্ণিমা তিথি'] ,
['পূর্ব কামেঙ্গ', 'পূর্ব কামেঙ্গ জেলা'] ,
['পূর্ব খাসি হিল্স', 'পূর্ব খাসি হিল্স জেলা'] ,
['পূর্ব গারো হিল্স', 'পূর্ব গারো হিল্স জেলা'] ,
['পূর্ব গোদাবরী', 'পূর্ব গোদাবরী জেলা'] ,
['পূর্ব চম্পারণ', 'পূর্ব চম্পারণ জেলা'] ,
['পূর্ব ফাল্গুনী নক্ষত্র', 'পূর্বফাল্গুনী'] ,
['পূর্ব মেদিনীপুর', 'পূর্ব মেদিনীপুর জেলা'] ,
['পূর্ব সিংভুম', 'পূর্ব সিংভুম জেলা'] ,
['পূর্ব সিকিম', 'পূর্ব সিকিম জেলা'] ,
['পূর্ব সিয়াঙ্গ', 'পূর্ব সিয়াঙ্গ জেলা'] ,
['পূর্ব সূচনা', 'পূর্বাভাস'] ,
['পূর্ব', 'পূর্ব দিশা', 'পূর্বীয়', 'প্রাচী', 'প্রাচ্য', 'প্রাথমিক', 'প্রারম্ভিক', 'ভূতপূর্ব', 'শুরুর'] ,
['পূর্বকথিত', 'পূর্বোক্ত'] ,
['পূর্বকর্ম', 'সঞ্চিত কর্ম'] ,
['পূর্বধারণা', 'পূর্বাগ্রহ'] ,
['পূর্বভাদ্রপদ', 'পূর্বভাদ্রপদ নক্ষত্র'] ,
['পূর্বা-ফাল্গুনী', 'পূর্বা-ফাল্গুনী নক্ষত্র'] ,
['পূর্বাভাস', 'ভবিষ্যদ্বাণী'] ,
['পৃথিবীর', 'ভূমন্ডলীয়'] ,
['পৃথুদর', 'ভুঁড়িওয়ালা'] ,
['পৃথ্বীরাজ', 'পৃথ্বীরাজ চৌহান'] ,
['পৃষ্ঠদেশ', 'পৃষ্ঠভূমি'] ,
['পৃষ্ঠা', 'পেজ'] ,
['পেঁচ', 'স্ক্রু'] ,
['পেকিং', 'বেজিং'] ,
['পেখম', 'ময়ূরপুচ্ছ', 'ময়ূরের পেখম'] ,
['পেখমওয়ালা', 'পেখমদার'] ,
['পেঙ্ঘট', 'পেঙ্ঘা'] ,
['পেট ভরা খাবার', 'ভারী খাবার'] ,
['পেট', 'ভুঁরি', 'মুখ'] ,
['পেটানো', 'প্রহার করা', 'মারা'] ,
['পেটুক', 'রসিক', 'স্বাদলোলুপ'] ,
['পেটেন্ট', 'সরকারি সনদ'] ,
['পেটের রোগ', 'বোগুমা'] ,
['পেট্রোল পাম্প', 'পেট্রোলপাম্প'] ,
['পেট্রোলিয়াম', 'পেট্রোলিয়াম জেলি'] ,
['পেনি', 'সেন্ট', 'সেন্টাইম', 'সেন্টিম'] ,
['পেনিসিলভেনিয়া ইউনিভারসিটি', 'পেনিসিলভেনিয়া বিশ্ববিদ্যালয়'] ,
['পেন্ট করা', 'পেন্টেড', 'রঙ করা'] ,
['পেন্ট', 'রঙ'] ,
['পেন্টিং', 'রঙ করা'] ,
['পেন্নার', 'পেন্নার নদী'] ,
['পেরম্বলুর', 'পেরম্বলুর জেলা', 'পেরম্বলুর শহর'] ,
['পেশ করা', 'প্রস্তুত করা', 'সামনে আনা'] ,
['পেশ', 'হাজির'] ,
['পেশী', 'মাংস-পেশী', 'মাংসপেশী'] ,
['পেষণ করা', 'পেষা'] ,
['পেষণ', 'পেষা'] ,
['পেষন', 'পেষাই'] ,
['পেসো', 'ফিলিপিনো পেসো', 'মেক্সিকান পেসো'] ,
['পেস্ট', 'লেই', 'স্প্রেড'] ,
['পেয়ারা', 'পেয়ারা গাছ'] ,
['পৈগনি', 'বঙ্কৌরা'] ,
['পৈঙ্গল', 'পৈঙ্গল উপনিষদ', 'পৈঙ্গলোপনিষদ'] ,
['পৈডি', 'মিকি'] ,
['পৈতৃক সম্পত্তি', 'মৌরুসি', 'সম্পদ'] ,
['পৈতৃক', 'বংশগত', 'বংশপরম্পরায়', 'বংশানুক্রমিক', 'মৌরুসী'] ,
['পৈল', 'পৈল ঋষি'] ,
['পোঁতানো', 'প্রোথিত করানো'] ,
['পোকা', 'লোনা'] ,
['পোজ', 'মুদ্রা'] ,
['পোতাশ্রয়', 'বন্দর'] ,
['পোনা', 'রহু', 'রুই', 'রোহিত', 'রোহিতক', 'রৌহিষ'] ,
['পোরবন্দর', 'পোরবন্দর জেলা', 'পোরবন্দর শহর'] ,
['পোরোমপট', 'পোরোমপট শহর'] ,
['পোর্ট বিলা', 'বিলা'] ,
['পোর্ট', 'পোর্ট ওয়াইন'] ,
['পোর্টফোলিও', 'বিনিয়োগ-তালিকা'] ,
['পোলিশ', 'পোলিশ ভাষা', 'পোল্যান্ডবাসী', 'পোল্যান্ডীয়'] ,
['পোলো', 'মার্কোপোলো'] ,
['পোল্ট্রি', 'মুরগী পালন কেন্দ্র'] ,
['পোষক', 'বর্ধক', 'বর্ধনকারী', 'বৃদ্ধিকারী'] ,
['পোষণ', 'বৃদ্ধি'] ,
['পোষ্য', 'প্রতিপালনীয়', 'প্রতিপাল্য'] ,
['পোসালিয়া', 'পোসালিয়া নদী'] ,
['পোস্ট কার্ড', 'পোস্টকার্ড'] ,
['পোস্ট-গ্র্যাজুয়েট', 'স্নাতকোত্তর'] ,
['পোস্টমর্টেম', 'শব পরাক্ষী', 'শব পরীক্ষণ', 'শবপরীক্ষণ', 'শবপরীক্ষা'] ,
['পোয়া', 'পৌনে', 'সোয়া'] ,
['পৌঁছানো', 'পৌঁছে যাওয়া'] ,
['পৌরপ্রধাণ', 'মেয়র'] ,
['পৌরাণিক জন্তু', 'পৌরাণিক জীব'] ,
['পৌরাণিক মহিলা', 'পৌরাণিক স্ত্রী'] ,
['পৌরাণিক স্থল', 'পৌরাণিক স্থান'] ,
['পৌরাণিক', 'মিথ সম্পর্কিত'] ,
['পৌরি গাড়োয়াল', 'পৌরি গাড়োয়াল জেলা'] ,
['পৌরি', 'পৌরি শহর'] ,
['পৌলুষি', 'সত্যযজ্ঞ', 'সত্যযজ্ঞ ঋষি'] ,
['পৌষ', 'পৌষ মাস'] ,
['পৌষ-কৃষ্ণা একাদশী', 'সফলা একাদশী', 'সফলা-একাদশী'] ,
['প্যাক', 'প্যাকেট'] ,
['প্যাট্রিক হোয়াইট', 'হোয়াইট'] ,
['প্যাণ্টোথিন', 'প্যাণ্টোথেনিক অ্যাসিড'] ,
['প্যাথোলজি', 'বিকারতত্ত্ব'] ,
['প্যাথোলজিকাল', 'বিকারতাত্ত্বিক'] ,
['প্যাথোলজিস্ট', 'বিকারবিজ্ঞানী', 'রোগ বিজ্ঞানী', 'রোগবিজ্ঞানী'] ,
['প্যান কার্ড', 'স্থায়ী খাতা ক্রমাঙ্ক কার্ড'] ,
['প্যারাগুয়ান', 'প্যারাগুয়েবাসী', 'প্যারাগুয়ের'] ,
['প্যারাগুয়ে', 'প্যারাগুয়ে দেশ', 'প্যারাগুয়ে নদী'] ,
['প্যারাথাইরয়েড', 'প্যারাথাইরয়েড গ্রন্থি'] ,
['প্যালেস', 'প্রাসাদ', 'মহল', 'রাজপ্রাসাদ', 'রাজবাড়ি', 'রাজমহল'] ,
['প্রকট হওয়া', 'প্রকোপ দেখা দেওয়া'] ,
['প্রকরণ', 'প্রসঙ্গ', 'বিষয়', 'বিষয়বস্তু', 'মামলা', 'সন্দর্ভ'] ,
['প্রকার', 'রূপ', 'স্ট্রেন'] ,
['প্রকাশনীয়', 'প্রকাশ্য'] ,
['প্রকাশম', 'প্রকাশম জেলা'] ,
['প্রকাশিত হওয়া', 'বেরোনো'] ,
['প্রক্ষিপ্ত', 'ফেলা'] ,
['প্রখণ্ড', 'ব্লক'] ,
['প্রগলভ্', 'প্রলাপী', 'বাচাল'] ,
['প্রচার', 'স্লোগান'] ,
['প্রচারক', 'প্রচারকারী'] ,
['প্রচেতা', 'প্রচেতা ঋষি'] ,
['প্রডিউসার', 'প্রযোজক'] ,
['প্রণয়', 'প্রার্থণা'] ,
['প্রণয়কৌতুক', 'ফষ্টিনষ্টি'] ,
['প্রণয়ী', 'প্রেমিক'] ,
['প্রতর্দন', 'প্রতর্দন ঋষি'] ,
['প্রতান', 'প্রতান ঋষি'] ,
['প্রতাপগড়', 'প্রতাপগড় জেলা', 'প্রতাপগড় শহর'] ,
['প্রতি এক', 'প্রতিটি', 'প্রত্যেক', 'সকল', 'সব', 'সমস্ত'] ,
['প্রতি পক্ষ', 'বিপক্ষ', 'বিরোধী পক্ষ'] ,
['প্রতিকন্নবর্ত্ম', 'প্রতিকন্নবর্ত্ম রোগ'] ,
['প্রতিকূল', 'বিপরীত', 'বিরুদ্ধ'] ,
['প্রতিকূলতা', 'বিরুদ্ধতা', 'বৈপরীত্য'] ,
['প্রতিক্রিয়া', 'প্রতিশোধ', 'ফিডব্যাক', 'বদলা'] ,
['প্রতিজ্ঞা বিরোধ', 'প্রতিজ্ঞা-বিরোধ', 'প্রতিজ্ঞাবিরোধ'] ,
['প্রতিজ্ঞা-বিরোধ', 'প্রতিজ্ঞাবিরোধ', 'বিরোধিতা'] ,
['প্রতিজ্ঞা-সন্যাস', 'প্রতিজ্ঞাসন্যাস'] ,
['প্রতিজ্ঞা-হানি', 'প্রতিজ্ঞাহানি'] ,
['প্রতিদিনের সাধারণ খাবার', 'রোজকার সাধারণ খাবার'] ,
['প্রতিদ্বন্দিতা করা', 'লড়া'] ,
['প্রতিদ্বন্দী', 'প্রতিযোগী', 'প্রতিস্পর্ধী', 'স্পর্ধী'] ,
['প্রতিদ্বন্দীতা', 'প্রতিযোগিতা'] ,
['প্রতিদ্বন্দ্ব', 'প্রতিদ্বন্দ্বিতা', 'প্রতিযোগিতা'] ,
['প্রতিদ্বন্দ্বী', 'প্রতিযোগী'] ,
['প্রতিধ্বনি', 'প্রতিশব্দ', 'প্রতিসরণ'] ,
['প্রতিনিধি মণ্ডল', 'প্রতিনিধিমণ্ডল'] ,
['প্রতিপক্ষ', 'প্রতিপক্ষীয়', 'প্রতিবাদী', 'বিপক্ষ', 'বিপক্ষীয়', 'বিরোধী'] ,
['প্রতিপক্ষী', 'বিপক্ষী', 'বিরোধী'] ,
['প্রতিপাদন', 'প্রদর্শন'] ,
['প্রতিপাদ্য', 'বাচ্য'] ,
['প্রতিপ্রভ', 'প্রতিপ্রভ ঋষি'] ,
['প্রতিফল', 'ফল', 'বদলা'] ,
['প্রতিবছর', 'ফিবছর', 'ফিসন'] ,
['প্রতিবন্ধ', 'শর্ত'] ,
['প্রতিবন্ধক', 'বাধা', 'বাধাদানকারী', 'রেলিং'] ,
['প্রতিবন্ধকতা', 'বাঁধা', 'ব্যাঘাত'] ,
['প্রতিবর্ত', 'প্রতিবর্তী ক্রিয়া'] ,
['প্রতিবাদ করা', 'বক্তৃতা দেওয়া', 'স্লোগান দেওয়া'] ,
['প্রতিব্রত', 'সতী ব্রত', 'সতীত্ব'] ,
['প্রতিভা', 'মেধা'] ,
['প্রতিভানু', 'প্রতিভানু ঋষি'] ,
['প্রতিভাবান', 'প্রতিভাশালী'] ,
['প্রতিভাশালী', 'প্রতিভাসম্পন্ন'] ,
['প্রতিভাস', 'বিভ্রম', 'ভ্রম', 'ভ্রান্ত ধারণা', 'ভ্রান্তি', 'মিথ্যা জ্ঞান'] ,
['প্রতিমন্ডক', 'প্রতিমন্ডক রাগ'] ,
['প্রতিমা', 'বিগ্রহ', 'মূর্তি'] ,
['প্রতিমূর্তি', 'প্রতিরূপ'] ,
['প্রতিযোগিতা করা', 'লড়াই করা'] ,
['প্রতিযোগীতা', 'প্রতিস্পর্ধা'] ,
['প্রতিরক্ষা', 'রক্ষা', 'সুরক্ষা'] ,
['প্রতিরোধ', 'বিরোধ', 'বিরোধিতা'] ,
['প্রতিলোম বিবাহ', 'প্রতিলোমবিবাহ'] ,
['প্রতিশোধকামী', 'প্রতিশোধপরায়ণ'] ,
['প্রতিষ্ঠাতা', 'সংস্থাপক'] ,
['প্রতিষ্ঠিত', 'স্থাপিত'] ,
['প্রতিস্থাপন', 'স্থাপন', 'স্থাপনা'] ,
['প্রতীত হওয়া', 'মনে হওয়া'] ,
['প্রতীত', 'মনে করা'] ,
['প্রতীতি', 'বিশ্বাস', 'ভরসা'] ,
['প্রত্যক্ষ অনুভূতি', 'প্রত্যক্ষ জ্ঞান'] ,
['প্রত্যক্ষ', 'সরাসরি', 'সোজা', 'সোজাসুজি'] ,
['প্রত্যক্ষদর্শী', 'সাক্ষী'] ,
['প্রত্যঙ্গিরা', 'প্রত্যঙ্গিরা ঋষি'] ,
['প্রত্যর্পণ করা', 'ফিরিয়ে দেওয়া'] ,
['প্রত্যাশী', 'মুখাপেক্ষী'] ,
['প্রত্যুতপন্নমতি', 'হাজিরজবাব'] ,
['প্রত্যেক প্রকারের', 'সকল প্রকারের'] ,
['প্রত্যেকের মধ্যে', 'সকলের মধ্যে', 'সবার মধ্যে'] ,
['প্রত্যয়িত', 'প্রমাণিত'] ,
['প্রথম গিয়ার', 'ফার্স্ট গিয়ার'] ,
['প্রথমতঃ', 'প্রথমে', 'শুরুতে', 'সর্ব প্রথম', 'সর্বপ্রথম'] ,
['প্রদক্ষিণ-পথ', 'প্রদক্ষিণ-মার্গ', 'প্ররিক্রমা পথ', 'প্ররিক্রমা মার্গ'] ,
['প্রদর', 'প্রদর রোগ'] ,
['প্রদর্শন কক্ষ', 'বিক্রী-কক্ষ', 'বিক্রয়-কক্ষ', 'শোরুম'] ,
['প্রদর্শনী কক্ষ', 'প্রদর্শনী হল'] ,
['প্রদীপ', 'প্রদীপ রাগ'] ,
['প্রদীপক', 'প্রদীপন'] ,
['প্রদেশ', 'সুবা'] ,
['প্রদোষ', 'প্রদোষ ব্রত', 'প্রদোষ-ব্রত'] ,
['প্রদ্যুমন', 'শম্বরারি', 'হরিসুত'] ,
['প্রধা', 'সুগ্রীবী'] ,
['প্রধাণ মন্ত্রী', 'প্রধাণমন্ত্রী'] ,
['প্রধাণ-মন্ত্রী', 'প্রধাণমন্ত্রী'] ,
['প্রধান অধ্যাপক', 'প্রধান শিক্ষক'] ,
['প্রধান অধ্যাপিকা', 'প্রধান শিক্ষিকা', 'প্রধানাধ্যাপিকা', 'মূখ্য অধ্যাপিকা'] ,
['প্রধান আচার্য', 'প্রধানাচার্যে'] ,
['প্রধান আচার্যা', 'প্রধানাচার্যা'] ,
['প্রধান আচার্য্য', 'প্রধানাচার্য্য', 'প্রিন্সিপাল'] ,
['প্রধান জেনারেল', 'প্রধান জেনারেল আধিকারিক'] ,
['প্রধান দরজা', 'মূখ্য দ্বার', 'মূখ্যদ্বার'] ,
['প্রধান নালী', 'প্রধান পাইপ', 'মেন পাইপ'] ,
['প্রধান নির্দেশক', 'মুখ্যনির্দেশক'] ,
['প্রধান বিষয়', 'মুখ্য বিষয়'] ,
['প্রধান রঙ', 'মুখ্য রঙ', 'মূল রঙ'] ,
['প্রধান', 'মুখ্য'] ,
['প্রপঞ্চন', 'বৈপরীত্য'] ,
['প্রবঞ্চনা', 'বেইমানি'] ,
['প্রবন্ধ', 'প্রবন্ধ-কাব্য', 'প্রবন্ধকাব্য', 'ব্যবস্হা'] ,
['প্রবন্ধিত', 'বিন্যস্ত', 'ব্যবস্থিত'] ,
['প্রবরা', 'প্রবরা নদী'] ,
['প্রবসিস', 'প্রবসিস বাদর', 'প্রবসিস বানর', 'প্রবোসিস', 'প্রবোসিস বাদর', 'প্রবোসিস বানর'] ,
['প্রবাদ', 'প্রবাদ-প্রবচন'] ,
['প্রবাল দ্বীপ', 'প্রবালদ্বীপ'] ,
['প্রবাসী', 'প্রোষিত'] ,
['প্রবাহিত করা', 'বইয়ে দেওয়া', 'ভাসানো'] ,
['প্রবাহিত হওয়া', 'বয়ে যাওয়া'] ,
['প্রবাহের দিকে', 'স্রোতের দিকে'] ,
['প্রবিষ্টি', 'প্রবেশ'] ,
['প্রবীণ', 'প্রাজ্ঞ'] ,
['প্রবেশদ্বার', 'সংযোগস্থল'] ,
['প্রবেশনীয়', 'প্রবেশ্য'] ,
['প্রভাতী', 'প্রভাবতী'] ,
['প্রভাব ফেলা', 'প্রভাবিত করা'] ,
['প্রভাবশালী', 'প্রভাবশীল'] ,
['প্রভিডেন্ট ফান্ড', 'ভবিষ্য-তহবিল'] ,
['প্রভুত্ব', 'শাসন', 'শাসনকাল'] ,
['প্রমাণ-পত্র', 'প্রমাণক', 'প্রমাণপত্র'] ,
['প্রমাণিকা', 'প্রমাণী'] ,
['প্রমাণিত হওয়া', 'সিদ্ধ হওয়া'] ,
['প্রমাণিত', 'প্রমাণীকরণ', 'সিদ্ধ'] ,
['প্রমুখ কার্যকারি আধিকারিক', 'মুখ্য কার্যকারি আধিকারিক', 'সর্বচ্চো কার্যকারি আধিকারিক', 'সর্বচ্চো প্রবন্ধ নির্ধেশক'] ,
['প্রমোদকামী', 'সুখিপ্সু'] ,
['প্রযত্ন সহকারে', 'যত্ন সহকারে', 'যত্নপূর্বক'] ,
['প্রযুক্ত', 'ব্যবহৃত'] ,
['প্রলম্ব', 'প্রলম্বাসুর'] ,
['প্রলাপ বকা', 'বকবক করা'] ,
['প্রলুব্ধ করা', 'লোভ দেখানো'] ,
['প্রলুব্ধ হওয়া', 'লুব্ধ হওয়া'] ,
['প্রলেপ লাগানো', 'লাগানো'] ,
['প্রলেপ', 'লেই', 'লেপ'] ,
['প্রলোভন', 'লালসা', 'লিপ্সা', 'লোভ', 'লোলুপতা'] ,
['প্রল্হাদ', 'ভক্ত প্রল্হাদ'] ,
['প্রলয়', 'বিনাশ', 'মহাপ্রলয়'] ,
['প্রশংসা করা', 'শাবাস বলা'] ,
['প্রশমনকারী', 'শান্তিকারী'] ,
['প্রশান্ত', 'প্রশান্ত মহাসাগর', 'শান্ত', 'স্থিরচিত্ত'] ,
['প্রশান্তি', 'শান্তি'] ,
['প্রশামক ওষুধ', 'শামক', 'শামক ওষুধ'] ,
['প্রশাসন', 'শাসন', 'শাসন ব্যবস্থা', 'সরকার'] ,
['প্রশাসিত', 'শাসিত'] ,
['প্রশিক্ষণ দেওয়া', 'প্রশিক্ষিত করা', 'যোগ্য করে তোলা'] ,
['প্রশ্ন করা', 'প্রশ্নচিহ্ন লাগানো', 'সন্দেহ করা'] ,
['প্রশ্ন চিহ্ন', 'প্রশ্নবাচক চিহ্ন', 'প্রশ্নবোধক চিহ্ন'] ,
['প্রশ্ন', 'প্রশ্ন উপনিষদ', 'প্রশ্নোপনিষদ', 'বিষয়', 'সমস্যা'] ,
['প্রশ্নকর্তা', 'প্রশ্নকর্ত্তা'] ,
['প্রশ্নমালা', 'প্রশ্নাবলী'] ,
['প্রশ্বাস', 'শ্বাস', 'শ্বাস নেওয়া'] ,
['প্রসঙ্গসম্বন্ধীয়', 'প্রাসঙ্গিক'] ,
['প্রসন্নান্ধ', 'প্রসন্নান্ধ রোগ'] ,
['প্রসবকারিনী', 'প্রসবিনী', 'প্রসূতি'] ,
['প্রসবিনী', 'প্রসুতা', 'প্রসুতি', 'প্রসুতিকা'] ,
['প্রসাধণ', 'মরবট'] ,
['প্রসার', 'বিস্তার'] ,
['প্রসিদ্ধ হওয়া', 'বিখ্যাত হওয়া'] ,
['প্রসেসর', 'সিপিয়ু'] ,
['প্রস্কণ্ড', 'প্রস্কণ্ড ঋষি'] ,
['প্রস্তর মূর্তি', 'শৈল্য প্রতিমা'] ,
['প্রস্তরারোহণ', 'রক কলাইম্বিং'] ,
['প্রস্তাব', 'সমাধাণ'] ,
['প্রস্তুত করা', 'সুসজ্জিত করা'] ,
['প্রস্তুত-কর্তা', 'প্রস্তুতকারক'] ,
['প্রস্ফুটিত হওয়া', 'ফোটা', 'বিকশিত হওয়া'] ,
['প্রস্রাব করা', 'মূত্রত্যাগ করা'] ,
['প্রস্রাব', 'মূত্র'] ,
['প্রস্রাবঘর', 'মূত্রাশয়'] ,
['প্রহৃত', 'প্রহৃত ঋষি'] ,
['প্রাইমারী কয়েল', 'প্রাথমিক কয়েল'] ,
['প্রাইস', 'মেরি লিওনটায়ন প্রাইস', 'লিওনটায়ন প্রাইস'] ,
['প্রাকৃতিক উতপাত', 'ভৌত্য সঙ্কট'] ,
['প্রাকৃতিক জায়গা', 'প্রাকৃতিক স্থান'] ,
['প্রাকৃতিক ভাবে পচনশীল', 'স্বাভাবিক ভাবে পচনশীল'] ,
['প্রাচীনকূল', 'প্রাচীনকূল ঋষি'] ,
['প্রাচীনপন্থী ব্যক্তি', 'সনাতনপন্থী ব্যক্তি'] ,
['প্রাচীনযোগ', 'প্রাচীনযোগ ঋষি'] ,
['প্রাজ্ঞ', 'লেখা পড়া জানা', 'শিক্ষিত'] ,
['প্রাজ্ঞী', 'বিদুষী'] ,
['প্রাণ নেওয়া', 'বধ করা', 'মেরে দেওয়া', 'হত করা', 'হত্যা করা'] ,
['প্রাণ বায়ু', 'প্রাণবায়ু'] ,
['প্রাণঘাতী', 'প্রাণান্তক'] ,
['প্রাণদণ্ড', 'মৃত্যুদণ্ড'] ,
['প্রাণপণ চেষ্টা করা', 'সর্বশক্তি প্রয়োগ করা'] ,
['প্রাণাগ্নি-হোত্র', 'প্রাণাগ্নি-হোত্র উপনিষদ', 'প্রাণাগ্নি-হোত্রোপনিষদ'] ,
['প্রাণীজাতি', 'প্রাণীমাত্র'] ,
['প্রাতঃকালে', 'সকাল সকাল'] ,
['প্রাতিপীয়', 'প্রাতিপীয় ঋষি', 'প্রাতিপেয়'] ,
['প্রাতৃদ', 'প্রাতৃদ ঋষি'] ,
['প্রাথমিক চিকিত্সা', 'ফার্স্ট এড'] ,
['প্রাদেশিক ভাষা', 'রাজ্যভাষা', 'রাষ্ট্রীয় ভাষা'] ,
['প্রাধান্য', 'শ্রেষ্ঠত্ব'] ,
['প্রান্ত দেশ', 'সীমাক্ষেত্র', 'সীমান্ত'] ,
['প্রান্ত', 'প্রান্ত ঋষি'] ,
['প্রাপ্ত', 'লব্দ্ধ', 'সহজপ্রাপ্য', 'সহজলভ্য'] ,
['প্রাপ্তি পত্র', 'প্রাপ্তিকা', 'রসিদ'] ,
['প্রামতি ঋষি', 'প্রামধি ঋষি'] ,
['প্রারম্ভিক', 'শুরু'] ,
['প্রার্থনা করা', 'মিনতি করা'] ,
['প্রার্থনা', 'বন্দনা', 'স্তব', 'স্তুতি', 'স্তোত্র'] ,
['প্রাসাদ', 'বাড়ি'] ,
['প্রায়ই আসা', 'প্রায়শঃই আসা'] ,
['প্রায়োগিক', 'প্রয়োগাত্মক'] ,
['প্রিয়তমা', 'প্রিয়া', 'প্রেমিকা', 'প্রেয়সী', 'বনিতা', 'সজনী'] ,
['প্রিয়বাদী', 'প্রিয়ভাষী', 'প্রিয়ম্বাদী'] ,
['প্রিয়মেধ', 'প্রিয়মেধ ঋষি'] ,
['প্রিয়াবৃত্ত', 'মৃগী'] ,
['প্রীতি', 'প্রেম'] ,
['প্রেক্ষাগার', 'প্রেক্ষাগৃহ'] ,
['প্রেত বাধা', 'প্রেত-বাধা', 'প্রেতবাধা', 'বাধা'] ,
['প্রেতপুরী', 'মৃত্যুলোক', 'যমপুরী', 'যমলোক'] ,
['প্রেতভূমি', 'শবদাহ স্থল', 'শ্মশান', 'শ্মশানঘাট'] ,
['প্রেম করা', 'ভালবাসা'] ,
['প্রেম প্রদর্শন', 'প্রেমাচার'] ,
['প্রেম হওয়া', 'প্রেমে পড়া'] ,
['প্রেম', 'প্রেম-প্রসঙ্গ', 'রোমান্স'] ,
['প্রেমকথা', 'প্রেমকাহিনী'] ,
['প্রেমবারি', 'প্রেমাশ্রু'] ,
['প্রেমিক', 'প্রেমী'] ,
['প্রেমে পূর্ণ', 'প্রেমের'] ,
['প্রেমের চিহ্ন', 'ভালোবাসার চিহ্ন'] ,
['প্রেরক', 'প্রেরণ কর্তা'] ,
['প্রেরণাত্মক', 'প্রেরণাদায়ক', 'প্রেরণাস্পদ'] ,
['প্রেরণাদানকারী', 'প্রেরণাদায়ী'] ,
['প্রেস কন্ফারেন্স', 'প্রেস সম্মেলন', 'প্রেসবার্তা'] ,
['প্রেসবার্গ', 'ব্রাতিস্লাভা'] ,
['প্রেয়', 'সিডাডে ডি প্রেয়'] ,
['প্রোজেশ', 'রোহিণী', 'রোহিণী নক্ষত্র'] ,
['প্রোটেস্টান্ট', 'প্রোটেস্টান্ট চার্চ', 'প্রোটেস্ট্যান্ট'] ,
['প্রোটোকল', 'সম্প্রেষণ প্রোটোকল'] ,
['প্রোড়োকিত', 'প্রোড়োকিত অলঙ্কার'] ,
['প্রোথিত', 'রোপা', 'রোপিত'] ,
['প্রোপাগান্ডা', 'স্বপ্রচার'] ,
['প্রোস্টেট গ্রন্থি', 'প্রোস্টেট গ্ল্যাণ্ড'] ,
['প্রৌড়', 'মধ্যবয়স্ক', 'মাঝবয়সি'] ,
['প্রৌঢ়', 'মধ্যবয়স্ক'] ,
['প্রয়োজনবতী লক্ষণা', 'প্রয়োজনবতীলক্ষণা'] ,
['প্রয়োজনীয় অবস্হা', 'প্রয়োজনীয় পরিস্হিতি'] ,
['প্লাজমা', 'রক্ত প্লাবিকা', 'রক্তরস'] ,
['প্লাবন', 'বাণ', 'ভাসা', 'মহা-প্লাবন'] ,
['প্লেগ', 'মরক', 'মহামারি'] ,
['প্লেট', 'প্লেট নদী'] ,
['পয়সা', 'সিকি'] ,
['ফ', 'ব্যঞ্জনবর্ণ ফ'] ,
['ফকিরানা', 'ফকিরী'] ,
['ফজলী', 'ফজলী আম'] ,
['ফটকিরি', 'ফিটকারি'] ,
['ফটফটি', 'বাইক', 'মটোরবাইক', 'মোটরসাইকেল', 'মোবাইক'] ,
['ফণ্ট', 'লিপি'] ,
['ফতেগড় শহর', 'ফতেহগড় সাহিব', 'ফতেহগড় সাহিব শহর'] ,
['ফতেগড় সাহিব', 'ফতেগড় সাহিব জেলা'] ,
['ফতেহপুর', 'ফতেহপুর জেলা', 'ফতেহপুর শহর', 'ফতেহপুর সিক্রী', 'ফতেহপুরসিক্রী'] ,
['ফতেহাবাদ', 'ফতেহাবাদ জেলা', 'ফতেহাবাদ শহর'] ,
['ফর-ফর আওয়াজ', 'ফরফরানি'] ,
['ফরফরানি', 'ফরফরানির শব্দ'] ,
['ফরশী', 'ফর্শী'] ,
['ফরাসী গুয়ানার', 'ফরাসী গুয়ানীয়'] ,
['ফরাসী', 'ফরাসী ভাষা'] ,
['ফরিদকোট', 'ফরিদকোট জেলা', 'ফরিদকোট শহর'] ,
['ফরিদাবাদ', 'ফরিদাবাদ জেলা', 'ফরিদাবাদ শহর'] ,
['ফরুখাবাদ', 'ফরুখাবাদ জেলা', 'ফরুখাবাদ শহর'] ,
['ফর্সা ভাব', 'ফর্সা হওয়া'] ,
['ফল দেয়', 'লাভ দেয়'] ,
['ফলওলা', 'ফলদায়ক', 'ফলদায়ী'] ,
['ফলক', 'ফলা', 'বোর্ড'] ,
['ফলদ', 'ফলদায়ক', 'ফলদায়ী', 'ফলপ্রদ'] ,
['ফলাফল', 'সার'] ,
['ফলিত জ্যোতিষ', 'ফলিত-জ্যোতিষ'] ,
['ফলিত', 'ফলীভূত'] ,
['ফলের উদ্যান', 'ফলের বাগান'] ,
['ফল্গু', 'ফল্গু নদী'] ,
['ফাঁদ', 'ফাঁস'] ,
['ফাঁপা', 'ফোলা', 'স্ফীতি'] ,
['ফাঁস', 'রশি'] ,
['ফাঁসানো', 'সমস্যায় ফেলা'] ,
['ফাইনাল', 'ফাইনাল ম্যাচ'] ,
['ফাগ', 'ফাগুয়া', 'হোলী'] ,
['ফাটল', 'ফেটে যাওয়া'] ,
['ফাটা', 'ফেটে যাওয়া'] ,
['ফাটিয়ে দেওয়া', 'ভেঙে ফেলা'] ,
['ফারসী', 'ফারসী লিপি'] ,
['ফার্টিলাইজার', 'সার'] ,
['ফার্স্ট ট্র্যাক আদালত', 'ফার্স্ট ট্র্যাক কোর্ট'] ,
['ফালতু', 'রদ্দি'] ,
['ফাল্গুন', 'বসন্ত'] ,
['ফাল্গুন-কৃষ্ণ একাদশী', 'বৈকুন্ঠ একাদশী'] ,
['ফাল্তু', 'বেকার', 'ব্যর্থ'] ,
['ফাস্সেল', 'ফাস্সেল আম', 'ফাস্সেল আম গাছ'] ,
['ফিকে', 'বেরঙা', 'মলিন', 'হাল্কা'] ,
['ফিক্সড ডিপোজিট', 'মেয়াদী জমা'] ,
['ফিক্স্ড ডিপোজিট', 'স্থায়ী আমানত'] ,
['ফিঙ্গা', 'ফিঙ্গে'] ,
['ফিট হওয়া', 'হওয়া'] ,
['ফিট', 'ফুট'] ,
['ফিতা', 'ফিতে', 'ফেটা', 'বন্ধনী', 'বলয়'] ,
['ফিতে', 'বন্ধ', 'রিবন'] ,
['ফিনল্যান্ডবাসী', 'ফিনল্যান্ডীয়'] ,
['ফিনল্যান্ডীয়', 'ফিনিশ'] ,
['ফিরঙ্গ', 'ফিরঙ্গদেশ', 'ফিরঙ্গিস্তান'] ,
['ফিরিঙ্গীবাত', 'ফিরিঙ্গীবাতরোগ'] ,
['ফিরিয়ে দেওয়া', 'ফেরত্'] ,
['ফিরে আসা', 'ফেরা'] ,
['ফিরোজপুর', 'ফিরোজপুর জেলা', 'ফিরোজপুর শহর'] ,
['ফিরোজাবাদ', 'ফিরোজাবাদ জেলা', 'ফিরোজাবাদ শহর'] ,
['ফিলিপিনীয়', 'ফিলিপিন্সবাসী'] ,
['ফিলিপিন্স', 'ফিলিপিন্স গণরাজ্য', 'ফিলিপিন্স দ্বীপসমূহ'] ,
['ফিল্ড', 'ফীল্ড', 'মাঠ', 'ময়দান'] ,
['ফিসফিস', 'ফিসফিসানি'] ,
['ফুকন নল', 'ব্লোয়ার'] ,
['ফুটকীযুক্ত', 'বিন্দু চিহ্নিত'] ,
['ফুটবলার', 'ফুটবলার খেলোয়াড়'] ,
['ফুটে যাওয়া', 'বাষ্পীভূত হওয়া'] ,
['ফুটো করানো', 'ফোটানো', 'বিঁধানো'] ,
['ফুরফুরে', 'হাল্কা'] ,
['ফুর্তি', 'স্ফুর্তি', 'স্বতস্ফুর্ততা'] ,
['ফুলকি', 'স্ফুলিঙ্গ'] ,
['ফুলবানি', 'ফুলবানি শহর'] ,
['ফুলসয্যা', 'ফুলসয্যার রাত', 'মধুরাত'] ,
['ফুলে যাওয়া', 'ফোলা'] ,
['ফুসকুড়ি', 'ফোঁড়া'] ,
['ফুস্কুরি', 'ব্রণ'] ,
['ফূর্তিবাজ', 'স্ফূর্তিবাজ'] ,
['ফেঁসে থাকা', 'বন্দী হওয়া', 'ব্যস্ত হয়ে থাকা'] ,
['ফেক', 'ফেক জেলা', 'ফেক শহর'] ,
['ফেটে যাওয়া', 'ভেঙে যাওয়া'] ,
['ফেটে যাওয়ার শব্দ', 'ভেঙে যাওয়ার শব্দ'] ,
['ফেন', 'ভাতের ফেন'] ,
['ফেনক', 'ফেনি'] ,
['ফেনাযুক্ত', 'ফেনিল'] ,
['ফেরত', 'ফেরত দেওয়া'] ,
['ফেরার', 'ফেরারী'] ,
['ফেলা', 'ফেলে দেওয়া'] ,
['ফৈজাবাদ', 'ফৈজাবাদ জেলা', 'ফৈজাবাদ শহর'] ,
['ফোঁটা', 'বিন্দু', 'শীকর'] ,
['ফোঁড়া সৃষ্টিকারী', 'ব্লিস্টার এজেণ্ট'] ,
['ফোঁড়া', 'ব্রণ'] ,
['ফোকর দরজা', 'হ্যাচ'] ,
['ফোট', 'ভাগ', 'যা', 'যা ভাগ'] ,
['ফোটা', 'বিদ্ধ হওয়া', 'বেধা'] ,
['ফোনোগ্রাফ', 'রেকর্ড প্লেয়ার', 'শব্দ উচ্চারণ যন্ত্র'] ,
['ফোর্স', 'বল', 'বাহিনি'] ,
['ফৌজদারি', 'ফৌজদারি আদালত', 'ফৌজদারি কোর্ট', 'ফৌজদারি বিচারালয়'] ,
['ফৌজদারী শাসন', 'মিলিটারি শাসন'] ,
['ফৌজি', 'যোদ্ধা', 'সেপাই', 'সৈনিক'] ,
['ফ্যাকাল্টি', 'শিক্ষক ও অশিক্ষক কর্মচারীবৃন্দ', 'স্টাফ'] ,
['ফ্যান', 'মাড়'] ,
['ফ্রিজ', 'রেফ্রিজারেটর'] ,
['ফ্রেঞ্চ গায়না', 'ফ্রেঞ্চ গিয়ানা', 'ফ্রেঞ্চ গুয়না'] ,
['ফ্রেঞ্চ সুদান', 'মালি', 'মালি গণরাজ্য'] ,
['ফ্লুনিট্রাজপেন', 'রোহাইপনাল', 'রোহিপ্নাল'] ,
['ফ্লোরিঙ্গান', 'ফ্লোরিঙ্গান আম', 'ফ্লোরিঙ্গান আম গাছ'] ,
['ব', 'ব্যঞ্জনবর্ণ ব'] ,
['বংশগতি', 'বংশানুক্রমিতা'] ,
['বংশজ', 'বংশধর', 'সন্তান'] ,
['বংশবলী', 'বংশবৃক্ষ'] ,
['বংশী বাদক', 'বাঁশিবাদক'] ,
['বংশী', 'বাঁশি', 'বেণু', 'মুরলী'] ,
['বউভক্তি', 'স্ত্রৈনতা'] ,
['বওয়া', 'বহন করা'] ,
['বওয়ানো', 'বহন করানো'] ,
['বক বক করা', 'বিড়বিড় করা'] ,
['বক', 'বকাসুর'] ,
['বকা', 'বকা-ঝকা', 'বকুনি'] ,
['বকুল', 'বসু', 'মৌলশ্রী', 'মৌলসিরী', 'শকদ্রুম', 'শারদ', 'শীঘুগন্ধ'] ,
['বকেয়া', 'বাকি', 'শেষ'] ,
['বক্তব্য রাখা', 'বলা', 'ভাষণ দেওয়া'] ,
['বক্তব্য', 'বয়ান'] ,
['বক্তৃতাদাতা', 'ভাষণদাতা'] ,
['বক্রতা', 'বাঁক', 'বেঁকা'] ,
['বক্রোক্তি করা', 'ব্যঙ্গোক্তি করা'] ,
['বক্রোক্তি', 'বাঁকা কথা'] ,
['বক্ষ', 'বক্ষ-স্থল', 'বুক'] ,
['বক্সার', 'বক্সার জেলা', 'বক্সার শহর'] ,
['বক্সিং', 'মুষ্টিযুদ্ধ'] ,
['বখর', 'মরেঠি'] ,
['বগলকোট', 'বগলকোট জেলা', 'বগলকোট শহর'] ,
['বঙ্গবাসী', 'বাঙ্গালী', 'বাঙ্গালী রাগ'] ,
['বঙ্গাইগাঁও', 'বঙ্গাইগাঁও জেলা', 'বঙ্গাইগাঁও শহর'] ,
['বচনবাগীশ', 'বাকচতুর', 'বাকপটু', 'বাকসিদ্ধ', 'বাক্যবাগীশ', 'বাক্যবিশারদ', 'বাগীশ', 'বাগ্মী', 'বাচস্পতি'] ,
['বছর', 'বর্ষ', 'সাল'] ,
['বছরের', 'বর্ষীয়'] ,
['বজায় থাকা', 'বহাল থাকা', 'হয়ে থাকা'] ,
['বজ্র', 'বল্লম', 'বাজ'] ,
['বজ্র-সূচি', 'বজ্র-সূচি উপনিষদ'] ,
['বজ্রপাত', 'বজ্রাঘাত', 'বিদ্যুতপাত'] ,
['বঞ্চিত রয়ে যাওয়া', 'বাদ রয়ে যাওয়া'] ,
['বট পূর্ণিমা', 'বট-পূর্ণিমা', 'বটপূর্ণিমা'] ,
['বটসাবিত্রী', 'সাবিত্রীব্রত'] ,
['বটের', 'বর্তক', 'ভরতপাখি', 'লাব', 'লাবক'] ,
['বট্টু', 'বোড়া'] ,
['বড় আকার নেওয়া', 'বাড়িয়ে তোলা'] ,
['বড় করা', 'বাড়িয়ে তোলা'] ,
['বড় টিয়া পাখি', 'হীরামন টিয়া পাখি'] ,
['বড় তুলাদণ্ড', 'বড় দাঁড়িপাল্লা'] ,
['বড় পাখী', 'বড় বিহঙ্গ'] ,
['বড় রাবড়ী', 'রাবড়ী'] ,
['বড়হংস', 'বড়হংস রাগ'] ,
['বড়ো ঘর', 'হল'] ,
['বড়ো থালা', 'বারকোশ'] ,
['বড়ো দাঁতযুক্ত', 'বড়ো দাঁতের'] ,
['বড়ো হাতুড়ি', 'হাতুড়ি'] ,
['বড়ো', 'বিস্তৃত', 'লম্বা চওড়া', 'লার্জ সাইজ'] ,
['বড়ো-জাল', 'মহাজাল'] ,
['বডি বিল্ডিং', 'শারীরিক সৌষ্ঠব'] ,
['বণিক', 'ব্যবসায়ী'] ,
['বত্রিশ', '৩২', '৩২,'] ,
['বত্স', 'বত্স ঋষি'] ,
['বদল করানো', 'বদলি করানো'] ,
['বদল', 'বদলে যাওয়া'] ,
['বদলানো', 'বদলে দেওয়া', 'স্থানান্তরিত করা', 'স্থানান্তরিত হওয়া'] ,
['বদলি', 'স্থানান্তকরণ', 'স্থানান্তরণ'] ,
['বদাযুঁ', 'বদাযুঁ জেলা'] ,
['বদায়ুঁ', 'বদায়ুঁ শহর'] ,
['বদ্ধ', 'বায়ুনিরোধী'] ,
['বদ্রীকাশ্রম', 'বদ্রীনাথ', 'বদ্রীনাথে ধাম'] ,
['বধ হওয়া', 'হত্যা হওয়া'] ,
['বন বিভাগ', 'বন-বিভাগ', 'বনবিভাগ'] ,
['বন', 'বন সন্ন্যাসী'] ,
['বনড়া', 'বনড়া রাগ'] ,
['বনড়াজৈত', 'বনড়াজৈত রাগ'] ,
['বনড়াদেবগরী', 'বনড়াদেবগরী রাগ'] ,
['বনপ্রস্থ', 'বনপ্রস্থ আশ্রম'] ,
['বনবকরা', 'বনবকরা পাখি'] ,
['বনবিড়াল', 'বনবেড়াল'] ,
['বনভূমি', 'বনাঞ্চল', 'শাদ্বল', 'সবুজ'] ,
['বনমাষ', 'মাষপর্ণী', 'লোমশপর্ণী', 'সিংহচিত্রা', 'সিংহপর্ণী'] ,
['বনরাজ', 'বনরাজ আম'] ,
['বনসানাই', 'শণঘণ্টা', 'শণঘণ্টিকা', 'শণপুষ্পী', 'শণসমা', 'শণিকা', 'স্বল্পঘণ্টা'] ,
['বনস্পতিহীন', 'বৃক্ষহীন', 'শস্যহীন'] ,
['বনাম', 'বিরুদ্ধে'] ,
['বনাস', 'বনাস নদী', 'বন্নাস', 'বন্নাস নদী', 'বাসিষ্ঠী'] ,
['বনিয়াদি', 'মূল'] ,
['বনেশান', 'বনেশান আম', 'বনেশান আমের গাছ'] ,
['বন্দবস্ত', 'ব্যবস্থা'] ,
['বন্দুকের মাছি', 'মাছি'] ,
['বন্ধক দেওয়া', 'বন্ধক রাখা'] ,
['বন্ধন', 'বাঁধন'] ,
['বন্ধনমুক্ত', 'মুক্ত', 'স্বাধীন'] ,
['বন্ধনী', 'বন্ধনী চিহ্ন'] ,
['বন্ধুত্ব', 'মিত্রতা', 'মৈত্রী'] ,
['বন্ধুত্বপূর্ণ', 'মৈত্রীপূর্ণ'] ,
['বন্ধুযুক্ত', 'মিত্রযুক্ত', 'সমিত্র', 'সসখ', 'সাথীযুক্ত'] ,
['বন্ধুরহিত', 'বন্ধুহীন', 'মিত্ররহিত', 'মিত্রহীন', 'সখাহীন'] ,
['বন্ধেজ', 'বাঁধনী', 'বাজীকরণ'] ,
['বন্ধ্যা', 'বাঁজ'] ,
['বন্যজন্তু', 'বন্যজীব'] ,
['বন্যা-পীড়িত', 'বন্যাকবলিত', 'বন্যাপীড়িত'] ,
['বপন করা', 'বোনা'] ,
['বপন', 'বীজারোপন'] ,
['বমন করা', 'বমি করা'] ,
['বমন করানো', 'বমি করানো'] ,
['বম্', 'বম্ ভোলা', 'বম্-বম্'] ,
['বম্বে গ্রীন', 'মালদা', 'মালদা আম'] ,
['বম্বে স্টক্ এক্সচেঞ্জ', 'বি এস আই', 'বিএসআই'] ,
['বম্বে', 'মুম্বাই'] ,
['বরগাঁও জেলা', 'বরগাম জেলা'] ,
['বরগাঁও শহর', 'বরগ্রাম শহর'] ,
['বরতন্তু', 'বরতন্তু ঋষি'] ,
['বরদাস্ত করা', 'সহ্য করা'] ,
['বরপণ', 'যৌতুক'] ,
['বরফ যুগ', 'হিম যুগ'] ,
['বরফ', 'হিম'] ,
['বরফাচ্ছাদিত', 'বরফাবৃত'] ,
['বরফি', 'বর্ফি'] ,
['বরফের মতো', 'হিমবত্'] ,
['বরবটি', 'লোবিয়া'] ,
['বরান', 'মানিটার'] ,
['বরাহ পুরাণ', 'বরাহপুরাণ'] ,
['বরাহ', 'বরাহ অবতার', 'বরাহ উপনিষদ', 'বরাহোপনিষদ'] ,
['বরাহকান্তা', 'শুকরী', 'শুয়োরী'] ,
['বরিষ্ঠ', 'বুড়ো', 'বৃদ্ধ', 'বয়স্ক', 'বয়োবৃদ্ধ'] ,
['বরিষ্ঠা', 'বুড়ি', 'বৃদ্ধা', 'বৃদ্ধা মহিলা', 'বয়স্কা', 'বয়োবৃদ্ধা'] ,
['বরুণেশ', 'শতভিষা', 'শতভিষা নক্ষত্র'] ,
['বরুথিনী একাদশী', 'বৈশাখ একাদশী'] ,
['বরুন্ডিবাসী', 'বরুন্ডিয়ান'] ,
['বরুন্ডির', 'বরুন্ডিয়ান', 'বরুন্ডীয়'] ,
['বরেলি', 'বরেলি শহর'] ,
['বরোলী', 'বরোলী জেলা'] ,
['বর্কর', 'মেষশাবক'] ,
['বর্গ', 'শ্রেণী', 'সমাজ', 'সমূহ', 'সম্প্রদায়'] ,
['বর্গকিমি', 'বর্গকিলোমিটার'] ,
['বর্গহীন', 'শ্রেণীহীন'] ,
['বর্গাকার', 'বর্গাকৃতির'] ,
['বর্গীয়', 'শ্রেণীর'] ,
['বর্জ্য পদার্থ', 'ময়লা'] ,
['বর্ডার', 'বাউন্ড্রি', 'সীমা', 'সীমানা'] ,
['বর্ণ সংকর', 'সংকরিত'] ,
['বর্ণ', 'বর্ণা', 'রঙ', 'রঙের'] ,
['বর্ণনা করা', 'ব্যাখ্যা করা'] ,
['বর্ণনা', 'বৃত্তান্ত', 'হুলিয়া'] ,
['বর্ণনাত্মক', 'বর্ণনামূলক'] ,
['বর্ণান্ধ', 'বর্ণান্ধতায় আক্রান্ত'] ,
['বর্ণিক', 'বার্ণিক'] ,
['বর্ধমান', 'বর্ধমান জেলা', 'বর্ধমান মহাবীর', 'বর্ধমান শহর', 'ভগবান মহাবীর', 'মহাবীর'] ,
['বর্ধা', 'বর্ধা জেলা', 'বর্ধা শহর'] ,
['বর্মা', 'ব্রক্ষদেশ', 'মায়ানমার'] ,
['বর্শী', 'মাছ ধরার ছিপ'] ,
['বর্ষণ করা', 'বৃষ্টি করা'] ,
['বর্ষণ', 'বর্ষা', 'বৃষ্টি'] ,
['বর্ষা হওয়া', 'বর্ষিত হওয়া', 'বৃষ্টি হওয়া'] ,
['বর্ষা', 'বৃষ্টি'] ,
['বর্ষাকালীন বায়ু', 'মৌসুমী বায়ু'] ,
['বল করে যে খেলোয়াড়', 'বোলার'] ,
['বলগা', 'রাশ', 'লাগাম'] ,
['বলগাহরিণ', 'রেনডিয়ার'] ,
['বলদ', 'বৃষ', 'বৃষভ', 'ষাঁড়'] ,
['বলবত্করণ', 'সিদ্ধকরণ'] ,
['বলরামপুর', 'বলরামপুর জেলা', 'বলরামপুর শহর'] ,
['বলসাড', 'বলসাড়', 'বলসাড় জেলা', 'বলসাড় শহর'] ,
['বলা', 'বোঝানো', 'শুনানো', 'শোনানো', 'সূচিত করা'] ,
['বলাঙ্গির জেলা', 'বোলাঙ্গির জেলা'] ,
['বলাঙ্গির', 'বোলাঙ্গির', 'বোলাঙ্গির শহর'] ,
['বলি', 'বলিপশু'] ,
['বলিচিহ্ন', 'বলিরেখা'] ,
['বলিভিয়া', 'বলিভিয়া গণতন্ত্র', 'বলিভিয়া গণরাজ্য'] ,
['বলিভিয়ান', 'বলিভীয়'] ,
['বলিষ্ঠ গঠনের', 'সুঠাম চেহারার', 'স্বাস্থ্যবান'] ,
['বলিষ্ঠ', 'বলী', 'শক্তিমান', 'শক্তিশালী'] ,
['বলিয়া', 'বলিয়া জেলা', 'বলিয়া শহর'] ,
['বল্কলপরিহিত', 'বাকলপরিহিত'] ,
['বল্খ', 'বাহলীক', 'বাহলীক দেশ'] ,
['বল্বজ', 'বল্বজা'] ,
['বল্লম', 'শক্তি'] ,
['বশিত্ব', 'বাশিত্ব'] ,
['বশীকরণ বিদ্যা', 'মোহিনী বিদ্যা', 'সম্মোহিনী বিদ্যা'] ,
['বশীকরণকারী', 'সম্মোহনকারী'] ,
['বশীভূত', 'মুগ্ধ', 'মোহিত'] ,
['বসন্ত উত্সব', 'বসন্ত-মহোত্সব', 'বসন্তোত্সব', 'মদন-মহোত্সব', 'মদনোত্সব', 'মধূত্সব'] ,
['বসন্ত পঞ্চমী', 'বসন্ত-পঞ্চমী'] ,
['বসন্ততিলক', 'বসন্ততিলকা'] ,
['বসন্তরোগ', 'মা', 'শীতলা'] ,
['বসপা', 'বহুজন সমাজ পার্টি'] ,
['বসবাসকারী', 'বাসিন্দা'] ,
['বসা', 'বসানো'] ,
['বসানো', 'লাগানো', 'স্থান দেওয়া'] ,
['বসাপ্রমেহ', 'বসাপ্রমেহ'] ,
['বসুকর্ণ', 'বসুকর্ণ ঋষি'] ,
['বসুকৃত', 'বসুকৃত ঋষি'] ,
['বসুক্র', 'বসুক্র ঋষি'] ,
['বসুটোল্যান্ড', 'লেসোটো', 'লেসোথো'] ,
['বসুবাহু', 'বসুবাহু ঋষি'] ,
['বসুমনা', 'বসুমনা ঋষি'] ,
['বসে থাকা', 'বেরোজগেরে থাকা'] ,
['বসে যাওয়া', 'সরে দাঁড়ানো'] ,
['বস্তর', 'বস্তর জেলা'] ,
['বস্তি', 'বস্তি জেলা', 'বস্তি শহর'] ,
['বস্তুত্প্রেক্ষা', 'বস্তুত্প্রেক্ষা অলঙ্কার'] ,
['বস্ত্রধারী', 'বস্ত্রপরিধানকারী', 'বস্ত্রাভূষিত'] ,
['বস্ত্রবিপণী', 'বস্ত্রভান্ডার', 'বস্ত্রাগার', 'বস্ত্রালয়'] ,
['বস্ত্রাচ্ছাদ', 'বস্ত্রাবরণ'] ,
['বহন করা', 'বয়ে নিয়ে যাওয়া'] ,
['বহরমপুর', 'বহরমপুর শহর'] ,
['বহরাইচ', 'বহরাইচ জেলা'] ,
['বহিঃঅঙ্গ', 'বাহ্য অঙ্গ'] ,
['বহিরঙ্গ', 'বাইরের', 'বাহ্য'] ,
['বহিরিন্দ্রিয়', 'বাহ্য ইন্দ্রিয়', 'বাহ্যেন্দ্রিয়'] ,
['বহির্ভিমুখী', 'বহির্মুখী', 'বাহিরমুখী'] ,
['বহির্ষি', 'বহির্ষি ঋষি'] ,
['বহিষ্ককরণ', 'বহিষ্কার'] ,
['বহিষ্কার করা', 'সরিয়ে দেওয়া', 'হটানো', 'হটিয়ে দেওয়া'] ,
['বহু কাল', 'যুগ'] ,
['বহু সময়', 'বহুদিন'] ,
['বহু হাজার', 'হাজার হাজার'] ,
['বহুজন সমাজবাদী পার্টি', 'বিএসপি'] ,
['বহুপ্রহৃত', 'মারখাওয়া'] ,
['বহুবর্শী গাছ', 'বহুবর্শীয় গাছ'] ,
['বহুবৃচ', 'বহুবৃচ উপনিষদ', 'বহুবৃচোপনিষদ'] ,
['বহুব্রীহি', 'বহুব্রীহি সমাস', 'বহুব্রীহিসমাস'] ,
['বহুভাষিক', 'বহুভাষী'] ,
['বহুমত', 'মেজরিটি'] ,
['বহুরঙা', 'রঙ-বেরঙের'] ,
['বহেড়া', 'বয়ড়া'] ,
['বাঁ হাত', 'বাম ভূজ', 'বাম হস্ত'] ,
['বাঁ', 'বাম'] ,
['বাঁক', 'ব্যবর্তন', 'মোচড়'] ,
['বাঁকা', 'বাঁকা জেলা', 'বাঁকা শহর'] ,
['বাঁকুড়া', 'বাঁকুড়া জেলা', 'বাঁকুড়া শহর'] ,
['বাঁচা', 'রক্ষা পাওয়া'] ,
['বাঁচানো', 'বাঁচিয়ে তোলা', 'ভাল রাখা', 'রক্ষা করা', 'সংরক্ষিত রাখা', 'সঞ্চয়', 'সুরক্ষিত রাখা'] ,
['বাঁদা', 'বাঁদা জেলা', 'বাঁদা শহর'] ,
['বাঁধাই', 'বাঁধানো', 'বানানো'] ,
['বাঁসবাড়া', 'বাঁসবাড়া জেলা'] ,
['বাংলা', 'বাংলা ভাষা'] ,
['বাইপাস', 'বাইপাস সার্জারি'] ,
['বাইর', 'বাহির'] ,
['বাইরে', 'বিদেশ'] ,
['বাউণ্ডলে', 'হতচ্ছাড়া'] ,
['বাউণ্ডুলে', 'ভবঘুরে'] ,
['বাকযন্ত্র', 'স্বরনালী', 'স্বরযন্ত্র'] ,
['বাকি থাকা', 'বাচা', 'রয়ে যাওয়া'] ,
['বাক্ চপল', 'বাচাল', 'মুখর'] ,
['বাক্ বিতণ্ডা', 'বাদানুবাদ'] ,
['বাক্যবাগীশ', 'বাচাল'] ,
['বাক্যহীন', 'বিগ্রহহীন'] ,
['বাগপত', 'বাগপত জেলা', 'বাগপত শহর'] ,
['বাগমতী', 'বাগমতী নদী'] ,
['বাগলি', 'বাগলি নদী'] ,
['বাগাড়ম্বর', 'শব্দাড়ম্বর'] ,
['বাগুয়া', 'বেলবাগুর'] ,
['বাঘমারা', 'বাঘমারা শহর'] ,
['বাঘিনী', 'মাদী বাঘ'] ,
['বাঙালি মিষ্টান্ন', 'বাঙালি মিষ্টি'] ,
['বাঙ্গাল', 'বাঙ্গাল রাগ'] ,
['বাচ্চা গাড়ি', 'শিশু যান'] ,
['বাচ্চা', 'বালক', 'শিশু'] ,
['বাচ্চাদের', 'শিশুসুলভ'] ,
['বাছা', 'বাছাই করা'] ,
['বাজ বাহাদুর', 'মালিক বায়জীদ'] ,
['বাজ', 'বাজপাখি', 'শশাদ', 'শশাদন', 'শ্যেন'] ,
['বাজনদার', 'বাদক'] ,
['বাজনা', 'বাদ্য', 'বাদ্য যন্ত্র', 'বাদ্যযন্ত্র'] ,
['বাজপ্য', 'বাজপ্য ঋষি'] ,
['বাজার', 'মার্কেট', 'হাট'] ,
['বাজি রাখা', 'বিপদে ফেলা'] ,
['বাজে ভাবে লেখা', 'বিশ্রী ভাবে লেখা'] ,
['বাঞ্জারা মেয়ে', 'মহিলা বাঞ্জারা'] ,
['বাটমারি', 'রাহজানি'] ,
['বাটিয়ার', 'বাটিয়ারা', 'বাট্যুপুষ্পী'] ,
['বাড়মের', 'বাড়মের জেলা'] ,
['বাড়া', 'বিস্তার', 'বৃদ্ধি', 'বৃদ্ধি হওয়া', 'বেড়ে ওঠা'] ,
['বাড়ানো', 'বৃদ্ধি করা', 'সঙ্গ দেওয়া', 'সাহায্য করা'] ,
['বাড়ি বাড়ি', 'বাড়ি-বাড়ি'] ,
['বাড়িয়ে নেওয়া', 'লম্বা করা'] ,
['বাড়ী রঙ করা', 'হাউস পেন্টিং'] ,
['বাণগঙ্গা', 'বাণগঙ্গা নদী'] ,
['বাণিজ্য মন্ত্রী', 'বাণিজ্যমন্ত্রী'] ,
['বাণিজ্যিক', 'ব্যবসায়িক'] ,
['বাতগুল্ম', 'বাতগুল্ম রোগ'] ,
['বাতঙ্কটক', 'বাতঙ্কটক রোগ'] ,
['বাতরক্ত', 'বাতরক্ত রোগ'] ,
['বাতায়ন', 'বাতায়ন ঋষি'] ,
['বাতেলাবাজ', 'মিথ্যাবাদী'] ,
['বাদ দেওয়া', 'বিয়োগ করা'] ,
['বাদ পরা', 'রয়ে যাওয়া'] ,
['বাদ', 'মত', 'সিদ্ধান্ত'] ,
['বাদ-বিবাদ', 'বাদ-বিসম্বাদ', 'বাদানুবাদ'] ,
['বাদগা', 'বাদগা জাতি'] ,
['বাদল', 'সাদা পাথর'] ,
['বাদশা', 'রাজা'] ,
['বাদশাহ', 'মল্লিকা', 'মহারাজা', 'মহারাণী', 'রাজা', 'রাণী', 'শাহ', 'সুলতান'] ,
['বাদশাহী', 'সুলতানি'] ,
['বাদামী সারস পাখি', 'সারস পাখি'] ,
['বাদী', 'বাদীপক্ষ'] ,
['বাদ্য যন্ত্রে সুর', 'বাদ্য যন্ত্রে স্বর', 'বাদ্য স্বর'] ,
['বাধা', 'বিঘ্ন'] ,
['বাধূল', 'বাধূল ঋষি'] ,
['বানপ্রস্থাশ্রমী', 'বানপ্রস্থী'] ,
['বানবর পাখি', 'মদগু'] ,
['বান্দ্রা', 'বান্দ্রা জেলা'] ,
['বাপের বাড়ি', 'মায়ের বাড়ি'] ,
['বাবরি', 'বাবরের'] ,
['বাবা বৈদ্যনাথ', 'বৈদ্যনাথ'] ,
['বাম', 'বামদেব', 'বামদেব ঋষি'] ,
['বামকক্ষ', 'বামকক্ষ ঋষি'] ,
['বামকী', 'বামকী দেবী'] ,
['বামন পুরান', 'বামনপুরান'] ,
['বামমার্গ', 'বামাচারী'] ,
['বার করা', 'বের করা'] ,
['বার বার', 'বারংবার'] ,
['বার হওয়া', 'বের হওয়া'] ,
['বারগড় জেলা', 'বেরগড় জেলা'] ,
['বারগড়', 'বারগড় শহর', 'বেরগড়'] ,
['বারণ করা', 'মানা করা'] ,
['বারপেটা', 'বারপেটা জেলা', 'বারপেটা শহর'] ,
['বারবধূ', 'বেশ্যা'] ,
['বারবাডোজ', 'বারবাডোজ দেশ', 'বারবাডোজ দ্বীপ'] ,
['বারবাডোস বাসী', 'বারবাডোসী'] ,
['বারবাডোসীয়', 'বারবাডোসের'] ,
['বারবানী জেলা', 'বারাবানী'] ,
['বারমের', 'বারমের শহর'] ,
['বারহবান', 'বারহবান সেনা'] ,
['বারাঁ', 'বারাঁ জেলা'] ,
['বারাংবকি', 'বারাংবকি জেলা', 'বারাংবকি শহর'] ,
['বারান্দা', 'ব্যালকনি'] ,
['বারাবানী', 'বারাবানী শহর'] ,
['বারামুলা', 'বারামুলা জেলা', 'বারামুলা শহর'] ,
['বারাসাত', 'বারাসাত শহর'] ,
['বারিন', 'বিরণ', 'বীরন'] ,
['বারুদ', 'রঞ্জক'] ,
['বারুদ-গোলা', 'বারুদগোলা'] ,
['বারূণী', 'সুরা'] ,
['বার্থ', 'সিট'] ,
['বার্ধক্য', 'বৃদ্ধাবস্থা', 'বৃদ্ধাবস্হা'] ,
['বার্মাবাসী', 'বার্মিস', 'মায়ানমারী'] ,
['বার্মিস', 'বার্মিস ভাষা', 'বার্মিস লিপি', 'মায়ানমারী'] ,
['বার্ষিক উত্সব', 'বার্ষিক সমারোহ', 'বার্ষিকোত্সব'] ,
['বালকৃষ্ণ', 'বালগোবিন্দ'] ,
['বালচন্দ্র', 'বালশশি'] ,
['বালসূর্য', 'বালার্ক'] ,
['বালাঘাট', 'বালাঘাট জেলা', 'বালাঘাট শহর'] ,
['বালাসোর জেলা', 'বালেশ্বর', 'বালেশ্বর জেলা'] ,
['বালাসোর', 'বালেশ্বর', 'বালেশ্বর শহর'] ,
['বালি', 'বালু', 'বালুকা', 'বালুভূমি', 'সিকতা জমি'] ,
['বালিকাবধূ', 'বাল্যবিবাহিতা'] ,
['বালিময়', 'বালুকাময়'] ,
['বালু মাছি', 'বালুমাছি'] ,
['বালুচর', 'সমুদ্রসৈকত'] ,
['বালুরঘাট', 'বালুরঘাট শহর'] ,
['বাল্মীকী রামায়ণ', 'রামায়ণ'] ,
['বাল্যখিল্য', 'বাল্যখিল্য ঋষি'] ,
['বাশিম', 'বাশিম জেলা', 'বাশিম শহর'] ,
['বাষট্টি', '৬২,'] ,
['বাষ্কল', 'বাষ্কল ঋষি'] ,
['বাষ্প ইঞ্জিন', 'বাষ্পচালিত ইঞ্জিন'] ,
['বাষ্প', 'ভাপ'] ,
['বাষ্পচালিত নৌকা', 'স্টীমার'] ,
['বাষ্পীকরণ', 'বাষ্পীভবন'] ,
['বাস গুমটি', 'বাস ডিপো'] ,
['বাস', 'বাস টোপোলজি'] ,
['বাসন্তী লতা', 'মাধবী', 'মাধবীকা', 'মাধবীলতা'] ,
['বাসমতি', 'বাসমতি চাল', 'শালিধান'] ,
['বাসস্থান পরিবর্তন', 'স্থান পরিবর্তন'] ,
['বাসি', 'বাসি খাবার'] ,
['বাসুদেব', 'বাসুদেব উপনিষদ', 'বাসুদেবোপনিষদ'] ,
['বাস্কেট বল টিম', 'বাস্কেট বল দল'] ,
['বাস্তবায়িত হওয়া', 'রূপ নেওয়া'] ,
['বাস্তবিক খবর', 'সত্যি খবর'] ,
['বাস্তবিক জায়গা', 'বাস্তবিক স্থান'] ,
['বাস্তবিকতা', 'যথার্থতা', 'সততা', 'সত্য', 'সত্যি'] ,
['বাস্তুকার', 'রচয়িতা'] ,
['বাস্তুবিদ', 'স্থাপত্যবিদ'] ,
['বাস্তুশাস্ত্র', 'স্থাপত্য'] ,
['বাস্তুশিল্প', 'শিল্পকৃতি'] ,
['বাহক পশু', 'ভারবাহক পশু'] ,
['বাহন', 'সওয়ারী'] ,
['বাহনহীন', 'যানহীন'] ,
['বাহবা', 'শাবাশ'] ,
['বাহরিনবাসী', 'বাহরিনি'] ,
['বাহাত্তর', '৭২', '৭২,'] ,
['বাহাদুর', 'সাহসী', 'হিম্মতদার'] ,
['বাহাদুরি', 'সাহস', 'হিম্মত'] ,
['বাহান্ন', '৫২,'] ,
['বাহামা', 'বাহামাস'] ,
['বাহামা-বাসী', 'বাহামাবাসী'] ,
['বাহিকা', 'বাহী'] ,
['বাহু', 'ভুজ'] ,
['বাহুহীন', 'ভূজহীন', 'হাতহীন'] ,
['বাহ্য শারীরিক অঙ্গ', 'বাহ্য শারীরিক ভাগ'] ,
['বায়বীয়', 'বায়ুমন্ডলীয়', 'বিমান', 'হাওয়াই'] ,
['বায়ানদ', 'বায়ানদ জেলা'] ,
['বায়ু কোষ', 'বায়ু থলি'] ,
['বায়ু পথ', 'বায়ু মার্গ'] ,
['বায়ু বাদ্য', 'শ্বাস বাদ্য'] ,
['বায়ুচাপ মাপার যন্ত্র', 'ব্যারোমিটার'] ,
['বি পি', 'ব্লাড প্রেসার', 'রক্তচাপ'] ,
['বি ব্লাডগ্রুপ', 'বি রক্তবর্গ', 'ব্লাডগ্রুপ বি'] ,
['বিওআই', 'ব্যাঙ্ক অফ ইন্ডিয়া', 'ব্যাঙ্ক অফ ইন্ডিয়া'] ,
['বিকশিত হওয়া', 'বিস্তার লাভ করা'] ,
['বিকানির', 'বিকানির জেলা', 'বিকানির শহর', 'বিকানের', 'বিকানের শহর'] ,
['বিকাশ দর', 'সংবৃদ্ধি দর'] ,
['বিকাশ', 'বৃদ্ধি'] ,
['বিকিরণ লেখ', 'রেডিয়েশান ডায়াগ্রাম', 'রেডিয়েশান প্যাটার্ন'] ,
['বিকিরণ', 'বিচ্ছুরণ'] ,
['বিকিরণ-চিকিত্সা', 'রেডিওথেরাপি'] ,
['বিকেশ', 'বিকেশ ঋষি'] ,
['বিক্রম', 'বিক্রমাদিত্য', 'বিক্রমার্ক', 'শকারি'] ,
['বিক্রমাব্দ', 'বিক্রমী সংবত', 'বিক্রমী-সংবত'] ,
['বিক্রমী', 'বিক্রমীয়'] ,
['বিক্রি করা', 'বিক্রয় করা', 'বেচা'] ,
['বিক্রি', 'বিক্রয়', 'বেচা'] ,
['বিক্রীত', 'বিনিময়কৃত'] ,
['বিক্ষেপ', 'বিক্ষেপণ'] ,
['বিখ্যাত ব্যক্তি', 'বিশিষ্ট ব্যক্তি'] ,
['বিখ্যাত', 'সুখ্যাত', 'সুপ্রসিদ্ধ'] ,
['বিগহর্ন', 'সিমরন'] ,
['বিঘ্নকারী', 'ব্যাঘাতকারী'] ,
['বিচরণ করা', 'বিহার করা'] ,
['বিচলন', 'স্খলন'] ,
['বিচলিত', 'স্খলিত'] ,
['বিচার বিবেচনা করে', 'বিচার বিবেচনা পূর্বক', 'বুঝে শুনে', 'বুঝে সুঝে', 'ভাবনা চিন্তা করে'] ,
['বিচার বিমর্ষ', 'ভাবনা চিন্তা'] ,
['বিচার বিষয়ক', 'বিচারের'] ,
['বিচার', 'বোধশক্তি', 'মত', 'মান্যতা', 'মূল্য', 'হিসাব'] ,
['বিচারবান', 'বিচারশীল', 'বিবেচক'] ,
['বিচারবুদ্ধি', 'বোধ'] ,
['বিচেতন', 'বিচেতনাবস্থা'] ,
['বিচ্ছেদ', 'বিচ্ছেদন', 'বিরতি', 'বিরহ', 'বিরাম', 'বিশৃঙ্খলতা', 'ভঙ্গ', 'ভঞ্জন করা', 'ভাঙা', 'যতি'] ,
['বিচ্যুত হওয়া', 'সরে যাওয়া'] ,
['বিচ্যূত করা', 'সরানো', 'স্থানচ্যূত করা'] ,
['বিচ্যূত হওয়া', 'লক্ষ্যচ্যূত হওয়া'] ,
['বিছানো', 'শোয়ানো'] ,
['বিজনোর', 'বিজনোর জেলা', 'বিজনোর শহর'] ,
['বিজরা', 'বিজরা নদী'] ,
['বিজাতীয়', 'ভিন্ন জাতীয়'] ,
['বিজাপুর', 'বিজাপুর জেলা', 'বিজাপুর শহর'] ,
['বিজিগীষু', 'বিজয়াভিলাষী'] ,
['বিজিঘৃক্ষু', 'যুযুত্সু'] ,
['বিজিয়ানগরম', 'বিজিয়ানগরম জেলা', 'বিজিয়ানগরম শহর'] ,
['বিজেপী', 'ভাজপা', 'ভারতীয় জনতা পার্টী'] ,
['বিজোড়', 'বিজোড় সংখ্যা'] ,
['বিজোহা', 'বিজ্জোহা'] ,
['বিজ্ঞানী', 'বৈজ্ঞানিক'] ,
['বিজয়', 'সফলতা', 'সিদ্ধি'] ,
['বিজয়লক্ষ্মী নেহেরু পণ্ডিত', 'বিজয়লক্ষ্মী পণ্ডিত'] ,
['বিড', 'বিড জেলা', 'বিড শহর'] ,
['বিড়াল', 'বিড়ালিনী'] ,
['বিড়ি', 'বিড়ি খাওয়া', 'সুট্টা'] ,
['বিতরণ করা', 'ভাগ করা'] ,
['বিতরণ করানো', 'ভাগ করানো'] ,
['বিতরণ কেন্দ্র', 'বিতরণকেন্দ্র'] ,
['বিতর্কিত', 'বিবাদগ্রস্থ'] ,
['বিতস্রদ্ধ হয়ে ওঠা', 'বিতৃষ্ণ হয়ে ওঠা'] ,
['বিতান', 'বিতান বৃত্ত'] ,
['বিদর্ভজা', 'লোপামুদ্রা'] ,
['বিদর্ভি', 'বিদর্ভি ঋষি'] ,
['বিদিশা', 'বিদিশা জেলা', 'বিদিশা শহর'] ,
['বিদেঘ', 'বিদেঘ ঋষি'] ,
['বিদ্বেষ', 'বিরোধ', 'বৈরীতা', 'মনোমালিন্য', 'শত্রুতা'] ,
['বিদ্যা', 'শাস্ত্র বিদ্যা', 'সায়েন্স'] ,
['বিদ্যাধর', 'মহান্দষ্ট্র'] ,
['বিদ্যাপীঠ', 'বিদ্যালয়', 'শিক্ষালয়'] ,
['বিদ্যালয়', 'মন্দির', 'শিক্ষালয়', 'স্কুল'] ,
['বিদ্যুত', 'বিদ্যুত ঋষি'] ,
['বিদ্যুতকেশ', 'বিদ্যুত্-কেশ'] ,
['বিদ্যুতের মিটার', 'মিটার'] ,
['বিদ্যুত্ বর্তনী', 'সার্কিট'] ,
['বিদ্যুত্প্রভ', 'বিদ্যুত্প্রভ ঋষি'] ,
['বিদ্রোহ', 'বিপ্লব'] ,
['বিদ্রোহী', 'বিশ্বাসঘাতক'] ,
['বিধবা', 'স্বামীহীনা'] ,
['বিধান সভা', 'বিধানসভা'] ,
['বিধান-পরিষদ্', 'বিধানপরিষদ', 'বিধানপরিষদ্'] ,
['বিধির লিখন', 'ব্রহ্মরেখা', 'ব্রহ্মলেখ', 'ভাগ্যরেখা'] ,
['বিধিসম্মত', 'সাংবিধানিক'] ,
['বিধিহীনভাবে', 'বেনিয়মে'] ,
['বিধুদার', 'বিধুপ্রিয়া', 'রোহিনী'] ,
['বিধেয়ক', 'বিল'] ,
['বিন জবাদ', 'বিনজবাদ'] ,
['বিনটিয়ন', 'বিনটিয়েন', 'বীনতিয়েন'] ,
['বিনম্র', 'বিনয়ী'] ,
['বিনম্রতা', 'সুশীলতা'] ,
['বিনায়ক দামোদর সাভারকার', 'বীর সাভারকর', 'সাভারকর'] ,
['বিনিময় ব্যবসা', 'বিনিময় লেন-দেন'] ,
['বিনিয়োগ করা পুঁজি', 'লগ্নী', 'লগ্নী', 'লগ্নীকৃত পুঁজি'] ,
['বিনীত', 'সজ্জন', 'সুশীল', 'সৌম্য'] ,
['বিনোদনপ্রিয়তা', 'হাস্যপ্রিয়তা'] ,
['বিন্দাস', 'বেপরোয়া'] ,
['বিন্ধ্য পর্বত', 'বিন্ধ্যাচল', 'বিন্ধ্যায়ন'] ,
['বিন্যাস', 'রূপ'] ,
['বিপজ্জনক', 'বিপদগর্ভ', 'সংকটপূর্ণ'] ,
['বিপদ', 'সংকট', 'সঙ্কট'] ,
['বিপদগ্রস্ত', 'বিপদাপন্ন', 'সংকটগ্রস্ত', 'সংকটাপন্ন'] ,
['বিপরীত', 'বিপরীতার্থক শব্দ'] ,
['বিপরীতপন্থী', 'বিপরীতমুখী'] ,
['বিপাপা', 'বিপাপা নদী'] ,
['বিপি', 'ব্লাডপ্রেশার', 'রক্তচাপ'] ,
['বিপ্লবী', 'বৈপ্লবিক', 'স্বাধীনতাসংগ্রামী'] ,
['বিবরণ', 'বৃত্তান্ত', 'রিপোর্ট'] ,
['বিবর্ণ', 'রঙহীন'] ,
['বিবাগী', 'বৈরাগী', 'সন্ন্যাসী'] ,
['বিবাহ করা', 'বিয়ে করা'] ,
['বিবাহ প্রস্তাব', 'সম্বন্ধ'] ,
['বিবাহ সমারোহ', 'বিয়ে'] ,
['বিবাহিত', 'বিবাহিত পুরুষ', 'বৈবাহিক', 'সধবা'] ,
['বিবেকবান', 'বিবেকশীল'] ,
['বিবেচনা', 'মীমাংসা'] ,
['বিভক্ত করা', 'ভাগ করা'] ,
['বিভক্ত', 'বিভাজিত'] ,
['বিভত্স', 'বিভত্স রস'] ,
['বিভাগ', 'মহকুমা', 'সেল'] ,
['বিভাজন', 'ভাগ', 'ভাগ কর্ম'] ,
['বিভাজ্য', 'ভাজ্য'] ,
['বিভাণ্ডক ঋষি', 'মহর্ষি বিভাণ্ডক'] ,
['বিভিন্নতা', 'বৈচিত্র্য'] ,
['বিভূষিত', 'বিভূষিতা', 'ভূষিত', 'সজ্জিত'] ,
['বিমলাদ্রি', 'শত্রুঞ্জয়'] ,
['বিমাতা', 'সত্ মা'] ,
['বিমান আক্রমণ', 'বিমান হামলা'] ,
['বিমান শালা', 'বিমানশালা'] ,
['বিরজা', 'বিরজা ঋষি'] ,
['বিরপাড়া', 'বিরপাড়া শহর', 'বিরপাডা', 'বিরপাডা শহর'] ,
['বিরহ বেদনা', 'বিরহ ব্যথা'] ,
['বিরহ', 'বিয়োগ'] ,
['বিরাট', 'বিশ্বরূপ'] ,
['বিরানব্বই', '৯২,'] ,
['বিরাশি', '৮২', '৮২,'] ,
['বিরুদ্ধরূপক', 'বিরুদ্ধরূপকে অলঙ্কার'] ,
['বিরুধনগর', 'বিরুধনগর জেলা'] ,
['বিরোধাভাস', 'বৈপরীত্য'] ,
['বিলনা', 'বিলনিয়াস', 'বিলনো', 'বিল্না', 'বিল্নো'] ,
['বিলনী', 'ভৃঙ্গ'] ,
['বিলাবল', 'বিলাবল রাগ'] ,
['বিলাসপুর', 'বিলাসপুর জেলা', 'বিলাসপুর শহর'] ,
['বিলিয়ন', 'লক্ষ কোটি', '০০০০০০০০০০০০', '১০০০০০০০০০', '১০০০০০০০০০০০০', '১০০০০০০০০০০০০,'] ,
['বিলিয়ার্ড খেলার ঘর', 'বিলিয়ার্ড রুম'] ,
['বিলীন', 'মিশ্রিত'] ,
['বিলুপুরম', 'বিলুপুরম জেলা', 'বিলুপুরম শহর'] ,
['বিলেপন করা', 'লেপন করা', 'লেপা'] ,
['বিলোড়িত', 'মথিত'] ,
['বিলোপ', 'লোপ'] ,
['বিল্বপত্র', 'বেল-পত্র', 'বেলপাতা'] ,
['বিশকোপরা', 'বিসখপরা', 'বিসফাপর'] ,
['বিশখাপর', 'বিসখপরা', 'বিসখপরী'] ,
['বিশাখা', 'বিশাখা নক্ষত্র', 'বিশাখা নক্ষত্রে'] ,
['বিশাখাপত্তনম', 'বিশাখাপত্তনম জেলা', 'বিশাখাপত্তনম শহর'] ,
['বিশাল পরিমাণ', 'সামলানোর অযোগ্য'] ,
['বিশালা', 'মহেন্দ্রবারুণী'] ,
['বিশিষ্ট', 'বিশেষ'] ,
['বিশিষ্টতা', 'বৈশিষ্ট্য'] ,
['বিশুদ্ধতা', 'বিশুদ্ধি', 'শুদ্ধতা'] ,
['বিশুদ্ধরূপে প্রস্তুত', 'শোধিত', 'সংস্কৃত'] ,
['বিশেষ অধিকার', 'বিশেষাধিকার'] ,
['বিশেষ পদ্ধতি', 'মূলমন্ত্র'] ,
['বিশেষ ভাবে', 'বিশেষতঃ'] ,
['বিশেষ', 'বিশেষ অর্থালঙ্কার', 'বিশেষার্থালঙ্কার'] ,
['বিশেষক', 'বিশেষক অর্থালঙ্কার'] ,
['বিশেষণযুক্ত', 'বিশেষিত'] ,
['বিশেষত্ব', 'বৈশিষ্ট্য'] ,
['বিশোকষষ্টী', 'স্কন্দষষ্ঠী'] ,
['বিশ্বজ্যোতিষ', 'বিশ্বজ্যোতিষ ঋষি'] ,
['বিশ্বনাথ প্রতাপ সিং', 'ভি পি সিং'] ,
['বিশ্বপতি', 'সোমেশ্বর'] ,
['বিশ্বপ্রসিদ্ধ', 'বিশ্ববিখ্যাত'] ,
['বিশ্ববর', 'বিশ্ববর ঋষি'] ,
['বিশ্বমনা', 'বিশ্বমনা ঋষি'] ,
['বিশ্বমহাযুদ্ধ', 'বিশ্বযুদ্ধ'] ,
['বিশ্বময়া', 'বিশ্বরূপী'] ,
['বিশ্বশক্তি', 'মহাশক্তি'] ,
['বিশ্বশ্রবা', 'বিশ্রবা'] ,
['বিশ্বসাম', 'বিশ্বসাম ঋষি'] ,
['বিশ্বস্ত', 'বিশ্বাসযোগ্য', 'বিশ্বাসী'] ,
['বিশ্বাসঘাতক', 'বিশ্বাসঘাতী'] ,
['বিশ্বাসপূর্বক', 'বিশ্বাসের সঙ্গে'] ,
['বিশ্বাসভাজন', 'বিশ্বাসী', 'বিশ্বাসের পাত্র', 'যে ভরসা করে'] ,
['বিশ্রবণ', 'বিশ্রবণ ঋষি'] ,
['বিশ্রামগৃহ', 'বিশ্রামস্থল', 'বিশ্রামাগার'] ,
['বিশ্লেষক', 'বিশ্লেষণকর্তা', 'মীমাংসক'] ,
['বিষ খাওয়ানো', 'বিষ দেওয়া', 'বিষ পান করানো'] ,
['বিষকাঁটালি', 'বেলেডোনা'] ,
['বিষদন্ত', 'বেড়াল', 'মার্জার'] ,
['বিষধর সর্প', 'বিষধর সাপ'] ,
['বিষধর', 'বিষাক্ত'] ,
['বিষম', 'বিষম অলংকার', 'বিষম জঠরাগ্নি', 'বিষম তাল'] ,
['বিষমপলাশ', 'যুগ্মপর্ণ', 'শারদী', 'শিরোরুজা', 'শুক্তিপর্ণ', 'সতিবন', 'সপ্তপত্র', 'সপ্তপ্রণ', 'সপ্তপ্রণী', 'সুপর্ণক'] ,
['বিষমরূপী', 'ভিন্নরূপী'] ,
['বিষমলিঙ্গীয়', 'বিষমলিঙ্গের'] ,
['বিষমাখা', 'বিষাক্ত'] ,
['বিষময়', 'বিষাক্ত'] ,
['বিষরহিত', 'বিষহীন'] ,
['বিষহীন সর্প', 'বিষহীন সাপ'] ,
['বিষাণ', 'শিং', 'শিঙ', 'শৃঙ্ক', 'শৃঙ্গ'] ,
['বিষাণক', 'বিষাণক ঋষি'] ,
['বিষাণবাদক', 'ভেরিবাদক'] ,
['বিষাণী', 'শিংযুক্ত', 'শৃঙ্গযুক্ত', 'শৃঙ্গী'] ,
['বিষুবীয় গিনি', 'বিষুবীয় গিনি গণরাজ্য', 'স্পেনীয় গিনি'] ,
['বিষ্ঠা', 'মল'] ,
['বিষ্ণু পুরাণ', 'বিষ্ণুপুরাণ'] ,
['বিষ্ণু মন্দির', 'হরি মন্দির', 'হরিতলা'] ,
['বিষ্ণু', 'বিষ্ণু ঋষি'] ,
['বিষ্ণুপুর', 'বিষ্ণুপুর জেলা', 'বিষ্ণুপুর শহর'] ,
['বিষ্বক্ষেন', 'বিষ্বক্ষেন মনু'] ,
['বিষয়', 'বিষয়-বস্তু', 'মামলা'] ,
['বিষয়ক', 'সংক্রান্ত', 'সম্পর্কিত', 'সম্বন্ধীয়'] ,
['বিসর্জন', 'ভাসান'] ,
['বিসর্প', 'বিসর্প রোগ', 'বিসর্পিকা'] ,
['বিসাত-খানা', 'বিসাতখানা'] ,
['বিসাপুর', 'বিসাপুর দুর্গ'] ,
['বিসিসিআই', 'ভারতীয় ক্রিকেট কন্ট্রোল বোর্ড', 'ভারতীয় ক্রিকেট বোর্ড'] ,
['বিস্কিট', 'বিস্কুট'] ,
['বিস্তার', 'সম্প্রসারণ'] ,
['বিস্তারিতভাবে', 'সবিস্তারে'] ,
['বিস্ফোরক', 'বিস্ফোরক পদার্থ', 'বিস্ফোরণকারী'] ,
['বিস্মরণ', 'বিস্মৃতি', 'ভুল'] ,
['বিস্মরণযোগ্য', 'বিস্মরণীয়'] ,
['বিস্মৃত', 'ভুলে যাওয়া'] ,
['বিস্ময়বোধক চিহ্ন', 'বিস্ময়সূচক চিহ্ন'] ,
['বিহার শরীফ', 'বিহার শরীফ শহর'] ,
['বিহার', 'বিহার জেলা', 'বিহার শহর'] ,
['বিহী', 'বীহী'] ,
['বিহীন', 'রহিত', 'শূণ্য'] ,
['বিয়াল্লিশ', '৪২', '৪২,'] ,
['বিয়োগ ফল', 'বিয়োগফল'] ,
['বিয়োগ শৃঙ্গার', 'বিয়োগ শৃঙ্গার রস'] ,
['বীজফল', 'বীজযুক্ত'] ,
['বীজা', 'বীজা বৃক্ষ'] ,
['বীজু', 'বীজু আম'] ,
['বীতহব্য', 'বীতহব্য ঋষি'] ,
['বীনকার', 'বীনবাদক'] ,
['বীর মহিলা', 'বীরাঙ্গনা', 'সবলা'] ,
['বীরত্ব', 'শৌর্য'] ,
['বীরবত্স', 'বীরভদ্র', 'ময়ু', 'যযু', 'যাযাবর'] ,
['বীরভূম', 'বীরভূম জেলা'] ,
['বীর্যকোষ', 'শুক্রগ্রন্থি'] ,
['বীর্যাণু', 'শুক্রাণু'] ,
['বুঁদিয়া', 'বোঁদে'] ,
['বুকুরেস্টী', 'বুচারেস্ট', 'বুচারেস্টী'] ,
['বুগি ভাষা', 'সুলভেসীয়'] ,
['বুগি', 'বুগি লিপি', 'সুলবেসিবাসী'] ,
['বুটিদার', 'বুটিযুক্ত'] ,
['বুড়ি', 'বৃদ্ধা', 'বৃদ্ধা মহিলা'] ,
['বুড়ো আঙুল', 'বৃদ্ধঙ্গুষ্ঠ'] ,
['বুড়ো', 'বৃদ্ধ', 'বৃদ্ধ পুরুষ', 'বয়স্ক'] ,
['বুদ্ধ প্রতিমা', 'বুদ্ধ মূর্তী'] ,
['বুদ্ধি', 'বোধ', 'সংজ্ঞা'] ,
['বুদ্ধির', 'মস্তিষ্ক খাটানোর কাজ', 'মানসিক'] ,
['বুদ্ধিশুদ্ধি', 'বোধবুদ্ধি'] ,
['বুধ', 'বুধবার'] ,
['বুনন করা', 'বোনা'] ,
['বুনন', 'বুননকার্য', 'বুনানি', 'বোনা', 'বয়ন'] ,
['বুনিয়াদ', 'ভিত্তি'] ,
['বুনিয়াদি', 'মূল'] ,
['বুন্দি', 'বুন্দি জেলা', 'বুন্দি শহর'] ,
['বুন্দেলা', 'বুন্দেলা বংশ'] ,
['বুরহানপুর', 'বুরহানপুর জেলা', 'বুরহানপুর শহর'] ,
['বুলগেরিয়ান', 'বুলগেরিয়ান লিপি', 'বুলগেরীয়'] ,
['বুলঢানা', 'বুলঢানা জেলা', 'বুলঢানা শহর'] ,
['বুলন্দশহর', 'বুলন্দশহর জেলা'] ,
['বুলি বাঁদর', 'বুলি মাঙ্কি'] ,
['বুলেট অভেদ্য', 'বুলেট নিরোধী', 'বুলেট প্রুফ'] ,
['বৃক', 'বৃকাসুর'] ,
['বৃত্তি', 'ভাতা'] ,
['বৃদ্ধি', 'বেড়ে যাওয়া'] ,
['বৃদ্ধিরহিত', 'বৃদ্ধিহীন'] ,
['বৃশ্চিক', 'বৃশ্চিক রাশি', 'বৃশ্চিক রাশিবিশিষ্ট', 'বৃশ্চিকরাশি'] ,
['বৃষ', 'বৃষ রাশি', 'বৃষরাশি'] ,
['বৃষপতি', 'হিজড়ে'] ,
['বৃষাসুর', 'ভস্ম', 'ভস্মাসুর'] ,
['বৃষ্ণিক', 'বৃষ্ণিক ঋষি'] ,
['বৃহজ্জাবাল', 'বৃহজ্জাবাল উপনিষদ', 'বৃহজ্জাবালোপনিষদ'] ,
['বৃহত কোণ', 'বৃহতকোণ'] ,
['বৃহদারণ্যক', 'বৃহদারণ্যক উপনিষদ', 'বৃহদারণ্যকোপনিষদ'] ,
['বৃহস্পতি', 'বৃহস্পতিবার'] ,
['বেঁধে যাওয়া', 'লেগে যাওয়া'] ,
['বেওয়ারিশ', 'বেওয়ারিশ ব্যক্তি'] ,
['বেকার ছোটাছুটি', 'বেকার দৌড়াদৌড়ি', 'ব্যর্থ দৌড়াদৌড়ি', 'ব্যর্থই ছোটাছুটি'] ,
['বেকার', 'বেরোজগার'] ,
['বেখুর', 'মলিন', 'মিল'] ,
['বেগম', 'রানী'] ,
['বেগার', 'বেগারী'] ,
['বেগুসরায়', 'বেগুসরায় জেলা', 'বেগুসরায় শহর'] ,
['বেঙ্গনপল্লী', 'বেঙ্গনপল্লী আম'] ,
['বেঙ্গালুরু গ্রামীণ জেলা', 'ব্যাঙ্গালোর গ্রামীণ জেলা'] ,
['বেঙ্গালুরু', 'বেঙ্গালুরু জেলা', 'ব্যাঙ্গালোর', 'ব্যাঙ্গালোর জেলা'] ,
['বেঙ্গালোর', 'বেঙ্গালোর আম'] ,
['বেড়া', 'রেলিং'] ,
['বেড়াল গোত্রের প্রাণী', 'বেড়াল জাতীয় প্রাণী', 'বেড়াল বংশের প্রাণী'] ,
['বেড়াল', 'মার্জার', 'মেকুর', 'হুলো'] ,
['বেণ', 'বেণু'] ,
['বেণে', 'বৈশ্য', 'ভূমিজীবী'] ,
['বেণ্ণা', 'বেণ্ণা নদী'] ,
['বেত', 'সুষেণ'] ,
['বেতন', 'মাইনে', 'শুল্ক'] ,
['বেতনভোগী', 'বৈতনিক'] ,
['বেতাজ', 'মুকটহীন'] ,
['বেতার', 'রেডিও'] ,
['বেতারযন্ত্র', 'রেডিও'] ,
['বেতিয়া', 'বেতিয়া শহর'] ,
['বেত্র', 'বেত্রাসুর'] ,
['বেদ', 'বেদ ঋষি'] ,
['বেদশ্ব', 'বেদশ্ব নদী'] ,
['বেদশ্রুতি', 'বেদশ্রুতি নদী'] ,
['বেদস্মৃতা নদী', 'বেদস্মৃতি', 'বেদস্মৃতি নদী'] ,
['বেদানা রঙের', 'বেদানারঙা'] ,
['বেদান্ত', 'বেদান্ত দর্শন', 'বেদান্ত শাস্ত্র', 'বেদান্তদর্শন', 'বেদান্তশাস্ত্র'] ,
['বেদী', 'মঞ্চ'] ,
['বেন ডাইক', 'বেন ডাইক আম'] ,
['বেনানি', 'বেনানিস'] ,
['বেনিনবাসী', 'বেনিনি', 'বেনিনিস'] ,
['বের হওয়া', 'বেরোনো', 'বয়ে যাওয়া'] ,
['বেরতী', 'বেরতী নক্ষত্র'] ,
['বেরুকী', 'বেরুকী রোগ'] ,
['বেল', 'শ্রীফল'] ,
['বেলগাঁও', 'বেলগাঁও জেলা', 'বেলগাঁও শহর'] ,
['বেলজিয়ামবাসী', 'বেলজিয়ামী'] ,
['বেলজিয়ামী', 'বেলজিয়ামী ভাষা'] ,
['বেলা', 'সময়'] ,
['বেলারুসবাসী', 'বেলারুসী'] ,
['বেলারুসিয়ান', 'বেলারুসী', 'বেলারুসী ভাষা'] ,
['বেলিজ বাসী', 'বেলিজিয়ান'] ,
['বেলিজ', 'ব্রিটিশ হনডুরাস'] ,
['বেলিজীয়', 'বেলিজের'] ,
['বেলুন', 'বেলুন যান'] ,
['বেলুর', 'বেলুর শহর'] ,
['বেলো', 'বেহালা', 'ভায়োলিন'] ,
['বেল্লারি', 'বেল্লারি জেলা', 'বেল্লারি শহর'] ,
['বেল্লুর', 'বেল্লুর জেলা', 'বেল্লুর শহর'] ,
['বেশ', 'বেশ-ভূষা', 'বেশভূষা'] ,
['বেশ্যাগমন', 'রেন্ডিবাজী'] ,
['বেশ্যাগামী', 'রেন্ডীবাজে'] ,
['বেশ্যাবাজ', 'মাগীবাজ'] ,
['বেসরকারীকরণ', 'স্বায়ত্তীকরণ'] ,
['বেসিন', 'সিঙ্ক'] ,
['বেসুর', 'সুরহীন'] ,
['বেয়োনেট', 'সঙ্গিন'] ,
['বৈখানসি', 'বৈখানসি ঋষি'] ,
['বৈগাই', 'বৈগাই নদী'] ,
['বৈজন্তি', 'বৈজন্তি হার', 'বৈজন্তি-মালা', 'বৈজন্তিমালা'] ,
['বৈজন্তী', 'বৈজন্তী মালা', 'বৈজন্তী হার'] ,
['বৈজয়ন্তী', 'বৈজয়ন্তী গাছ'] ,
['বৈতুল', 'বৈতুল জেলা', 'বৈতুল শহর'] ,
['বৈদিক ধর্ম', 'সনাতন ধর্ম', 'হিন্দু ধর্ম'] ,
['বৈদিক স্তোত্র', 'স্তোত্র'] ,
['বৈদুর্য্য', 'বৈদুর্য্যমণি'] ,
['বৈদ্যুতিক ইঞ্জিন', 'বৈদ্যুতিক মোটর'] ,
['বৈবস্বত মনু', 'বৈবস্বতমনু', 'রবিনন্দন', 'সত্যব্রত'] ,
['বৈবস্বত', 'বৈবস্বত মন্বন্তর', 'বৈবস্বত রুদ্র', 'শনি', 'শনি গ্রহ', 'শনিদেব', 'শনিশ্চর'] ,
['বৈভণ্ডি', 'বৈভণ্ডি ঋষি'] ,
['বৈভ্রাজ', 'বৈভ্রাজ বন', 'বৈভ্রাজবন'] ,
['বৈমাত্রেয় বোন', 'সত্ বোন'] ,
['বৈমাত্রেয়', 'সত্', 'সত্ ভাই'] ,
['বৈরাগী', 'বৈষ্ণব সাধু'] ,
['বৈরিতাপূর্ণ', 'শত্রুতাপূর্ণ'] ,
['বৈরী', 'শত্রু'] ,
['বৈশম্পায়ন', 'বৈশম্পায়ন ঋষি'] ,
['বৈশাখ শুক্ল একাদশী', 'মোহিনী একাদশী'] ,
['বৈশাখ', 'বৈশাখ ঋষি', 'বৈশাখ মাস'] ,
['বৈশালী', 'বৈশালী জেলা'] ,
['বৈশেষিক', 'বৈশেষিকদর্শন', 'বৈশেষিকশাস্ত্র'] ,
['বৈশ্রম্ভক', 'বৈশ্রম্ভক বন'] ,
['বৈষ্ণব', 'বৈষ্ণব সম্প্রদায়'] ,
['বোকারো', 'বোকারো জেলা', 'বোকারো শহর'] ,
['বোখা', 'বোখা জেলা', 'বোখা শহর'] ,
['বোঝা', 'ভার'] ,
['বোঝাপড়া', 'সমঝোতা', 'সম্মতি', 'সাম়ঞ্জস্য'] ,
['বোডো', 'বোডো লিবারেশন টাইগার', 'বোডো লিবারেশন টাইগার ফোর্স'] ,
['বোতাম', 'সুইচ'] ,
['বোত্সবানন', 'বোত্সবানা বাসী', 'বোত্সবানাবাসী', 'বোত্সবানার', 'বোত্সবানীয়'] ,
['বোদানি', 'বোদানি ফণ্ট', 'মডার্ন', 'মডার্ন ফণ্ট'] ,
['বোধি', 'বোধিবৃক্ষ', 'মহা বোধিবৃক্ষ', 'মহাবোধি বট', 'মহাবোধিবৃক্ষ'] ,
['বোধ্য', 'সরল', 'সহজ', 'সহজবোধ্য', 'সুগম'] ,
['বোন', 'ভগিনী'] ,
['বোনপো', 'ভগিনেয়'] ,
['বোনা', 'লাগানো'] ,
['বোনাই', 'বোনার মজুরি'] ,
['বোবা মহিলা', 'বোবা মেয়ে'] ,
['বোম', 'বোমা'] ,
['বোমডিলা', 'বোমডিলা শহর'] ,
['বোমা নিক্ষেপকারী', 'বোমাবাজ'] ,
['বোম্বাইএর', 'বোম্বাইয়া', 'মুম্বইএর', 'মুম্বইয়া'] ,
['বোম্বাইবাসী', 'বোম্বাইয়া', 'মুম্বাইবাসী', 'মুম্বাইয়া'] ,
['বোম্বে গ্রীন', 'মালদা', 'মালদা আম'] ,
['বোরবান', 'বোরবান আম', 'বোরবান আমের গাছ', 'স্পাডা', 'স্পাডা আম'] ,
['বোল', 'বোলি'] ,
['বোলতা', 'ভিমরুল'] ,
['বোসনিয়া', 'বোসনিয়া-হার্জগোভিনা'] ,
['বোসনিয়ান', 'বোসনিয়ান ভাষা', 'বোসনিয়াবাসী', 'বোসনিয়ার'] ,
['বোহরা', 'বোহরা জাতি'] ,
['বোয়াম', 'মর্তবান'] ,
['বৌদ শহর', 'বৌধ শহর', 'বৌর জেলা'] ,
['বৌদ্ধ ভিক্ষুকণী', 'ভিক্ষুকণী'] ,
['বৌদ্ধ স্তুপ', 'বৌদ্ধ-স্তুপ', 'স্তুপ'] ,
['বৌদ্ধ', 'বৌদ্ধ ধর্মাবলম্বী'] ,
['বৌদ্ধকাল', 'বৌদ্ধযুগ'] ,
['বৌধ শহর', 'বৌর'] ,
['বৌধায়ন', 'বৌধায়ন ঋষি'] ,
['ব্যকরণ সম্বন্ধীয়', 'ব্যকরণের'] ,
['ব্যক্তিত্ব আরোপ', 'মানবীকরণ'] ,
['ব্যঙ্গ করা', 'মজা করা', 'হাসাহাসি করা'] ,
['ব্যঙ্গ', 'ব্যঙ্গার্থ', 'মজা'] ,
['ব্যঞ্জন', 'ব্যঞ্জন বর্ণ'] ,
['ব্যঞ্জনবর্ণ ভ', 'ভ'] ,
['ব্যঞ্জনবর্ণ ম', 'ম'] ,
['ব্যঞ্জনবর্ণ য', 'য'] ,
['ব্যঞ্জনবর্ণ র', 'র'] ,
['ব্যঞ্জনবর্ণ ল', 'ল'] ,
['ব্যঞ্জবর্ণ শ', 'শ'] ,
['ব্যঞ্জবর্ণ ষ', 'ষ'] ,
['ব্যঞ্জবর্ণ স', 'স'] ,
['ব্যথা দেওয়া', 'লাগিয়ে দেওয়া'] ,
['ব্যবস্থাপূর্বক', 'সঠিকভাবে', 'সুষ্ঠুভাবে'] ,
['ব্যবস্থিত করা', 'সাজানো'] ,
['ব্যবহার কুশলতা', 'ব্যবহার কৌশল'] ,
['ব্যবহারিক', 'ব্যবহার্য'] ,
['ব্যশ্ব', 'ব্যশ্ব ঋষি'] ,
['ব্যস্ত থাকা', 'লেগে থাকা'] ,
['ব্যা ব্যা করা', 'ম্যাঁ ম্যাঁ করা'] ,
['ব্যাখ্যান দাতা', 'লেকচারার'] ,
['ব্যাঘ্রপাত', 'ব্যাঘ্রপাত ঋষি'] ,
['ব্যাঘ্রাপুষ্পি', 'ব্যাঘ্রাপুষ্পি ঋষি'] ,
['ব্যাঙ', 'ভেক'] ,
['ব্যাঙ্ক কর্মচারী', 'ব্যাঙ্ককর্মী', 'ব্যাঙ্কার'] ,
['ব্যাঙ্ক সংক্রান্ত', 'ব্যাঙ্কিং'] ,
['ব্যাট', 'রেকেট'] ,
['ব্যাথা হওয়া', 'যন্ত্রণা করা', 'যন্ত্রণা হওয়া'] ,
['ব্যাধ', 'মৃগয়াজীবী', 'শিকারী'] ,
['ব্যাধি', 'রোগ'] ,
['ব্যান', 'ব্যান বায়ু'] ,
['ব্যারাক', 'সেনা নিবাস'] ,
['ব্যালট পেপার', 'মত-পত্র', 'মতদান-পত্র'] ,
['ব্যালেট-বক্স', 'ব্যালেট-বাক্স'] ,
['ব্যায়াম শালা', 'ব্যায়ামশালা'] ,
['ব্যায়াম সম্পর্কিত', 'ব্যায়ামের'] ,
['ব্রক্ষচর্য পালক', 'ব্রক্ষচারী', 'ব্রতী'] ,
['ব্রজ ভাষা', 'ব্রজভাষা'] ,
['ব্রতি', 'যজমান'] ,
['ব্রহ্ম পূরাণ', 'ব্রহ্মপূরাণ'] ,
['ব্রহ্ম বৈবর্ত পূরাণ', 'ব্রহ্মবৈবর্ত পূরাণ', 'ব্রহ্মবৈবর্তপূরাণ'] ,
['ব্রহ্ম সাবর্ণি মনু', 'ব্রহ্মসাবর্ণি মনু'] ,
['ব্রহ্ম', 'ব্রহ্ম উপনিষদ', 'ব্রহ্মোপনিষদ'] ,
['ব্রহ্মঋষি', 'ব্রাহ্মণ ঋষি'] ,
['ব্রহ্মজ্ঞানী', 'সিদ্ধ'] ,
['ব্রহ্মতিথি', 'ব্রহ্মতিথি ঋষি'] ,
['ব্রহ্মপুরী', 'ব্রহ্মলোক'] ,
['ব্রহ্মবিদ্যা', 'ব্রহ্মবিদ্যা উপনিষদ'] ,
['ব্রহ্মমণ্ডূকী', 'মণ্ডুকপর্ণী'] ,
['ব্রহ্মরন্ধ্র', 'ব্রহ্মান্ড দ্বার'] ,
['ব্রহ্মাণ্ড পুরাণ', 'ব্রহ্মাণ্ডপুরাণ'] ,
['ব্রাউজিং', 'সার্ফিং'] ,
['ব্রাজিল নাট', 'ব্রাজিলীয় বাদাম'] ,
['ব্রাজিল সম্পর্কিত', 'ব্রাজিলিয়ান', 'ব্রাজিলীয়'] ,
['ব্রাজিল', 'ব্রাজিল নাট', 'ব্রাসিল'] ,
['ব্রাজিলবাসী', 'ব্রাজিলিয়ান'] ,
['ব্রাহ্মণ-কুমার', 'ব্রাহ্মণ-পুত্র', 'ব্রাহ্মণেটা', 'ব্রাহ্মপুত্র'] ,
['ব্রাহ্মণী', 'ব্রাহ্মণী চিল', 'ব্রাহ্মণী নদী'] ,
['ব্রাহ্মাণী', 'ব্রাহ্মী', 'ব্রাহ্মী লিপি'] ,
['ব্রাহ্মী', 'লাবন্য', 'সোমলতা'] ,
['ব্রাহ্ম্যবেলা', 'ব্রাহ্ম্যমূহুর্ত'] ,
['ব্রুক্স', 'ব্রুক্স আম', 'ব্রুক্স আমের গাছ'] ,
['ব্রুনো ডলার', 'ব্রুনো রিঙ্গিট', 'রিঙ্গিট'] ,
['ব্রেল', 'ব্রেল লিপি'] ,
['ব্রোমাইন', 'ব্রোমিন'] ,
['ব্লাড গ্রুপ', 'রক্ত বর্গ', 'রক্তের বিভাগ'] ,
['ব্লাড সুগার', 'রক্ত শর্করা'] ,
['বয়স্ক', 'সোয়ানা'] ,
['ভক্ত রৈদাস', 'রৈদাস'] ,
['ভক্ত-বত্সল', 'ভক্তবত্সল'] ,
['ভগ', 'ভগ দেবতা'] ,
['ভগীরথ', 'ভাগীরথ', 'রাজা ভগীরথ'] ,
['ভগ্ন পোত', 'ভাঙা জাহাজ'] ,
['ভগ্ন শিশ্ন', 'যোনির উপরিভাগ'] ,
['ভগ্নাংশ', 'ভগ্নাংশ সংখ্যা'] ,
['ভঙ্গ করা', 'ভাঙা', 'ভাঙ্গা', 'ভেঙে দেওয়া'] ,
['ভঙ্গ', 'ভাগ', 'ভেগ'] ,
['ভঙ্গিমা', 'ভাব-ভঙ্গিমা', 'ভাবভঙ্গিমা'] ,
['ভজন শৃঙ্খলা', 'ভজন সংগ্রহ'] ,
['ভণ্ড', 'ভণ্ডাসুর'] ,
['ভণ্ডিত', 'ভণ্ডিত ঋষি'] ,
['ভতিণ্ডা', 'ভতিণ্ডা জেলা', 'ভতিণ্ডা শহর'] ,
['ভতৃহরি', 'রাগ ভতৃহরি'] ,
['ভদ্র', 'ভালো', 'শিষ্ট', 'সজ্জন', 'সদাচারী', 'সভ্য', 'সুশীল'] ,
['ভদ্রক', 'ভদ্রক জেলা', 'ভদ্রক শহর'] ,
['ভদ্রতা', 'ভালোমানুষি', 'শালীনতা', 'শিষ্টতা', 'সভ্যতা', 'সৌজন্য', 'সৌহার্দ্যতা'] ,
['ভব-চক্র', 'ভব-জাল', 'ভবচক্র', 'ভবজাল', 'মায়া-জাল', 'মায়াজাল', 'সাংসারিকতা'] ,
['ভব-চক্রে', 'ভবচক্রে'] ,
['ভব-বন্ধন', 'সাংসারিক দুঃখ'] ,
['ভবসাগর', 'ভবসিন্ধু'] ,
['ভবানীপাটনা', 'ভবানীপাটনা শহর'] ,
['ভবিষ্য পুরাণ', 'ভবিষ্যপুরাণ'] ,
['ভবোদয়', 'ভবোদয় অলঙ্কার'] ,
['ভভুয়া', 'ভভুয়া শহর'] ,
['ভর দিয়ে', 'সাহায্যে'] ,
['ভরণী', 'ভরণী নক্ষত্র', 'ভরণী লগ্ন', 'যমেশ'] ,
['ভরত', 'ভরত মুণি'] ,
['ভরতনাট্যম', 'ভরতনাট্যম নৃত্য'] ,
['ভরতপুর', 'ভরতপুর জেলা', 'ভরতপুর শহর'] ,
['ভরতুকি', 'সাবসিডি'] ,
['ভরদ্বাজ', 'ভরদ্বাজ ঋষি'] ,
['ভরপুর', 'ভরা'] ,
['ভরা', 'ভরানো', 'ভারগ্রস্ত', 'ভারবাহী', 'সাজানো'] ,
['ভরি', 'মাষক', 'মাষা'] ,
['ভরুচ', 'ভরুচ জেলা', 'ভরুচ শহর'] ,
['ভর্তি', 'রিক্রুটমেন্ট'] ,
['ভল্লক', 'ভল্লু'] ,
['ভস্ত্রা', 'হাপর'] ,
['ভাঁড়ার', 'ভাণ্ডার'] ,
['ভাই', 'ভ্রাতা'] ,
['ভাইপো', 'ভাতৃজ', 'ভাত্রা পুত্র'] ,
['ভাইফোঁটা', 'ভাতৃদ্বিতীয়া'] ,
['ভাগ সংখ্যা', 'হর'] ,
['ভাগ-ফল', 'ভাগফল'] ,
['ভাগবত্', 'ভাগবত্ পূরাণ', 'ভাগবত্পূরাণ', 'শ্রীমদভাগবত্পুরাণ'] ,
['ভাগলপুর', 'ভাগলপুর শহর'] ,
['ভাগানো', 'ভাগিয়ে দেওয়া'] ,
['ভাগ্যবান', 'ভাগ্যশালী', 'সৌভাগ্যশালী'] ,
['ভাঙচুর করা', 'ভাঙা চোরা', 'ভাঙাচোরা'] ,
['ভাঙা', 'ভেঙে পড়া'] ,
['ভাঙ্গা', 'ভাঙ্গা-চোড়া', 'ভেঙ্গে পড়া', 'ভেঙ্গে যাওয়া'] ,
['ভাজক', 'ভাজক সংখ্যা'] ,
['ভাজ্য', 'ভাজ্য সংখ্যা'] ,
['ভাটা', 'ভাটিয়াল'] ,
['ভাড়া', 'শুল্ক'] ,
['ভাণ্ডার', 'স্টক'] ,
['ভাণ্ডারা', 'ভাণ্ডারা জেলা', 'ভাণ্ডারা শহর'] ,
['ভাতখোর', 'ভেতো'] ,
['ভাদই', 'ভাদাই', 'ভাদ্রমাসের'] ,
['ভাদোদরা', 'ভাদোদরা জেলা', 'ভাদোদরা শহর'] ,
['ভাদ্র', 'ভাদ্র মাস'] ,
['ভান্ডার', 'সমুদ্র', 'সাগর'] ,
['ভাব প্রকাশ', 'ভাব প্রকাশ নির্ঘন্ট', 'ভাবপ্রকাশ'] ,
['ভাবন', 'ভাবন উপনিষদ', 'ভাবনোপনিষদ'] ,
['ভাবনগর', 'ভাবনগর জেলা', 'ভাবনগর শহর'] ,
['ভাবনাহীন', 'হাল্কা'] ,
['ভাবপূর্ণ', 'ভাবাত্মক', 'মর্মস্পর্শী', 'হৃদয়স্পর্শী'] ,
['ভাববাচক', 'ভাববাচক সজ্ঞা'] ,
['ভাবর', 'ভাভর'] ,
['ভাবহীন', 'মনোগ্রাহী'] ,
['ভাবা', 'মনে করা'] ,
['ভাবার্থ', 'সারসংক্ষেপ', 'সারাংশ'] ,
['ভামপলাশি', 'ভীমপলশ্রী'] ,
['ভারগ্রস্ত', 'ভারবোঝাই', 'ভারাক্রান্ত'] ,
['ভারতবাসী', 'ভারতীয়'] ,
['ভারতী', 'ভারতী সন্ন্যাসী'] ,
['ভারতীয় প্রতিভূতি ও বিনিময় পরিষদ', 'ভারতীয় প্রতিভূতি ও বিনিময় বোর্ড', 'সেবী'] ,
['ভারতীয় স্টেট ব্যাঙ্ক', 'স্টেট ব্যাঙ্ক অফ ইন্ডিয়া'] ,
['ভারতীয়', 'হিন্দী', 'হিন্দুস্তানী'] ,
['ভারবাহক', 'ভারবাহী'] ,
['ভার্টেক্স', 'শীর্ষবিন্দু'] ,
['ভালো আচরণ', 'ভালো ব্যবহার', 'সত্ ব্যবহার', 'সদাচরণ', 'সদাচার', 'সদ্ব্যবহার'] ,
['ভালো কথা', 'ভালো ব্যাপার'] ,
['ভালো করে', 'ভালো ভাবে', 'ভালোভাবে'] ,
['ভালো খবর', 'শুভ সমাচার', 'সুখবর', 'সুসংবাদ'] ,
['ভালো দিন', 'সুদিন'] ,
['ভালো দেশ', 'সুরাষ্ট্র'] ,
['ভালো প্রদর্শনী', 'সুন্দর প্রদর্শনী'] ,
['ভালো ভাগ্য', 'সৌভাগ্য', 'সৌভাগ্য উপনিষদ', 'সৌভাগ্যোপনিষদ'] ,
['ভালো মানুয', 'সজ্জন', 'সজ্জন ব্যক্তি', 'সত্পুরুষ', 'সাধু', 'সুজন'] ,
['ভালো লাগা', 'মানানো'] ,
['ভালো', 'ভালোভাবে', 'রোচক', 'সুস্বাদু'] ,
['ভাল্লুক', 'মদ্দা ভাল্লুক'] ,
['ভাষা গোষ্ঠী', 'ভাষা সমষ্টি'] ,
['ভাষা বিজ্ঞান', 'ভাষা-বিজ্ঞান'] ,
['ভাষা শৈলী', 'শৈলী'] ,
['ভাষাবিজ্ঞানী', 'ভাষাবিদ'] ,
['ভাষার', 'ভাষিক'] ,
['ভাসতে থাকা', 'ভাসমান'] ,
['ভাস্কর', 'মূর্তিকার'] ,
['ভাস্কো ডা গামা', 'ভাস্কো ডি গামা'] ,
['ভিক্টোরিয়ান যুগ', 'ভিক্টোরীয় যুগ'] ,
['ভিক্ষা', 'ভিক্ষা করা', 'ভিক্ষা চাওয়া'] ,
['ভিক্ষাপ্রার্থী', 'ভিক্ষু', 'ভিক্ষুক', 'ভিখারী', 'যাচক'] ,
['ভিক্ষুক', 'ভিক্ষুক উপনিষদ', 'ভিক্ষুকোপনিষদ'] ,
['ভিজা', 'ভিজে', 'ভেজা'] ,
['ভিজে যাওয়া', 'ভেজা'] ,
['ভিট', 'ভিটে'] ,
['ভিণ্ড', 'ভিণ্ড জেলা', 'ভিণ্ড শহর'] ,
['ভিতর', 'ভিতরের দিক'] ,
['ভিতরে', 'ভেতরে'] ,
['ভিত্তিস্তম্ভ', 'মূল ভিত্তি'] ,
['ভিনভিন', 'ভিনভিন আওয়াজ'] ,
['ভিবানি', 'ভিবানি জেলা', 'ভিবানি শহর'] ,
['ভিল', 'ভিল জাতি'] ,
['ভিলওয়ারা', 'ভিলওয়ারা জেলা', 'ভিলওয়ারা শহর'] ,
['ভিলীয়', 'ভিলের'] ,
['ভিশক', 'ভিশক ঋষি'] ,
['ভিয়েতনামবাসী', 'ভিয়েতনামী'] ,
['ভিয়েতনামিস', 'ভিয়েতনামী'] ,
['ভীত', 'ভয়ভীত', 'ভয়ার্ত', 'মূল'] ,
['ভীনমাল', 'ভীনমাল তহশীল', 'ভীনমাল শহর'] ,
['ভীম', 'ভীমসেন'] ,
['ভুক্তভোগী', 'ভোগী'] ,
['ভুজ', 'ভুজ শহর'] ,
['ভুজঙ্গী', 'মাদি সাপ', 'সাপিনী'] ,
['ভুবন', 'লোক'] ,
['ভুরুণ্ড', 'ভুরুণ্ড ঋষি'] ,
['ভুল ধারণা', 'ভ্রম', 'ভ্রান্ত ধারণা', 'ভ্রান্তি'] ,
['ভুলে যাওয়া', 'ভোলা'] ,
['ভূ-ক্ষরণ', 'ভূক্ষরণ'] ,
['ভূ-গর্ভ-শাস্ত্র', 'ভূ-বিজ্ঞান', 'ভূ-শাস্ত্র', 'ভূগর্ভ-শাস্ত্র', 'ভূগর্ভশাস্ত্র', 'ভূবিজ্ঞান', 'ভূশাস্ত্র'] ,
['ভূ-ভৌতিকী', 'ভূভৌতিকী'] ,
['ভূঅভ্যন্তরস্থ', 'ভূগর্ভস্থ'] ,
['ভূকম্প', 'ভূমিকম্প'] ,
['ভূখণ্ড', 'ভূভাগ', 'ভৌগোলিক ক্ষেত্র'] ,
['ভূগোল', 'ভূগোলবিদ্যা', 'ভূগোলশাস্ত্র'] ,
['ভূগোলবিজ্ঞানী', 'ভূগোলবিদ', 'ভূগোলশাস্ত্রজ্ঞ', 'ভূগোলশাস্ত্রী'] ,
['ভূগোলীয়', 'ভৌগলিক'] ,
['ভূটানবাসী', 'ভূটানি'] ,
['ভূটানী', 'ভূটিয়া'] ,
['ভূত বিষয়ক', 'ভৌতিক'] ,
['ভূত', 'ভূত চতুর্দশী'] ,
['ভূপতি', 'ভূপতি রাগ'] ,
['ভূপ্রকৃতি', 'ভূমিরূপ'] ,
['ভূমি-বায়ু ক্ষেপণাস্ত্র', 'সাম', 'সারফেস টু এয়ার মিসাইল'] ,
['ভূমিকা', 'রোল'] ,
['ভূমিলবণ', 'সোরা'] ,
['ভূষণ্ডি', 'ভূষণ্ডী'] ,
['ভৃগু রেখা', 'ভৃগু লতা', 'ভৃগুরেখা', 'ভৃগুলতা', 'শ্রীবত্স'] ,
['ভৃম্যশ্ব', 'ভৃম্যশ্ব ঋষি'] ,
['ভেজা', 'সিক্ত', 'স্নাত'] ,
['ভেড়া', 'মেষ', 'লাগা'] ,
['ভেদক', 'ভেদকারী'] ,
['ভেদনীয়', 'ভেদ্য'] ,
['ভেনাস', 'শুক্র', 'শুক্র গ্রহ'] ,
['ভেনেজুয়েলা নিবাসী', 'ভেনেজুয়েলান', 'ভেনেজুয়েলাবাসী'] ,
['ভেনেজুয়েলান', 'ভেনেজুয়েলার', 'ভেনেজুয়েলীয়'] ,
['ভেনেজুয়েলার', 'ভেনেজুয়েলীয়'] ,
['ভেপসে যাওয়া', 'ভ্যাপসানো'] ,
['ভেরী', 'যুদ্ধ ডঙ্কা', 'রণভেরী'] ,
['ভেল', 'ভেল ঋষি'] ,
['ভেলভেট', 'মখমল'] ,
['ভৈরব', 'রাগ ভৈরব'] ,
['ভৈরবী যন্ত্রণা', 'ভৈরবী যাতনা'] ,
['ভৈরবী', 'মা ভৈরবী'] ,
['ভোঁ-ভোঁ করা', 'শোঁ-শোঁ করা'] ,
['ভোগ করা', 'ভোগা'] ,
['ভোগবিলাস', 'মজা', 'সম্ভোগ'] ,
['ভোগ্যপণ্য', 'ভোগ্যবস্তু'] ,
['ভোজ', 'ভোজ রাজা', 'রাজা ভোজ', 'সহভোগ'] ,
['ভোজপুর', 'ভোজপুর জেলা'] ,
['ভোট', 'মত'] ,
['ভোটদাতা বর্গ', 'ভোটদাতাগণ'] ,
['ভোটদান', 'ভোটপ্রদান'] ,
['ভোটাধিকার', 'মতাধিকার'] ,
['ভোপাল', 'ভোপাল জেলা', 'ভোপাল শহর'] ,
['ভৌ ভৌ', 'ভৌ-ভৌ'] ,
['ভ্রম জাল', 'ভ্রম-জাল', 'ভ্রমজাল'] ,
['ভ্রমণ', 'যাত্রা', 'সফর'] ,
['ভ্রমিত', 'হতবুদ্ধি'] ,
['ভ্রাত়ৃত্ব', 'ভ্রাতৃভাব'] ,
['ভ্রান্ত করা', 'মায়াবিষ্ট করা', 'মোহাবিষ্ট করা'] ,
['ভ্রান্ত', 'মিথ্যা'] ,
['ভ্রুণীয় কোষিকা', 'রচনাত্মক কোষিকা'] ,
['ভ্লাদিমির ইলিচ উলানফ', 'ভ্লাদিমির লেনিন', 'লেনিন'] ,
['ভয় দেখানো', 'ভয়ভীত করা'] ,
['ভয় পাওয়া', 'ভয়ভীত হওয়া'] ,
['ভয়ানক', 'ভয়ানক রস'] ,
['মঊ', 'মঊ জেলা', 'মঊ শহর'] ,
['মওকা', 'সময়', 'সুযোগ'] ,
['মকড়া', 'মকড়া বাঁদর'] ,
['মকর রেখা', 'মকররেখা'] ,
['মকর সংক্রান্তি', 'সংক্রান্তি'] ,
['মকর', 'মকর রাশি', 'মকর রাশিবিশিষ্ট', 'মকররাশি'] ,
['মকরধ্বজ', 'রসসিঁদুর'] ,
['মক্কল', 'মক্কল রোগ'] ,
['মক্ষিকা', 'মাছি'] ,
['মগজ', 'মস্তিষ্ক'] ,
['মগধের', 'মাগধী'] ,
['মঘা', 'মঘা নক্ষত', 'মঘা নক্ষত্রে'] ,
['মঙ্গল সূত্র', 'মঙ্গলসূত্র'] ,
['মঙ্গল', 'মঙ্গল গ্রহ', 'মঙ্গলবার'] ,
['মঙ্গলকারী গ্রহ', 'মঙ্গলগ্রহ'] ,
['মঙ্গলদাই', 'মঙ্গলদাই শহর'] ,
['মঙ্গলপাঠ', 'মঙ্গলাচরণ'] ,
['মঙ্গলোত্সব', 'শুভ উত্সব'] ,
['মঙ্গাবে', 'মঙ্গাবে বাঁদর'] ,
['মঙ্গোল ভাষা', 'মঙ্গোলিয়ান ভাষা'] ,
['মঙ্গোল', 'মঙ্গোল জাতি', 'মঙ্গোলীয়'] ,
['মঙ্গোলিয়ান', 'মঙ্গোলিয়ান ভাষা'] ,
['মঙ্গোলীয়া', 'মঙ্গোলীয়া গণরাজ্য'] ,
['মচিলীপটনম', 'মচিলীপটনম শহর'] ,
['মছিন্দরনাথ', 'মীননাথ'] ,
['মজা', 'মস্তি'] ,
['মজ্জা', 'হড্ডজ'] ,
['মঞ্চ', 'মাচা', 'স্টেজ'] ,
['মঞ্চক', 'মঞ্চকাসুর'] ,
['মঞ্চপত্রী', 'সুরপত্রী'] ,
['মঞ্চস্থ', 'মঞ্চের'] ,
['মঞ্জরি', 'মুকুল'] ,
['মঞ্জুরীপ্রাপ্ত', 'মান্য', 'স্বীকৃত'] ,
['মটকোড়বা', 'মটকোড়া'] ,
['মটরমালা', 'মোহনমালা'] ,
['মঠ কক্ষ', 'মঠের ঘর'] ,
['মঠাদক্ষা', 'মঠাধিকারিনী'] ,
['মঠাধিকারী', 'মঠাধ্যক্ষ', 'মোহান্ত'] ,
['মডিকেরি', 'মডিকেরি শহর'] ,
['মণি মালা', 'রত্ন মালা', 'রত্নহার', 'রত্নাবলী'] ,
['মণিখচিত', 'মণিমণ্ডিত', 'মণিময়'] ,
['মণিগুণ', 'শশিকলা'] ,
['মণিপুর', 'মণিপুর চক্র'] ,
['মণিভদ্রক', 'মণিভদ্রক নাগ'] ,
['মণ্ডপ', 'শামিয়ানা'] ,
['মণ্ডলব্রাহ্মণ', 'মণ্ডলব্রাহ্মণ উপনিষদ', 'মণ্ডলব্রাহ্মণোপনিষদ'] ,
['মণ্ডলা', 'মণ্ডলা জেলা', 'মণ্ডলা শহর'] ,
['মণ্ডি', 'মণ্ডি জেলা', 'মণ্ডি শহর'] ,
['মণ্ডিয়ালী', 'মণ্ডিয়ালী ভাষা'] ,
['মণ্ডয়া জেলা', 'মাণ্ডয়া জেলা'] ,
['মণ্ডয়া', 'মণ্ডয়া শহর'] ,
['মতলা', 'মত্লা'] ,
['মতৈক্য', 'সর্বসম্মতি'] ,
['মত্ত', 'মাতাল'] ,
['মত্স পুরাণ', 'মত্সপুরাণ'] ,
['মত্স', 'মত্স অবতার', 'মত্সাবতার'] ,
['মত্স্য শিকার', 'মাছ শিকার'] ,
['মথিত', 'মন্থিত'] ,
['মথুরা', 'মথুরা জেলা', 'মথুরা শহর'] ,
['মদ', 'মস্তি'] ,
['মদকারী পাখি', 'শাহুতেলা'] ,
['মদিরা', 'মালিনী'] ,
['মদিরা-পান', 'মদিরাপান', 'মদ্য-পান', 'মদ্য-সেবন', 'মদ্যপান', 'মধুপান', 'সুরাপান'] ,
['মদুরাই', 'মদুরাই জেলা', 'মদুরাই শহর'] ,
['মদের দোকান', 'মদের ভাঁটি'] ,
['মদ্দা শুয়োর', 'শুয়োর', 'শূকর'] ,
['মদ্যপ', 'মাতাল'] ,
['মধু', 'মহুয়া'] ,
['মধুকর', 'মৌমাছি'] ,
['মধুকার শাহ', 'মধুকার শাহ জুদেব'] ,
['মধুকোষ', 'মৌচাক'] ,
['মধুছন্দা', 'মধুছন্দা ঋষি'] ,
['মধুত্থ', 'মোম', 'সিকথ'] ,
['মধুবনি', 'মধুবনি জেলা', 'মধুবনি শহর'] ,
['মধুবাহী', 'মধুবাহী নদী'] ,
['মধুমাত', 'মধুমাত রাগ'] ,
['মধুমাতসরঙ্গ', 'মধুমাতসরঙ্গ রাগ'] ,
['মধুযষ্টিকা', 'মধুরা', 'মধুলী', 'যষ্ঠিমধু'] ,
['মধুযষ্ঠী', 'মধূলিকা', 'মুলেঠী', 'যষ্ঠীমধু'] ,
['মধুর ভাষণ', 'মিষ্ট ভাষণ', 'মৃদু ভাষণ', 'সুভাষণ'] ,
['মধুর', 'মিষ্ট', 'মিষ্টি', 'রুচিকর', 'সুরেলা'] ,
['মধুরতা', 'মাধুর্য', 'মিষ্টতা', 'মিষ্টভাব'] ,
['মধুরিকা', 'মৌরি', 'শালেয়'] ,
['মধেপুরা', 'মধেপুরা জেলা', 'মধেপুরা শহর'] ,
['মধ্য আফ্রিকার গণতন্ত্র', 'সেন্ট্রাল আফ্রিকা', 'সেন্ট্রাল আফ্রিকান রিপাব্লিকান'] ,
['মধ্য বর্গ', 'মিডল ক্লাস'] ,
['মধ্য-রাত্রি', 'মধ্যরাত', 'মধ্যরাত্রি'] ,
['মধ্যকাল', 'মধ্যবর্তী সময়'] ,
['মধ্যম', 'মাঝামাঝি'] ,
['মধ্যমাত্রেয়', 'মধ্যমাত্রেয় ঋষি'] ,
['মধ্যান্তর', 'মধ্যান্তরাল'] ,
['মন গড়া গল্প', 'মিথ্যে কথা বলা'] ,
['মন জয় করা', 'মুগ্ধ করা', 'মোহিত করা'] ,
['মনঃ', 'মনোগত', 'মানসিক'] ,
['মনঃস্থিতি', 'মনোদশা', 'মনোবস্থা', 'মানসিক অবস্থা'] ,
['মনগড়া', 'স্বকপোল কল্পিত', 'স্বকপোলকল্পিত'] ,
['মনস্তাপ', 'মনোব্যথা'] ,
['মনীলা', 'মনীলা আম'] ,
['মনু-স্মৃতি', 'মনুসংহিতা. মনু-সংহিতা', 'মনুস্মৃতি'] ,
['মনুষ্যজাতি', 'মানবজাতি', 'মানুষ'] ,
['মনুষ্যত্ব', 'মানবতা', 'মানবীয়তা'] ,
['মনুষ্যভোজী', 'মানবভুক'] ,
['মনুষ্যোচিত', 'মানুষের মতো'] ,
['মনে করা', 'স্মরণ করা'] ,
['মনে করানো', 'স্মরণ করানো'] ,
['মনে রাখা', 'স্মরণ করা', 'স্মরণে রাখা'] ,
['মনের রাগ', 'মানসিক রাগ'] ,
['মনোগত', 'স্বগত'] ,
['মনোধ্যান', 'মনোধ্যান রাগ'] ,
['মনোনিবেশ করা', 'মনোযোগ দেওয়া'] ,
['মনোবিজ্ঞান', 'মনোবিদ্যা', 'মানস শাস্ত্র', 'মানস-বিজ্ঞান', 'মানসশাস্ত্র', 'সাইকোলজি'] ,
['মনোবিজ্ঞানী', 'মনোবৈজ্ঞনিক', 'মনোবৈজ্ঞানিক', 'মনোরোগ বিশেষজ্ঞ'] ,
['মনোবৈজ্ঞানিক', 'মানসিক'] ,
['মনোযোগ সহকারে', 'সাবধানতাপূর্বক', 'সাবধানতার সঙ্গে'] ,
['মনোরম', 'মনোহর', 'মোহিনী', 'সুদর্শন', 'সুদর্শন চক্র', 'সুন্দর'] ,
['মনোরোগ চিকিতসক', 'মনোরোগ-বিশেষজ্ঞ'] ,
['মনোহর', 'মনোহর রাগ'] ,
['মন্তর', 'মন্ত্র', 'স্তুতি মন্ত্র'] ,
['মন্ত্রমুগ্দ্ধ', 'মুগ্দ্ধ', 'মোহিত'] ,
['মন্ত্রী-মন্ডল', 'মন্ত্রীমন্ডল'] ,
['মন্ত্রীমণ্ডলীয়', 'মন্ত্রীমণ্ডলের'] ,
['মন্থান', 'মন্থান রাগ'] ,
['মন্দ হাসি', 'হাসি'] ,
['মন্দর', 'মন্দরাচল'] ,
['মন্দসোর', 'মন্দসোর জেলা', 'মন্দসোর শহর'] ,
['মন্দার', 'মন্দার বৃক্ষ', 'মন্দারক', 'শূকফল'] ,
['মন্দোদরী', 'ময়তনয়া'] ,
['মন্মথপ্রিয়া', 'রতি', 'রতি দেবী', 'রাগলতা', 'রেবা', 'শুভাঙ্গী'] ,
['মন্যুদেব', 'মন্যুদেব ঋষি'] ,
['মব্রোকা', 'মব্রোকা আম'] ,
['মমতা', 'মমত্ব', 'স্নেহ'] ,
['মমিত', 'মমিত জেলা', 'মমিত শহর'] ,
['মর-মর', 'মরণাপন্ন', 'মৃতপ্রায়', 'মৃত্যুভয়'] ,
['মরণাপন্ন হওয়া', 'মরমর অবস্থা হওয়া', 'মৃতপ্রায় হওয়া'] ,
['মরণাপন্ন', 'মুমূর্ষু', 'মৃতপ্রায়'] ,
['মরণোত্তর', 'মৃত্যুপরান্ত'] ,
['মরশুমী কর্মচারী', 'মরশুমী মজুর'] ,
['মরিগাঁও', 'মরিগাঁও জেলা', 'মরিগাঁও শহর'] ,
['মরিশাস নিবাসী', 'মরিশাসবাসী'] ,
['মরিশাস সম্পর্কিত', 'মরিশাসের'] ,
['মরিশাস', 'মরিশাস গণরাজ্য'] ,
['মরীচি', 'মরীচি ঋষি'] ,
['মরীচিকা', 'মৃগ-মরীচিকা', 'মৃগতৃষ্ণা', 'মৃগতৃষ্ণিকা'] ,
['মরু', 'মরুভূমি', 'মরুস্থল'] ,
['মরুভূমি নিবাসী', 'মরুস্হলীয়'] ,
['মরুভূমির', 'মরুস্হলীয়'] ,
['মরোক্কান', 'মরোক্কো সম্পর্কিত', 'মরোক্কোর'] ,
['মর্গ', 'লাশঘর', 'শব-কক্ষ', 'শব-গৃহ', 'শবকক্ষ', 'শবকক্ষ', 'শবগৃহ'] ,
['মর্দন করা', 'মালিশ করা'] ,
['মর্দল', 'মাদল'] ,
['মর্ম', 'মর্ম স্থল', 'মর্ম স্থান', 'মর্মস্থল'] ,
['মর্মঘাতী', 'মর্মভেদী', 'মর্মস্পর্শী', 'হৃদয়-বিদায়ক'] ,
['মর্মরপ্রস্তর', 'মার্বেল'] ,
['মর্যাদাহীন', 'মানসম্মানহীন'] ,
['মল ত্যাগ', 'শৌচ', 'শৌচকর্ম'] ,
['মলগোবা', 'মলগোবা আম', 'মলগোবা আমের গাছ'] ,
['মলঙ্গ', 'মলঙ্গা'] ,
['মলদোভান লেউ', 'লেউ'] ,
['মলপাত্র', 'মলাধার', 'সিট'] ,
['মলম', 'লোশন'] ,
['মলমলের ওড়না', 'মলমলের শাল'] ,
['মলা', 'মূল', 'মূল নক্ষত্র'] ,
['মলাভি', 'মলাভি গণরাজ্য'] ,
['মলারী', 'মলারী রাগ'] ,
['মলাশয়', 'রেক্টম'] ,
['মল্কানগিরি', 'মল্কানগিরি জেলা', 'মল্কানগিরি শহর'] ,
['মল্ল', 'মল্ল জাতি'] ,
['মল্লারি', 'মল্লারী'] ,
['মল্লিকা', 'মল্লিকা আম'] ,
['মলয় বাসী', 'মলয়বাসী'] ,
['মলয়ালম', 'মলয়ালি'] ,
['মশরু', 'মসরু'] ,
['মশলাদার', 'মশলাযুক্ত'] ,
['মসকলা', 'মসকলী'] ,
['মসৃণ', 'স্নিগ্ধ'] ,
['মস্তক', 'মাথা', 'ললাট'] ,
['মস্তকের', 'মাথার'] ,
['মহড়া', 'রিহার্সাল'] ,
['মহত্', 'মহত্ উপনিষদ'] ,
['মহত্ব', 'মহিমা', 'মাহাত্ম্য', 'মূল্য'] ,
['মহম্মদ', 'হজরত মহম্মদ'] ,
['মহরম', 'মহরম মাস'] ,
['মহা কাব্য', 'মহাকাব্য'] ,
['মহা জ্ঞানি', 'মহা পণ্ডিন', 'মহা বিদ্বান', 'মহা বিদ্বান'] ,
['মহা সমুদ্র', 'মহাসাগর'] ,
['মহাকন্য', 'মহাকন্য'] ,
['মহাকাল', 'মহাকালেশ্বর'] ,
['মহাকাশযান', 'স্পেসক্রাফ্ট'] ,
['মহাকিপ্টে', 'মহাকৃপণ'] ,
['মহাগৌরী', 'মহাগৌরী'] ,
['মহাজনি', 'সাহুকারী'] ,
['মহাজনী', 'মহাজনী লিপি', 'মুণ্ডী'] ,
['মহাত্মা জ্যোতিবা ফুলে', 'মহাত্মা জ্যোতিরাও গোবিন্দরাও ফুলে', 'মহাত্মা ফুলে'] ,
['মহাত্মা', 'সাধু'] ,
['মহাদজী', 'মহাদজী সিন্ধিয়া'] ,
['মহাদেব গণ', 'শিব গণ', 'শিব-কিঙ্কর', 'শিবকিঙ্কর', 'শিবগণ', 'শৈলাদি'] ,
['মহাধিবেশন', 'মহাবৈঠক', 'মহাসম্মেলন'] ,
['মহানগরীয়', 'মহানগরের'] ,
['মহানন্দা', 'মহানন্দা নদী'] ,
['মহানারায়ণ', 'মহানারায়ণ উপনিষদ', 'মহানারায়ণোপনিষদ'] ,
['মহানুভব', 'মহাশয়'] ,
['মহাপথ', 'রাজপথ', 'রাজমার্গ', 'হাইওয়ে'] ,
['মহাপাত্র', 'মহাব্রাহ্মণ'] ,
['মহাপুরুষ', 'শ্রেষ্ঠ পুরুষ'] ,
['মহাপ্রভা', 'মহাপ্রভা নদী'] ,
['মহাপ্রলয়', 'মহাবিনাশ'] ,
['মহাপ্রস্থান', 'মহাপ্রয়াণ', 'মৃত্যু', 'মোক্ষ'] ,
['মহাফেজখানা', 'সংগ্রহশালা', 'সংরক্ষণাগার'] ,
['মহাবক', 'মানিক-জোর', 'লকলক', 'লগলগ'] ,
['মহাবাক্য', 'মহাবাক্য উপনিষদ', 'মহাবাক্যোপনিষদ'] ,
['মহাভীষ্ম', 'শান্তনু'] ,
['মহামায়নগর', 'মহামায়নগর শহর', 'হাথরস'] ,
['মহামায়া', 'মায়া', 'মায়া আম', 'মায়া দেবী'] ,
['মহামায়ানগর', 'মহামায়ানগর জেলা', 'হাথরস', 'হাথরস জেলা'] ,
['মহারাজগঞ্জ', 'মহারাজগঞ্জ জেলা', 'মহারাজগঞ্জ শহর'] ,
['মহারাণা কুম্ভ', 'রাণা কুম্ভ'] ,
['মহারাণা প্রতাপ', 'রাণা প্রতাপ', 'রাণা প্রতাপ সিংহ'] ,
['মহালক্ষী', 'সনাতনী'] ,
['মহালত', 'মূতরী'] ,
['মহাশয়', 'মহোদয়'] ,
['মহাশয়া', 'মহোদয়া'] ,
['মহাসমুন্দ', 'মহাসমুন্দ জেলা', 'মহাসমুন্দ শহর'] ,
['মহাসোন', 'সোন', 'সোন নদী', 'সোনভদ্র'] ,
['মহিলা সাধু', 'যোগিনী', 'সন্ন্যাসিনী', 'স্ত্রী বৈরাগী'] ,
['মহিশাসুর', 'মহিষ'] ,
['মহিষ', 'মোষ'] ,
['মহিসুর', 'মহিসুর শহর'] ,
['মহেঞ্জো-দাড়ো', 'মহেঞ্জোদাড়ো'] ,
['মহেন্দ্রগড়', 'মহেন্দ্রগড় জেলা', 'মহেন্দ্রগড় শহর'] ,
['মহেন্দ্রাল', 'মহেন্দ্রাল নদী'] ,
['মহেন্দ্রী', 'মহেন্দ্রী নদী'] ,
['মহোখ', 'মহোখা'] ,
['মহোবা', 'মহোবা জেলা', 'মহোবা শহর'] ,
['মাংস', 'মাস', 'মিট'] ,
['মাংসপিণ্ড', 'মাংসের টুকরো'] ,
['মাংসভোজী', 'মাংসাশী'] ,
['মাংসরুহা', 'মাংসরোহিণী'] ,
['মাইক্রনেশিয়া', 'মাইক্রনেসিয়া', 'মাইক্রোনেশিয়া', 'মাইক্রোনেসিয়া'] ,
['মাইনে', 'মাস মাইনে', 'মাসিক বেতন'] ,
['মাউণ্ট', 'রাইডিং হর্স', 'সওয়ারি ঘোড়া', 'সেডল হর্স'] ,
['মাখনভরা', 'মাখনমিশ্রিত'] ,
['মাখানো', 'লেপা'] ,
['মাগধী', 'মাগধী প্রাকৃত'] ,
['মাঘ', 'মাঘ মাস'] ,
['মাচা', 'মাচান'] ,
['মাছ', 'মীন'] ,
['মাজা', 'মার্জন করা'] ,
['মাজা-ঘষা করা', 'রগড়ানো'] ,
['মাঝ', 'মাঝারি'] ,
['মাঝি', 'মাল্লার'] ,
['মাঝে-মাঝে', 'সময়ে-সময়ে'] ,
['মাটির পাত্র', 'মাটির বাসন', 'মৃত্পাত্র'] ,
['মাটির বাসন তৈরীর কারখানা', 'মৃত্পাত্র নির্মাণের কারখানা'] ,
['মাণব', 'মাণবক'] ,
['মাণ্ডব্য', 'মাণ্ডব্য ঋষি'] ,
['মাণ্ডু', 'মাণ্ডু শহর'] ,
['মাণ্ডুক্য', 'মাণ্ডুক্য উপনিষদ', 'মাণ্ডুক্যোপনিষদ'] ,
['মাতঙ্গ', 'মাতঙ্গ ঋষি'] ,
['মাতা মেরী', 'মেরী'] ,
['মাতুল', 'মামা'] ,
['মাতুলানী', 'মামী'] ,
['মাতৃ কোষিকা', 'মাতৃকোষিকা'] ,
['মাতৃষ্বসা', 'মাসি'] ,
['মাতৃহীন', 'মাহারা'] ,
['মাত্রা', 'স্বরমাত্রা'] ,
['মাত্রাবদ্ধ', 'মাত্রাযুক্ত', 'মাত্রাসম্বন্ধীয়', 'মাত্রিক'] ,
['মাত্রাসমক', 'মাত্রাসমক ছন্দ'] ,
['মাত্রিক গণ', 'মাত্রিক-গণ'] ,
['মাথা নেড়া করার সংস্কার', 'মাথা মুড়োনো সংস্কার'] ,
['মাথা', 'মুণ্ড'] ,
['মাদা', 'স্ত্রী', 'স্ত্রী প্রজাতি'] ,
['মাদাগাস্কার সম্পর্কিত', 'মাদাগাস্কারীয়'] ,
['মাদাগাস্কার', 'মাদাগাস্কার গণরাজ্য', 'মালগাসী গণরাজ্য'] ,
['মাদাগাস্কারবাসী', 'মাদাগাস্কারি'] ,
['মাদি ইঁদুর', 'মুষিকা', 'স্ত্রী ইঁদুর'] ,
['মাদি শিয়াল', 'শৃগালী'] ,
['মাদী কুকুর', 'মেয়ে কুকুর'] ,
['মাদী জননাঙ্গ', 'স্ত্রী গুপ্তাঙ্গ', 'স্ত্রী জননাঙ্গ'] ,
['মাদী', 'মাদী নদী'] ,
['মাধব', 'মাধব রাগ'] ,
['মাধবিকা', 'মাধবী'] ,
['মাধী', 'মাধী রাগ'] ,
['মান-সর', 'মানস-সর', 'মানস-সরোবর', 'মানসরোবর'] ,
['মাননীয়', 'সম্মানীয়'] ,
['মানব নির্মিত বস্তু', 'মানবকৃতি'] ,
['মানব প্রেম', 'লৌকিক প্রেম', 'সাংসারিক প্রেম'] ,
['মানবকৃত', 'মানবরচিত'] ,
['মানববিজ্ঞানী', 'মানবশাস্ত্রী'] ,
['মানবিক', 'মানবীয়'] ,
['মানভঞ্জন করা', 'মানানো'] ,
['মানভঞ্জন করানো', 'মানানো'] ,
['মানসা', 'মানসা জেলা', 'মানসা নদী', 'মানসা শহর'] ,
['মানসিক অস্থিরতা', 'মেন্টাল ডিসঅর্ডার'] ,
['মানা', 'মান্য করা'] ,
['মানানো', 'স্বীকার করানো'] ,
['মানি অর্ডার', 'মানিঅর্ডার'] ,
['মানিনী', 'রুষ্টা'] ,
['মান্ত্রিক', 'মান্ত্রিক উপনিষদ', 'মান্ত্রিকোপনিষদ'] ,
['মাপ নেওয়া', 'মাপা'] ,
['মাপ', 'মাপজোক', 'মাপা'] ,
['মাফ করানো', 'মুকুব করানো'] ,
['মামলা', 'মামলাবাজী'] ,
['মামলাবাজ', 'মোকদ্দমাবাজ'] ,
['মামাতো বোন', 'মামাতো ভগিনী'] ,
['মার-পিট', 'মারপিট', 'মারা-মারি', 'মারামারি'] ,
['মারগাঁও', 'মারগাঁও শহর'] ,
['মারধোর করা', 'মারা'] ,
['মারফত', 'মার্ফত'] ,
['মারসা', 'মারসা গৌরী রাগ'] ,
['মারা', 'হত্যা করানো'] ,
['মার্কণ্ডেয়', 'মার্কণ্ডেয় ঋষি'] ,
['মার্কন্ডেয় পুরাণ', 'মার্কন্ডেয়পুরাণ'] ,
['মার্কা লাগানো', 'মার্কাযুক্ত'] ,
['মার্গ', 'রাস্তা'] ,
['মার্চ', 'মিছিল'] ,
['মার্জালীয়', 'মার্জালীয় ঋষি'] ,
['মার্টিন লুথার', 'মার্টিন লুথার কিং'] ,
['মাল', 'মালী'] ,
['মালকোষ', 'মালকোষ রাগ'] ,
['মালডোবা গণরাজ্য', 'মোল্ডভিয়া'] ,
['মালদহ জেলা', 'মালদা জেলা'] ,
['মালপ্পুরম', 'মালপ্পুরম জেলা', 'মালপ্পুরম শহর'] ,
['মালব', 'মালব রাগ'] ,
['মালবাহী জাহাজ', 'মালবাহী নৌকা'] ,
['মালহায়ন', 'মালহায়ন ঋষি'] ,
['মালা', 'হার'] ,
['মালাই', 'সর'] ,
['মালাফল', 'রুদ্রাক্ষ'] ,
['মালীদ', 'মালীদবডেনাম'] ,
['মালুমকাঠ', 'মাস্তুল'] ,
['মালেশিয়ান', 'মালেশিয়ার'] ,
['মাল্টা', 'মাল্টা গণতন্ত্র', 'মাল্টা গণরাজ্য', 'মাল্টা দ্বীপ'] ,
['মাল্টাই লীরা', 'লীরা'] ,
['মাল্যবতী', 'মাল্যবতী নদী'] ,
['মালয়েশিয়া নিবাসী', 'মালয়েশিয়ান'] ,
['মালয়েশিয়ান রিংগিট', 'রিংগিট'] ,
['মালয়েশিয়ান', 'মালয়েশিয়ার', 'মালয়েশিয়ার ভাষা', 'মালয়েশীয়'] ,
['মাশুল', 'রাজস্ব'] ,
['মাসতুতো বোন', 'মাসতুতো ভগিনী'] ,
['মাসিক', 'মাসিক ধর্ম', 'মাসের', 'রজঃধর্ম', 'স্ত্রীকুসুম'] ,
['মাস্ক', 'মুখোশ'] ,
['মাহে', 'মাহে জেলা', 'মাহে শহর'] ,
['মিইয়ে যাওয়া', 'ম্রিয়মাণ হওয়া', 'ম্লান হওয়া', 'শুকিয়ে যাওয়া'] ,
['মিউজিয়াম', 'যাদুঘর', 'সংগ্রহশালা', 'সংগ্রহালয়'] ,
['মিক্স', 'মিশ্রণ'] ,
['মিক্সার', 'মিক্সি', 'মিশ্রণ-যন্ত্র'] ,
['মিছরি', 'মিশ্রী'] ,
['মিজো', 'মিজো ভাষা'] ,
['মিটার পদ্ধতি', 'মিটার প্রণালী'] ,
['মিডিয়া', 'সঞ্চার মাধ্যম'] ,
['মিতব্যয়ী', 'স্বল্পব্যয়ী'] ,
['মিতভাষী', 'স্বল্পভাষী'] ,
['মিতাহারী', 'সংযমী'] ,
['মিত্র', 'মিত্র দেবতা'] ,
['মিত্রঘ্ন', 'মিত্রহন্তা'] ,
['মিত্রা', 'মিত্রী', 'সুমিত্রা'] ,
['মিথুন', 'মিথুন রাশি', 'মিথুন রাশিবিশিষ্ট', 'মিথুনরাশি'] ,
['মিথ্যা অভিযোগ', 'মিথ্যা আরোপ'] ,
['মিথ্যা ধমকি', 'মিথ্যা শাসানি', 'মিথ্যা হুমকি'] ,
['মিনাকারি', 'মিনে'] ,
['মিনামিসোমা', 'মিনামিসোমা শহর'] ,
['মিমি', 'মিলিমিটার'] ,
['মির্জাপুর', 'মির্জাপুর জেলা', 'মির্জাপুর শহর'] ,
['মিল হওয়া', 'যাওয়া'] ,
['মিল', 'যুক্তি', 'যোগ', 'সংযোগ'] ,
['মিলন হওয়া', 'সঙ্গম হওয়া'] ,
['মিলিটারি ট্রেনিং', 'সেনা প্রশিক্ষণ'] ,
['মিলিটারি', 'স্থল সেনা', 'স্থল-সেনা', 'স্থলসেনা'] ,
['মিলিত হওয়া', 'মিশে যাওয়া', 'সমাবিষ্ট হওয়া'] ,
['মিশন', 'মিশনারী'] ,
['মিশিগান বিশ্ববিদ্যালয়', 'মিশিগান য়ুনিভার্সিটি'] ,
['মিশ্র রাগ', 'সংকর রাগ'] ,
['মিশ্র', 'মিশ্রা', 'মিশ্রিত'] ,
['মিশ্রণ', 'সংমিশ্রণ'] ,
['মিশ্রিত করা', 'মেশানো', 'সম্মিশ্রিত করা'] ,
['মিষ্টভাষী', 'মৃদুভাষী', 'সুভাষী'] ,
['মিষ্টান্ন', 'মিষ্টি', 'মেঠাই'] ,
['মিষ্টি লেবু', 'শরবতি লেবু'] ,
['মিষ্টি সোডা', 'সোডা'] ,
['মিষ্টি', 'শেষপাতের খাবার'] ,
['মিসিসিপি', 'মিসিসিপি নদী', 'মিসিসিপি রাজ্য'] ,
['মিহি', 'সূক্ষ্ম'] ,
['মীন', 'মীন রাশি', 'মীনরাশি'] ,
['মীনা', 'মীনা জাতি'] ,
['মীনাক্ষী', 'মীনাক্ষী দেবী'] ,
['মীমাংসা শাস্ত্র', 'মীমাংসাশাস্ত্র'] ,
['মীমাংসিত', 'সমাধিত'] ,
['মীরা', 'মীরা বাই', 'মীরাবাই'] ,
['মীরুত জেলা', 'মেরঠ জেলা'] ,
['মুকুন্দ', 'সাঠী ধান'] ,
['মুকুল', 'মুদ্রল'] ,
['মুক্তসর', 'মুক্তসর জেলা', 'মুক্তসর শহর'] ,
['মুক্তা মালা', 'মুক্তা লতা', 'মুক্তা হার', 'মুক্তাকলাপ', 'মুক্তাবলী', 'মুক্তামালা', 'মুক্তালতা', 'মুক্তাহার'] ,
['মুক্তা', 'মুক্তো', 'শুক্তিবীজ'] ,
['মুক্তি', 'রেহাই', 'স্বাধীনতা'] ,
['মুক্তিক', 'মুক্তিক উপনিষদ', 'মুক্তিকোপনিষদ'] ,
['মুখ গোমড়া করা', 'রাগ করা'] ,
['মুখ সম্পর্কিত', 'মুখের'] ,
['মুখ', 'মুখটি', 'মুখের হাবভাব', 'মুখোশ', 'সামনের দিক'] ,
['মুখপাক', 'মুখপাক রোগ'] ,
['মুখবন্দ', 'মুখবন্দ রোগ'] ,
['মুখর', 'মুখরিত'] ,
['মুখরোচক', 'রুচিকর', 'রুচিশীল', 'রোচক'] ,
['মুখোমুখি হওয়া', 'মোকাবিলা করা'] ,
['মুখ্য ধারা', 'মুখ্যধারা'] ,
['মুখ্য বিষয়', 'মেজর'] ,
['মুঘল আমল', 'মুঘল কাল'] ,
['মুঘলী', 'মোগলাই'] ,
['মুঘলীয়', 'মোঘলীয়'] ,
['মুঘোল নারী', 'মুঘোল পত্নী'] ,
['মুঙ্গের', 'মুঙ্গের জেলা', 'মুঙ্গের শহর'] ,
['মুচকুন্দ', 'মুচকুন্দ গাছ', 'মুচকুন্দ বৃক্ষ', 'মুচুকুন্দ', 'মুচুকুন্দ গাছ', 'মুচুকুন্দ বৃক্ষ'] ,
['মুছে ফেলা', 'মেরে ফেলা', 'শেষ করা'] ,
['মুজফ্ফরনগর', 'মুজফ্ফরনগর জেলা'] ,
['মুজফ্ফরপুর', 'মুজফ্ফরপুর জেলা', 'মুজফ্ফরপুর শহর'] ,
['মুটে', 'শ্রমজীবি', 'শ্রমিক'] ,
['মুঠা', 'মুঠা নদী'] ,
['মুঠি', 'মুঠো', 'মুষ্টি', 'মুষ্টিকা'] ,
['মুড়িয়ে নেওয়া', 'মুন্ডন', 'মুন্ডন করা', 'মোড়ানো'] ,
['মুণ্ডক', 'মুণ্ডক উপনিষদ', 'মুণ্ডকোপনিষদ'] ,
['মুদগল', 'মুদগল উপনিষদ', 'মুদগল ঋষি', 'মুদগলোপনিষদ'] ,
['মুদি দোকান', 'মুদিখানা', 'রিটেল'] ,
['মুদিখানা', 'মুদির দোকান'] ,
['মুদ্রক', 'মুদ্রণ কর্তা', 'মুদ্রাকর'] ,
['মুদ্রণ যন্ত্র', 'মুদ্রণযন্ত্র'] ,
['মুদ্রা টোরী', 'মুদ্রাটোরী'] ,
['মুদ্রা বিজ্ঞান', 'মুদ্রা শাস্ত্র'] ,
['মুদ্রা বিনিময়', 'মুদ্রা-বিনিময়'] ,
['মুদ্রা-কান্হাড়া', 'মুদ্রাকান্হাড়া'] ,
['মুন', 'সান মিউঙ্গ মুন'] ,
['মুনাফা', 'লাভ'] ,
['মুমূর্ষা', 'মৃত্যুর ইচ্ছা'] ,
['মুরা', 'মুরা মোষ'] ,
['মুরাদাবাদ জেলা', 'মোরাদাবাদ জেলা'] ,
['মুরাদাবাদ', 'মুরাদাবাদ শহর'] ,
['মুরৈনা', 'মুরৈনা জেলা', 'মুরৈনা শহর'] ,
['মুর্শিদাবাদ', 'মুর্শিদাবাদ শহর'] ,
['মুলতবি করানো', 'স্থগিত করানো'] ,
['মুলতুবি করা', 'স্থগিত করা'] ,
['মুলতুবি হওয়া', 'স্থগিত হওয়া'] ,
['মুলা', 'মুলা লতা'] ,
['মুশির্দাবাদ', 'মুশির্দাবাদ জেলা'] ,
['মুষ্টিক', 'মুষ্টিকাসুর'] ,
['মুসমার', 'মুসমার পাখি'] ,
['মুসলমান', 'মুসলিম'] ,
['মুসাম্বি', 'মোসাম্বি'] ,
['মুসী', 'মুসী নদী'] ,
['মুসুর', 'মুসুর ডাল', 'মুসুরি ডাল'] ,
['মূখ্য', 'মেজর'] ,
['মূত্রকৃচ্ছ্র', 'মূত্রদোষ'] ,
['মূত্রনালিকা', 'মূত্রবাহিকা'] ,
['মূত্রনিরোধ', 'মূত্ররোধ'] ,
['মূত্রবাহিনী', 'মূত্রমালি'] ,
['মূদ্রা-স্ফীতি', 'মূদ্রাস্ফীতি'] ,
['মূর্দ্ধন্য', 'মূর্দ্ধন্য বর্ণ'] ,
['মূল কাজ', 'মৌলিক কাজ', 'মৌলিক রচনা'] ,
['মূল', 'মূল নক্ষত্র'] ,
['মূলা', 'মূলা নদী'] ,
['মূলাধার', 'মূলাধার চক্র'] ,
['মূল্য দেওয়া', 'মূল্যাঙ্কন করা'] ,
['মৃকণ্ড', 'মৃকণ্ড ঋষি'] ,
['মৃগ কানন', 'মৃগয়া ক্ষেত্র', 'সংরক্ষিত এলাকা'] ,
['মৃগ', 'মৃগত্তোম', 'মৃগশির', 'মৃগশিরা নক্ষত্র', 'শশিদেব', 'হরিণ'] ,
['মৃগছানা', 'মৃগশাবক'] ,
['মৃগনয়নী', 'মৃগলোচনা'] ,
['মৃগশিরা', 'মৃগশিরা নক্ষত্র'] ,
['মৃগয়া', 'শিকার'] ,
['মৃতদেহ', 'লাশ', 'শব', 'শবদেহ'] ,
['মৃতসঞ্জীবনী', 'সঞ্জীবনী'] ,
['মৃত্যু শোক', 'শোক'] ,
['মৃত্যুচিন্তা', 'মৃত্যুভয়'] ,
['মৃদুনাদী', 'মৃদুভাষী'] ,
['মেওয়া বিক্রেতা', 'মেওয়া বিক্রয়কারী'] ,
['মেওয়াড়', 'মেওয়াড় রাগ'] ,
['মেকআপ করা', 'সাজগোজ করা'] ,
['মেকআপ', 'শৃঙ্গার', 'সজ্জা', 'সাজ'] ,
['মেকাক', 'মেকাক বাঁদর'] ,
['মেক্সিকান', 'মেক্সিকীয়', 'মেক্সিকোবাসী', 'মেক্সিকোর'] ,
['মেঘ মল্লার', 'মেঘমল্লার'] ,
['মেঘ', 'মেঘ রাগ', 'মেঘরাগ'] ,
['মেঘনাট', 'মেঘনাট রাগ'] ,
['মেঘনাদ রস', 'মেঘনাদ-রস', 'মেঘনাদরস'] ,
['মেঘাচ্ছন্ন', 'মেঘাচ্ছাদিত'] ,
['মেজনিলো-নুনেজ', 'মেজনিলো-নুনেজ আম'] ,
['মেডক', 'মেডক জেলা'] ,
['মেথি', 'মেথিকা', 'শালিনী'] ,
['মেদিনীপুর', 'মেদিনীপুর জেলা'] ,
['মেধাতিথি', 'মেধাতিথি ঋষি'] ,
['মেধ্য', 'হবনীয়'] ,
['মেনকা', 'ময়না'] ,
['মেনাবলী ছন্দ', 'সারং ছন্দ'] ,
['মেনে নেওয়া', 'রাজি হওয়া', 'রাজি হয়ে যাওয়া', 'সহমত হওয়া', 'সহমত হয়ে যাওয়া', 'স্বীকার', 'স্বীকার করা', 'স্বীকার করে নেওয়া'] ,
['মেন্ড্রিল', 'মেন্ড্রিল বাঁদর'] ,
['মেম', 'মেমসাহেব'] ,
['মেরঠ', 'মেরঠ শহর'] ,
['মেরামত', 'মেরামতি'] ,
['মেরুদণ্ডী জীব', 'মেরুদণ্ডী প্রাণী'] ,
['মেরুরজ্জু', 'সুষুন্মা কান্ড'] ,
['মেশা', 'সংকোচ ত্যাগ করা'] ,
['মেশিন গান', 'মেশিনগান'] ,
['মেষ', 'মেষ রাশি', 'মেষরাশি', 'মেষরাশিবিশিষ্ট'] ,
['মেষপাল', 'মেষপালক', 'মেষের রাখাল'] ,
['মেসিডোনিয়ান', 'মেসিডোনীয়'] ,
['মেসিডোনিয়ার', 'মেসিডোনীয়'] ,
['মেসো', 'মোসোমশাই'] ,
['মেহসোনা', 'মেহসোনা জেলা', 'মেহসোনা শহর'] ,
['মেহেদি', 'মেহেন্দি', 'হেনা'] ,
['মেহেন্দী', 'মেহেন্দী পাউডার', 'রঞ্জক', 'হিনা', 'হেনা'] ,
['মেহেবুবনগর', 'মেহেবুবনগর জেলা'] ,
['মেয়াদযুক্ত', 'মেয়াদী'] ,
['মৈত্রায়ণী', 'মৈত্রায়ণী উপনিষদ'] ,
['মৈত্রেয়', 'মৈত্রেয় ঋষি'] ,
['মৈত্রেয়ী', 'মৈত্রেয়ী উপনিষদ'] ,
['মৈনপুরি', 'মৈনপুরি জেলা', 'মৈনপুরি শহর'] ,
['মৈনী', 'মৈনী গাই'] ,
['মৈসুর', 'মৈসুর জেলা'] ,
['মো', 'রেসিপ্রোকাল ওহম', 'সাইমেন্স'] ,
['মোকোকচুঙ্গ', 'মোকোকচুঙ্গ জেলা', 'মোকোকচুঙ্গ শহর'] ,
['মোক্ষদায়ক', 'মোক্ষদায়ী'] ,
['মোগলি', 'সাই', 'সাইকাঁটা'] ,
['মোগা', 'মোগা জেলা', 'মোগা শহর'] ,
['মোজাম্বিক', 'মোজাম্বিক গণরাজ্য'] ,
['মোট', 'সর্বসাকুল্যে'] ,
['মোটর গাড়ি অধিনিয়ম', 'মোটর ভেইকল অ্যাক্ট'] ,
['মোটর চালিত নৌকা', 'যন্ত্রচালিত নৌকা'] ,
['মোটরবোট', 'যন্ত্র চালিত নৌকা'] ,
['মোটা দড়ি', 'হস্তিঙ্গি'] ,
['মোটা', 'স্থূল', 'স্থূলকায়', 'স্থূলতা'] ,
['মোড়ওলা', 'মোড়যুক্ত'] ,
['মোডি', 'মোডি লিপি'] ,
['মোতিহারি', 'মোতিহারি শহর'] ,
['মোনস', 'মোনস ঋষি'] ,
['মোনাকো', 'মোনাকো-বিলে'] ,
['মোরক্কো বাসী', 'মোরক্কোবাসী'] ,
['মোরধ্বজ', 'ময়ূরধ্বজ'] ,
['মোরা দিফ্লু', 'মোরা দিফ্লু নদী'] ,
['মোরিটানিয়া বাসী', 'মোরিটানিয়ান'] ,
['মোরিটানিয়া', 'মোরিটানিয়া মুস্লিম গণরাজ্য'] ,
['মোর্মোসেট', 'মোর্মোসেট বাঁদর'] ,
['মোল্ডোভান', 'মোল্ডোভীয়'] ,
['মোল্ডোভার', 'মোল্ডোভীয়'] ,
['মোল্লা', 'মৌলবী'] ,
['মোষ', 'মোষের মাংস'] ,
['মোহনী ক্ষমতা', 'মোহিনী শক্তি'] ,
['মোহর', 'শীল', 'শীলমোহর', 'স্ট্যাম্প', 'স্বর্ণমুদ্রা'] ,
['মোহরযুক্ত', 'শিলমোহরযুক্ত'] ,
['মোহরা', 'সেনাগ্র', 'সেনামুখ'] ,
['মোহিনী অট্টম', 'মোহিনী অট্টম নৃত্য'] ,
['মৌনব্রতধারী', 'মৌনী'] ,
['মৌরিজাতীয় সুগন্ধী লতা', 'শুলফা', 'শৌলফা'] ,
['মৌরিটানিয়ার', 'মৌরিটানীয়'] ,
['মৌর্য', 'মৌর্য রাজবংশ'] ,
['ম্যাঁ', 'ম্যাঁ ম্যাঁ', 'ম্যাঁম্যাঁ'] ,
['ম্যাঁও', 'ম্যাঁও ম্যাঁও'] ,
['ম্যাঙ্গালোর', 'ম্যাঙ্গালোর শহর'] ,
['ম্লেচ্ছ', 'ম্লেচ্ছ জাতি'] ,
['ময়', 'ময়দানব'] ,
['ময়ুরভঞ্জ', 'ময়ুরভঞ্জ জেলা'] ,
['ময়ূর শিখা', 'ময়ূরশিখা'] ,
['যকৃত', 'লিভার'] ,
['যকৃপ্রদাহ', 'হেপাটাইটিস'] ,
['যক্ষ', 'যক্ষরাজ', 'যখ'] ,
['যক্ষণ', 'যক্ষি', 'যক্ষিণী', 'যক্ষী'] ,
['যক্ষ্মনাশন', 'যক্ষ্মনাশন ঋষি'] ,
['যজু', 'যজুশ্রুতি', 'যর্জুবেদ'] ,
['যজ্ঞ অনুষ্ঠান', 'যজ্ঞ কর্ম'] ,
['যজ্ঞ বেদী', 'যোজ্ঞ কুণ্ড', 'হোম কুণ্ড', 'হোমকুণ্ড'] ,
['যজ্ঞকাঠ', 'সমিধ'] ,
['যজ্ঞগার', 'যজ্ঞগৃহ', 'যজ্ঞশালা', 'যজ্ঞস্থল', 'হোমগৃহ'] ,
['যত', 'যতটা'] ,
['যথার্থ', 'সঠিক', 'সত্য'] ,
['যথাশক্তি', 'যথাসম্ভব', 'যথাসাধ্য'] ,
['যথাসময়ে', 'সময়ানুসারে'] ,
['যদু', 'রাজা যদু'] ,
['যদুবংশ', 'যাদব'] ,
['যন্ত্র চালিত', 'যান্ত্রিক', 'স্বচালিত'] ,
['যন্ত্র বিন্যাস', 'যন্ত্রবিন্যাস'] ,
['যন্ত্র-মানব', 'রোবট'] ,
['যবতমাল', 'যবতমাল শহর'] ,
['যবনেষ্ট', 'লঙ্কা'] ,
['যবাপমরুত', 'যবাপমরুত'] ,
['যমজ', 'যুগ্মজাত'] ,
['যমন', 'যমন শহর'] ,
['যমস্তোম', 'যমস্তোম যজ্ঞ'] ,
['যমাতিরাত্র', 'যমাতিরাত্র যজ্ঞ'] ,
['যমুনা নগর', 'যমুনানগর', 'যমুনানগর জেলা'] ,
['যস্ক', 'যস্ক ঋষি'] ,
['যাওয়াআসা', 'যাতাযাত'] ,
['যাজ', 'যাজ ঋষি'] ,
['যাজুষি-অনুষ্টুপ', 'যাজুষি-অনুষ্টুপ ছন্দ'] ,
['যাজুষি-উষ্ণিক', 'যাজুষি-উষ্ণিক ছন্দ'] ,
['যাজুষি-গায়ত্রী ছন্দ', 'যাজুষিগায়ত্রী'] ,
['যাজুষি-জগতী', 'যাজুষিজগতী ছন্দ'] ,
['যাজুষি-ত্রিষ্টুপ', 'যাজুষিত্রিষ্টুপ ছন্দ'] ,
['যাজুষি-পংক্তি', 'যাজুষিপংক্তি ছন্দ'] ,
['যাজুষি-বৃহতী', 'যাজুষিবৃহতী ছন্দ'] ,
['যাজ্ঞবল্ক্য', 'যাজ্ঞবল্ক্য উপনিষদ', 'যাজ্ঞবল্ক্যোপনিষদ'] ,
['যাথার্থ', 'সত্যতা'] ,
['যান বাহন দৌড়', 'যান বাহন দৌড় প্রতিযোগিতা'] ,
['যান', 'যানবাহন'] ,
['যানবাহনে', 'যানে'] ,
['যাস্ক', 'যাস্ক ঋষি'] ,
['যিঙ্গকিওঙ্গ', 'যিঙ্গকিওঙ্গ শহর'] ,
['যুক্ত অক্ষর', 'যুক্তাক্ষর', 'সংযুক্ত অক্ষর'] ,
['যুক্ত থাকা', 'যুক্ত হওয়া'] ,
['যুক্ত', 'যুক্ত হওয়ার যোগ্য', 'যোজ্য'] ,
['যুক্তিগ্রাহ্য', 'যুক্তিপূর্ণ'] ,
['যুক্তিপূর্ণ', 'যুক্তিসঙ্গত'] ,
['যুক্তিপূর্ণভাবে', 'যুক্তিপূর্বক'] ,
['যুগযন্ধি', 'যুগযন্ধিক্ষণ'] ,
['যুগোশ্লাভিয়া', 'সারবিয়া এবং মন্টেনিগ্রো'] ,
['যুগোশ্লাভিয়ান', 'যুগোশ্লাভিয়াবাসী'] ,
['যুঝা', 'যোঝা', 'লড়াই করা'] ,
['যুদ্ধ অভ্যাস', 'যুদ্ধাভ্যাস'] ,
['যুদ্ধ করা', 'যোঝা', 'লড়া'] ,
['যুদ্ধ ঝাণ্ডা', 'যুদ্ধ ধ্বজা', 'যুদ্ধ পতাকা'] ,
['যুদ্ধ বাদ্য', 'রণ বাদ্য', 'সমর বাদ্য'] ,
['যুদ্ধ বিরাম ধ্বজা', 'যুদ্ধ বিরাম পতাকা'] ,
['যুদ্ধ', 'লড়াই', 'সংগ্রাম'] ,
['যুদ্ধক্ষেত্র', 'যুদ্ধভূমি', 'রণক্ষেত্র'] ,
['যুদ্ধজাহাজ', 'যুদ্ধপোত'] ,
['যুদ্ধনাদ', 'যুদ্ধভেরী'] ,
['যুদ্ধনীতি', 'রণনীতি'] ,
['যুদ্ধপলায়ন', 'রণপলায়ন'] ,
['যুদ্ধবীর', 'রণবীর'] ,
['যুবাকাল', 'যৌবন'] ,
['যুযুধান', 'সাত্যকী'] ,
['যূস্কুভ', 'স্কোপজে'] ,
['যে আঁচড় কাটে', 'যে খোঁটে'] ,
['যে কোনো অবস্থায়', 'যে কোনো পরিস্থিতিতে', 'যে কোনো ভাবে'] ,
['যে ভাবে', 'যেরকম ভাবে'] ,
['যে ভুক্তভোগী নয়', 'যে ভোগ করেনি'] ,
['যোগ আসন', 'যোগাসন'] ,
['যোগ', 'যোগ পরিণাম', 'যোগদান', 'যোগফল'] ,
['যোগ-কুণ্ডলিনি', 'যোগ-কুণ্ডলিনি উপনিষদ'] ,
['যোগচূড়ামণি', 'যোগচূড়ামণি উপনিষদ'] ,
['যোগতত্ত্ব', 'যোগতত্ত্ব উপনিষদ', 'যোগতত্ত্বোপনিষদ'] ,
['যোগদর্শন', 'যোগশাস্ত্র'] ,
['যোগদা', 'যোগদা নদী'] ,
['যোগধারা', 'যোগধারা নদী'] ,
['যোগধারী', 'যোগীন্দ্র', 'যোগীরাজ', 'যোগীশ', 'যোগীশ্বর', 'যোগেশ্বর', 'যোগোশ'] ,
['যোগশাস্ত্রের অভ্যাস', 'যোগাভ্যাস'] ,
['যোগশিক্ষা', 'যোগশিক্ষা উপনিষদ'] ,
['যোগসূত্র', 'সংযোজক'] ,
['যোগানদার', 'সরবরাহকারী'] ,
['যোগাযোগ', 'সম্পর্ক'] ,
['যোগিয়া', 'যোগিয়া রাগ'] ,
['যোগ্যতা', 'সামর্থ্য'] ,
['যোজক চিহ্ন', 'যোজকচিহ্ন', 'সংযোজক চিহ্ন'] ,
['যোজক', 'সংঘটক', 'সংঘটনকারী', 'সংযোজক'] ,
['যোজনযোগ্য', 'যোজনীয়', 'যোজ্য'] ,
['যোধপুরী জুতো', 'যোধপুরী বুট'] ,
['যোনিভ্রংশ', 'যোনিভ্রংশ রোগ'] ,
['যৌগ', 'যৌগিক পদার্থ'] ,
['যৌন শিক্ষা', 'সেক্স এডুকেশন'] ,
['যৌন', 'লিঙ্গ সংক্রান্ত'] ,
['রকি', 'রকি পর্বত'] ,
['রক্ত কণিকা', 'রক্ত কোষ'] ,
['রক্ত দান', 'রক্তদান'] ,
['রক্ত', 'রুধির', 'শোণিত'] ,
['রক্ত-পুষ্পিকা', 'রক্তপুষ্পা'] ,
['রক্তচন্দন', 'লাল চন্দন'] ,
['রক্তপাত', 'রক্তস্রাব', 'রুধিরস্রাব'] ,
['রক্তপ্রবৃত্তি', 'রক্তপ্রবৃত্তি রোগ'] ,
['রক্তপ্রমেহ', 'রক্তপ্রমেহ রোগ'] ,
['রক্তফলা', 'সোনাবল্লী'] ,
['রক্তরঞ্জিত', 'শোণিতধৌত'] ,
['রক্তশূণ্য', 'রক্তহীন', 'রক্তাল্পতাযুক্ত'] ,
['রক্তহংসা', 'রক্তহংসা রাগিনী'] ,
['রক্তহীন', 'রুধিরহীন'] ,
['রক্তাভ', 'রক্তিম', 'লাল', 'লোহিত'] ,
['রক্ষঃপুরী', 'রক্ষোধাম', 'রাক্ষসপুরী', 'লঙ্কা'] ,
['রক্ষক', 'রক্ষাকর্তা', 'রক্ষী'] ,
['রক্ষা মন্ত্রালয়', 'রক্ষা-মন্ত্রালয়', 'রক্ষামন্ত্রালয়ে'] ,
['রক্ষা মন্ত্রী', 'রক্ষামন্ত্রী'] ,
['রক্ষাবন্ধন', 'রাখি', 'রাখি পূর্ণিমা', 'রাখী'] ,
['রক্ষিত', 'সুরক্ষিত'] ,
['রঘুনন্দন', 'রাঘবেন্দ্র', 'সীতাপতি'] ,
['রঙ করা', 'রাঙানো', 'লেপন করা'] ,
['রঙ করানো', 'লেপানো'] ,
['রঙ করার মজুরী', 'লেপন করার মজুরী'] ,
['রঙ পঞ্চমী', 'রঙপঞ্চমী'] ,
['রঙ', 'সবুজ রঙ'] ,
['রঙ-ভেদ', 'রঙভেদ'] ,
['রঙদানি', 'রঙের পাত্র'] ,
['রঙমেজাজি', 'রসিকতা'] ,
['রঙহীন', 'সাদা'] ,
['রঙ্গারেড্ডী', 'রঙ্গারেড্ডী জেলা'] ,
['রঙ্গীন', 'রসিক', 'রাঙ্গা', 'সুন্দর'] ,
['রঙ্গীলা-টোড়ী', 'রঙ্গীলা-টোড়ী রাগ'] ,
['রচনা করা', 'লেখা', 'সৃষ্টি করা'] ,
['রচনা শীর্ষক', 'শিরোনাম', 'শীর্ষক'] ,
['রচনা', 'সাহিত্যক কৃতি', 'সাহিত্যক রচনা'] ,
['রচনাকার', 'রচয়িতা', 'লেখক', 'সৃজক', 'সৃজনকর্তা'] ,
['রচনাত্মক', 'সৃজনাত্মক'] ,
['রচয়ীতা', 'সৃজনকর্তা', 'স্রষ্টা'] ,
['রজত জয়ন্তী', 'সিলভার জুবিলী'] ,
['রজত পাত্র', 'রৌপ্যপাত্র'] ,
['রজত', 'রূপো'] ,
['রজো', 'রজোগুণ'] ,
['রজৌরি', 'রজৌরি জেলা', 'রজৌরি শহর'] ,
['রজ্জুপথ', 'রোপ ওয়ে'] ,
['রঞ্জক', 'রঞ্জক দ্রব্য'] ,
['রণজী', 'রণজী ট্রফি'] ,
['রতলাম', 'রতলাম জেলা', 'রতলাম শহর'] ,
['রত্নাকর', 'রত্নের আকর'] ,
['রত্নাগিরি', 'রত্নাগিরি জেলা'] ,
['রত্নাগিরী', 'রত্নাগিরী শহর'] ,
['রথ', 'স্যন্দন'] ,
['রথ-সৈন্য', 'রথসেনা'] ,
['রথবাহ', 'রথাশ্ব'] ,
['রথারূঢ়', 'রথারোহী'] ,
['রবান্ডা নিবাসী', 'রবান্ডাবাসী'] ,
['রবান্ডা সম্পর্কিত', 'রবান্ডার'] ,
['রবার', 'রবার গাছ'] ,
['রবি বাসর', 'রবিবার'] ,
['রবিকান্ত মণি', 'রবিমণি', 'সূর্যকান্ত', 'সূর্যকান্ত পর্বত', 'সূর্যকান্ত মণি', 'সূর্যকান্তমণি'] ,
['রবিন', 'লালমুনিয়া'] ,
['রবিনন্দ', 'রবিনন্দন', 'সাবর্ণি', 'সাবর্ণি মনু'] ,
['রমণীয়', 'রম্য'] ,
['রম্ভ', 'রম্ভাসুর'] ,
['রম্ভিনী', 'রম্ভিনী রাগিনী'] ,
['রম্য চিত্র', 'রম্য-চিত্র'] ,
['রম্য', 'হাসি', 'হাস্য'] ,
['রশি', 'সুতো'] ,
['রস', 'শরবত', 'স্রাব'] ,
['রসদ', 'রসদ সামগ্রী', 'রেশন সামগ্রী'] ,
['রসপূর্ণ', 'রসালো', 'সরস'] ,
['রসায়ন', 'রাসায়ানিক দ্রব্য', 'স্বর্ণ সিদ্ধি'] ,
['রহস্য উন্মোচক', 'রহস্যোদ্ঘাটক'] ,
['রাঁচী', 'রাঁচী জেলা', 'রাঁচী শহর'] ,
['রাঁধানো', 'রান্না করানো'] ,
['রাই তোতা', 'রাজশুক', 'শতপত্রক'] ,
['রাইট টু ইন্ফোরমেশন', 'সূচনার স্বত্বাধিকার অধিনিয়ম'] ,
['রাখটী', 'লাখড়া'] ,
['রাখা', 'রেখে দেওয়া', 'সমর্পিত করা'] ,
['রাগ বিস্তার', 'সুর তান'] ,
['রাগবি ফুটবল', 'রাগ্বি'] ,
['রাগে গর্জে ওঠা', 'রাগে লাল হয়ে যাওয়া'] ,
['রাজ ঋষি', 'রাজর্ষি'] ,
['রাজ ঘরানা', 'রাজকুল', 'রাজঘরানা', 'রাজবংশ'] ,
['রাজ দন্ড', 'রাজদন্ড'] ,
['রাজ ব্যবস্থা', 'রাজ-কাজ', 'রাজ্য নিয়ম', 'রাজ্য ব্যবস্থা'] ,
['রাজ হরিশচন্দ্র', 'হরিশচন্দ্র'] ,
['রাজ', 'রাজ্য', 'রাজ্য কাল', 'রাজ্যকাল', 'শাসন', 'শাসন কাল', 'শাসনকাল'] ,
['রাজ-সভা', 'রাজসভা', 'রাজ্য-সভা', 'রাজ্যসভা'] ,
['রাজকন্যা', 'রাজকুমারী'] ,
['রাজকীয়', 'রাজাসুলভ', 'রাজ্যের'] ,
['রাজকুমার শাসিত ক্ষেত্র', 'রাজকুমার শাসিত প্রদেশ'] ,
['রাজকুমার', 'রাজপুত্র'] ,
['রাজকোট', 'রাজকোট জেলা', 'রাজকোট শহর'] ,
['রাজগড়', 'রাজগড় জেলা', 'রাজগড় শহর'] ,
['রাজগুরু', 'শিবরাম হরি রাজগুরু'] ,
['রাজঝুমকা', 'রাজঝুমকা ফুল', 'রাজস্বর্ণ'] ,
['রাজদ', 'রাষ্ট্রীয় জনতা দল'] ,
['রাজনন্দ গ্রাম', 'রাজনন্দগ্রাম শহর'] ,
['রাজনান্দগাঁও', 'রাজনান্দগাঁও জেলা'] ,
['রাজনীতি বিষয়ক', 'রাজনৈতিক'] ,
['রাজনীতিজ্ঞ', 'রাজনীতিবিদ'] ,
['রাজনৈতিক দৌড়', 'রাজনৈতিক প্রতিদ্বন্দ্বিতা'] ,
['রাজপিপলা', 'রাজপিপলা শহর'] ,
['রাজপ্রতিনিধি', 'রিজেণ্ট'] ,
['রাজপ্রতিনিধির শাসনকাল', 'রিজেন্সি'] ,
['রাজরাজেশ্বরী', 'সম্রাজ্ঞী', 'সম্রাট পত্নী'] ,
['রাজসমন্দ', 'রাজসমন্দ জেলা', 'রাজসমন্দ শহর'] ,
['রাজসিংহাসন', 'সিংহাসন'] ,
['রাজসূয় যজ্ঞ', 'রাজসূয়-যজ্ঞ'] ,
['রাজহংস', 'রাজহাঁস'] ,
['রাজা সগর', 'সগর'] ,
['রাজা সবাই জয়সিংহ', 'সবাই জয়সিংহ'] ,
['রাজাপুরী', 'রাজাপুরী আম'] ,
['রাজাসমন্দ', 'রাজাসমন্দ ঝিল'] ,
['রাজ্ঞী', 'রানী'] ,
['রাজ্য বিষয়ক', 'রাজ্য সংক্রান্ত'] ,
['রাজ্য', 'সাম্রাজ্য'] ,
['রাজ্যসভার সদস্য', 'সিনেটার'] ,
['রাডার', 'রাডারযন্ত্র'] ,
['রাণা সংগ্রাম সিংহ', 'রাণা সাংগা'] ,
['রাণীক্ষেত', 'রাণীখেত'] ,
['রাতহব্য', 'রাতহব্য ঋষি'] ,
['রান আউট', 'রানআউট'] ,
['রান্নাঘরের উপকরণ', 'রান্নার সরঞ্জাম'] ,
['রান্নার পাত্র', 'রান্নার বাসন'] ,
['রাপ্তী', 'রাপ্তী নদী'] ,
['রাব', 'শোট'] ,
['রাম', 'রিড ওনলি মেমোরি'] ,
['রাম-বাণ', 'রামবাণ'] ,
['রাম-লীলা', 'রামলীলা'] ,
['রামকথক', 'রামায়ণী'] ,
['রামকৃষ্ণ পরমহংস', 'শ্রী রামকৃষ্ণ পরমহংস'] ,
['রামগঙ্গা', 'রামগঙ্গা নদী'] ,
['রামচরিত মানস', 'রামচরিতমানস'] ,
['রামতাপণি', 'রামতাপণি উপনিষদ'] ,
['রামধনুর', 'রামধনুর ন্যায়'] ,
['রামধুন', 'রামনাম'] ,
['রামনন্দ', 'রামানন্দ', 'স্বামী রামানন্দ'] ,
['রামনাথপুরম', 'রামনাথপুরম জেলা', 'রামনাথপুরম শহর'] ,
['রামপুর', 'রামপুর জেলা', 'রামপুর শহর'] ,
['রামরজ', 'রামরজ মাটি'] ,
['রামরহস্য', 'রামরহস্য উপনিষদ', 'রামরহস্যোপনিষদ'] ,
['রামলোক', 'সাকেত', 'সাকেত লোক'] ,
['রামেশ্বর', 'রামেশ্বর ধাম', 'রামেশ্বরম', 'শ্রী রামেশ্বরম'] ,
['রাশি', 'স্তূপ'] ,
['রাশিবিজ্ঞানী', 'সংখ্যাতত্তবিদ'] ,
['রাশিয়া', 'রুশ'] ,
['রাশিয়ান রুবেল', 'রুবেল'] ,
['রাশিয়ান', 'রুশ', 'রুশ ভাষা', 'রুশা-বাসী', 'রুশাধিবাসী', 'রুশি'] ,
['রাস', 'রাসলীলা'] ,
['রাসায়নিক', 'রাসায়নিক পদার্থ', 'রাসায়নিক বস্তু'] ,
['রায়গড়', 'রায়গড় জেলা', 'রায়গড় শহর'] ,
['রায়গড়া', 'রায়গড়া জেলা', 'রায়গড়া শহর'] ,
['রায়চুর', 'রায়চুর জেলা', 'রায়চুর শহর'] ,
['রায়পুর', 'রায়পুর জেলা', 'রায়পুর শহর'] ,
['রায়বেরিলী', 'রায়বেরিলী জেলা', 'রায়বেরিলী শহর'] ,
['রায়সেন', 'রায়সেন জেলা', 'রায়সেন শহর'] ,
['রি ভোই', 'রি ভোই জেলা'] ,
['রিকেট', 'শুকনা'] ,
['রিক্টার মাপনি', 'রিক্টার স্কেল'] ,
['রিক্ততা', 'শূণ্যতা'] ,
['রিজার্ভেশন', 'সংরক্ষণ'] ,
['রিঠা', 'রিঠে'] ,
['রিডার', 'লেকচারার'] ,
['রিপোর্ট কার্ড', 'রিপোর্টকার্ড'] ,
['রিপোর্টার', 'সংবাদদাতা', 'সাংবাদিক'] ,
['রিফ', 'শৈলপ্রাচীর'] ,
['রিবা', 'রিবা জেলা', 'রিবা শহর', 'রেবা', 'রেবা জেলা', 'রেবা শহর'] ,
['রিমাইন্ডার', 'স্মারকলিপি'] ,
['রিল', 'রোল'] ,
['রিয়াল', 'রেয়াল', 'সৌদি আরব রিয়াল'] ,
['রীতি', 'শৈলী'] ,
['রীসাস', 'রীসাস বাদর', 'রীসাস বানর', 'রেসস', 'রেসস বাদর', 'রেসস বানর', 'রেসাস', 'রেসাস বাদর', 'রেসাস বানর', 'হৃসাস', 'হৃসাস বাদর', 'হৃসাস বানর'] ,
['রুচি দেব সাবর্ণি', 'রৌচ্য', 'রৌচ্য মনু'] ,
['রুডবোরস্টজে', 'রুডবোরস্টজে আম'] ,
['রুথিনিয়াম', 'রুথিনিয়াম'] ,
['রুদ্র জটা', 'শঙ্করজটা'] ,
['রুদ্র সাবর্ণি', 'রুদ্র সাবর্ণি মনু'] ,
['রুদ্র', 'রুদ্র দেবতা'] ,
['রুদ্র-হৃদয়', 'রুদ্র-হৃদয় উপনিষদ', 'রুদ্র-হৃদয়োপনিষদ'] ,
['রুদ্রপ্রয়াগ', 'রুদ্রপ্রয়াগ জেলা', 'রুদ্রপ্রয়াগ শহর'] ,
['রুদ্রবীণা', 'রুদ্রী'] ,
['রুদ্রাণী', 'রুদ্রাণী রাগ'] ,
['রুনী', 'রুনী ঘোড়া'] ,
['রুপ-লাবণ্য', 'সৌন্দর্য্য'] ,
['রুপোর মুদ্রা', 'রৌপো মুদ্রা'] ,
['রুবাইএমন', 'রুবাইএমন রাগ'] ,
['রুমন্বান', 'রুমন্বান ঋষি'] ,
['রুমা', 'রোমা'] ,
['রুমানি', 'রুমানি আম'] ,
['রুমানিয়াবাসী', 'রুমানীয়'] ,
['রুমানী', 'রুমানী আম'] ,
['রুমানীয়', 'রুমানীয় ভাষা'] ,
['রুরু', 'রুরু ঋষি', 'রুরু রাগ'] ,
['রুলার', 'স্কেল'] ,
['রুশঙ্গু', 'রুশদ্গু'] ,
['রুষ্ট হওয়া', 'রেগে যাওয়া'] ,
['রূডবোরস্টজে আম', 'রূডবোরস্টজে আমের গাছ'] ,
['রূপ', 'শব্দরূপ'] ,
['রূপ-লাবণ্য', 'সৌন্দর্য্য'] ,
['রূপক', 'রূপক অলঙ্কার', 'রূপকালঙ্কার'] ,
['রূপনগর', 'রূপনগর জেলা', 'রূপনগর শহর'] ,
['রূপবতী', 'রূপসী'] ,
['রূপবান ব্যক্তি', 'সুদর্শন', 'সুন্দর পুরুষ', 'সুপুরুষ', 'সুশ্রী পুরুষ'] ,
['রূপল', 'রূপল তাল'] ,
['রেওয়াড়ি', 'রেওয়াড়ি জেলা', 'রেওয়াড়ি শহর'] ,
['রেকর্ড', 'রেকর্ড বুক'] ,
['রেকাঙ্গ পেও', 'রেকাঙ্গ পেও শহর'] ,
['রেখা চিত্র', 'রেখাঙ্কন'] ,
['রেগর', 'রেগর জাতি'] ,
['রেজাই', 'লেপ'] ,
['রেডক্রস', 'রেডক্রস সংস্থা'] ,
['রেডক্লিফ হল', 'হল'] ,
['রেডি সক্রিয়তা', 'রেডিও অ্যাক্টিভিটি'] ,
['রেডিও আবৃত্তি', 'রেডিও ফ্রিকোএনসি'] ,
['রেণ্ডম অ্যাকসেস মেমোরি', 'রেম'] ,
['রেভ', 'রেভ ঋষি'] ,
['রেল জাংশন', 'রেল সংযোগস্থল'] ,
['রেল ব্যবস্থা', 'রেলতন্ত্র'] ,
['রেল মন্ত্রী', 'রেলমন্ত্রী'] ,
['রেল সীমান্ত', 'রেল হেড'] ,
['রেল হেড', 'রেলমার্গীয় সৈনিকদের ব্যবহার্য সামগ্রী ভাণ্ডার'] ,
['রেলওয়ে স্টেশন', 'স্টেশন'] ,
['রেলওয়ে', 'রেলবিভাগ'] ,
['রেশন কার্ড', 'রেশনকার্ড'] ,
['রেশম কীট', 'রেশম পোকা'] ,
['রেশম', 'সিল্ক'] ,
['রেশমী', 'সিল্ক', 'সিল্কি'] ,
['রৈবত', 'রৈবত পর্বত'] ,
['রোইঙ্গ', 'রোইঙ্গ শহর'] ,
['রোগ নিবৃত্তি', 'স্বাস্থ্যলাভ'] ,
['রোগনিদান', 'রোগনির্ণয়'] ,
['রোগীর কক্ষ', 'রোগীর ঘর'] ,
['রোগের লক্ষণ', 'লক্ষণ'] ,
['রোচিসা', 'রোচিসা ঋষি'] ,
['রোজউড', 'শীশম'] ,
['রোট', 'লিট্টি'] ,
['রোদ', 'রোদ্দুর', 'সূর্যাতপ'] ,
['রোদ-স্নান', 'রোদস্নান'] ,
['রোপণ করা', 'লাগানো'] ,
['রোম বাসী', 'রোমান'] ,
['রোম', 'লোম'] ,
['রোমক সংখ্যা', 'রোমান সংখ্যা'] ,
['রোমকূপ', 'রোমরন্ধ্র', 'লোমকূপ', 'লোমরন্ধ্র'] ,
['রোমশ', 'লোমশ'] ,
['রোমাঞ্চক', 'রোমাঞ্চকারী'] ,
['রোমান', 'রোমান লিপি', 'ল্যাটিন লিপি'] ,
['রোমানিয়া লেউ', 'লেউ'] ,
['রোমানিয়ার', 'রোমানীয়'] ,
['রোমেশ', 'রোমেশ ঋষি'] ,
['রোহতক', 'রোহতক জেলা', 'রোহতক শহর'] ,
['রোহতাস', 'রোহতাস জেলা'] ,
['রৌদ্র', 'রৌদ্র রস'] ,
['রৌরব', 'রৌরব নরক'] ,
['রয়েল স্পেশাল', 'রয়েল স্পেশাল আম', 'রয়েল স্পেশাল আমের গাছ'] ,
['লক্ষ লক্ষ', 'লাখ লাখ'] ,
['লক্ষ', 'লাখ', '১০০০০০'] ,
['লক্ষণরেখা', 'সীমারেখা'] ,
['লক্ষপতি', 'লাখপতি'] ,
['লক্ষ্মী পেঁচা', 'সাদা পেঁচা'] ,
['লক্ষ্যচ্যূত', 'লক্ষ্যভ্রষ্ট'] ,
['লখনউ', 'লখনউ জেলা', 'লখনউ শহর'] ,
['লখিমপুর খেরি', 'লখিমপুর খেরি জেলা', 'লখিমপুর খেরি শহর'] ,
['লখিমপুর', 'লখিমপুর জেলা', 'লখিমপুর শহর'] ,
['লখিসরায়', 'লখিসরায় জেলা', 'লখিসরায় শহর'] ,
['লগ্ন-দন্ড', 'লাগ-ডাঁট'] ,
['লঘু', 'হাল্কা'] ,
['লঙ্ক-টঙ্কটা', 'লঙ্কটঙ্কটা'] ,
['লঙ্কাগুড়ো', 'লঙ্কার পাউডার'] ,
['লঙ্গা', 'লঙ্গা গীত', 'লঙ্গা জাতি'] ,
['লঙ্ঘন', 'লঙ্ঘন চাল'] ,
['লজ্জা পাওযা', 'লজ্জাবোধ করা', 'লজ্জিত হওযা'] ,
['লজ্জা পাওয়া', 'সংকোচ করা'] ,
['লজ্জাকর', 'লজ্জাজনক'] ,
['লজ্জাশীল', 'লাজুক'] ,
['লড়াই করতে শুরু করা', 'লড়াই করা'] ,
['লড়াই করা', 'সংঘর্ষ করা'] ,
['লড়াই', 'সংঘর্ষ'] ,
['লড়াকু', 'সংগ্রামী', 'সংঘর্ষকারী'] ,
['লড্ডু', 'লড্ডুক', 'লাড্ডু'] ,
['লব কুশ কাণ্ড', 'লব-কুশ কাণ্ড'] ,
['লব', 'লব সংখ্যা'] ,
['লবঙ্গ লতা', 'লবঙ্গ-লতা', 'লবঙ্গলতা'] ,
['লবণ', 'লবণাসুর'] ,
['লভ্যতা', 'সহজ প্রাপ্যতা', 'সহজলভ্যতা'] ,
['লম্বা টুকরো', 'সরু এবং লম্বা টুকরো'] ,
['ললনা', 'ললনা বর্ণবৃত্ত', 'ললনাবৃত্ত'] ,
['ললন্তিকা', 'সারট'] ,
['ললিত', 'ললিত রাগ'] ,
['ললিতপুর', 'ললিতপুর জেলা', 'ললিতপুর শহর'] ,
['ললিতলোচন', 'সুনেত্র', 'সুনয়ন', 'সুলোচন'] ,
['ললিতা-পঞ্চমী', 'ললিতাপঞ্চমী'] ,
['ললিতা-ষষ্ঠী', 'ললিতাষষ্ঠী'] ,
['ললিতা-সপ্তমী', 'ললিতাসপ্তমী'] ,
['লাইট অ্যাম্প্লিফিকেশন বাই স্টিম্যুলেটেড এমিশান এফ রেডিয়েশন', 'লেজার'] ,
['লাইবেরিয়া', 'লাইবেরিয়া গণতন্ত্র', 'লিবেরিয়া', 'লিবেরিয়া গণতন্ত্র'] ,
['লাইভ', 'সরাসরি'] ,
['লাও', 'লাও ভাষা', 'লাও লিপি', 'লাওস বাসী', 'লাওয়েশিয়ান'] ,
['লাক্ষা ঘর', 'লাক্ষাগৃহ'] ,
['লাখ', '১০০০০০'] ,
['লাখটাকার', 'লাখটাকিয়া'] ,
['লাগা', 'লাগানো', 'লেগে যাওয়া'] ,
['লাগানো ভাঙ্গানো', 'লাগানো-ভাঙ্গানো'] ,
['লাটাই', 'লাটিম', 'লাট্টু'] ,
['লাটিম', 'লাট্টু'] ,
['লাঠিয়াল', 'লেঠেল'] ,
['লাতভিয়ান', 'লাতভিয়ান ভাষা', 'লাতভিয়াবাসী'] ,
['লাতিন আমেরিকা', 'ল্যাটিন আমেরিকা'] ,
['লাতিন', 'ল্যাটিন'] ,
['লাতিনীয়', 'ল্যাটিন', 'ল্যাতিন'] ,
['লাতুর', 'লাতুর জেলা', 'লাতুর শহর'] ,
['লাফ দেওয়া', 'লাফানো'] ,
['লাফানো', 'লাফালাফি করা', 'লাফিয়ে চলা'] ,
['লাভ প্রাপ্তকারী', 'লাভবান'] ,
['লাভহীন', 'লোকসান'] ,
['লাভার্থী', 'হিতাধিকারী'] ,
['লামজ', 'লামজ্জক'] ,
['লামফেলপট', 'লামফেলপট শহর'] ,
['লাল ফিতে', 'লালফিতে'] ,
['লাল বাহাদুর', 'লাল বাহাদুর শাস্ত্রী'] ,
['লাল রক্ত কণিকা', 'লোহিত রক্ত কণিকা'] ,
['লাল রঙের মুক্তো', 'লাল রঙের মোতি'] ,
['লাল লঙ্কা', 'লালমির্চ'] ,
['লাল', 'লাল রঙ', 'লোহিত'] ,
['লালপ্রমেহ রোগ', 'লালমধুমেহ রোগ'] ,
['লালসা করা', 'লোভ করা'] ,
['লালসাদা', 'সাদাকালো'] ,
['লালসাপূর্ণ', 'লুব্ধ'] ,
['লালসির', 'লালসির হাঁস'] ,
['লালা', 'শ্লেষ্মা'] ,
['লালাভ', 'হাল্কা লাল'] ,
['লালাসা', 'লোভ'] ,
['লাস ভেগাস', 'লাসভেগাস'] ,
['লাহোল', 'লাহোল শহর'] ,
['লিখিত চিহ্ন', 'লিখিত প্রতীক', 'লিখিত সংকেত'] ,
['লিখিত', 'লেখাঙ্কিত'] ,
['লিঙ্গ পুরাণ', 'লিঙ্গপুরাণ'] ,
['লিঙ্গ', 'শিব লিঙ্গ', 'শিবলিঙ্গ'] ,
['লিড্ডার', 'লিড্ডার নদী'] ,
['লিথুনিয়া-বাসী', 'লিথুনিয়াই', 'লিথুনিয়াই ভাষা'] ,
['লিথুয়ানিয়ান', 'লিথুয়ানীয়'] ,
['লিনেন', 'শন', 'শনের কাপড়'] ,
['লিপস্টিক', 'লুজ'] ,
['লিপিবদ্ধ করা', 'লেখা'] ,
['লিপিবদ্ধকরণ', 'লেখন'] ,
['লিপিবদ্ধন', 'লেখা'] ,
['লিপিসজ্জা', 'লেখন সামগ্রী', 'লেখন-সামগ্রী', 'স্টেশনারি'] ,
['লিপেন্স', 'লিপেন্স আম', 'লিপেন্স আম গাছ'] ,
['লিপ্সু', 'লোভী', 'লোলুপ'] ,
['লিবিয়ান', 'লিবিয়াবাসী', 'লিবিয়ার', 'লিবীয়'] ,
['লিবেরিয়া সম্পর্কিত', 'লিবেরিয়ার'] ,
['লিবেরিয়াবাসী', 'লিবেরিয়ার', 'লিবেরিয়ার নিবাসী'] ,
['লিম্ফোসাইট', 'শ্বেত কোণিকা', 'শ্বেতকোণিকা'] ,
['লিলগিনী', 'লিলগেনী'] ,
['লুক্সিমবর্গীয়', 'লুক্সেমবুর্গিস'] ,
['লুক্সেমবার্গ', 'লুক্সেমবার্গ সিটি'] ,
['লুক্সেমবুর্গীয়', 'লুক্সেমবুর্গের'] ,
['লুঙ্গলেই', 'লুঙ্গলেই জেলা', 'লুঙ্গলেই শহর'] ,
['লুটপাট', 'লুঠতরাজ'] ,
['লুঠ করা', 'লুন্ঠন করা'] ,
['লুধিয়ানা', 'লুধিয়ানা জেলা', 'লুধিয়ানা শহর'] ,
['লুনি', 'লুনি নদী'] ,
['লেখ', 'লেখা'] ,
['লেখন-ভঙ্গী', 'লেখন-শৈলী'] ,
['লেখা', 'হিসাব'] ,
['লেখাজোখা', 'হিসাব কিতাব', 'হিসাব কেতাব'] ,
['লেখাপড়া', 'শিক্ষিত', 'সাক্ষর'] ,
['লেখার খাতা', 'হিসাবখাতা'] ,
['লেজবিশিষ্ট', 'লেজযুক্ত'] ,
['লেজবিহীন', 'লেজহীন'] ,
['লেজ়র চিকিত্সা', 'লেজ়র ট্রিটমেন্ট'] ,
['লেজ়ার', 'লেজার'] ,
['লেড', 'সীসা'] ,
['লেন-দেন', 'লেনদেন'] ,
['লেপন করা', 'লেপা'] ,
['লেবানন বাসী', 'লেবাননী'] ,
['লেবানন', 'লেবানন গণরাজ্য'] ,
['লেবাননী', 'লেবানীস'] ,
['লেবুর শরবত', 'শিকঞ্জবীন'] ,
['লেসোথি', 'লেসোথোবাসী'] ,
['লেসোথোর', 'লেসোথোর-সম্পর্কিত'] ,
['লেহ', 'লেহ জেলা', 'লেহ শহর'] ,
['লোক গীতি', 'লোকগীতি'] ,
['লোক জনশক্তি পার্টি', 'লোজপা'] ,
['লোক সেবা নিগম', 'লোকসেবা নিগম'] ,
['লোক-নৃত্য', 'লোকনৃত্য'] ,
['লোককথা', 'লোকগাথা'] ,
['লোকাট', 'লোকাট গাছ'] ,
['লোঙ্গতলাই', 'লোঙ্গতলাই জেলা', 'লোঙ্গতলাই শহর'] ,
['লোতেহার', 'লোতেহার জেলা', 'লোতেহার শহর'] ,
['লোভী', 'লোলুপ'] ,
['লোহরদগ্গা', 'লোহরদগ্গা জেলা', 'লোহরদগ্গা শহর'] ,
['লোহা', 'লৌহ', 'লৌহতত্ত্ব'] ,
['লোহার খাঁচা', 'লৌহ্য খাঁচা'] ,
['লোহার গদা', 'লোহার মুগুর'] ,
['লোহার টুকরো', 'লৌহখণ্ড'] ,
['লোহার ভাণ্ডার', 'লৌহ্য ভাণ্ডার'] ,
['লোহালক্কর সম্পর্কিত', 'লোহালক্করের'] ,
['লোহিত', 'লোহিত জেলা', 'লোহিত নদী'] ,
['লোহিতা', 'সুলোচন', 'সুলোহিতা'] ,
['লোহিয়া', 'লোহিয়া বলদ'] ,
['লৌহ-পুরুষ', 'লৌহপুরুষ'] ,
['ল্যাংড়া', 'ল্যাংড়া আম'] ,
['ল্যাঙড়া', 'ল্যাঙড়া আম'] ,
['ল্যাটিন', 'ল্যাটিন ভাষা'] ,
['ল্যাপটপ', 'ল্যাপটপ কম্পিউটার'] ,
['লয়', 'সুর'] ,
['শংখ্যদ্রাব', 'শংখ্যদ্রাবক'] ,
['শংয়ু', 'শংয়ু ঋষি'] ,
['শক', 'শক জাতি'] ,
['শকট', 'শকটাসুর'] ,
['শকর পারা', 'শকরপারা'] ,
['শকরি মুনিয়া', 'শকরিমুনিয়া'] ,
['শকুন্ত', 'শকুন্তক'] ,
['শক্তির উপাসক', 'শাক্ত', 'শাক্ত সম্প্রদায়'] ,
['শঙ্কর তাল', 'শঙ্করতাল'] ,
['শঙ্করা', 'শঙ্করা রাগ', 'শঙ্করি'] ,
['শঙ্কাহীন', 'সন্দেহহীন', 'সন্দেহাতীত'] ,
['শঙ্কু', 'শাঙ্কবাকার'] ,
['শঙ্খ', '১০০০০০০০০০০০০০০০০০'] ,
['শঙ্খপুষ্পিকা', 'শঙ্খপুষ্পী'] ,
['শজারু', 'শল্যক'] ,
['শণ', 'শণগাছ'] ,
['শণক', 'শণক ঋষি'] ,
['শত অর্বুদ', '১০০০০০০০০০০০'] ,
['শত শত', 'শয়ে শয়ে'] ,
['শতক', 'শতরান', 'সেঞ্চুরি'] ,
['শতকুন্ডী', 'শতকুন্ডী মহাযজ্ঞ'] ,
['শতকুম্ভ', 'শতকুম্ভা', 'শতকুম্ভা নদী'] ,
['শতকের', 'শতরানের'] ,
['শতপোদ', 'শতপোদক'] ,
['শতপ্রভেদন', 'শতপ্রভেদন ঋষি'] ,
['শতানন্দ', 'শতানন্দ ঋষি'] ,
['শনি', 'শনিবার'] ,
['শন্দীল', 'শন্দীল ঋষি'] ,
['শব-চুল্লী', 'শবদাহ স্থান'] ,
['শবরিমালা', 'শবরীমালা'] ,
['শবরী', 'শ্রমণা'] ,
['শমণ', 'শমন'] ,
['শমীক', 'শমীক ঋষি'] ,
['শম্বুক', 'শম্বুকা', 'শামুক'] ,
['শরতকালীন', 'শারদ', 'শারদীয়'] ,
['শরত্ ঋতু', 'শরত্কাল', 'শারদ'] ,
['শরদন্ত', 'হিমঋতু', 'হেমন্ত', 'হেমন্তকাল'] ,
['শরদবান', 'শরদবান ঋষি'] ,
['শরবত বানানোর', 'শরবতের'] ,
['শরবতগড়ী', 'শরবতগড়ী আম'] ,
['শরভ', 'শরভ উপনিষদ', 'শরভোপনিষদ'] ,
['শরভঙ্গ', 'শরভঙ্গ ঋষি'] ,
['শরীর-বিজ্ঞান', 'শরীরবিজ্ঞান'] ,
['শরীরী গঠন', 'শারীরিক গঠন'] ,
['শর্করা স্তর', 'সুগার'] ,
['শর্করাক্ষ', 'শর্করাক্ষ ঋষি'] ,
['শর্টহ্যান্ড', 'সাঁটলিপি'] ,
['শর্বক', 'শর্বক ঋষি'] ,
['শর্যাতি', 'শর্যাতি ঋষি'] ,
['শলঙ্কু', 'শলঙ্কু ঋষি'] ,
['শলণ্টক', 'শলণ্টক ঋষি'] ,
['শলাথল', 'শলাথল ঋষি'] ,
['শল্য উপকরণ', 'শস্ত্র'] ,
['শল্য-চিকিত্সাশাস্ত্র', 'শল্য-শাস্ত্র', 'শল্যচিকিত্সা শাস্ত্র', 'শল্যশাস্ত্র'] ,
['শশকর্ণ', 'শশকর্ণ ঋষি'] ,
['শাঁখারি', 'শাঁখারি জাতি'] ,
['শাঁখের তৈরী', 'শাঙ্খিক'] ,
['শাক দ্বীপ', 'শাকদ্বীপ'] ,
['শাক্য', 'শাক্য সাল'] ,
['শাখা', 'সম্প্রদায়'] ,
['শাখা-প্রশাখাযুক্ত', 'শাখাযুক্ত'] ,
['শাঙ্খায়ন', 'শাঙ্খায়ন ঋষি'] ,
['শাজাপুর', 'শাজাপুর জেলা', 'শাজাপুর শহর'] ,
['শাণ্ডিল্য', 'শাণ্ডিল্য ঋষি'] ,
['শাত্যাযনি', 'শাত্যাযনি উপনিষদ'] ,
['শাদ্বল', 'সজীব', 'সবুজ'] ,
['শান্ডিল্য', 'শান্ডিল্য উপনিষদ', 'শান্ডিল্যোপনিষদ'] ,
['শান্ত', 'শান্ত রস', 'স্হির'] ,
['শান্তি-প্রেমী', 'শান্তিপ্রিয়'] ,
['শান্তিদায়ক', 'শান্তিদায়ী', 'শান্তিপ্রদ'] ,
['শান্তিপূর্ণ', 'শান্তিময়'] ,
['শাপভঙ্গ', 'শাপমুক্তি', 'শাপমোচন'] ,
['শামিল হওয়া', 'সমাবিষ্ট হওয়া'] ,
['শামুক', 'সিন্ধুজা'] ,
['শারদা', 'শারদা লিপি'] ,
['শারীরক', 'শারীরক উপনিষদ', 'শারীরকোপনিষদ'] ,
['শারীরিক অংশ', 'শারীরিক ভাগ'] ,
['শারীরিক কষ্ট', 'শারীরিক ক্লেশ', 'শারীরিক পীড়া'] ,
['শারীরিক তরল', 'শারীরিক তরল পদার্থ', 'শারীরিক দ্রব', 'শারীরিক দ্রব পদার্থ'] ,
['শালক', 'শালক রাগ', 'শালকরাগ'] ,
['শালঙ্কটাঙ্কট', 'সুকেশি'] ,
['শালবাহন', 'শালিবাহন'] ,
['শালরস', 'সুকুন্দ'] ,
['শালা', 'শ্যালক', 'সম্বন্ধী'] ,
['শালাক্য', 'শালাক্যশাস্ত্র'] ,
['শালিগ্রাম', 'শালিগ্রাম শিলা'] ,
['শালীনতাপূর্বক', 'শিষ্টতাপূর্বক', 'শিষ্টভাবে'] ,
['শালু', 'শালু কাপড়', 'সালু', 'সালু কাপড়'] ,
['শাল্ম দ্বীপ', 'শাল্মদ্বীপ'] ,
['শাল্মলি', 'শাল্মলী', 'শিমূল'] ,
['শাশ্বত বাদ', 'শাশ্বতবাদ'] ,
['শাসকীয়', 'সরকারি'] ,
['শাস্ত্র-বিরুদ্ধ', 'শাস্ত্রবিরুদ্ধ', 'শাস্ত্রবিরোধী'] ,
['শাস্ত্রার্থ', 'শাস্ত্রের অর্থ'] ,
['শাস্ত্রীয় নৃত্য', 'শাস্ত্রীয়-নৃত্য'] ,
['শাহজানপুর', 'শাহজানপুর জেলা', 'শাহজানপুর শহর'] ,
['শাহানা কান্হড়া', 'শাহানাকান্হড়া'] ,
['শিংবিহীন', 'শৃঙ্গহীন'] ,
['শিক্রা', 'শিক্রা পাখি'] ,
['শিক্ষা মন্ত্রী', 'শিক্ষামন্ত্রী'] ,
['শিক্ষা শুল্ক', 'শিক্ষা-শুল্ক'] ,
['শিক্ষাগত', 'শৈক্ষিক'] ,
['শিখর বৈঠক', 'শিখর সম্মেলন'] ,
['শিখরা', 'শিখরী'] ,
['শিখা-সুত্র', 'শিখাসুত্র'] ,
['শিনি', 'শিনি ঋষি'] ,
['শিপ্র', 'শিপ্র ধিল'] ,
['শিপ্রা', 'শিপ্রা নদী'] ,
['শিব পুরাণ', 'শিবপুরাণ'] ,
['শিব মন্দির', 'শিবালয়'] ,
['শিব-প্রতিমা', 'শিব-বিগ্রহ', 'শিব-মূর্তি', 'শিবপ্রতিমা', 'শিববিগ্রহ', 'শিবমূর্তি'] ,
['শিবগঙ্গা', 'শিবগঙ্গা জেলা', 'শিবগঙ্গা শহর'] ,
['শিবপুর', 'শিবপুর জেলা', 'শিবপুর শহর'] ,
['শিবপুরি', 'শিবপুরি জেলা', 'শিবপুরি শহর'] ,
['শিবভক্ত', 'শৈব', 'শৈব সম্প্রদায়'] ,
['শিবসাগর', 'শিবসাগর জেলা', 'শিবসাগর শহর'] ,
['শিবহর', 'শিবহর জেলা', 'শিবহর শহর'] ,
['শিবালিক', 'শিবালিক পর্বতশ্রেণী'] ,
['শিম', 'শিম্ব', 'শিম্বা'] ,
['শিমলা', 'শিমলা জেলা', 'শিমলা শহর'] ,
['শিরডী', 'শিরিডী', 'শির্ডী'] ,
['শিরণাস্ত্র', 'হেলমেট'] ,
['শিরীষ', 'শুকদ্রুম', 'শুকবৃক্ষ'] ,
['শিরোণাস্ত্র', 'শিরোস্ত্র'] ,
['শিলং', 'শিলং শহর'] ,
['শিলচর', 'শিলচর শহর'] ,
['শিলন্ধর', 'শিলন্ধর ঋষি'] ,
['শিলের উপরিভাগ', 'শিলের মাথা'] ,
['শিল্প ব্যবসা', 'শিল্প-ব্যবসা'] ,
['শিল্প শাস্ত্র', 'শিল্পবিজ্ঞান', 'শিল্পশাস্ত্র'] ,
['শিল্প', 'শিল্প কর্ম', 'শিল্পকার্য'] ,
['শিল্পপোযোগিতা', 'শিল্পসংক্রান্ত'] ,
['শিল্পবিদ্যা', 'হস্তশিল্প'] ,
['শিল্পী', 'হস্তশিল্পী'] ,
['শিল্পীগণ', 'শিল্পীবর্গ', 'শিল্পীবৃন্দ'] ,
['শিল্পোদ্যোগ সংক্রান্ত', 'শিল্পোদ্যোগ সম্পর্কিত'] ,
['শিশির', 'শিশির ঋতু', 'শীত'] ,
['শিশুথলিকাযুক্ত পশু', 'শিশুথলিকাযুক্ত প্রাণী'] ,
['শিয়া', 'শিয়া সম্প্রদায়'] ,
['শিয়াল', 'শৃগাল'] ,
['শীতলপাটি', 'শীতলপাটী'] ,
['শীর্ষ-বিন্দু', 'শীর্ষবিন্দু', 'শীর্ষভাগ'] ,
['শুক', 'শুকদেব'] ,
['শুক-রহস্য', 'শুক-রহস্য উপনিষদ', 'শুক-রহস্যোপনিষদ'] ,
['শুকনাশ', 'শ্যোনাক'] ,
['শুকনো মহুয়া', 'সোখরি'] ,
['শুকিয়ে যাওয়া', 'শুষ্ক হওয়া'] ,
['শুক্ল পক্ষ', 'শুক্লপক্ষ'] ,
['শুক্ল', 'শুক্লা', 'শুভ্র', 'শ্বেত', 'সাদা'] ,
['শুক্লকন্দা', 'শ্বেতকন্দা'] ,
['শুদ্ধ', 'সঠিক'] ,
['শুধু বসে থাকা', 'হাতে হাত রেখে বসে থাকা'] ,
['শুনক', 'শুনক ঋষি'] ,
['শুভ ক্ষণ', 'শুভ মূহুর্ত', 'শুভ লগ্ন'] ,
['শুভ চিহ্ন', 'শুভ লক্ষণ', 'সুলক্ষণ'] ,
['শুভ দিন', 'শুভদিন'] ,
['শুভ বুদ্ধি', 'সুমতি'] ,
['শুভচিন্তক', 'শুভাকাঙ্খী', 'হিতৈষী'] ,
['শুরভু', 'শুরভূমি'] ,
['শুশ্রুষা', 'সেবা-শুশ্রুষা'] ,
['শুষ্কগর্ভ', 'শুষ্কগর্ভ রোগ'] ,
['শূদ্রপত্নী', 'শূদ্রাণী', 'শূদ্রী'] ,
['শৃঙ্গ', 'শৃঙ্গ ঋষি'] ,
['শৃঙ্গার করা', 'সজ্জিত হওয়া', 'সাজগোজ করা', 'সাজা'] ,
['শেখপুরা', 'শেখপুরা জেলা', 'শেখপুরা শহর'] ,
['শেঠ. মহাজন', 'সাহুকার'] ,
['শের খান', 'শের শাহ সুরি', 'শেরশাহ', 'শেরশাহ সুরি'] ,
['শেষ করা', 'সম্পাদন করা'] ,
['শেষ হওয়া', 'সম্পূর্ণ হওয়া'] ,
['শেয়ার বাজার', 'স্টক এক্সচেঞ্জ'] ,
['শৈবাল', 'শ্যাওলা'] ,
['শৈলী', 'স্টাইল'] ,
['শৈশির', 'শৈশির ঋষি'] ,
['শোকগ্রস্ত', 'শোকপূর্ণ', 'শোকাকুল'] ,
['শোণিতপুর', 'শোণিতপুর জেলা', 'শোণিতপুর শহর'] ,
['শোনা', 'শ্রবণ', 'শ্রবণ করা', 'শ্রুত'] ,
['শোনার মতো', 'শ্রবণীয়', 'শ্রব্য', 'শ্রাব্য', 'শ্রোতব্য'] ,
['শোভন', 'শোভন রাগ', 'সিংহিকা'] ,
['শোভা পাওয়া', 'শোভিত'] ,
['শোলাপুর', 'শোলাপুর শহর'] ,
['শোয়া', 'শয়ন'] ,
['শৌকি', 'শৌকি ঋষি'] ,
['শৌল্কায়নি', 'শৌল্কায়নি ঋষি'] ,
['শ্বসন তন্ত্র', 'শ্বসন-তন্ত্র', 'শ্বসনতন্ত্র'] ,
['শ্বেত তুলসী', 'সাদা তুলসী'] ,
['শ্বেত নদী', 'সাদা নদী', 'হোয়াইট নদী'] ,
['শ্বেত বস্ত্র', 'শ্বেতাম্বর'] ,
['শ্বেত রোগ', 'শ্বেতী'] ,
['শ্বেত সিন্ধুবার', 'সম্ভালু', 'স্বর্ণশেফালিকা'] ,
['শ্বেতকেতু', 'শ্বেতকেতু ঋষি'] ,
['শ্বেতগজ', 'সাদা হাতি'] ,
['শ্বেতসারযুক্ত', 'স্টার্চযুক্ত'] ,
['শ্বেতাম্বর', 'শ্বেতাম্বর সাধু'] ,
['শ্বেতাশ্বতর', 'শ্বেতাশ্বতর উপনিষদ', 'শ্বেতাশ্বতরোপনিষদ'] ,
['শ্যাওস্ব', 'শ্যাওস্ব ঋষি'] ,
['শ্যাম', 'শ্যাম রাগ', 'শ্যামবর্ণ', 'শ্যামল', 'শ্যামলা'] ,
['শ্যামল হওয়া', 'সবুজ হওয়া'] ,
['শ্যেন', 'শ্যেন ঋষি'] ,
['শ্রবণ ইন্দ্রিয়', 'শ্রবণেন্দ্রিয়'] ,
['শ্রবণ', 'শ্রবণ কুমার', 'শ্রবণ ভক্তি'] ,
['শ্রবণা', 'শ্রবণা নক্ষত্র'] ,
['শ্রবণীয়', 'শ্রাব্য', 'শ্রোতব্য'] ,
['শ্রম বিভাগ', 'শ্রম-বিভাগ'] ,
['শ্রাদ্ধ', 'শ্রাদ্ধকর্ম'] ,
['শ্রাবণ', 'শ্রাবণ মাস'] ,
['শ্রাবস্তী', 'শ্রাবস্তী জেলা', 'শ্রাবস্তী শহর'] ,
['শ্রী অরবিন্দ', 'শ্রী অরবিন্দ ঘোষ'] ,
['শ্রী সত্য সাঁই বাবা', 'শ্রী সত্য সাঁইবাবা', 'শ্রী সত্য সাইবাবা', 'শ্রী সাইবাবা', 'সাঁইবাবা', 'সাই বাবা', 'সাইবাবা'] ,
['শ্রী সাঁই বাবা', 'শ্রী সাঁইবাবা', 'শ্রী সাই বাবা', 'শ্রী সাইবাবা', 'সাঁই', 'সাঁই বাবা', 'সাঁইবাবা', 'সাই বাবা', 'সাইবাবা'] ,
['শ্রী', 'শ্রী রাগ', 'শ্রীরাগ'] ,
['শ্রীকাকুলম', 'শ্রীকাকুলম জেলা', 'শ্রীকাকুলম শহর'] ,
['শ্রীচন্দন', 'সাদা চন্দন'] ,
['শ্রীনগর', 'শ্রীনগর জেলা', 'শ্রীনগর শহর'] ,
['শ্রীবর্দ্ধন', 'শ্রীবর্দ্ধন রাগ'] ,
['শ্রীভান', 'শ্রীভানু'] ,
['শ্রীলঙ্কা', 'সিংহল', 'সিংহল দ্বীপ'] ,
['শ্রীলঙ্কাবাসী', 'সিংহলী'] ,
['শ্রীসমাধ', 'শ্রীসমাধ রাগ'] ,
['শ্রুতবিদ', 'শ্রুতবিদ ঋষি'] ,
['শ্রেণী', 'সামাজিক শ্রেণী'] ,
['শ্লেষ', 'শ্লেষ অলঙ্কার', 'শ্লেষালঙ্কার'] ,
['শ্লেষ্মা গ্রন্থি', 'শ্লেষ্মাগ্রন্থি'] ,
['শ্লেষ্মাতক বন', 'শ্লেষ্মাতকবন'] ,
['শয়ন-কক্ষ', 'শয়নকক্ষ'] ,
['ষটতিলা', 'ষটতিলা একাদশী'] ,
['ষষ্ঠানকাল ব্রত', 'ষষ্ঠানকালে'] ,
['ষাট', 'ষাট বছর', '৬০'] ,
['ষোড়শ', 'ষোলো'] ,
['ষোড়ষোপচার', 'ষোল উপচার'] ,
['সংকর', 'সংকর জাতি'] ,
['সংকলন', 'সংগ্রহ', 'সংহতি', 'সঞ্চয়', 'সম্ভার'] ,
['সংকলিত', 'সংগৃহীত', 'সঞ্চিত'] ,
['সংকল্প', 'সিদ্ধান্ত নেওয়া', 'স্হির করা'] ,
['সংকেত', 'সংকেত স্হান', 'সিগনাল', 'সিগন্যাল'] ,
['সংকোচক', 'স্তম্ভক'] ,
['সংক্রমণ কাল', 'সংক্রান্তি'] ,
['সংক্ষিপ্ত', 'সার'] ,
['সংক্ষিপ্তকরণ', 'সংক্ষেপ'] ,
['সংগঠন', 'সংস্থা'] ,
['সংগঠিত', 'সৌহার্দ্যপূর্ণ'] ,
['সংগরেড্ডী', 'সংগরেড্ডী শহর'] ,
['সংগ্রহ', 'সম্পদ'] ,
['সংগ্রহকারী', 'সংগ্রহী'] ,
['সংগ্রামিক', 'সামরিক'] ,
['সংঘ', 'সমবায় সংঘ', 'সমিতি'] ,
['সংঘর্ষপূর্ণ', 'সংঘর্ষময়'] ,
['সংজ্ঞাশূণ্য', 'সংজ্ঞাহীন'] ,
['সংবরণ', 'সংবরণ ঋষি'] ,
['সংবর্ত্তক', 'সংবর্ত্তক ঋষি'] ,
['সংবাদদাতা', 'সাংবাদিক'] ,
['সংবেদনশীল', 'সমব্যাথী'] ,
['সংবেদনা', 'সহমর্মী', 'সহানুভূতি'] ,
['সংমিশ্রণ', 'সংশ্লেষ', 'সমন্বয়'] ,
['সংযমশীল', 'সংযমী'] ,
['সংযোগ শৃঙ্গার', 'সংযোগ শৃঙ্গার রস'] ,
['সংযোজক', 'সংযোজক শব্দ'] ,
['সংযোজন', 'সমাবেশ'] ,
['সংরক্ষণ', 'সুরক্ষা'] ,
['সংরক্ষিত এলাকা', 'সংরক্ষিত ক্ষেত্র'] ,
['সংলগ্নতা', 'সন্নিহিত'] ,
['সংশয়োপোমা', 'সংশয়োপোমালঙ্কার'] ,
['সংসদ', 'সংসদ ভবন'] ,
['সংসর্গ', 'সংস্পর্শ', 'সঙ্গ'] ,
['সংসিদ্ধ', 'সুসম্পন্ন'] ,
['সংস্কৃতি-সংক্রান্ত', 'সাংস্কৃতিক'] ,
['সংস্থানবিহীন', 'সংস্থানহীন'] ,
['সংস্পর্শ', 'সম্পর্ক', 'স্পর্শ'] ,
['সংহিতা', 'সন্ধি'] ,
['সই করা', 'স্বাক্ষর করা', 'হস্তাক্ষর করা'] ,
['সই', 'হস্তাক্ষর'] ,
['সইহা', 'সইহা জেলা', 'সইহা শহর'] ,
['সঈ', 'সর্পিকা', 'স্যন্দিকা'] ,
['সকলে', 'সবাই'] ,
['সকাল সকাল', 'সকালে'] ,
['সগুণ ব্রাহ্মণ', 'সাকার ব্রাহ্মণ'] ,
['সগোত্রী', 'সমগোত্রীয়'] ,
['সঙ্কটজনক', 'সঙ্কটপূর্ণ'] ,
['সঙ্কটনাশক', 'সঙ্কটনাশী', 'সঙ্কটমোচনকারী'] ,
['সঙ্গ দেওয়া', 'সঙ্গী হওয়া'] ,
['সঙ্গরুর', 'সঙ্গরুর জেলা', 'সঙ্গরুর শহর'] ,
['সঙ্গায়', 'সঙ্গায় হরিণ'] ,
['সঙ্গিনী', 'সহচরী'] ,
['সঙ্গী', 'সহচর'] ,
['সঙ্গীত নির্দেশক', 'সঙ্গীতকার'] ,
['সঙ্গীত রচনা', 'সঙ্গীত রচনা করা'] ,
['সঙ্গীত স্বর', 'সুর', 'স্বর'] ,
['সঙ্গে', 'সমেত', 'সহিত', 'সাথে'] ,
['সচিবসংক্রান্ত', 'সচিবের', 'সচিবের কাজ সংক্রান্ত'] ,
['সচেতন করা', 'সাবধান করা'] ,
['সজাতি', 'সমজাতি'] ,
['সজ্জিত', 'সাজাগোজা'] ,
['সঞ্চরণ', 'সঞ্চার'] ,
['সঞ্চার', 'সম্প্রচার', 'সম্প্রসারণ'] ,
['সঞ্চারী', 'সঞ্চারী ভাব'] ,
['সঞ্চিত নিধি', 'সঞ্চয়'] ,
['সঞ্জীব নরক', 'সঞ্জীবন নরক'] ,
['সতবৃত্তি', 'সত্কর্ম', 'সত্গুণ'] ,
['সতারুক', 'সতারুক রোগ'] ,
['সতী প্রথা', 'সহগমন'] ,
['সতী', 'সহগামিনী'] ,
['সতীর্থ', 'সহপাঠী'] ,
['সতীসাবিত্রী', 'সাবিত্রী'] ,
['সতেরো', 'সপ্তদশ', '১৭,'] ,
['সত্তর', 'সত্তর বছর', '৭০'] ,
['সত্য গল্প', 'সত্যি ঘটনা'] ,
['সত্যকাম', 'সত্যকাম ঋষি'] ,
['সত্যনিষ্ট', 'সত্যব্রত'] ,
['সত্যবক্তা', 'সত্যবাদী', 'সত্যভাষী', 'সাচ্চা'] ,
['সত্যবাদিনী', 'সত্যভাষিণী'] ,
['সত্যভামা', 'সত্রাজিতী'] ,
['সত্যসন্ধ', 'সন্ধ'] ,
['সত্সঙ্গে', 'সত্সমাগম'] ,
['সদস্য', 'সভাসদ'] ,
['সদ্গুরু', 'সুতীর্থ'] ,
['সনসেট', 'সনসেট আম'] ,
['সনাতনধর্মী', 'সনাতনী'] ,
['সন্ত কবীর নগর', 'সন্ত কবীর নগর জেলা'] ,
['সন্ত রবিদাস নগর', 'সন্ত রবিদাস নগর জেলা'] ,
['সন্ততিহোম', 'সন্ততিহোম যজ্ঞ'] ,
['সন্তরণ', 'সাঁতার'] ,
['সন্তুষ্ট করার যোগ্য', 'সন্তুষ্টির যোগ্য'] ,
['সন্তুষ্টি', 'সন্তোষ'] ,
['সন্তোষজনক', 'সন্তোষপ্রদ'] ,
['সন্দিগ্ধ', 'সন্দেহজনক', 'সন্দেহপূর্ণ'] ,
['সন্দীপন', 'সন্দীপনী'] ,
['সন্দেরশা আমে', 'সন্দেরশা আমের গাছ'] ,
['সন্দেরশা', 'সন্দেরশা আম'] ,
['সন্ধি', 'সমঝোতা'] ,
['সন্ধিপাদ জন্তু', 'সন্ধিপাদ প্রাণী'] ,
['সন্ধ্যা', 'সন্ধ্যোপাসনা'] ,
['সন্নিহিত', 'সমাহিত'] ,
['সন্ন্যাস', 'সন্ন্যাসাশ্রম'] ,
['সন্যাস', 'সন্যাস উপনিষদ', 'সন্যাসোপনিষদ'] ,
['সপ্ত ঋষি', 'সপ্তর্ষি'] ,
['সপ্ত', 'সাত', '৭'] ,
['সপ্ত-সত্গুণ', 'সপ্তগুণ', 'সাতটি সত্গুণ'] ,
['সপ্তপদী', 'সাতপাক'] ,
['সপ্তমী', 'সপ্তমী তিথি'] ,
['সপ্তাহ অন্ত', 'সপ্তাহান্ত'] ,
['সপ্তাহ', 'হপ্তা'] ,
['সফর', 'সফরি'] ,
['সফল', 'সার্থক', 'সিদ্ধ'] ,
['সফেদা', 'সফেদা আম'] ,
['সব নিয়ে', 'সব মিলিয়ে'] ,
['সবচেয়ে গুরুত্বপূর্ণ', 'সর্বোপরি'] ,
['সবন', 'সবন ঋষি'] ,
['সবরমতী', 'সবরমতী নদী'] ,
['সবাই মাধোপুর শহর', 'সাবোই মাধোপুর'] ,
['সবাই মাধোপুর', 'সবাই মাধোপুর জেলা'] ,
['সবেদা', 'সীতাফল'] ,
['সব্জী ওয়ালা', 'সব্জী বিক্রেতা'] ,
['সব্য', 'সব্য ঋষি'] ,
['সভা মণ্ডপ', 'সভা-মণ্ডপ', 'সভামণ্ডপ'] ,
['সভা সমাপন', 'সভা সমাপ্তি'] ,
['সভাধ্যক্ষ', 'সভাপতি'] ,
['সম রাশি', 'সমসংখ্যা'] ,
['সমকালীন', 'সমসাময়িক'] ,
['সমক্ষ', 'সম্মুখ', 'সম্মুখে', 'সামনে'] ,
['সমতল ভূমি', 'সমস্থল'] ,
['সমতাবাদ', 'সাম্যবাদ'] ,
['সমতুল্য হওয়া', 'সমান হওয়া'] ,
['সমতুল্য', 'সমান'] ,
['সমনার্থক', 'সমনার্থী', 'সমর্থক'] ,
['সমবর্গীয়', 'স্বজাতি', 'স্বজাতীয়'] ,
['সমব্যাথী', 'সহানুভূতিশীল'] ,
['সমরবেহিস্ত', 'সমরবেহিস্ত আম'] ,
['সমষ্টিগত অর্থভাণ্ডার', 'সমষ্টিগত ধনকোষ', 'সর্বজনীন অর্থভাণ্ডার'] ,
['সমস্তিপুর', 'সমস্তিপুর জেলা', 'সমস্তিপুর শহর'] ,
['সমাজ বিজ্ঞান', 'সমাজ শাস্ত্র', 'সামাজিক বিজ্ঞান'] ,
['সমাজ সেবা', 'সমাজসেবা'] ,
['সমাজতন্ত্রবাদী', 'সমাজবাদী', 'সোসালিস্ট'] ,
['সমাজতাত্ত্বিক', 'সমাজবিদ'] ,
['সমাজতান্ত্রিক', 'সমাজবাদী'] ,
['সমাজসেবক', 'সমাজসেবী'] ,
['সমাধান করা', 'সামলানো', 'সোজা হওয়া'] ,
['সমাধানযোগ্য', 'সামাধানীয়'] ,
['সমাধি-স্থল', 'সমাধি-স্থান'] ,
['সমান অংশ', 'সমান ভাগ'] ,
['সমান মাত্রা', 'সমানুপাত'] ,
['সমাপন', 'সমাপ্তি'] ,
['সমাপনীয়', 'সমাপ্য'] ,
['সমাবর্তন', 'সমাবর্তন অনুষ্ঠান'] ,
['সমার্থক', 'সমার্থবোধক'] ,
['সমুদ্র ফল', 'সমুদ্রফল'] ,
['সমুদ্র', 'সাগর', 'সাগর জেলা'] ,
['সমুদ্র-ফল', 'সমুদ্রফল'] ,
['সমুদ্রজ', 'সমুদ্রজাত', 'সামুদ্রিক'] ,
['সমুন্দর-সোখ', 'সমুন্দরসোখ'] ,
['সমৃদ্ধ', 'সম্পন্ন'] ,
['সমৃদ্ধি', 'সম্পন্নতা'] ,
['সম্পন্ন করা', 'সাধন করা'] ,
['সম্পর্ক কেটে যাওয়া', 'সম্পর্ক ভেঙে যাওয়া'] ,
['সম্পর্ক', 'সম্বন্ধ'] ,
['সম্পর্কযুক্ত', 'সম্পর্কিত', 'সম্বন্ধযুক্ত'] ,
['সম্পর্কে', 'সম্বন্ধে'] ,
['সম্পাদন করার যোগ্য', 'সম্পাদনীয়'] ,
['সম্পূর্ণ', 'সম্পূর্ণ রূপে'] ,
['সম্প্রদান', 'সম্প্রদান কারক', 'সম্প্রদানকারক'] ,
['সম্প্রাপ্তি কাল', 'সম্প্রাপ্তি-কাল'] ,
['সম্বন্ধ কারক', 'সম্বন্ধকারক'] ,
['সম্বলপুর', 'সম্বলপুর জেলা', 'সম্বলপুর শহর'] ,
['সম্বোধক', 'সম্বোধনকারী'] ,
['সম্ভব', 'সম্ভাব্য'] ,
['সম্ভবত', 'হয়তো'] ,
['সম্মতি দেওয়া', 'স্বীকার করা', 'স্বীকৃতি দেওয়া', 'হ্যাঁ বলা'] ,
['সম্মান দেওয়া', 'সম্মানিত করা'] ,
['সম্মান সমারোহ', 'সম্মানোত্সব'] ,
['সম্মানিত', 'সম্মানীয়'] ,
['সম্মুখীন হওয়া', 'সামনা-সামনি হওয়া'] ,
['সম্মুখে আগমন', 'সামনে যাওয়া'] ,
['সময় নির্ধারিত করা', 'সময় নিশ্চিত করা'] ,
['সরদার প্যাটেল', 'সর্দার বল্লভ ভাই প্যাটেল'] ,
['সরন', 'সরন জেলা'] ,
['সরল', 'সহজ', 'সিধাসাধা', 'সুগম', 'সোজা'] ,
['সরলতা', 'সহজতা'] ,
['সরষে', 'সরিষা', 'সর্ষপ'] ,
['সরস্বতী', 'সরস্বতী সন্ন্যাসী'] ,
['সরস্বতী-রহস্য', 'সরস্বতী-রহস্য উপনিষদ', 'সরস্বতী-রহস্যোপনিষদ'] ,
['সরাইওয়ালা', 'সরাইখানার মালিক'] ,
['সরাইওয়ালি', 'সরাইয়ের মালকিন'] ,
['সরাইকেলা খরসাবাঁ', 'সরাইকেলা খরসাবাঁ শহর'] ,
['সরাফ খানা', 'সরাফা'] ,
['সরীসৃপ', 'সরীসৃপ জীব', 'সরীসৃপ প্রাণী'] ,
['সরু', 'সূক্ষ্ম'] ,
['সর্পগন্ধা', 'সর্পসুগন্ধা', 'সর্পসুগন্ধিকা', 'সর্পাক্ষী'] ,
['সর্পদন্তা', 'সিংহলী পীপল', 'সিংহলীপীপল'] ,
['সর্পি', 'সর্পি ঝষি'] ,
['সর্পিল', 'সর্পিল নক্সা', 'সর্পিলা'] ,
['সর্ব সম্মতি', 'সর্বমত'] ,
['সর্ব-সার উপনিষদ', 'সর্ব-সারোপনিষদ', 'সর্বসার'] ,
['সর্বগুণসম্পন্ন', 'সর্বগুণান্বিত'] ,
['সর্বজনীন শৌচাগার', 'সর্বজনীন শৌচালয়'] ,
['সর্বজনীন', 'সর্বদেশীয়', 'সাধারণ', 'সার্বভৌম', 'সার্বভৌমিক', 'সার্বিক'] ,
['সর্বজ্ঞ', 'সর্ববিত্'] ,
['সর্বদা পূজনীয়', 'সর্বদা পূজ্য'] ,
['সর্বপ্রধান', 'সর্বোচ্চ ক্ষমতাধারী', 'সর্বোচ্চ ক্ষমতাযুক্ত'] ,
['সর্বভক্ষ্য', 'সর্বভুক'] ,
['সর্বভুক', 'সর্বাহারী'] ,
['সর্বশক্তিমান', 'সর্বশক্তিশালী'] ,
['সর্বশ্রেষ্ঠ', 'সর্বোত্কৃষ্ট', 'সর্বোত্তম'] ,
['সর্বাঙ্গিক', 'সর্বাঙ্গীন'] ,
['সর্বোচ্চ', 'সর্বোপরি'] ,
['সলোমন', 'সলোমন দ্বীপসমূহ'] ,
['সশস্ত্র', 'হাতিয়ারসৃদ্ধ'] ,
['সস্নেহ', 'স্নেহশীল'] ,
['সহকারি সংস্থা', 'সহকারি সমিতি'] ,
['সহকারী', 'সহযোগ কারী', 'সহযোগী ব্যক্তি', 'সহায়ক', 'সাহায্যকারী'] ,
['সহগামী', 'সহযাত্রী'] ,
['সহজ প্রবৃত্তি', 'স্বাভাবিক প্রবৃত্তি'] ,
['সহজ প্রাপ্য', 'সহজলভ্য', 'সুপ্রাপ্য'] ,
['সহজ', 'সুবিধাজনক', 'সুবিধাপূর্ণ', 'স্বাভাবিক'] ,
['সহডোল', 'সহডোল জেলা', 'সহডোল শহর'] ,
['সহন', 'সহ্য'] ,
['সহনশীল', 'সহিষ্ণু'] ,
['সহনশীলতা', 'সহিষ্ণুতা'] ,
['সহভাগ', 'সহযোগ', 'সহযোগিতা'] ,
['সহযোগিতা', 'সহায়তা', 'সাহায্য'] ,
['সহরসা', 'সহরসা জেলা', 'সহরসা শহর'] ,
['সহরোলী', 'সহরোলী আম'] ,
['সহস্র', 'হাজার'] ,
['সহস্রার', 'সহস্রার চক্র'] ,
['সহায়তা করা', 'সাহায্য করা', 'সাহায্যের হাত বাড়ানো'] ,
['সহায়তা প্রাপ্ত', 'সাহায্যপ্রাপ্ত'] ,
['সহায়তাপ্রাপ্ত', 'স্বাবলম্বী'] ,
['সাঁইত্রিশ', '৩৭,'] ,
['সাঁবত', 'সাঁবত রাগ'] ,
['সাঁবাঁ', 'সাবা'] ,
['সাংখ্য', 'সাংখ্যদর্শন', 'সাংখ্যশাস্ত্র'] ,
['সাইপ্রাস বাসী', 'সাইপ্রাসি'] ,
['সাইপ্রাস', 'সাইপ্রাস গণতন্ত্র', 'সাইপ্রাস গণরাজ্য'] ,
['সাইবার অপরাধ', 'সাইবার ক্রাইম', 'সাইবারঅপরাধ', 'সাইবারক্রাইম'] ,
['সাইবেরিয়ার', 'সাইবেরীয়'] ,
['সাও টোম ও প্রিন্সিপে', 'সাও টোম ও প্রিন্সিপে জনতান্ত্রিক গণরাজ্য', 'সেন্ট থমাস ও প্রিন্সিপে'] ,
['সাকী', 'সাকী বাঁদর'] ,
['সাগর', 'সাগর শহর', 'সাগর সন্ন্যাসী'] ,
['সাগুদানা', 'সাবুদানা'] ,
['সাঙ্গলী', 'সাঙ্গলী জেলা', 'সাঙ্গলী শহর'] ,
['সাজদা', 'সিজদা'] ,
['সাজসজ্জা', 'সাজসরঞ্জাম'] ,
['সাজা', 'সাজা বৃক্ষ'] ,
['সাজুনে মহিলা', 'সাজুনে মেয়ে'] ,
['সাতচল্লিশ', '৪৭,'] ,
['সাতরঙা', 'সাতরঙের'] ,
['সাতশো', '৭০০'] ,
['সাতষট্টি', '৬৭', '৬৭,'] ,
['সাতাত্তর', '৭৭', '৭৭,'] ,
['সাতানব্বই', '৯৭', '৯৭,'] ,
['সাতান্ন', '৫৭', '৫৭,'] ,
['সাতারা', 'সাতারা জেলা', 'সাতারা শহর'] ,
['সাতাশি', '৮৭', '৮৭,'] ,
['সাদা গোলাপ', 'সেবতী'] ,
['সাদা ল্যাঙড়া', 'সাদা ল্যাঙড়া আম'] ,
['সাদামাটা', 'সাধারণ'] ,
['সাদাসিধে মহিলা', 'সাদাসিধে স্ত্রীলোক'] ,
['সাধন সম্পন্ন', 'সাধনপূর্ণ', 'সাধনযুক্ত'] ,
['সাধনীয়', 'সাধ্য'] ,
['সাধারণ', 'সামান্য'] ,
['সাধারণতঃ', 'সামান্যতঃ'] ,
['সাধারণতা', 'সামান্যতা'] ,
['সাধ্বস', 'সাধ্বস'] ,
['সান্ডিল্য', 'সান্ডিল্য মুনি'] ,
['সান্দীপনি', 'সান্দীপনি ঋষি'] ,
['সাপুড়া', 'হড়পি', 'হড়পী'] ,
['সাপের ফেনা', 'সাপের লাল'] ,
['সাবধানে থাকা', 'সামলে থাকা'] ,
['সাবরকাণ্ঠা', 'সাবরকাণ্ঠা জেলা'] ,
['সাবিত্র', 'সৌর'] ,
['সাবিত্রি', 'সাবিত্রি উপনিষদ'] ,
['সাবিত্রী', 'সাবিত্রী সংস্কার'] ,
['সামগ্রিক ভাবে', 'সামূহিক ভাবে'] ,
['সামনে', 'সোজা'] ,
['সামন্ত যুগের', 'সামন্তকালীন'] ,
['সামন্ত', 'সামন্ত রাগ'] ,
['সামন্ত-ভারতী', 'সামন্ত-ভারতী রাগ'] ,
['সামন্ত-সারঙ্গ', 'সামন্ত-সারঙ্গ রাগ'] ,
['সামন্ততন্ত্র', 'সামন্তপ্রথা'] ,
['সামবেদীয়', 'সামবৈদিক'] ,
['সামলানো', 'সামলে নেওয়া', 'সুরক্ষিত রাখা'] ,
['সামাজিক কর্ম', 'সামাজিক কাজ', 'সামাজিক কার্য'] ,
['সামাজিক নিধান', 'সামাজিক প্রবন্ধ', 'সামাজিক ব্যবস্থা'] ,
['সামুদ্রিক পথে', 'সামুদ্রিক রাস্তা'] ,
['সামুদ্রিক', 'সৈন্ধব'] ,
['সার', 'সার তত্ত্ব', 'সার বস্তু'] ,
['সারং', 'সারং রাগ'] ,
['সারঙ্গী', 'সারিন্দা', 'সারেঙ্গী'] ,
['সারবিয়ান', 'সারবিয়ান ভাষা'] ,
['সারস্বত', 'সারস্বত ঋষি', 'সারস্বত ব্রাহ্মণ'] ,
['সার্ক', 'হাঙর', 'হাঙ্গর'] ,
['সার্কাস', 'সার্কাসের খেলা'] ,
['সার্জনাক্ষি', 'সার্জনাক্ষি ঋষি'] ,
['সার্পরাজ্ঞি', 'সার্পরাজ্ঞি ঋষি'] ,
['সার্বজনীনতা', 'সার্বভৌমিকতা'] ,
['সার্বিয়া', 'সার্বিয়া গণরাজ্য'] ,
['সার্ভিস', 'সেবা'] ,
['সাল', 'সাল গাছ'] ,
['সালঙ্ক', 'সালঙ্ক রাগ'] ,
['সালমমিশ্রী', 'সুধামূলী'] ,
['সালিশ', 'সালিশসভা'] ,
['সাসারাম', 'সাসারাম শহর'] ,
['সাহারনপুর', 'সাহারনপুর জেলা'] ,
['সাহিত্যকার', 'সাহিত্যিক'] ,
['সাহেবগঞ্জ', 'সাহেবগঞ্জ জেলা', 'সাহেবগঞ্জ শহর'] ,
['সিঁড়ি', 'সোপানশ্রেনী'] ,
['সিঁথি', 'সীমন্ত'] ,
['সিঁদুরি', 'সিঁদুরি আম'] ,
['সিংহ', 'সিংহ রাশি', 'সিংহ রাশিযুক্ত', 'সিংহরাশি'] ,
['সিংহনাদ', 'সিংহের গর্জন'] ,
['সিংহলী', 'সিংহলী লিপি'] ,
['সিংহিনী', 'সিংহী'] ,
['সিকন্দরা', 'সিগনাল'] ,
['সিক্ত', 'সিঞ্চিত'] ,
['সিখ', 'সিখ ধর্মালম্বী'] ,
['সিঙ্গরী', 'সিঙ্গল'] ,
['সিঙ্গাপুর আম', 'সিঙ্গাপুর আমের গাছ'] ,
['সিঙ্গাপুর বাসী', 'সিঙ্গাপুরি'] ,
['সিঙ্গাপুর', 'সিঙ্গাপুর আম', 'সিঙ্গাপুর গণরাজ্য', 'সিঙ্গাপুর দ্বীপ'] ,
['সিঙ্গি', 'সিঙ্গি মাছ'] ,
['সিঙ্গোটা', 'সিঙ্ঘোটা'] ,
['সিঞ্চন', 'সেচ', 'সেচন'] ,
['সিতামারি', 'সিতামারি শহর'] ,
['সিদ্ধান্ত গ্রহণের ক্ষমতা', 'সিদ্ধান্ত নেওয়ার ক্ষমতা'] ,
['সিদ্ধার্থনগর', 'সিদ্ধার্থনগর জেলা'] ,
['সিধা', 'সোজা'] ,
['সিধি', 'সিধি জেলা', 'সিধি শহর'] ,
['সিধে', 'সোজা'] ,
['সিনেগাল', 'সিনেগাল গণরাজ্য', 'সিনেগাল নদী'] ,
['সিনেগালবাসী', 'সিনেগালি', 'সিনেগালিস'] ,
['সিনেগালি', 'সিনেগালিস', 'সিনেগালীয়'] ,
['সিন্দাবাদ', 'সিন্দাবাদ নাবিক'] ,
['সিন্দুরি', 'সিন্দুরি আম'] ,
['সিন্ধ', 'সিন্ধবী'] ,
['সিন্ধী', 'সিন্ধী ভাষা', 'সিন্ধী লিপি', 'সিন্ধুবাসী'] ,
['সিন্ধু', 'সিন্ধু নদ', 'সিন্ধু নদী', 'সিন্ধু রাগ'] ,
['সিন্ধুদুর্গ', 'সিন্ধুদুর্গ জেলা'] ,
['সিন্ধুরা', 'সিন্ধুরা রাগ'] ,
['সিবনি জেলা', 'সিবানি', 'সিয়ানি', 'সিয়ানি জেলা'] ,
['সিবনি', 'সিবানি শহর'] ,
['সিবমোগা জেলা', 'সিমোগা', 'সিমোগা শহর'] ,
['সিবমোগা', 'সিবমোগা শহর', 'সিমোগা', 'সিমোগা শহর'] ,
['সিবান', 'সিবান জেলা', 'সিবান শহর'] ,
['সিমডেগা', 'সিমডেগা জেলা', 'সিমডেগা শহর'] ,
['সিমাই', 'সিমুই'] ,
['সিয়েরা লিওনিয়ান', 'সিয়েরা লিওনের'] ,
['সিরমৌর', 'সিরমৌর জেলা', 'সিরমৌর শহর'] ,
['সিরসা', 'সিরসা জেলা', 'সিরসা শহর'] ,
['সিরসী লবা', 'সিরসী লাবা'] ,
['সিরিয়া', 'সিরিয়ান আরব গণরাজ্য'] ,
['সিরিয়ান', 'সিরিয়াবাসী'] ,
['সিরোহি', 'সিরোহি জেলা', 'সিরোহি শহর'] ,
['সিল', 'সিল মাছ'] ,
['সিলা', 'সীলা'] ,
['সিল্লা', 'সীলা'] ,
['সিসিলি', 'সিসিলি দ্বীপ'] ,
['সিহোর', 'সিহোর জেলা', 'সিহোর শহর', 'সেহোর', 'সেহোর শহর'] ,
['সিয়েরা লিওন বাসী', 'সিয়েরা লিওনিয়ান'] ,
['সিয়েরা লিওন', 'সিয়েরা লিওন গণরাজ্য'] ,
['সীকর', 'সীকর জেলা', 'সীকর শহর'] ,
['সীতাপুর', 'সীতাপুর জেলা', 'সীতাপুর শহর'] ,
['সীনা', 'সীনা নদী'] ,
['সীমা অঙ্কন', 'সীমাঙ্কন'] ,
['সীমা উল্লঙ্ঘন', 'সীমান্ত অতিক্রমণ'] ,
['সীমা প্রহরী', 'সীমা রক্ষক', 'সীমান্ত প্রহরী', 'সীমান্ত রক্ষক'] ,
['সীমা রক্ষক', 'সীমা রক্ষকারী', 'সীমান্ত রক্ষক', 'সীমান্ত রক্ষাকারী'] ,
['সীমা সুরক্ষা ফৌজ', 'সীমান্ত সুরক্ষা বাহিনী'] ,
['সীমান্ত কর্ম', 'সীমান্ত সংস্কার', 'সীমান্তন্নয়ন সংস্কার'] ,
['সীমান্তকর', 'সীমান্তশুল্ক'] ,
['সুইজারল্যান্ড', 'সুইটজারল্যান্ড'] ,
['সুইজারল্যান্ডবাসী', 'সুইজারল্যান্ডীয়'] ,
['সুইজারল্যান্ডীয়', 'সুইজারল্যান্ডের'] ,
['সুইডিশ', 'সুইডিশ ভাষা', 'সুইডেনবাসী'] ,
['সুকুমার বন', 'সুকুমারবন'] ,
['সুকৃতী', 'সুকৃতী ঋষি'] ,
['সুকেশা', 'সুকেশী'] ,
['সুক্ত বাক্য', 'সুক্তি', 'সুবচন'] ,
['সুক্ষ্ম কোণ', 'সুক্ষ্মকোণ'] ,
['সুখদেও', 'সুখদেও থাপর'] ,
['সুখপূর্ণ', 'সুখময়', 'সুখী'] ,
['সুগঠিত', 'সুডৌল'] ,
['সুঘরাই-কান্হাড়া', 'সুঘরাইকান্হাড়া'] ,
['সুঘরাই-টোড়ী', 'সুঘরাইটোড়ী'] ,
['সুডৌল হওয়ার অবস্হা', 'সৌষ্ঠব'] ,
['সুডৌলতা', 'সৌষ্ঠব'] ,
['সুতি', 'সুতির কাপড়', 'সুতী', 'সুতো'] ,
['সুদর্শনা', 'সুশ্রী'] ,
['সুদান বাসী', 'সুদানবাসী', 'সুদানি', 'সুদানিস'] ,
['সুদান', 'সুদান গণরাজ্য', 'সুদান সম্পর্কিত', 'সুদানীয়'] ,
['সুদের দর', 'সুদের হার'] ,
['সুধামা', 'সুধামা ঋষি'] ,
['সুনিপুণ', 'সুনিপুণা'] ,
['সুন্দর কাণ্ড', 'সুন্দরকাণ্ড'] ,
['সুন্দর ঢঙ', 'সুন্দর ভঙ্গি'] ,
['সুন্দর', 'সুষ্ঠ'] ,
['সুন্দরগড়', 'সুন্দরগড় জেলা', 'সুন্দরগড় শহর'] ,
['সুন্দরভাবে লিখিত', 'স্পষ্টভাবে লিখিত'] ,
['সুন্দরী আম', 'সুন্দরী আম গাছ', 'সুবর্ণরেখা আম'] ,
['সুন্নী', 'সুন্নী মতাবলম্বী', 'সুন্নী সম্প্রদায়'] ,
['সুপক্ক্ব', 'সুসিদ্ধ'] ,
['সুপরিণাম', 'সুফল'] ,
['সুপর্ণ', 'সুপর্ণ ঋষি'] ,
['সুপাত্রতা', 'সুযোগ্যতা'] ,
['সুপৌল', 'সুপৌল জেলা', 'সুপৌল শহর'] ,
['সুফি', 'সুফি সম্প্রদায়'] ,
['সুবন্ধু', 'সুবন্ধু ঋষি'] ,
['সুবর্ণ মন্দির', 'স্বর্ণ মন্দির'] ,
['সুবর্ণ রঙ', 'সোনালী রঙ', 'স্বর্ণালী রঙ'] ,
['সুবর্ণ', 'সোনালী', 'স্বর্ণ', 'হিরণ্ময়', 'হৈম'] ,
['সুবর্ণপুর', 'সোনপুর', 'সোনাপুর জেলা', 'সোনেপুর জেলা'] ,
['সুবর্ণরেখা', 'সুবর্ণরেখা নদী'] ,
['সুবা', 'সুবা মোষ'] ,
['সুবাল', 'সুবাল উপনিষদ', 'সুবালোপনিষদ'] ,
['সুবাসিত হওয়া', 'সুরভিত হওয়া'] ,
['সুবিধাবাদী', 'সুযোগসন্ধানী'] ,
['সুবিন্যস্ত', 'সুব্যবস্থিত'] ,
['সুবেদ', 'সুবেদ ঋষি'] ,
['সুবেদারনি', 'সুবেদারের বউ'] ,
['সুব্রত নাথ', 'সুব্রতনাথ'] ,
['সুমঙ্গা', 'সুমঙ্গা নদী'] ,
['সুমনায়ন', 'সুমনায়ন ঋষি'] ,
['সুমসুখড়া', 'সুমসুখড়া রোগ'] ,
['সুমেধা', 'সুমেধা ঋষি'] ,
['সুরক্ষা জমা', 'সুরক্ষা রাশি'] ,
['সুরক্ষা বল', 'সুরক্ষা বাহিনী', 'সুরক্ষাবল', 'সুরক্ষাবাহিনী'] ,
['সুরজা', 'সুরজা নদী'] ,
['সুরট-মল্লার', 'সুরটমল্লার'] ,
['সুরথা', 'সুরথা নদী'] ,
['সুরমা রঙের', 'হাল্কা নীল'] ,
['সুরসুরি দেওয়া', 'হাত বোলানোর ক্রিয়া'] ,
['সুরাজ্য', 'সুশাসন'] ,
['সুরাট', 'সুরাট জেলা', 'সুরাট শহর'] ,
['সুরি', 'সুরি শহর'] ,
['সুরিনাম বাসী', 'সুরিনামিজ'] ,
['সুরিনামীয়', 'সুরিনামের'] ,
['সুরুয়া', 'সূপ'] ,
['সুরেন্দ্রনগর', 'সুরেন্দ্রনগর জেলা'] ,
['সুলতানপুর', 'সুলতানপুর জেলা', 'সুলতানপুর শহর'] ,
['সুলতানী', 'সুল্তানী'] ,
['সুশ্রবা', 'সুশ্রবা ঋষি'] ,
['সুস্পষ্ট', 'স্পষ্ট'] ,
['সুহস্ত্য', 'সুহস্ত্য ঋষি'] ,
['সুহা', 'সুহা রাগ'] ,
['সুহা-কানাড়া', 'সুহাকানাড়া'] ,
['সুহা-টোড়ী', 'সুহাটোড়ী'] ,
['সুহা-বিলাবল', 'সুহাবিলাবল'] ,
['সুহা-শ্যাম', 'সুহাশ্যাম'] ,
['সুহেল', 'সুহেলে তারা'] ,
['সুহোত্র', 'সুহোত্র ঋষি', 'সুহোত্র দৈত্য'] ,
['সূঁচ', 'সূচিকা'] ,
['সূচ', 'সূচনীয়'] ,
['সূচকাঁঙ্ক', 'সেনসেক্স'] ,
['সূত্রী', 'সূত্রীয়'] ,
['সূর্য লোক', 'সূর্যলোক'] ,
['সূর্যকিরণ', 'সূর্যরশ্মি'] ,
['সূর্যোপাসক', 'সৌরপত'] ,
['সেইরকম', 'সেরকম'] ,
['সেগান', 'সেগান আম', 'সেগান আম গাছ'] ,
['সেগুন', 'সেগুন কাঠ'] ,
['সেচ করা', 'সেচন করা'] ,
['সেনাধিপতি', 'সেনাধ্যক্ষ', 'সেনানায়ক', 'সেনাপতি', 'সেনাপতি শহর'] ,
['সেনাপতি', 'সেনাপতি জেলা', 'সেনাপতি শহর'] ,
['সেন্ট কীটস', 'সেন্ট ক্রিস্টোফার'] ,
['সেন্ট কীটস্ ও নীবিস', 'সেন্ট ক্রিস্টোফার-নেবিস'] ,
['সেন্টিমিটার', 'সেমি'] ,
['সেন্সেশান', 'সেন্সেশান আম'] ,
['সেপা', 'সেপা শহর'] ,
['সেবনযোগ্য', 'সেবনীয়'] ,
['সেমি ফাইনাল', 'সেমিফাইনাল'] ,
['সেরছিপ', 'সেরছিপ জেলা', 'সেরছিপ শহর'] ,
['সেরডিকা', 'সোফিয়া'] ,
['সেরাব', 'সেরো'] ,
['সেলম', 'সেলম জেলা', 'সেলম শহর'] ,
['সেলাই', 'সেলাই করা', 'সেলাই-কাজ'] ,
['সেলাম', 'স্যালুট'] ,
['সেশিল্জ বাসী', 'সেশিল্জবাসী'] ,
['সেশোল্স', 'সেশোল্স গণরাজ্য'] ,
['সেসিল', 'সেসিল আম', 'সেসিল আম গাছ'] ,
['সোচ্চার হওয়া', 'স্লোগান দেওয়া'] ,
['সোজা করা', 'সোজা রাস্তায় নিয়ে আসা'] ,
['সোজা', 'সোজাসুজি'] ,
['সোন', 'সোন পাখি'] ,
['সোনপুর', 'সোনপুর শহর'] ,
['সোনভদ্র', 'সোনভদ্র জেলা'] ,
['সোনার খনি', 'স্বর্ণ খনি', 'স্বর্ণখনি', 'স্বর্ণাকর'] ,
['সোনার', 'স্বর্ণ'] ,
['সোনাল', 'সোনাল জেলা', 'সোনাল শহর'] ,
['সোনিপত', 'সোনিপত জেলা', 'সোনিপত শহর'] ,
['সোমনাথ', 'সোমেশ', 'সোমেশ্বর'] ,
['সোমহুতি', 'সোমহুতি ঋষি'] ,
['সোমালিয়া-বাসী', 'সোমালিয়ান'] ,
['সোমালিয়া-সম্পর্কিত', 'সোমালীয়'] ,
['সোরনি', 'সোরনি সংস্কার'] ,
['সোহর', 'সোহর গান'] ,
['সোয়া', 'সোয়া গুণ'] ,
['সৌকারয়ণ', 'সৌকারয়ণ ঋষি'] ,
['সৌদামণী', 'সৌদামিণী'] ,
['সৌদি আরব', 'সৌদি আরব রাজ্য'] ,
['সৌভর', 'সৌভর ঋষি'] ,
['সৌভরি', 'সৌভরি ঋষি'] ,
['সৌরজগত্', 'সৌরমন্ডল'] ,
['সৌরাষ্টী ভাষা', 'সৌরাষ্ট্রী'] ,
['সৌরাষ্ট্রীয়', 'সৌরাষ্ট্রের'] ,
['সৌরী', 'সৌরী মাছ'] ,
['স্কন্দ পুরাণ', 'স্কন্দপুরাণ'] ,
['স্কন্দ', 'স্কন্দ উপনিষদ', 'স্কন্দোপনিষদ'] ,
['স্কন্ধ', 'স্কন্ধমল্লক'] ,
['স্টকহোম', 'স্টাকহোম'] ,
['স্টাইল করা', 'স্টাইল করে দেওয়া'] ,
['স্টার্টার', 'স্টার্টার মোটর'] ,
['স্টিয়ারিং', 'হুইল'] ,
['স্টেনফোর্ড হোয়াইট', 'হোয়াইট'] ,
['স্টেবিলাইজার', 'স্থায়িকারি', 'স্থিরক', 'স্থিরকারী'] ,
['স্তন্যপায়ী জীব', 'স্তন্যপায়ী প্রাণী'] ,
['স্তব্ধ হওয়া', 'স্থির হয়ে যাওয়া'] ,
['স্তম্ভিত হওয়া', 'হতচকিত হওয়া'] ,
['স্তরীয়', 'স্তরের'] ,
['স্ত্রীজিত', 'স্ত্রৈণ'] ,
['স্থগিত করা', 'স্থগিতকরণ'] ,
['স্থলচর', 'স্থলচর জীব', 'স্থলবাসী'] ,
['স্থাণুরোগে', 'স্থানুরোগ'] ,
['স্থানিক', 'স্থানীয় আঞ্চলিক'] ,
['স্থাপনীয়', 'স্থাপ্য'] ,
['স্নাত হওয়া', 'স্নান করা'] ,
['স্নায়ু সংক্রান্ত', 'স্নায়ুবিদ্যা সংক্রান্ত'] ,
['স্পন্দিত কোরো না', 'হৃদয়ে চাপ দেওয়া'] ,
['স্পর্শ বর্ণ', 'স্পর্শবর্ণ'] ,
['স্পষ্ট হওয়া', 'স্পষ্টতা'] ,
['স্পা', 'স্বাস্থ্য কেন্দ্র'] ,
['স্পিতি', 'স্পিতি শহর'] ,
['স্পিন', 'স্পিন বল নিক্ষেপ করা'] ,
['স্পেনবাসী', 'স্পেনীয়'] ,
['স্পেনীয় লিপি', 'স্প্যানিশ'] ,
['স্পেনীয়', 'স্প্যানিশ'] ,
['স্প্রিং-ফেল্স', 'স্প্রিং-ফেল্স আম', 'স্প্রিং-ফেল্স আমের গাছ'] ,
['স্প্রিংওলা', 'স্প্রিংযুক্ত'] ,
['স্ফটিকসুলভ', 'স্ফটিকের মতো'] ,
['স্ফুর্তি সহকারে', 'স্ফুর্তিতে', 'স্ফুর্তিপূর্বক'] ,
['স্বতঃপ্রমানিত', 'স্বতঃসিদ্ধ', 'সয়ংসিদ্ধ তত্ত্ব'] ,
['স্বতন্ত্র ভাবে', 'স্বাধীন ভাবে'] ,
['স্বপ্ন চুরমার হয়ে যাওয়া', 'স্বপ্ন ভেঙে যাওয়া'] ,
['স্বপ্ন সম্পর্কিত', 'স্বপ্নের'] ,
['স্বভাবগত', 'স্বভাবজাত'] ,
['স্বর', 'স্বর বর্ণ', 'স্বরযুক্ত'] ,
['স্বরাজ', 'স্বশাসন'] ,
['স্বর্ণ মুদ্রা', 'স্বর্ণ মোহর'] ,
['স্বর্ণকাল', 'স্বর্ণযুগ'] ,
['স্বর্ণপত্রী', 'স্বর্ণমুখী'] ,
['স্বর্ণপর্ণী', 'স্বর্ণলতা'] ,
['স্বর্ণবর্ণা', 'হরিদ্রা', 'হলুদ'] ,
['স্বল্পবয়স্ক অবস্থা', 'স্বল্পবয়স্কতা'] ,
['স্বাক্ষরিত', 'হস্তাক্ষরিত'] ,
['স্বাজী', 'স্বাজী ভাষা', 'স্বাজীল্যান্ড নিবাসী', 'স্বাজীল্যান্ডবাসী'] ,
['স্বাজীল্যান্ড', 'স্বাজীল্যান্ড গণরাজ্য'] ,
['স্বাতি', 'স্বাতি নক্ষত্র'] ,
['স্বাতী', 'স্বাতী নক্ষত্র'] ,
['স্বাদপূর্ণ', 'স্বাদযুক্ত'] ,
['স্বাধিষ্ঠান', 'স্বাধিষ্ঠান চক্র'] ,
['স্বামী দয়ানন্দ', 'স্বামী দয়ানন্দ সরস্বতী'] ,
['স্বার্জিত', 'স্বোপার্জিত', 'স্বয়ম অধিগত', 'স্বয়ম অর্জিত'] ,
['স্বার্থকেন্দ্রিক', 'স্বার্থপর', 'স্বার্থান্বেষী'] ,
['স্বার্থকেন্দ্রীক', 'স্বার্থপরায়ণ', 'স্বার্থান্বেষী'] ,
['স্বাস্থ্য মন্ত্রী', 'স্বাস্থ্যমন্ত্রী'] ,
['স্বাস্থ্য সেবা', 'হেল্থকেয়ার'] ,
['স্বাস্থ্যকর', 'স্বাস্থ্যপ্রদ'] ,
['স্বীকার পত্র', 'স্বীকৃতিপত্র'] ,
['স্বীকৃতি পত্র', 'স্বীকৃতিপত্র'] ,
['স্বৈরতান্ত্রিক', 'স্বৈরাচারি'] ,
['স্বয়ংবর', 'স্বয়ংবরণ', 'স্বয়ংবরসভা'] ,
['স্বয়ম্ভু', 'স্বয়ম্ভূ'] ,
['স্মরণশক্তি', 'স্মৃতি'] ,
['স্মরণীয় স্থান', 'স্মারক'] ,
['স্মার্ত', 'স্মৃতিসম্বন্ধীয়'] ,
['স্মিত', 'হাসতে থাকা', 'হাস্যরত'] ,
['স্মিথ', 'স্মিথ আম'] ,
['স্মৃতিবিহীনতা', 'স্মৃতিহীনতা'] ,
['স্যমন্তক', 'স্যমন্তক মণি'] ,
['স্যাঁকা', 'স্যাঁকা হওয়া'] ,
['স্যেন', 'স্যেন নদী'] ,
['স্লীপার', 'হাওয়াই চটি', 'হাওয়াই চপ্পল'] ,
['স্লেজ', 'স্লেজ গাড়ি'] ,
['স্লেট রঙের', 'স্লেটের রঙের'] ,
['স্লোভাকিয়াবাসী', 'স্লোভাকীয়'] ,
['স্লোভাকীয়', 'স্লোভাকীয় ভাষা'] ,
['স্লোভেনিয়া', 'স্লোভেনিয়া গণরাজ্য'] ,
['স্লোভেনিয়ার', 'স্লোভেনীয়'] ,
['হংস', 'হংস উপনিষদ', 'হংসোপনিষদ'] ,
['হংসগমনা', 'হংসগামীনী'] ,
['হই হুল্লোড়', 'হুল্লোড়'] ,
['হট লাইন', 'হটলাইন'] ,
['হট্ট', 'হাট'] ,
['হণ্ডুরাসীয়', 'হণ্ডুরাসের'] ,
['হতাশ হওয়া', 'হত�'] ,
['হনডুরাস', 'হনডুরাস গণতন্ত্র', 'হনডুরাস গণরাজ্য'] ,
['হনুমান জয়ন্তী', 'হনুমানজয়ন্তী'] ,
['হনুমানগড়', 'হনুমানগড় জেলা', 'হনুমানগড় শহর'] ,
['হনোদ', 'হনোদ রাগ'] ,
['হন্ডা', 'হন্ডিকা', 'হন্ডিয়া', 'হন্ডী', 'হাঁড়া', 'হাঁড়ি', 'হান্ডা', 'হান্ডী'] ,
['হবিষ্য', 'হবিষ্যান্ন', 'হবিষ্যি'] ,
['হমিরপুর', 'হমিরপুর জেলা', 'হমিরপুর শহর'] ,
['হর', 'হর রাক্ষস'] ,
['হরদা', 'হরদা জেলা', 'হরদা শহর'] ,
['হরদোই', 'হরদোই জেলা', 'হরদোই শহর'] ,
['হরি জন', 'হরিজন'] ,
['হরিগীতা ছন্দ', 'হরিগীতিকা ছন্দ'] ,
['হরিদ্ধার', 'হরিদ্ধার শহর'] ,
['হরিদ্বার', 'হরিদ্বার জেলা'] ,
['হরিদ্রা', 'হলিদা', 'হলুদ'] ,
['হরিশঙ্কর', 'হরিহর'] ,
['হলন্ত', 'হলন্ত চিহ্ন', 'হসন্ত', 'হসন্ত চিহ্ন'] ,
['হলবাহক', 'হেলে'] ,
['হলুদ রঙের ধুতি', 'হলুদ রঙের শাড়ি'] ,
['হলুদ', 'হলুদ রঙ'] ,
['হস্ত দ্বারা', 'হস্তসঞ্চালন দ্বারা', 'হাত দিয়ে'] ,
['হস্ত নির্মিত', 'হস্তনির্মিত'] ,
['হস্ত পরিধান', 'হস্তাবরণ'] ,
['হস্ত মৈথুন', 'হস্ত-মৈথুন', 'হস্তমৈথুন'] ,
['হস্তরেখাবিদ্', 'হস্তরেখাবিশারদ'] ,
['হস্তলিখিত', 'হস্তাঙ্কিত'] ,
['হস্তলিপি বিজ্ঞানী', 'হস্তলিপি বিশারদ', 'হস্তলিপি বিশেষজ্ঞ'] ,
['হস্তা', 'হস্তা নক্ষত্র'] ,
['হস্তান্তকরণ', 'হস্তান্তর'] ,
['হস্তিকুম্ভ', 'হস্তিমস্তক', 'হাতির মাথা'] ,
['হস্তিপ্রমেহ', 'হস্তিপ্রমেহ রোগ'] ,
['হস্তিমস্তক', 'হাতির মাথা'] ,
['হস্তী', 'হাতি'] ,
['হা হা', 'হাহা'] ,
['হাঁক দেওয়া', 'হাঁক লাগানো'] ,
['হাঁস', 'হাঁসের মাংস'] ,
['হাইতি বাসী', 'হাইতিয়ান'] ,
['হাইতি', 'হাইতি গণতন্ত্র', 'হাইতি গণরাজ্য', 'হিস্পেনিয়োল'] ,
['হাইল্যাণ্ডবাসী', 'হাইল্যাণ্ডবাসী স্কট'] ,
['হাউলার', 'হাউলার বাঁদর'] ,
['হাওড়া', 'হাওড়া জেলা', 'হাওড়া শহর'] ,
['হাওয়া মহল', 'হাওয়ামহল'] ,
['হাওয়াই', 'হাওয়াই দ্বীপ', 'হাওয়াই শহর'] ,
['হাওয়াদার', 'হাওয়াযুক্ত'] ,
['হাওয়ার অনুকূলে', 'হাওয়ার দিকে'] ,
['হাজত', 'হেপাজত'] ,
['হাজার', '১০০০'] ,
['হাজারিবাগ', 'হাজারিবাগ জেলা', 'হাজারিবাগ শহর'] ,
['হাজি', 'হাজী'] ,
['হাজিপুর', 'হাজিপুর শহর'] ,
['হাটকলোচন', 'হিরণ্যাক্ষ'] ,
['হাটাবা', 'হাটাবা শহর'] ,
['হাড়ী', 'হাড়ী রাগ'] ,
['হাত পা', 'হাত মুখ'] ,
['হাত সাফাই', 'হাতসাফাই'] ,
['হাতপান', 'হাতফুল'] ,
['হাতল', 'হ্যান্ডেল'] ,
['হাতলওয়ালা', 'হাতলযুক্ত'] ,
['হাতের অলংকার', 'হাতের আভূষণ', 'হাতের গয়না'] ,
['হাফলাংগ', 'হাফলাংগ শহর'] ,
['হাবেরি', 'হাবেরি জেলা', 'হাবেরি শহর'] ,
['হামিরপুর', 'হামিরপুর জেলা', 'হামিরপুর শহর'] ,
['হামীর', 'হামীর রাগ'] ,
['হাম্বা হাম্বা করা', 'হাম্বা হাম্বা ডাকা'] ,
['হারমোনিয়া', 'হারমোনিয়াম'] ,
['হারানো', 'হারিয়ে যাওয়া'] ,
['হারামজাদা', 'হারামী'] ,
['হারিত', 'হারিত ঋষি', 'হারী'] ,
['হার্ভাড', 'হার্ভাড বিশ্ববিদ্যালয়'] ,
['হাল', 'হালফিল'] ,
['হাল্কা নীল', 'হাল্কা নীল রঙ'] ,
['হাসান', 'হাসান জেলা', 'হাসান শহর'] ,
['হাসি', 'হাস্য'] ,
['হাসিখুশি', 'হাস্যমুখর', 'হাস্যময়'] ,
['হাস্য', 'হাস্য রস'] ,
['হাস্যকর', 'হাস্যপূর্ণ', 'হাস্যপ্রদ', 'হাস্যস্পদ'] ,
['হাহাকার', 'হায় হায় রব'] ,
['হায়দরাবাদ', 'হায়দরাবাদ জেলা'] ,
['হিং', 'হিঙ্গুল'] ,
['হিংসাগ্রস্ত', 'হিংসাজর্জরিত', 'হিংসাপীড়িত'] ,
['হিঙ্গোলী', 'হিঙ্গোলী জেলা', 'হিঙ্গোলী শহর'] ,
['হিজরী', 'হিজরী বছর'] ,
['হিন্তাল', 'হেঁতাল'] ,
['হিন্দী', 'হিন্দী ভাষা'] ,
['হিন্দুকুশ', 'হিন্দুকুশ পর্বত'] ,
['হিন্দোল', 'হিন্দোল রাগ'] ,
['হিমসাগর', 'হিমসাগর আম', 'হিমসাগর আমের গাছ'] ,
['হিমালয়ী', 'হৈমবত'] ,
['হিরণ্য লোমা', 'হিরণ্য লোমা ঋষি'] ,
['হিরণ্য', 'হিরণ্য নদী'] ,
['হিরণ্যস্তূপ', 'হিরণ্যস্তূপ ঋষি'] ,
['হিরা', 'হেরা'] ,
['হিলিঙ্স্গফোর্স', 'হিল্সিঙ্কী', 'হেলিঙ্স্গফোর্স', 'হেল্সিঙ্কী'] ,
['হিসাবনবিশ', 'হিসাবপরীক্ষক', 'হিসাবরক্ষক'] ,
['হিসার', 'হিসার জেলা', 'হিসার শহর'] ,
['হীরক', 'হীরা', 'হীরে'] ,
['হীরামন', 'হীরামন টিঁয়া'] ,
['হুগলী', 'হুগলী জেলা', 'হুগলী নদী'] ,
['হুজূর', 'হুজূর'] ,
['হুমা', 'হুমা পাখি'] ,
['হুসেনী-কান্হড়া', 'হুসেনীকান্হড়া'] ,
['হৃত্স্পন্দন', 'হৃদয়ের স্পন্দন'] ,
['হৃদরোগ', 'হৃদয়-রোগ'] ,
['হেডন', 'হেডন আম', 'হেডন আমের গাছে'] ,
['হেতবন্তর', 'হেতু-অন্তর'] ,
['হেম্না', 'হেম্না রাগ'] ,
['হৈলাকাণ্ডী', 'হৈলাকাণ্ডী জেলা', 'হৈলাকাণ্ডী শহর'] ,
['হোলি', 'হোলিকা'] ,
['হোশঙ্গাবাদ', 'হোশঙ্গাবাদ জেলা', 'হোশঙ্গাবাদ শহর'] ,
['হোশিয়ারপুর', 'হোশিয়ারপুর জেলা', 'হোশিয়ারপুর শহর']]


# Returns a clean Text
def clean_text(text):
    if type(text)!=type(''):
        raise TypeError("Argument must be a string")
    else:
        strDelete = '''।,.?!…:;@#$^&*(){}[]'"‘’“”-_'''
        table = text.maketrans('\t\n', '  ', strDelete)
        text = text.translate(table)
        test = re.sub('\s\s+', ' ', text) # Remove multiple space
        text = text.strip()
        return text
        

# Returns a list of Words
def word_tokenize(sentence):
    if type(sentence)!=type(''):
        raise TypeError("Argument must be a string")
    else:
        sentence = clean_text(sentence) 
        return sentence.split()


# Returns a list of Sentences
def sent_tokenize(paragraph):
    if type(paragraph)!=type(''):
        raise TypeError("Argument must be a string")
    else:                    
        strDelete = ''',.…:;@#$^&*(){}[]'"‘’“”-_'''
        table = paragraph.maketrans('\t\n', '  ', strDelete)
        paragraph = paragraph.translate(table)        
        paragraph = re.sub('\s\s+', ' ', paragraph)
        paragraph = paragraph.strip(' ।?!')
        paragraph = re.split(r'[।?!]\s*', paragraph)
        
        return list(filter(None, paragraph))     


# Returns POS tag of a word 
def pos_tag(word):
    if type(word)!=type(''):
        raise TypeError("Argument must be a string")
    else:   
        try:
            word = word.strip()
            if word[0] in ['১','২','৩','৪','৫','৬','৭','৮','৯','০']:
                return 'CD'
            else:
                w = get_close_matches(word, dictPos.keys(), n=1, cutoff=0.6)
                if w == []:
                    return 'UNK'
                else:
                    return dictPos[w[0]]
        except:
            return 'UNK'


# Returns Synonym of a word 
def synonym(word):
    if type(word)!=type(''):
        raise TypeError("Argument must be a string")
    else:   
        for s in listSyn:
            if word in s:
                return s
        return [word]
    

# Returns Stemmed word 
pronoun_dict = {
    'আপনি': ['আপনি', 'আপনার', 'আপনাদের', 'আপনাকে', 'আপনারে', 'আপনাকেও', 'আপনারা'],
    'আমি': ['আমি', 'আমার', 'আমাদের', 'আমাদেরকে', 'আমাকে', 'আমাকেও', 'আমায়', 'আমাতে', 'আমরা'],
    'এটি': ['এটি', 'এটা', 'এটির', 'এটার', 'এটাকে', 'এটিকে', 'এটাতে', 'এটিতে', 'এটিও', 'এটাও', 'এটিই'],
    'এরা': ['এরা', 'এঁরা', 'একে', 'এদেরকে', 'এদের', 'এঁদের', 'এদেরকেও'],
    'ওটি': ['ওটি', 'ওটা', 'ওটির', 'ওটার', 'ওটাকে', 'ওটাকেও', 'ওটিকে', 'ওটাতে', 'ওটিতে', 'ওটিও', 'ওটাও'],
    'সেটি': ['সেটা', 'সেটির', 'সেটার', 'সেটাকে', 'সেটিকে', 'সেটাতে', 'সেটিতে', 'সেটি', 'সেটাই'],
    'ওরা': ['ওরা', 'ওদের', 'ওদেরকে', 'ওদেরকেও'],
    'তারা': ['তারা', 'তাদের', 'তাদেরকে', 'তাদেরকেও', 'তাঁরা', 'তাঁদের', 'তাঁদেরকে', 'তাঁদেরকেও'],
    'তুমি': ['তুমি', 'তুই', 'তোমার', 'তোমাদের', 'তোমাকে', 'তোমাদেরকে', 'তোমাতে', 'তোমাকেও', 'তোমারে', 'তোর', 'তোমায়', 'তোমরা'],
    'সে': ['তার', 'তাকে', 'সে', 'তিনি'],
    'সেগুলো': ['সেগুলোতে', 'সেগুলাতে', 'সেগুলোর', 'সেগুলার', 'সেগুলো']
}

noun_suffix = ['তাবাদীরা', 'তাবাদী', 'বাদীরা', 'বাদী', 'আবলি', 'আলা', 'এরা', 'এরে', 'কারী', 'ধারী', 'কুলের', 'কেই', 'কেও', 
			  'খানা', 'খানি', 'াটাই', 'াটাকেও',
              'াটাকে', 'টুকুন', 'টুকু', 'দলের', 'দল', 'দনি', 'দিগকে', 'দিগেতে', 'দিগেরে', 'দিগের', 'দিতে', 'দিগে',
              'দিগ', 'দেরই', 'দেরে', 'দের', 'নিকর', 'নিচয়', 'নের', 'পানা', 'পানি', 'পাল', 'পুঞ্জ', 'পের', 'বৎ', 'বর্গ',
              'বীনি', 'বৃন্দ', 'মণ্ডলী', 'মন্ডলি', 'মালার', 'মালায়', 'মালা', 'যূথ', 'য়ই', 'দের', 'রও', 'রই', 'রাই', 'রাওতো',
              'রাও', 'রাজি', 'রাশি', 'সকল', 'সব', 'সমুদয়', 'সমুহের', 'সমূহের', 'সমুহ', 'সমূহ', 'সহ', 'সাৎ', 'হারা',
              'গন', 'গণ', 'গণে', 'গাছা', 'গাছি', 'গিরি', 'গুচ্ছ', 'গুলা', 'গুলিকে', 'গুলিতে', 'গুলিন', 'গুলির', 'গুলি',
              'গুলোও', 'গুলোকে', 'গুলোয়', 'গুলোতে', 'গুলোর', 'গুলো', 'গোটা', 'চস', 'টাও', 'টাই', 'টাকে', 'টার', 'টায়',
              'টিকেই', 'টিকে', 'টিতেও', 'টিতে', 'টির', 'টিও', 'াটাও', 'াটা', 'াটি', 'ামি', 'িকা', 'েরই',
              'িক', 'েরও', 'েরা', 'েরাও', 'েরে', 'াই', 'টা', 'তা', 'কে', 'রা', 'য়ে', 'ায়',
              'ে', 'ও', 'ন']

verb_suffix = ['াইয়াছিলেন', 'াইয়াছিলাম', 'াইতেছিলেন', 'াইতেছিলাম', 'িয়েছিলেন', 'িয়াছিলেন', 'িয়াছিলাম', 'িতেছিলেন', 'িতেছিলাম',
               'ায়েছিলাম', 'াচ্ছিলেম', 'াচ্ছিলেন', 'াচ্ছিলুম', 'াচ্ছিলাম', 'াইয়াছিলে', 'াইয়াছিলি', 'াইতেছিলে', 'াইতেছিলি', 'য়েছিলাম',
               'তেছিলাম', 'চ্ছিলেন', 'চ্ছিলাম', 'িয়েছিলে', 'িয়েছিলি', 'িয়াছিলে', 'িয়াছিলি', 'িতেছিলে', 'িতেছিলি', 'াচ্ছিলে', 'াচ্ছিলি',
               'াইয়াছেন', 'াইয়াছিস', 'াইয়াছিল', 'াইতেছেন', 'াইতেছিস', 'াইতেছিল', 'চ্ছিলে', 'চ্ছিলি', 'ইছিলাম', 'েছিলেন', 'েছিলাম',
               'িয়েছেন', 'িয়েছিস', 'িয়েছিল', 'িয়াছেন', 'িয়াছিস', 'িতেছেন', 'িতেছিস', 'িতেছিল', 'ানোতেই', 'াচ্ছেন', 'াচ্ছিস',
               'াচ্ছিল', 'াইয়াছে', 'াইয়াছি', 'াইতেছে', 'াইতেছি', 'াইতাছে', 'াইতাছস', 'তেছেন', 'তিছেন', 'তাছেন', 'ছেননি', 'ছেনটা',
               'ছিলেম', 'ছিলুম', 'ছিলাম', 'চ্ছেন', 'চ্ছিস', 'চ্ছিল', 'েছিলে', 'েছিলি', 'িয়েছো', 'িয়েছে', 'িয়েছি', 'িয়াছে', 'িয়াছি',
               'িতেছি', 'িছিলে', 'িআছিল', 'ালেনও', 'ায়েছে', 'াবেনই', 'াবানি', 'ানোসহ', 'ানোরও', 'ানোরই', 'ানোতে', 'ানোটা',
               'ানোর', 'াচ্ছে', 'াচ্ছি', 'াইলেন', 'াইলাম', 'াইয়াছ', 'াইবেন', 'াইবো', 'াইবার', 'াইনতে', 'াইতেন', 'াইতেছ',
               'াইতিস', 'াইতাম', 'লেনই', 'লামই', 'তেনা', 'তেছি', 'তিছি', 'তাছে', 'তাছি', 'ছেনও', 'ছেনই', 'ছিলি', 'েননি',
               'েছেন', 'েছিস', 'েছিল', 'িলেন', 'িলাম', 'িয়াছ', 'িলেম', 'িলুম', 'িবেন', 'িতেন', 'িতেছ', 'িতেও', 'িতিস',
               'িতাম', 'ালেম', 'ালেন', 'ালেও', 'ালেই', 'ালুম', 'ালাম', 'ায়নি', 'াবেন', 'াবেও', 'াবো', 'াবার', 'ানোর',
               'ানোয়', 'ানোও', 'ানোই', 'ানো', 'াননি', 'াতেম', 'াতেন', 'াতেছ', 'াতেও', 'াতেই', 'াতুম', 'াতিস', 'াতাম',
               'াছেন', 'াছিস', 'াচ্ছ', 'াইলে', 'াইলি', 'াইলা', 'াইয়ো', 'াইয়া', 'াইবে', 'াইবি', 'াইনি', 'াইতে', 'াইছে',
               'াইছি', 'লেম', 'লেন', 'লেও', 'লেই', 'লাম', 'েনই', 'নোয়', 'নোর', 'তেম', 'তেন', 'তুম', 'তুত', 'তিস', 'তাম',
               'ছেন', 'ছেও', 'ছেই', 'ছিস', 'ছিল', 'ইয়া', 'ইবে', 'ইছে', 'েতে', 'েছে', 'েছি', 'িলে', 'িলি', 'িবে', 'িবা',
               'িনী', 'ালু', 'ায়ো', 'ায়ে', 'ায়ও', 'াবো', 'াবে', 'াবি', 'ানো', 'াতি', 'াছে', 'াইস', 'াইল',
               'াইব', 'াইত', 'াইও', 'েও', 'লো', 'লে', 'েন', 'েই', 'ছো', 'ছে', 'ইস', 'ইয়', 'ইত', 'েন', 'েছ', 'িল',
               'িন', 'াব', 'াক', 'ে', 'ছ']

adjective_suffix = ['তাত্ত্বিক', 'শ্রেষ্ঠ', 'ভিত্তিক', 'গ্রস্ত', 'মণ্ডিত', 'গ্রস্থ', 'াত্মক', 'পূর্ণ', 'বিহীন', 'যোগ্য', 'পন্থী', 'বন্দী', 'যুক্ত',
                    'চালিত', 'পীড়িত', 'বর্তী', 'মুক্ত', 'মূলক', 'দায়ক', 'কারক', 'জনিত', 'বদ্ধ', 'কারী', 'শালী', 'ঘটিত', 'বাদী',
                    'বদ্ধ', 'প্রদ', 'সূচক', 'সংক্রান্ত', 'বাচক', 'বহুল', 'হীন', 'কৃত', 'ময়ী', 'বতী', 'শীল', 'মান', 'ের', 'ীন',
                    'ভাবে', 'কালে', 'কর', 'িক', 'তর', 'ীয়', 'তম', 'গত', 'কেও', 'ও', 'িতে', 'ী', 'ি', 'ের', 'াঙ্গ', 'ে']


def stemmer(word):
    if type(word)!=type(''):
        raise TypeError("Argument must be a string")
    else:
        word = word.strip()
        pos = pos_tag(word)
        
        if pos in ['PR','PRP']:
            for i in pronoun_dict.items():
                if word in i[-1]:
                    return i[0]

        elif pos in ['NN','NNS','NNP','NNPS','NNV']:    
            for i in noun_suffix:
                if word.endswith(i):
                    return word[:-len(i)]

        elif pos in ['RB','RBR','RBS','VB','VBD','VBG','VBN','VBP','VBZ']:
            for i in verb_suffix:
                if word.endswith(i):
                    return word[:-len(i)]
                    
        elif pos in ['JJ','JJR','JJS','']:
            for i in adjective_suffix:
                if word.endswith(i):
                    return word[:-len(i)]
                    
        else:
            pass
        return word

